Class: Aws::Glue::Types::Aggregate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Aggregate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass Aggregate data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
groups: [ # required
["EnclosedInStringProperty"],
],
aggs: [ # required
{
column: ["EnclosedInStringProperty"], # required
agg_func: "avg", # required, accepts avg, countDistinct, count, first, last, kurtosis, max, min, skewness, stddev_samp, stddev_pop, sum, sumDistinct, var_samp, var_pop
},
],
}
Specifies a transform that groups rows by chosen fields and computes the aggregated value by specified function.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggs ⇒ Array<Types::AggregateOperation>
Specifies the aggregate functions to be performed on specified fields.
-
#groups ⇒ Array<Array<String>>
Specifies the fields to group by.
-
#inputs ⇒ Array<String>
Specifies the fields and rows to use as inputs for the aggregate transform.
-
#name ⇒ String
The name of the transform node.
Instance Attribute Details
#aggs ⇒ Array<Types::AggregateOperation>
Specifies the aggregate functions to be performed on specified fields.
143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-glue/types.rb', line 143 class Aggregate < Struct.new( :name, :inputs, :groups, :aggs) SENSITIVE = [] include Aws::Structure end |
#groups ⇒ Array<Array<String>>
Specifies the fields to group by.
143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-glue/types.rb', line 143 class Aggregate < Struct.new( :name, :inputs, :groups, :aggs) SENSITIVE = [] include Aws::Structure end |