Class: Aws::Glue::Types::AggregateOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AggregateOperation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass AggregateOperation data as a hash:
{
column: ["EnclosedInStringProperty"], # required
agg_func: "avg", # required, accepts avg, countDistinct, count, first, last, kurtosis, max, min, skewness, stddev_samp, stddev_pop, sum, sumDistinct, var_samp, var_pop
}
Specifies the set of parameters needed to perform aggregation in the aggregate transform.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agg_func ⇒ String
Specifies the aggregation function to apply.
-
#column ⇒ Array<String>
Specifies the column on the data set on which the aggregation function will be applied.
Instance Attribute Details
#agg_func ⇒ String
Specifies the aggregation function to apply.
Possible aggregation functions include: avg countDistinct, count, first, last, kurtosis, max, min, skewness, stddev_samp, stddev_pop, sum, sumDistinct, var_samp, var_pop
178 179 180 181 182 183 |
# File 'lib/aws-sdk-glue/types.rb', line 178 class AggregateOperation < Struct.new( :column, :agg_func) SENSITIVE = [] include Aws::Structure end |
#column ⇒ Array<String>
Specifies the column on the data set on which the aggregation function will be applied.
178 179 180 181 182 183 |
# File 'lib/aws-sdk-glue/types.rb', line 178 class AggregateOperation < Struct.new( :column, :agg_func) SENSITIVE = [] include Aws::Structure end |