Class: Aws::Glue::Types::ApplyMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ApplyMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass ApplyMapping data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
mapping: [ # required
{
to_key: "EnclosedInStringProperty",
from_path: ["EnclosedInStringProperty"],
from_type: "EnclosedInStringProperty",
to_type: "EnclosedInStringProperty",
dropped: false,
children: {
# recursive Mappings
},
},
],
}
Specifies a transform that maps data property keys in the data source to data property keys in the data target. You can rename keys, modify the data types for keys, and choose which keys to drop from the dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#mapping ⇒ Array<Types::Mapping>
Specifies the mapping of data property keys in the data source to data property keys in the data target.
-
#name ⇒ String
The name of the transform node.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-glue/types.rb', line 239 class ApplyMapping < Struct.new( :name, :inputs, :mapping) SENSITIVE = [] include Aws::Structure end |
#mapping ⇒ Array<Types::Mapping>
Specifies the mapping of data property keys in the data source to data property keys in the data target.
239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-glue/types.rb', line 239 class ApplyMapping < Struct.new( :name, :inputs, :mapping) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-glue/types.rb', line 239 class ApplyMapping < Struct.new( :name, :inputs, :mapping) SENSITIVE = [] include Aws::Structure end |