Class: Aws::Glue::Types::AssetFormEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A form on an asset, consisting of the form type identifier and its JSON content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The JSON content of the form, conforming to the schema of the specified form type.

Returns:

  • (String)


471
472
473
474
475
476
# File 'lib/aws-sdk-glue/types.rb', line 471

class AssetFormEntry < Struct.new(
  :form_type_id,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#form_type_idString

The identifier of the form type that defines this form’s schema.

Returns:

  • (String)


471
472
473
474
475
476
# File 'lib/aws-sdk-glue/types.rb', line 471

class AssetFormEntry < Struct.new(
  :form_type_id,
  :content)
  SENSITIVE = []
  include Aws::Structure
end