Class: Aws::Glue::Types::AssociateGlossaryTermsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset to associate glossary terms with.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
# File 'lib/aws-sdk-glue/types.rb', line 540

class AssociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
# File 'lib/aws-sdk-glue/types.rb', line 540

class AssociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_term_identifiersArray<String>

The list of glossary term identifiers to associate with the asset.

Returns:

  • (Array<String>)


540
541
542
543
544
545
546
547
548
# File 'lib/aws-sdk-glue/types.rb', line 540

class AssociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form. Required when iterableFormName is specified.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
# File 'lib/aws-sdk-glue/types.rb', line 540

class AssociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are associated with an item within the iterable form rather than the asset itself.

Returns:

  • (String)


540
541
542
543
544
545
546
547
548
# File 'lib/aws-sdk-glue/types.rb', line 540

class AssociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end