Class: Aws::Glue::Types::AssociateGlossaryTermsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset.

Returns:

  • (String)


568
569
570
571
572
573
574
575
# File 'lib/aws-sdk-glue/types.rb', line 568

class AssociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms now associated with the asset.

Returns:

  • (Array<String>)


568
569
570
571
572
573
574
575
# File 'lib/aws-sdk-glue/types.rb', line 568

class AssociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form, if applicable.

Returns:

  • (String)


568
569
570
571
572
573
574
575
# File 'lib/aws-sdk-glue/types.rb', line 568

class AssociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form, if the association targets an item.

Returns:

  • (String)


568
569
570
571
572
573
574
575
# File 'lib/aws-sdk-glue/types.rb', line 568

class AssociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end