Class: Aws::Glue::Types::AthenaConnectorSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AthenaConnectorSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass AthenaConnectorSource data as a hash:
{
name: "NodeName", # required
connection_name: "EnclosedInStringProperty", # required
connector_name: "EnclosedInStringProperty", # required
connection_type: "EnclosedInStringProperty", # required
connection_table: "EnclosedInStringPropertyWithQuote",
schema_name: "EnclosedInStringProperty", # required
output_schemas: [
{
columns: [
{
name: "GlueStudioColumnNameString", # required
type: "ColumnTypeString",
},
],
},
],
}
Specifies a connector to an Amazon Athena data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection that is associated with the connector.
-
#connection_table ⇒ String
The name of the table in the data source.
-
#connection_type ⇒ String
The type of connection, such as marketplace.athena or custom.athena, designating a connection to an Amazon Athena data store.
-
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
-
#name ⇒ String
The name of the data source.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom Athena source.
-
#schema_name ⇒ String
The name of the Cloudwatch log group to read from.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection that is associated with the connector.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_table ⇒ String
The name of the table in the data source.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of connection, such as marketplace.athena or custom.athena, designating a connection to an Amazon Athena data store.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data source.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom Athena source.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the Cloudwatch log group to read from. For example, `/aws-glue/jobs/output`.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-glue/types.rb', line 304 class AthenaConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :connection_table, :schema_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |