Class: Aws::Glue::Types::BatchCreatePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchCreatePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be created.
-
#database_name ⇒ String
The name of the metadata database in which the partition is to be created.
-
#partition_input_list ⇒ Array<Types::PartitionInput>
A list of ‘PartitionInput` structures that define the partitions to be created.
-
#table_name ⇒ String
The name of the metadata table in which the partition is to be created.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be created. Currently, this should be the Amazon Web Services account ID.
930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-glue/types.rb', line 930 class BatchCreatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_input_list) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the metadata database in which the partition is to be created.
930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-glue/types.rb', line 930 class BatchCreatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_input_list) SENSITIVE = [] include Aws::Structure end |
#partition_input_list ⇒ Array<Types::PartitionInput>
A list of ‘PartitionInput` structures that define the partitions to be created.
930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-glue/types.rb', line 930 class BatchCreatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_input_list) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the metadata table in which the partition is to be created.
930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-glue/types.rb', line 930 class BatchCreatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_input_list) SENSITIVE = [] include Aws::Structure end |