Class: Aws::Glue::Types::BatchDeleteConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default.



865
866
867
868
869
870
# File 'lib/aws-sdk-glue/types.rb', line 865

class BatchDeleteConnectionRequest < Struct.new(
  :catalog_id,
  :connection_name_list)
  SENSITIVE = []
  include Aws::Structure
end

#connection_name_listArray<String>

A list of names of the connections to delete.



865
866
867
868
869
870
# File 'lib/aws-sdk-glue/types.rb', line 865

class BatchDeleteConnectionRequest < Struct.new(
  :catalog_id,
  :connection_name_list)
  SENSITIVE = []
  include Aws::Structure
end