Class: Aws::Glue::Types::BatchDeleteConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeleteConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Hash<String,Types::ErrorDetail>
A map of the names of connections that were not successfully deleted to error details.
-
#succeeded ⇒ Array<String>
A list of names of the connection definitions that were successfully deleted.
Instance Attribute Details
#errors ⇒ Hash<String,Types::ErrorDetail>
A map of the names of connections that were not successfully deleted to error details.
1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-glue/types.rb', line 1005 class BatchDeleteConnectionResponse < Struct.new( :succeeded, :errors) SENSITIVE = [] include Aws::Structure end |
#succeeded ⇒ Array<String>
A list of names of the connection definitions that were successfully deleted.
1005 1006 1007 1008 1009 1010 |
# File 'lib/aws-sdk-glue/types.rb', line 1005 class BatchDeleteConnectionResponse < Struct.new( :succeeded, :errors) SENSITIVE = [] include Aws::Structure end |