Class: Aws::Glue::Types::BatchGetCustomEntityTypesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetCustomEntityTypesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchGetCustomEntityTypesRequest data as a hash:
{
names: ["NameString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
A list of names of the custom patterns that you want to retrieve.
Instance Attribute Details
#names ⇒ Array<String>
A list of names of the custom patterns that you want to retrieve.
853 854 855 856 857 |
# File 'lib/aws-sdk-glue/types.rb', line 853 class BatchGetCustomEntityTypesRequest < Struct.new( :names) SENSITIVE = [] include Aws::Structure end |