Class: Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#runs ⇒ Array<Types::DataQualityRulesetEvaluationRun>
A list of evaluation run details for the requested run IDs.
-
#runs_not_found ⇒ Array<String>
A list of run IDs that were not found.
Instance Attribute Details
#runs ⇒ Array<Types::DataQualityRulesetEvaluationRun>
A list of evaluation run details for the requested run IDs.
1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-glue/types.rb', line 1296 class BatchGetDataQualityRulesetEvaluationRunResponse < Struct.new( :runs, :runs_not_found) SENSITIVE = [] include Aws::Structure end |
#runs_not_found ⇒ Array<String>
A list of run IDs that were not found.
1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-glue/types.rb', line 1296 class BatchGetDataQualityRulesetEvaluationRunResponse < Struct.new( :runs, :runs_not_found) SENSITIVE = [] include Aws::Structure end |