Class: Aws::Glue::Types::BatchGetIterableFormsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetIterableFormsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset.
-
#item_identifiers ⇒ Array<String>
The list of item identifiers to retrieve.
-
#iterable_form_name ⇒ String
The name of the iterable form to retrieve items from.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-glue/types.rb', line 1295 class BatchGetIterableFormsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifiers) SENSITIVE = [] include Aws::Structure end |
#item_identifiers ⇒ Array<String>
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-glue/types.rb', line 1295 class BatchGetIterableFormsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifiers) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form to retrieve items from.
1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/aws-sdk-glue/types.rb', line 1295 class BatchGetIterableFormsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifiers) SENSITIVE = [] include Aws::Structure end |