Class: Aws::Glue::Types::BatchGetTriggersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetTriggersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchGetTriggersRequest data as a hash:
{
trigger_names: ["NameString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#trigger_names ⇒ Array<String>
A list of trigger names, which may be the names returned from the `ListTriggers` operation.
Instance Attribute Details
#trigger_names ⇒ Array<String>
A list of trigger names, which may be the names returned from the `ListTriggers` operation.
1026 1027 1028 1029 1030 |
# File 'lib/aws-sdk-glue/types.rb', line 1026 class BatchGetTriggersRequest < Struct.new( :trigger_names) SENSITIVE = [] include Aws::Structure end |