Class: Aws::Glue::Types::BatchGetWorkflowsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass BatchGetWorkflowsRequest data as a hash:

{
  names: ["NameString"], # required
  include_graph: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_graphBoolean

Specifies whether to include a graph when returning the workflow resource metadata.

Returns:

  • (Boolean)


829
830
831
832
833
834
# File 'lib/aws-sdk-glue/types.rb', line 829

class BatchGetWorkflowsRequest < Struct.new(
  :names,
  :include_graph)
  SENSITIVE = []
  include Aws::Structure
end

#namesArray<String>

A list of workflow names, which may be the names returned from the `ListWorkflows` operation.

Returns:

  • (Array<String>)


829
830
831
832
833
834
# File 'lib/aws-sdk-glue/types.rb', line 829

class BatchGetWorkflowsRequest < Struct.new(
  :names,
  :include_graph)
  SENSITIVE = []
  include Aws::Structure
end