Class: Aws::Glue::Types::BatchStopJobRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchStopJobRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchStopJobRunRequest data as a hash:
{
job_name: "NameString", # required
job_run_ids: ["IdString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_name ⇒ String
The name of the job definition for which to stop job runs.
-
#job_run_ids ⇒ Array<String>
A list of the `JobRunIds` that should be stopped for that job definition.
Instance Attribute Details
#job_name ⇒ String
The name of the job definition for which to stop job runs.
894 895 896 897 898 899 |
# File 'lib/aws-sdk-glue/types.rb', line 894 class BatchStopJobRunRequest < Struct.new( :job_name, :job_run_ids) SENSITIVE = [] include Aws::Structure end |
#job_run_ids ⇒ Array<String>
A list of the `JobRunIds` that should be stopped for that job definition.
894 895 896 897 898 899 |
# File 'lib/aws-sdk-glue/types.rb', line 894 class BatchStopJobRunRequest < Struct.new( :job_name, :job_run_ids) SENSITIVE = [] include Aws::Structure end |