Class: Aws::Glue::Types::BatchUpdatePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchUpdatePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be updated.
-
#database_name ⇒ String
The name of the metadata database in which the partition is to be updated.
-
#entries ⇒ Array<Types::BatchUpdatePartitionRequestEntry>
A list of up to 100
BatchUpdatePartitionRequestEntryobjects to update. -
#table_name ⇒ String
The name of the metadata table in which the partition is to be updated.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be updated. Currently, this should be the Amazon Web Services account ID.
1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/aws-sdk-glue/types.rb', line 1620 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the metadata database in which the partition is to be updated.
1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/aws-sdk-glue/types.rb', line 1620 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#entries ⇒ Array<Types::BatchUpdatePartitionRequestEntry>
A list of up to 100 BatchUpdatePartitionRequestEntry objects to update.
1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/aws-sdk-glue/types.rb', line 1620 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the metadata table in which the partition is to be updated.
1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/aws-sdk-glue/types.rb', line 1620 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |