Class: Aws::Glue::Types::BetweenConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BetweenConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Configuration that defines how BETWEEN range filter operations are translated into REST API request parameters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#high_bound_key ⇒ String
The parameter name used for the upper bound value in a BETWEEN filter operation.
-
#low_bound_key ⇒ String
The parameter name used for the lower bound value in a BETWEEN filter operation.
-
#template ⇒ String
A template string for constructing the BETWEEN filter expression.
Instance Attribute Details
#high_bound_key ⇒ String
The parameter name used for the upper bound value in a BETWEEN filter operation.
1872 1873 1874 1875 1876 1877 1878 |
# File 'lib/aws-sdk-glue/types.rb', line 1872 class BetweenConfiguration < Struct.new( :low_bound_key, :high_bound_key, :template) SENSITIVE = [] include Aws::Structure end |
#low_bound_key ⇒ String
The parameter name used for the lower bound value in a BETWEEN filter operation.
1872 1873 1874 1875 1876 1877 1878 |
# File 'lib/aws-sdk-glue/types.rb', line 1872 class BetweenConfiguration < Struct.new( :low_bound_key, :high_bound_key, :template) SENSITIVE = [] include Aws::Structure end |
#template ⇒ String
A template string for constructing the BETWEEN filter expression.
1872 1873 1874 1875 1876 1877 1878 |
# File 'lib/aws-sdk-glue/types.rb', line 1872 class BetweenConfiguration < Struct.new( :low_bound_key, :high_bound_key, :template) SENSITIVE = [] include Aws::Structure end |