Class: Aws::Glue::Types::BlueprintRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BlueprintRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The details of a blueprint run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprint_name ⇒ String
The name of the blueprint.
-
#completed_on ⇒ Time
The date and time that the blueprint run completed.
-
#error_message ⇒ String
Indicates any errors that are seen while running the blueprint.
-
#parameters ⇒ String
The blueprint parameters as a string.
-
#role_arn ⇒ String
The role ARN.
-
#rollback_error_message ⇒ String
If there are any errors while creating the entities of a workflow, we try to roll back the created entities until that point and delete them.
-
#run_id ⇒ String
The run ID for this blueprint run.
-
#started_on ⇒ Time
The date and time that the blueprint run started.
-
#state ⇒ String
The state of the blueprint run.
-
#workflow_name ⇒ String
The name of a workflow that is created as a result of a successful blueprint run.
Instance Attribute Details
#blueprint_name ⇒ String
The name of the blueprint.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time that the blueprint run completed.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Indicates any errors that are seen while running the blueprint.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ String
The blueprint parameters as a string. You will have to provide a
value for each key that is required from the parameter spec that is
defined in the Blueprint$ParameterSpec.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN. This role will be assumed by the Glue service and will be used to create the workflow and other entities of a workflow.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#rollback_error_message ⇒ String
If there are any errors while creating the entities of a workflow, we try to roll back the created entities until that point and delete them. This attribute indicates the errors seen while trying to delete the entities that are created.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The run ID for this blueprint run.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time that the blueprint run started.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the blueprint run. Possible values are:
-
Running — The blueprint run is in progress.
-
Succeeded — The blueprint run completed successfully.
-
Failed — The blueprint run failed and rollback is complete.
-
Rolling Back — The blueprint run failed and rollback is in progress.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of a workflow that is created as a result of a successful blueprint run. If a blueprint run has an error, there will not be a workflow created.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 |
# File 'lib/aws-sdk-glue/types.rb', line 2006 class BlueprintRun < Struct.new( :blueprint_name, :run_id, :workflow_name, :state, :started_on, :completed_on, :error_message, :rollback_error_message, :parameters, :role_arn) SENSITIVE = [] include Aws::Structure end |