Class: Aws::Glue::Types::CancelStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CancelStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CancelStatementRequest data as a hash:
{
session_id: "NameString", # required
id: 1, # required
request_origin: "OrchestrationNameString",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ Integer
The ID of the statement to be cancelled.
-
#request_origin ⇒ String
The origin of the request to cancel the statement.
-
#session_id ⇒ String
The Session ID of the statement to be cancelled.
Instance Attribute Details
#id ⇒ Integer
The ID of the statement to be cancelled.
1710 1711 1712 1713 1714 1715 1716 |
# File 'lib/aws-sdk-glue/types.rb', line 1710 class CancelStatementRequest < Struct.new( :session_id, :id, :request_origin) SENSITIVE = [] include Aws::Structure end |
#request_origin ⇒ String
The origin of the request to cancel the statement.
1710 1711 1712 1713 1714 1715 1716 |
# File 'lib/aws-sdk-glue/types.rb', line 1710 class CancelStatementRequest < Struct.new( :session_id, :id, :request_origin) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The Session ID of the statement to be cancelled.
1710 1711 1712 1713 1714 1715 1716 |
# File 'lib/aws-sdk-glue/types.rb', line 1710 class CancelStatementRequest < Struct.new( :session_id, :id, :request_origin) SENSITIVE = [] include Aws::Structure end |