Class: Aws::Glue::Types::Catalog

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The catalog object represents a logical grouping of databases in the Glue Data Catalog or a federated source. You can now create a Redshift-federated catalog or a catalog containing resource links to Redshift databases in another account or region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_full_table_external_data_accessString

Allows third-party engines to access data in Amazon S3 locations that are registered with Lake Formation.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#catalog_idString

The ID of the catalog. To grant access to the default catalog, this field should not be provided.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#catalog_propertiesTypes::CatalogPropertiesOutput

A CatalogProperties object that specifies data lake access properties and other custom properties.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#create_database_default_permissionsArray<Types::PrincipalPermissions>

An array of PrincipalPermissions objects. Creates a set of default permissions on the database(s) for principals. Used by Amazon Web Services Lake Formation. Not used in the normal course of Glue operations.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#create_table_default_permissionsArray<Types::PrincipalPermissions>

An array of PrincipalPermissions objects. Creates a set of default permissions on the table(s) for principals. Used by Amazon Web Services Lake Formation. Not used in the normal course of Glue operations.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the catalog was created.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Description string, not more than 2048 bytes long, matching the URI address multi-line string pattern. A description of the catalog.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#federated_catalogTypes::FederatedCatalog

A FederatedCatalog object that points to an entity outside the Glue Data Catalog.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the catalog. Cannot be the same as the account ID.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

A map array of key-value pairs that define parameters and properties of the catalog.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) assigned to the catalog resource.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#target_redshift_catalogTypes::TargetRedshiftCatalog

A TargetRedshiftCatalog object that describes a target catalog for database resource linking.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The time at which the catalog was last updated.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
# File 'lib/aws-sdk-glue/types.rb', line 2289

class Catalog < Struct.new(
  :catalog_id,
  :name,
  :resource_arn,
  :description,
  :parameters,
  :create_time,
  :update_time,
  :target_redshift_catalog,
  :federated_catalog,
  :catalog_properties,
  :create_table_default_permissions,
  :create_database_default_permissions,
  :allow_full_table_external_data_access)
  SENSITIVE = []
  include Aws::Structure
end