Class: Aws::Glue::Types::CatalogProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure that specifies data lake access properties and other custom properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_propertiesHash<String,String>

Additional key-value properties for the catalog, such as column statistics optimizations.

Returns:

  • (Hash<String,String>)


2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-glue/types.rb', line 2639

class CatalogProperties < Struct.new(
  :data_lake_access_properties,
  :iceberg_optimization_properties,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#data_lake_access_propertiesTypes::DataLakeAccessProperties

A DataLakeAccessProperties object that specifies properties to configure data lake access for your catalog resource in the Glue Data Catalog.



2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-glue/types.rb', line 2639

class CatalogProperties < Struct.new(
  :data_lake_access_properties,
  :iceberg_optimization_properties,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#iceberg_optimization_propertiesTypes::IcebergOptimizationProperties

A structure that specifies Iceberg table optimization properties for the catalog. This includes configuration for compaction, retention, and orphan file deletion operations that can be applied to Iceberg tables in this catalog.



2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-glue/types.rb', line 2639

class CatalogProperties < Struct.new(
  :data_lake_access_properties,
  :iceberg_optimization_properties,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end