Class: Aws::Glue::Types::CatalogTableConfigOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The configuration for a Glue Data Catalog table used to store data quality results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

A unique identifier for the Glue Data Catalog.

Returns:

  • (String)


2754
2755
2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-glue/types.rb', line 2754

class CatalogTableConfigOptions < Struct.new(
  :database_name,
  :table_name,
  :s3_location,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database in the Glue Data Catalog.

Returns:

  • (String)


2754
2755
2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-glue/types.rb', line 2754

class CatalogTableConfigOptions < Struct.new(
  :database_name,
  :table_name,
  :s3_location,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#s3_locationString

The Amazon S3 location for storing the results.

Returns:

  • (String)


2754
2755
2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-glue/types.rb', line 2754

class CatalogTableConfigOptions < Struct.new(
  :database_name,
  :table_name,
  :s3_location,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table in the Glue Data Catalog.

Returns:

  • (String)


2754
2755
2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-glue/types.rb', line 2754

class CatalogTableConfigOptions < Struct.new(
  :database_name,
  :table_name,
  :s3_location,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end