Class: Aws::Glue::Types::CatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Glue Data Catalog target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection for an Amazon S3-backed Data Catalog table to be a target of the crawl when using a
Catalogconnection type paired with aNETWORKConnection type. -
#database_name ⇒ String
The name of the database to be synchronized.
-
#dlq_event_queue_arn ⇒ String
A valid Amazon dead-letter SQS ARN.
-
#event_queue_arn ⇒ String
A valid Amazon SQS ARN.
-
#tables ⇒ Array<String>
A list of the tables to be synchronized.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection for an Amazon S3-backed Data Catalog
table to be a target of the crawl when using a Catalog connection
type paired with a NETWORK Connection type.
2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-glue/types.rb', line 2791 class CatalogTarget < Struct.new( :database_name, :tables, :connection_name, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database to be synchronized.
2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-glue/types.rb', line 2791 class CatalogTarget < Struct.new( :database_name, :tables, :connection_name, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#dlq_event_queue_arn ⇒ String
A valid Amazon dead-letter SQS ARN. For example,
arn:aws:sqs:region:account:deadLetterQueue.
2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-glue/types.rb', line 2791 class CatalogTarget < Struct.new( :database_name, :tables, :connection_name, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#event_queue_arn ⇒ String
A valid Amazon SQS ARN. For example,
arn:aws:sqs:region:account:sqs.
2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-glue/types.rb', line 2791 class CatalogTarget < Struct.new( :database_name, :tables, :connection_name, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#tables ⇒ Array<String>
A list of the tables to be synchronized.
2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-glue/types.rb', line 2791 class CatalogTarget < Struct.new( :database_name, :tables, :connection_name, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |