Class: Aws::Glue::Types::CheckSchemaVersionValidityInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CheckSchemaVersionValidityInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_format ⇒ String
The data format of the schema definition.
-
#schema_definition ⇒ String
The definition of the schema that has to be validated.
Instance Attribute Details
#data_format ⇒ String
The data format of the schema definition. Currently AVRO, JSON
and PROTOBUF are supported.
2789 2790 2791 2792 2793 2794 |
# File 'lib/aws-sdk-glue/types.rb', line 2789 class CheckSchemaVersionValidityInput < Struct.new( :data_format, :schema_definition) SENSITIVE = [] include Aws::Structure end |
#schema_definition ⇒ String
The definition of the schema that has to be validated.
2789 2790 2791 2792 2793 2794 |
# File 'lib/aws-sdk-glue/types.rb', line 2789 class CheckSchemaVersionValidityInput < Struct.new( :data_format, :schema_definition) SENSITIVE = [] include Aws::Structure end |