Class: Aws::Glue::Types::Classifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Classifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Classifiers are triggered during a crawl task. A classifier checks whether a given file is in a format it can handle. If it is, the classifier creates a schema in the form of a StructType object that matches that data format.
You can use the standard classifiers that Glue provides, or you can write your own classifiers to best categorize your data sources and specify the appropriate schemas to use for them. A classifier can be a grok classifier, an XML classifier, a JSON classifier, or a custom CSV classifier, as specified in one of the fields in the Classifier object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#csv_classifier ⇒ Types::CsvClassifier
A classifier for comma-separated values (CSV).
-
#grok_classifier ⇒ Types::GrokClassifier
A classifier that uses
grok. -
#json_classifier ⇒ Types::JsonClassifier
A classifier for JSON content.
-
#xml_classifier ⇒ Types::XMLClassifier
A classifier for XML content.
Instance Attribute Details
#csv_classifier ⇒ Types::CsvClassifier
A classifier for comma-separated values (CSV).
2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-glue/types.rb', line 2597 class Classifier < Struct.new( :grok_classifier, :xml_classifier, :json_classifier, :csv_classifier) SENSITIVE = [] include Aws::Structure end |
#grok_classifier ⇒ Types::GrokClassifier
A classifier that uses grok.
2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-glue/types.rb', line 2597 class Classifier < Struct.new( :grok_classifier, :xml_classifier, :json_classifier, :csv_classifier) SENSITIVE = [] include Aws::Structure end |
#json_classifier ⇒ Types::JsonClassifier
A classifier for JSON content.
2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-glue/types.rb', line 2597 class Classifier < Struct.new( :grok_classifier, :xml_classifier, :json_classifier, :csv_classifier) SENSITIVE = [] include Aws::Structure end |
#xml_classifier ⇒ Types::XMLClassifier
A classifier for XML content.
2597 2598 2599 2600 2601 2602 2603 2604 |
# File 'lib/aws-sdk-glue/types.rb', line 2597 class Classifier < Struct.new( :grok_classifier, :xml_classifier, :json_classifier, :csv_classifier) SENSITIVE = [] include Aws::Structure end |