Class: Aws::Glue::Types::ColumnStatisticsTaskRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The object that shows the details of the column stats run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog where the table resides. If none is supplied, the Amazon Web Services account ID is used by default.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#column_name_listArray<String>

A list of the column names. If none is supplied, all column names for the table will be used by default.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#column_statistics_task_run_idString

The identifier for the particular column statistics task run.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#computation_typeString

The type of column statistics computation.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that this task was created.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#customer_idString

The Amazon Web Services account ID.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The database where the table resides.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#dpu_secondsFloat

The calculated DPU usage in seconds for all autoscaled workers.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time of the task.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message for the job.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The last point in time when this task was modified.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers used to generate column statistics. The job is preconfigured to autoscale up to 25 instances.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The IAM role that the service assumes to generate statistics.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#sample_sizeFloat

The percentage of rows used to generate statistics. If none is supplied, the entire table will be used to generate stats.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

Name of the security configuration that is used to encrypt CloudWatch logs for the column stats task run.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time of the task.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the task run.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table for which column statistics is generated.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of workers being used for generating stats. The default is g.1x.



3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-glue/types.rb', line 3504

class ColumnStatisticsTaskRun < Struct.new(
  :customer_id,
  :column_statistics_task_run_id,
  :database_name,
  :table_name,
  :column_name_list,
  :catalog_id,
  :role,
  :sample_size,
  :security_configuration,
  :number_of_workers,
  :worker_type,
  :computation_type,
  :status,
  :creation_time,
  :last_updated,
  :start_time,
  :end_time,
  :error_message,
  :dpu_seconds)
  SENSITIVE = []
  include Aws::Structure
end