Class: Aws::Glue::Types::ColumnStatisticsTaskRunningException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ColumnStatisticsTaskRunningException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An exception thrown when you try to start another job while running a column stats generation job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
A message describing the problem.
Instance Attribute Details
#message ⇒ String
A message describing the problem.
3756 3757 3758 3759 3760 |
# File 'lib/aws-sdk-glue/types.rb', line 3756 class ColumnStatisticsTaskRunningException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |