Class: Aws::Glue::Types::Condition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Condition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a condition under which a trigger fires.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawl_state ⇒ String
The state of the crawler to which this condition applies.
-
#crawler_name ⇒ String
The name of the crawler to which this condition applies.
-
#job_name ⇒ String
The name of the job whose
JobRunsthis condition applies to, and on which this trigger waits. -
#logical_operator ⇒ String
A logical operator.
-
#state ⇒ String
The condition state.
Instance Attribute Details
#crawl_state ⇒ String
The state of the crawler to which this condition applies.
3929 3930 3931 3932 3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-glue/types.rb', line 3929 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#crawler_name ⇒ String
The name of the crawler to which this condition applies.
3929 3930 3931 3932 3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-glue/types.rb', line 3929 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job whose JobRuns this condition applies to, and
on which this trigger waits.
3929 3930 3931 3932 3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-glue/types.rb', line 3929 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#logical_operator ⇒ String
A logical operator.
3929 3930 3931 3932 3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-glue/types.rb', line 3929 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The condition state. Currently, the only job states that a trigger
can listen for are SUCCEEDED, STOPPED, FAILED, and TIMEOUT.
The only crawler states that a trigger can listen for are
SUCCEEDED, FAILED, and CANCELLED.
3929 3930 3931 3932 3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-glue/types.rb', line 3929 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |