Class: Aws::Glue::Types::ConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure that is used to specify a connection to create or update.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_propertiesHash<String,String>

These key-value pairs define parameters for the connection.

Returns:

  • (Hash<String,String>)


2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of the connection. Currently, these types are supported:

  • ‘JDBC` - Designates a connection to a database through Java Database Connectivity (JDBC).

  • ‘KAFKA` - Designates a connection to an Apache Kafka streaming platform.

  • ‘MONGODB` - Designates a connection to a MongoDB document database.

  • ‘NETWORK` - Designates a network connection to a data source within an Amazon Virtual Private Cloud environment (Amazon VPC).

  • ‘MARKETPLACE` - Uses configuration settings contained in a connector purchased from Amazon Web Services Marketplace to read from and write to data stores that are not natively supported by Glue.

  • ‘CUSTOM` - Uses configuration settings contained in a custom connector to read from and write to data stores that are not natively supported by Glue.

SFTP is not supported.

Returns:

  • (String)


2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the connection.

Returns:

  • (String)


2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#match_criteriaArray<String>

A list of criteria that can be used in selecting this connection.

Returns:

  • (Array<String>)


2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connection.

Returns:

  • (String)


2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsTypes::PhysicalConnectionRequirements

A map of physical connection requirements, such as virtual private cloud (VPC) and ‘SecurityGroup`, that are needed to successfully make this connection.



2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-glue/types.rb', line 2655

class ConnectionInput < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :physical_connection_requirements)
  SENSITIVE = []
  include Aws::Structure
end