Class: Aws::Glue::Types::ConnectionTypeBrief

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Brief information about a supported connection type returned by the ListConnectionTypes API.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capabilitiesTypes::Capabilities

The supported authentication types, data interface types (compute environments), and data operations of the connector.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#categoriesArray<String>

A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The name of the connection type.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#connection_type_variantsArray<Types::ConnectionTypeVariant>

A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the connection type.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The human-readable name for the connection type that is displayed in the Glue console.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#logo_urlString

The URL of the logo associated with a connection type.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end

#vendorString

The name of the vendor or provider that created or maintains this connection type.



4737
4738
4739
4740
4741
4742
4743
4744
4745
4746
4747
4748
# File 'lib/aws-sdk-glue/types.rb', line 4737

class ConnectionTypeBrief < Struct.new(
  :connection_type,
  :display_name,
  :vendor,
  :description,
  :categories,
  :capabilities,
  :logo_url,
  :connection_type_variants)
  SENSITIVE = []
  include Aws::Structure
end