Class: Aws::Glue::Types::ConnectorDataTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorDataTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a target generated with standard connection options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_type ⇒ String
The
connectionType, as provided to the underlying Glue library. -
#data ⇒ Hash<String,String>
A map specifying connection options for the node.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of this target node.
Instance Attribute Details
#connection_type ⇒ String
The connectionType, as provided to the underlying Glue library.
This node type supports the following connection types:
-
opensearch -
azuresql -
azurecosmos -
bigquery -
saphana -
teradata -
vertica
4976 4977 4978 4979 4980 4981 4982 4983 |
# File 'lib/aws-sdk-glue/types.rb', line 4976 class ConnectorDataTarget < Struct.new( :name, :connection_type, :data, :inputs) SENSITIVE = [] include Aws::Structure end |
#data ⇒ Hash<String,String>
A map specifying connection options for the node. You can find standard connection options for the corresponding connection type in the Connection parameters section of the Glue documentation.
4976 4977 4978 4979 4980 4981 4982 4983 |
# File 'lib/aws-sdk-glue/types.rb', line 4976 class ConnectorDataTarget < Struct.new( :name, :connection_type, :data, :inputs) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
4976 4977 4978 4979 4980 4981 4982 4983 |
# File 'lib/aws-sdk-glue/types.rb', line 4976 class ConnectorDataTarget < Struct.new( :name, :connection_type, :data, :inputs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of this target node.
4976 4977 4978 4979 4980 4981 4982 4983 |
# File 'lib/aws-sdk-glue/types.rb', line 4976 class ConnectorDataTarget < Struct.new( :name, :connection_type, :data, :inputs) SENSITIVE = [] include Aws::Structure end |