Class: Aws::Glue::Types::ConnectorOAuth2Properties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

OAuth2 configuration container that defines the authentication properties and flow-specific configurations for OAuth2-based connections.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorization_code_propertiesTypes::ConnectorAuthorizationCodeProperties

Configuration properties specific to the OAuth2 Authorization Code grant type flow.



4786
4787
4788
4789
4790
4791
4792
4793
# File 'lib/aws-sdk-glue/types.rb', line 4786

class ConnectorOAuth2Properties < Struct.new(
  :o_auth_2_grant_type,
  :client_credentials_properties,
  :jwt_bearer_properties,
  :authorization_code_properties)
  SENSITIVE = []
  include Aws::Structure
end

#client_credentials_propertiesTypes::ClientCredentialsProperties

Configuration properties specific to the OAuth2 Client Credentials grant type flow.



4786
4787
4788
4789
4790
4791
4792
4793
# File 'lib/aws-sdk-glue/types.rb', line 4786

class ConnectorOAuth2Properties < Struct.new(
  :o_auth_2_grant_type,
  :client_credentials_properties,
  :jwt_bearer_properties,
  :authorization_code_properties)
  SENSITIVE = []
  include Aws::Structure
end

#jwt_bearer_propertiesTypes::JWTBearerProperties

Configuration properties specific to the OAuth2 JWT Bearer grant type flow.



4786
4787
4788
4789
4790
4791
4792
4793
# File 'lib/aws-sdk-glue/types.rb', line 4786

class ConnectorOAuth2Properties < Struct.new(
  :o_auth_2_grant_type,
  :client_credentials_properties,
  :jwt_bearer_properties,
  :authorization_code_properties)
  SENSITIVE = []
  include Aws::Structure
end

#o_auth_2_grant_typeString

The OAuth2 grant type to use for authentication, such as CLIENT_CREDENTIALS, JWT_BEARER, or AUTHORIZATION_CODE.

Returns:

  • (String)


4786
4787
4788
4789
4790
4791
4792
4793
# File 'lib/aws-sdk-glue/types.rb', line 4786

class ConnectorOAuth2Properties < Struct.new(
  :o_auth_2_grant_type,
  :client_credentials_properties,
  :jwt_bearer_properties,
  :authorization_code_properties)
  SENSITIVE = []
  include Aws::Structure
end