Class: Aws::Glue::Types::Crawler

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a crawler program that examines a data source and uses classifiers to try to determine its schema. If successful, the crawler records metadata concerning the data source in the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classifiersArray<String>

A list of UTF-8 strings that specify the custom classifiers that are associated with the crawler.

Returns:

  • (Array<String>)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationString

Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler's behavior. For more information, see Setting crawler configuration options.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#crawl_elapsed_timeInteger

If the crawler is running, contains the total time elapsed since the last crawl began.

Returns:

  • (Integer)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#crawler_security_configurationString

The name of the SecurityConfiguration structure to be used by this crawler.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the crawler was created.

Returns:

  • (Time)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database in which the crawler's output is stored.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the crawler.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lake_formation_configurationTypes::LakeFormationConfiguration

Specifies whether the crawler should use Lake Formation credentials for the crawler instead of the IAM role credentials.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_crawlTypes::LastCrawlInfo

The status of the last crawl, and potentially error information if an error occurred.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The time that the crawler was last updated.

Returns:

  • (Time)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_configurationTypes::LineageConfiguration

A configuration that specifies whether data lineage is enabled for the crawler.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the crawler.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#recrawl_policyTypes::RecrawlPolicy

A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The Amazon Resource Name (ARN) of an IAM role that's used to access customer resources, such as Amazon Simple Storage Service (Amazon S3) data.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::Schedule

For scheduled crawlers, the schedule when the crawler runs.

Returns:



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::SchemaChangePolicy

The policy that specifies update and delete behaviors for the crawler.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Indicates whether the crawler is running, or whether a run is pending.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#table_prefixString

The prefix added to the names of tables that are created.

Returns:

  • (String)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#targetsTypes::CrawlerTargets

A collection of targets to crawl.



5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of the crawler.

Returns:

  • (Integer)


5218
5219
5220
5221
5222
5223
5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-glue/types.rb', line 5218

class Crawler < Struct.new(
  :name,
  :role,
  :targets,
  :database_name,
  :description,
  :classifiers,
  :recrawl_policy,
  :schema_change_policy,
  :lineage_configuration,
  :state,
  :table_prefix,
  :schedule,
  :crawl_elapsed_time,
  :creation_time,
  :last_updated,
  :last_crawl,
  :version,
  :configuration,
  :crawler_security_configuration,
  :lake_formation_configuration)
  SENSITIVE = []
  include Aws::Structure
end