Class: Aws::Glue::Types::CrawlerNodeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CrawlerNodeDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The details of a Crawler node present in the workflow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawls ⇒ Array<Types::Crawl>
A list of crawls represented by the crawl node.
Instance Attribute Details
#crawls ⇒ Array<Types::Crawl>
A list of crawls represented by the crawl node.
2702 2703 2704 2705 2706 |
# File 'lib/aws-sdk-glue/types.rb', line 2702 class CrawlerNodeDetails < Struct.new( :crawls) SENSITIVE = [] include Aws::Structure end |