Class: Aws::Glue::Types::CrawlsFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CrawlsFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A list of fields, comparators and value that you can use to filter the crawler runs for a specified crawler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
A key used to filter the crawler runs for a specified crawler.
-
#field_value ⇒ String
The value provided for comparison on the crawl field.
-
#filter_operator ⇒ String
A defined comparator that operates on the value.
Instance Attribute Details
#field_name ⇒ String
A key used to filter the crawler runs for a specified crawler. Valid values for each of the field names are:
-
CRAWL_ID: A string representing the UUID identifier for a crawl. -
STATE: A string representing the state of the crawl. -
START_TIMEandEND_TIME: The epoch timestamp in milliseconds. -
DPU_HOUR: The number of data processing unit (DPU) hours used for the crawl.
5246 5247 5248 5249 5250 5251 5252 |
# File 'lib/aws-sdk-glue/types.rb', line 5246 class CrawlsFilter < Struct.new( :field_name, :filter_operator, :field_value) SENSITIVE = [] include Aws::Structure end |
#field_value ⇒ String
The value provided for comparison on the crawl field.
5246 5247 5248 5249 5250 5251 5252 |
# File 'lib/aws-sdk-glue/types.rb', line 5246 class CrawlsFilter < Struct.new( :field_name, :filter_operator, :field_value) SENSITIVE = [] include Aws::Structure end |
#filter_operator ⇒ String
A defined comparator that operates on the value. The available operators are:
-
GT: Greater than. -
GE: Greater than or equal to. -
LT: Less than. -
LE: Less than or equal to. -
EQ: Equal to. -
NE: Not equal to.
5246 5247 5248 5249 5250 5251 5252 |
# File 'lib/aws-sdk-glue/types.rb', line 5246 class CrawlsFilter < Struct.new( :field_name, :filter_operator, :field_value) SENSITIVE = [] include Aws::Structure end |