Class: Aws::Glue::Types::CreateGlossaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-glue/types.rb', line 6222

class CreateGlossaryRequest < Struct.new(
  :name,
  :description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the glossary.

Returns:

  • (String)


6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-glue/types.rb', line 6222

class CreateGlossaryRequest < Struct.new(
  :name,
  :description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the glossary.

Returns:

  • (String)


6222
6223
6224
6225
6226
6227
6228
# File 'lib/aws-sdk-glue/types.rb', line 6222

class CreateGlossaryRequest < Struct.new(
  :name,
  :description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end