Class: Aws::Glue::Types::CreateGlossaryTermRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-glue/types.rb', line 6278

class CreateGlossaryTermRequest < Struct.new(
  :glossary_identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_identifierString

The unique identifier of the glossary in which to create the term.

Returns:

  • (String)


6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-glue/types.rb', line 6278

class CreateGlossaryTermRequest < Struct.new(
  :glossary_identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#long_descriptionString

A long description of the glossary term.

Returns:

  • (String)


6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-glue/types.rb', line 6278

class CreateGlossaryTermRequest < Struct.new(
  :glossary_identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the glossary term.

Returns:

  • (String)


6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-glue/types.rb', line 6278

class CreateGlossaryTermRequest < Struct.new(
  :glossary_identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#short_descriptionString

A short description of the glossary term.

Returns:

  • (String)


6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-glue/types.rb', line 6278

class CreateGlossaryTermRequest < Struct.new(
  :glossary_identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end