Class: Aws::Glue::Types::CreateGlueIdentityCenterConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Response from creating a new Glue Identity Center configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.

Returns:

  • (String)


6474
6475
6476
6477
6478
# File 'lib/aws-sdk-glue/types.rb', line 6474

class CreateGlueIdentityCenterConfigurationResponse < Struct.new(
  :application_arn)
  SENSITIVE = []
  include Aws::Structure
end