Class: Aws::Glue::Types::CreateIntegrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateIntegrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_encryption_context ⇒ Hash<String,String>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption.
-
#data_filter ⇒ String
Selects source tables for the integration using Maxwell filter syntax.
-
#description ⇒ String
A description of the integration.
-
#integration_config ⇒ Types::IntegrationConfig
The configuration settings.
-
#integration_name ⇒ String
A unique name for an integration in Glue.
-
#kms_key_id ⇒ String
The ARN of a KMS key used for encrypting the channel.
-
#source_arn ⇒ String
The ARN of the source resource for the integration.
-
#tags ⇒ Array<Types::Tag>
Metadata assigned to the resource consisting of a list of key-value pairs.
-
#target_arn ⇒ String
The ARN of the target resource for the integration.
Instance Attribute Details
#additional_encryption_context ⇒ Hash<String,String>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#data_filter ⇒ String
Selects source tables for the integration using Maxwell filter syntax.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the integration.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#integration_config ⇒ Types::IntegrationConfig
The configuration settings.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#integration_name ⇒ String
A unique name for an integration in Glue.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of a KMS key used for encrypting the channel.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The ARN of the source resource for the integration.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Metadata assigned to the resource consisting of a list of key-value pairs.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of the target resource for the integration.
6221 6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 |
# File 'lib/aws-sdk-glue/types.rb', line 6221 class CreateIntegrationRequest < Struct.new( :integration_name, :source_arn, :target_arn, :description, :data_filter, :kms_key_id, :additional_encryption_context, :tags, :integration_config) SENSITIVE = [] include Aws::Structure end |