Class: Aws::Glue::Types::CreateJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The unique name that was provided for this job definition.
Instance Attribute Details
#name ⇒ String
The unique name that was provided for this job definition.
6273 6274 6275 6276 6277 |
# File 'lib/aws-sdk-glue/types.rb', line 6273 class CreateJobResponse < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |