Class: Aws::Glue::Types::CreateMLTransformRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass CreateMLTransformRequest data as a hash:

{
  name: "NameString", # required
  description: "DescriptionString",
  input_record_tables: [ # required
    {
      database_name: "NameString", # required
      table_name: "NameString", # required
      catalog_id: "NameString",
      connection_name: "NameString",
    },
  ],
  parameters: { # required
    transform_type: "FIND_MATCHES", # required, accepts FIND_MATCHES
    find_matches_parameters: {
      primary_key_column_name: "ColumnNameString",
      precision_recall_tradeoff: 1.0,
      accuracy_cost_tradeoff: 1.0,
      enforce_provided_labels: false,
    },
  },
  role: "RoleString", # required
  glue_version: "GlueVersionString",
  max_capacity: 1.0,
  worker_type: "Standard", # accepts Standard, G.1X, G.2X, G.025X
  number_of_workers: 1,
  timeout: 1,
  max_retries: 1,
  tags: {
    "TagKey" => "TagValue",
  },
  transform_encryption: {
    ml_user_data_encryption: {
      ml_user_data_encryption_mode: "DISABLED", # required, accepts DISABLED, SSE-KMS
      kms_key_id: "NameString",
    },
    task_run_security_configuration_name: "NameString",
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the machine learning transform that is being defined. The default is an empty string.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#input_record_tablesArray<Types::GlueTable>

A list of Glue table definitions used by the transform.

Returns:



6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

`MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.

  • If either `NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.

  • If `MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.

  • If `WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

  • `MaxCapacity` and `NumberOfWorkers` must both be at least 1.

When the `WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.

When the `WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry a task for this transform after a task run fails.

Returns:

  • (Integer)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique name that you give the transform when you create it.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined `workerType` that are allocated when this task runs.

If `WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

Returns:

  • (Integer)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::TransformParameters

The algorithmic parameters that are specific to the transform type used. Conditionally dependent on the transform type.



6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role with the required permissions. The required permissions include both Glue service role permissions to Glue resources, and Amazon S3 permissions required by the transform.

  • This role needs Glue service role permissions to allow access to resources in Glue. See [Attach a Policy to IAM Users That Access Glue].

  • This role needs permission to your Amazon Simple Storage Service (Amazon S3) sources, targets, temporary directory, scripts, and any libraries used by the task run for this transform.

[1]: docs.aws.amazon.com/glue/latest/dg/attach-policy-iam-user.html

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to use with this machine learning transform. You may use tags to limit access to the machine learning transform. For more information about tags in Glue, see [Amazon Web Services Tags in Glue] in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/monitor-tags.html

Returns:

  • (Hash<String,String>)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The timeout of the task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters `TIMEOUT` status. The default is 2,880 minutes (48 hours).

Returns:

  • (Integer)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#transform_encryptionTypes::TransformEncryption

The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.



6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.

  • For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the `G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the `G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

`MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.

  • If either `NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.

  • If `MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.

  • If `WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

  • `MaxCapacity` and `NumberOfWorkers` must both be at least 1.

Returns:

  • (String)


6576
6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
6589
6590
6591
6592
# File 'lib/aws-sdk-glue/types.rb', line 6576

class CreateMLTransformRequest < Struct.new(
  :name,
  :description,
  :input_record_tables,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :tags,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end