Class: Aws::Glue::Types::CreatePartitionIndexRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreatePartitionIndexRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CreatePartitionIndexRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partition_index: { # required
keys: ["NameString"], # required
index_name: "NameString", # required
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The catalog ID where the table resides.
-
#database_name ⇒ String
Specifies the name of a database in which you want to create a partition index.
-
#partition_index ⇒ Types::PartitionIndex
Specifies a `PartitionIndex` structure to create a partition index in an existing table.
-
#table_name ⇒ String
Specifies the name of a table in which you want to create a partition index.
Instance Attribute Details
#catalog_id ⇒ String
The catalog ID where the table resides.
6656 6657 6658 6659 6660 6661 6662 6663 |
# File 'lib/aws-sdk-glue/types.rb', line 6656 class CreatePartitionIndexRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_index) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
Specifies the name of a database in which you want to create a partition index.
6656 6657 6658 6659 6660 6661 6662 6663 |
# File 'lib/aws-sdk-glue/types.rb', line 6656 class CreatePartitionIndexRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_index) SENSITIVE = [] include Aws::Structure end |
#partition_index ⇒ Types::PartitionIndex
Specifies a `PartitionIndex` structure to create a partition index in an existing table.
6656 6657 6658 6659 6660 6661 6662 6663 |
# File 'lib/aws-sdk-glue/types.rb', line 6656 class CreatePartitionIndexRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_index) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
Specifies the name of a table in which you want to create a partition index.
6656 6657 6658 6659 6660 6661 6662 6663 |
# File 'lib/aws-sdk-glue/types.rb', line 6656 class CreatePartitionIndexRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_index) SENSITIVE = [] include Aws::Structure end |