Class: Aws::Glue::Types::CreateScriptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateScriptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dag_edges ⇒ Array<Types::CodeGenEdge>
A list of the edges in the DAG.
-
#dag_nodes ⇒ Array<Types::CodeGenNode>
A list of the nodes in the DAG.
-
#language ⇒ String
The programming language of the resulting code from the DAG.
Instance Attribute Details
#dag_edges ⇒ Array<Types::CodeGenEdge>
A list of the edges in the DAG.
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-glue/types.rb', line 7536 class CreateScriptRequest < Struct.new( :dag_nodes, :dag_edges, :language) SENSITIVE = [] include Aws::Structure end |
#dag_nodes ⇒ Array<Types::CodeGenNode>
A list of the nodes in the DAG.
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-glue/types.rb', line 7536 class CreateScriptRequest < Struct.new( :dag_nodes, :dag_edges, :language) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The programming language of the resulting code from the DAG.
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-glue/types.rb', line 7536 class CreateScriptRequest < Struct.new( :dag_nodes, :dag_edges, :language) SENSITIVE = [] include Aws::Structure end |