Class: Aws::Glue::Types::CreateTriggerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::Action>

The actions initiated by this trigger when it fires.

Returns:



8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the new trigger.

Returns:

  • (String)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#event_batching_conditionTypes::EventBatchingCondition

Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.



8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the trigger.

Returns:

  • (String)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#predicateTypes::Predicate

A predicate to specify when the new trigger should fire.

This field is required when the trigger type is CONDITIONAL.

Returns:



8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

A cron expression used to specify the schedule (see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, you would specify: cron(15 12 * * ? *).

This field is required when the trigger type is SCHEDULED.

Returns:

  • (String)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#start_on_creationBoolean

Set to true to start SCHEDULED and CONDITIONAL triggers when created. True is not supported for ON_DEMAND triggers.

Returns:

  • (Boolean)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to use with this trigger. You may use tags to limit access to the trigger. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide.

Returns:

  • (Hash<String,String>)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the new trigger.

Returns:

  • (String)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_nameString

The name of the workflow associated with the trigger.

Returns:

  • (String)


8011
8012
8013
8014
8015
8016
8017
8018
8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-glue/types.rb', line 8011

class CreateTriggerRequest < Struct.new(
  :name,
  :workflow_name,
  :type,
  :schedule,
  :predicate,
  :actions,
  :description,
  :start_on_creation,
  :tags,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end