Class: Aws::Glue::Types::CreateWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workflow which was provided as part of the request.
Instance Attribute Details
#name ⇒ String
The name of the workflow which was provided as part of the request.
5137 5138 5139 5140 5141 |
# File 'lib/aws-sdk-glue/types.rb', line 5137 class CreateWorkflowResponse < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |