Class: Aws::Glue::Types::CursorConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Cursor-based pagination configuration that defines how to handle pagination using cursor tokens or next page identifiers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limit_parameterTypes::ExtractedParameter

The parameter name used to specify the maximum number of results to return per page.



8229
8230
8231
8232
8233
8234
# File 'lib/aws-sdk-glue/types.rb', line 8229

class CursorConfiguration < Struct.new(
  :next_page,
  :limit_parameter)
  SENSITIVE = []
  include Aws::Structure
end

#next_pageTypes::ExtractedParameter

The parameter name or JSON path that contains the cursor or token for retrieving the next page of results.



8229
8230
8231
8232
8233
8234
# File 'lib/aws-sdk-glue/types.rb', line 8229

class CursorConfiguration < Struct.new(
  :next_page,
  :limit_parameter)
  SENSITIVE = []
  include Aws::Structure
end