Class: Aws::Glue::Types::CustomCode
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CustomCode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CustomCode data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
code: "ExtendedString", # required
class_name: "EnclosedInStringProperty", # required
output_schemas: [
{
columns: [
{
name: "GlueStudioColumnNameString", # required
type: "ColumnTypeString",
},
],
},
],
}
Specifies a transform that uses custom code you provide to perform the data transformation. The output is a collection of DynamicFrames.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#class_name ⇒ String
The name defined for the custom code node class.
-
#code ⇒ String
The custom code that is used to perform the data transformation.
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom code transform.
Instance Attribute Details
#class_name ⇒ String
The name defined for the custom code node class.
7859 7860 7861 7862 7863 7864 7865 7866 7867 |
# File 'lib/aws-sdk-glue/types.rb', line 7859 class CustomCode < Struct.new( :name, :inputs, :code, :class_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#code ⇒ String
The custom code that is used to perform the data transformation.
7859 7860 7861 7862 7863 7864 7865 7866 7867 |
# File 'lib/aws-sdk-glue/types.rb', line 7859 class CustomCode < Struct.new( :name, :inputs, :code, :class_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The data inputs identified by their node names.
7859 7860 7861 7862 7863 7864 7865 7866 7867 |
# File 'lib/aws-sdk-glue/types.rb', line 7859 class CustomCode < Struct.new( :name, :inputs, :code, :class_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
7859 7860 7861 7862 7863 7864 7865 7866 7867 |
# File 'lib/aws-sdk-glue/types.rb', line 7859 class CustomCode < Struct.new( :name, :inputs, :code, :class_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom code transform.
7859 7860 7861 7862 7863 7864 7865 7866 7867 |
# File 'lib/aws-sdk-glue/types.rb', line 7859 class CustomCode < Struct.new( :name, :inputs, :code, :class_name, :output_schemas) SENSITIVE = [] include Aws::Structure end |