Class: Aws::Glue::Types::DataLakeAccessPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataLakeAccessPropertiesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The output properties of the data lake access configuration for your catalog resource in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_type ⇒ String
Specifies a federated catalog type for the native catalog resource.
-
#data_lake_access ⇒ Boolean
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.
-
#data_transfer_role ⇒ String
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
-
#kms_key ⇒ String
An encryption key that will be used for the staging bucket that will be created along with the catalog.
-
#managed_workgroup_name ⇒ String
The managed Redshift Serverless compute name that is created for your catalog resource.
-
#managed_workgroup_status ⇒ String
The managed Redshift Serverless compute status.
-
#redshift_database_name ⇒ String
The default Redshift database resource name in the managed compute.
-
#status_message ⇒ String
A message that gives more detailed information about the managed workgroup status.
Instance Attribute Details
#catalog_type ⇒ String
Specifies a federated catalog type for the native catalog resource.
The currently supported type is aws:redshift.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#data_lake_access ⇒ Boolean
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#data_transfer_role ⇒ String
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
An encryption key that will be used for the staging bucket that will be created along with the catalog.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#managed_workgroup_name ⇒ String
The managed Redshift Serverless compute name that is created for your catalog resource.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#managed_workgroup_status ⇒ String
The managed Redshift Serverless compute status.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#redshift_database_name ⇒ String
The default Redshift database resource name in the managed compute.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message that gives more detailed information about the managed workgroup status.
8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/aws-sdk-glue/types.rb', line 8611 class DataLakeAccessPropertiesOutput < Struct.new( :data_lake_access, :data_transfer_role, :kms_key, :managed_workgroup_name, :managed_workgroup_status, :redshift_database_name, :status_message, :catalog_type) SENSITIVE = [] include Aws::Structure end |