Class: Aws::Glue::Types::DataQualityEncryption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies how Data Quality assets in your account should be encrypted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_quality_encryption_modeString

The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.

Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.

Returns:

  • (String)


8344
8345
8346
8347
8348
8349
# File 'lib/aws-sdk-glue/types.rb', line 8344

class DataQualityEncryption < Struct.new(
  :data_quality_encryption_mode,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

Returns:

  • (String)


8344
8345
8346
8347
8348
8349
# File 'lib/aws-sdk-glue/types.rb', line 8344

class DataQualityEncryption < Struct.new(
  :data_quality_encryption_mode,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end