Class: Aws::Glue::Types::DataQualityResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Describes a data quality result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregated_metrics ⇒ Types::DataQualityAggregatedMetrics
A summary of ‘DataQualityAggregatedMetrics` objects showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.
-
#analyzer_results ⇒ Array<Types::DataQualityAnalyzerResult>
A list of ‘DataQualityAnalyzerResult` objects representing the results for each analyzer.
-
#completed_on ⇒ Time
The date and time when this data quality run completed.
-
#data_source ⇒ Types::DataSource
The table associated with the data quality result, if any.
-
#evaluation_context ⇒ String
In the context of a job in Glue Studio, each node in the canvas is typically assigned some sort of name and data quality nodes will have names.
-
#job_name ⇒ String
The job name associated with the data quality result, if any.
-
#job_run_id ⇒ String
The job run ID associated with the data quality result, if any.
-
#observations ⇒ Array<Types::DataQualityObservation>
A list of ‘DataQualityObservation` objects representing the observations generated after evaluating the rules and analyzers.
-
#profile_id ⇒ String
The Profile ID for the data quality result.
-
#result_id ⇒ String
A unique result ID for the data quality result.
-
#rule_results ⇒ Array<Types::DataQualityRuleResult>
A list of ‘DataQualityRuleResult` objects representing the results for each rule.
-
#ruleset_evaluation_run_id ⇒ String
The unique run ID for the ruleset evaluation for this data quality result.
-
#ruleset_name ⇒ String
The name of the ruleset associated with the data quality result.
-
#score ⇒ Float
An aggregate data quality score.
-
#started_on ⇒ Time
The date and time when this data quality run started.
Instance Attribute Details
#aggregated_metrics ⇒ Types::DataQualityAggregatedMetrics
A summary of ‘DataQualityAggregatedMetrics` objects showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#analyzer_results ⇒ Array<Types::DataQualityAnalyzerResult>
A list of ‘DataQualityAnalyzerResult` objects representing the results for each analyzer.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time when this data quality run completed.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The table associated with the data quality result, if any.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#evaluation_context ⇒ String
In the context of a job in Glue Studio, each node in the canvas is typically assigned some sort of name and data quality nodes will have names. In the case of multiple nodes, the ‘evaluationContext` can differentiate the nodes.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The job name associated with the data quality result, if any.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#job_run_id ⇒ String
The job run ID associated with the data quality result, if any.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#observations ⇒ Array<Types::DataQualityObservation>
A list of ‘DataQualityObservation` objects representing the observations generated after evaluating the rules and analyzers.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The Profile ID for the data quality result.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#result_id ⇒ String
A unique result ID for the data quality result.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#rule_results ⇒ Array<Types::DataQualityRuleResult>
A list of ‘DataQualityRuleResult` objects representing the results for each rule.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#ruleset_evaluation_run_id ⇒ String
The unique run ID for the ruleset evaluation for this data quality result.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#ruleset_name ⇒ String
The name of the ruleset associated with the data quality result.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#score ⇒ Float
An aggregate data quality score. Represents the ratio of rules that passed to the total number of rules.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when this data quality run started.
8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 |
# File 'lib/aws-sdk-glue/types.rb', line 8184 class DataQualityResult < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |