Class: Aws::Glue::Types::DataQualityRuleRecommendationRunAdditionalRunOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Additional run options you can specify for a recommendation run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_log_group_prefixString

A custom prefix for the CloudWatch log group names. When specified, recommendation run logs are written to <CustomLogGroupPrefix>/error and <CustomLogGroupPrefix>/output instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.

Returns:

  • (String)


9033
9034
9035
9036
9037
# File 'lib/aws-sdk-glue/types.rb', line 9033

class DataQualityRuleRecommendationRunAdditionalRunOptions < Struct.new(
  :custom_log_group_prefix)
  SENSITIVE = []
  include Aws::Structure
end