Class: Aws::Glue::Types::DataQualityRuleResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityRuleResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Describes the result of the evaluation of a data quality rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the data quality rule.
-
#evaluated_metrics ⇒ Hash<String,Float>
A map of metrics associated with the evaluation of the rule.
-
#evaluation_message ⇒ String
An evaluation message.
-
#name ⇒ String
The name of the data quality rule.
-
#result ⇒ String
A pass or fail status for the rule.
Instance Attribute Details
#description ⇒ String
A description of the data quality rule.
5955 5956 5957 5958 5959 5960 5961 5962 5963 |
# File 'lib/aws-sdk-glue/types.rb', line 5955 class DataQualityRuleResult < Struct.new( :name, :description, :evaluation_message, :result, :evaluated_metrics) SENSITIVE = [] include Aws::Structure end |
#evaluated_metrics ⇒ Hash<String,Float>
A map of metrics associated with the evaluation of the rule.
5955 5956 5957 5958 5959 5960 5961 5962 5963 |
# File 'lib/aws-sdk-glue/types.rb', line 5955 class DataQualityRuleResult < Struct.new( :name, :description, :evaluation_message, :result, :evaluated_metrics) SENSITIVE = [] include Aws::Structure end |
#evaluation_message ⇒ String
An evaluation message.
5955 5956 5957 5958 5959 5960 5961 5962 5963 |
# File 'lib/aws-sdk-glue/types.rb', line 5955 class DataQualityRuleResult < Struct.new( :name, :description, :evaluation_message, :result, :evaluated_metrics) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data quality rule.
5955 5956 5957 5958 5959 5960 5961 5962 5963 |
# File 'lib/aws-sdk-glue/types.rb', line 5955 class DataQualityRuleResult < Struct.new( :name, :description, :evaluation_message, :result, :evaluated_metrics) SENSITIVE = [] include Aws::Structure end |
#result ⇒ String
A pass or fail status for the rule.
5955 5956 5957 5958 5959 5960 5961 5962 5963 |
# File 'lib/aws-sdk-glue/types.rb', line 5955 class DataQualityRuleResult < Struct.new( :name, :description, :evaluation_message, :result, :evaluated_metrics) SENSITIVE = [] include Aws::Structure end |