Class: Aws::Glue::Types::DataQualityRuleResultsOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityRuleResultsOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The configuration for writing data quality rule results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_table_config ⇒ Types::CatalogTableConfigOptions
The Glue Data Catalog table configuration for storing the rule results.
-
#write_data_quality_rule_results_enabled ⇒ Boolean
Set to true to write data quality rule results.
Instance Attribute Details
#catalog_table_config ⇒ Types::CatalogTableConfigOptions
The Glue Data Catalog table configuration for storing the rule results.
9160 9161 9162 9163 9164 9165 |
# File 'lib/aws-sdk-glue/types.rb', line 9160 class DataQualityRuleResultsOptions < Struct.new( :write_data_quality_rule_results_enabled, :catalog_table_config) SENSITIVE = [] include Aws::Structure end |
#write_data_quality_rule_results_enabled ⇒ Boolean
Set to true to write data quality rule results.
9160 9161 9162 9163 9164 9165 |
# File 'lib/aws-sdk-glue/types.rb', line 9160 class DataQualityRuleResultsOptions < Struct.new( :write_data_quality_rule_results_enabled, :catalog_table_config) SENSITIVE = [] include Aws::Structure end |