Class: Aws::Glue::Types::DataQualityTargetTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityTargetTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An object representing an Glue table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_name ⇒ String
The name of the database where the Glue table exists.
-
#table_name ⇒ String
The name of the Glue table.
Instance Attribute Details
#database_name ⇒ String
The name of the database where the Glue table exists.
5650 5651 5652 5653 5654 5655 |
# File 'lib/aws-sdk-glue/types.rb', line 5650 class DataQualityTargetTable < Struct.new( :table_name, :database_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the Glue table.
5650 5651 5652 5653 5654 5655 |
# File 'lib/aws-sdk-glue/types.rb', line 5650 class DataQualityTargetTable < Struct.new( :table_name, :database_name) SENSITIVE = [] include Aws::Structure end |