Class: Aws::Glue::Types::DatabaseIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure that describes a target database for resource linking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides.

Returns:

  • (String)


8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-glue/types.rb', line 8388

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :region)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database.

Returns:

  • (String)


8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-glue/types.rb', line 8388

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :region)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

Region of the target database.

Returns:

  • (String)


8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-glue/types.rb', line 8388

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :region)
  SENSITIVE = []
  include Aws::Structure
end