Class: Aws::Glue::Types::DeleteAttachmentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset.

Returns:

  • (String)


9842
9843
9844
9845
9846
9847
9848
# File 'lib/aws-sdk-glue/types.rb', line 9842

class DeleteAttachmentResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form, if applicable.

Returns:

  • (String)


9842
9843
9844
9845
9846
9847
9848
# File 'lib/aws-sdk-glue/types.rb', line 9842

class DeleteAttachmentResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form, if the deletion targets an item.

Returns:

  • (String)


9842
9843
9844
9845
9846
9847
9848
# File 'lib/aws-sdk-glue/types.rb', line 9842

class DeleteAttachmentResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier)
  SENSITIVE = []
  include Aws::Structure
end