Class: Aws::Glue::Types::DeleteBlueprintResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteBlueprintResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
Returns the name of the blueprint that was deleted.
Instance Attribute Details
#name ⇒ String
Returns the name of the blueprint that was deleted.
6339 6340 6341 6342 6343 |
# File 'lib/aws-sdk-glue/types.rb', line 6339 class DeleteBlueprintResponse < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |