Class: Aws::Glue::Types::DeleteCustomEntityTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteCustomEntityTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the custom pattern that you want to delete.
Instance Attribute Details
#name ⇒ String
The name of the custom pattern that you want to delete.
7471 7472 7473 7474 7475 |
# File 'lib/aws-sdk-glue/types.rb', line 7471 class DeleteCustomEntityTypeRequest < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |