Class: Aws::Glue::Types::DeleteDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.



9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-glue/types.rb', line 9454

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database to delete. For Hive compatibility, this must be all lowercase.



9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-glue/types.rb', line 9454

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end