Class: Aws::Glue::Types::DeleteMLTransformResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteMLTransformResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#transform_id ⇒ String
The unique identifier of the transform that was deleted.
Instance Attribute Details
#transform_id ⇒ String
The unique identifier of the transform that was deleted.
6314 6315 6316 6317 6318 |
# File 'lib/aws-sdk-glue/types.rb', line 6314 class DeleteMLTransformResponse < Struct.new( :transform_id) SENSITIVE = [] include Aws::Structure end |