Class: Aws::Glue::Types::DeletePartitionIndexRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The catalog ID where the table resides.

Returns:

  • (String)


8961
8962
8963
8964
8965
8966
8967
8968
# File 'lib/aws-sdk-glue/types.rb', line 8961

class DeletePartitionIndexRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

Specifies the name of a database from which you want to delete a partition index.

Returns:

  • (String)


8961
8962
8963
8964
8965
8966
8967
8968
# File 'lib/aws-sdk-glue/types.rb', line 8961

class DeletePartitionIndexRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end

#index_nameString

The name of the partition index to be deleted.

Returns:

  • (String)


8961
8962
8963
8964
8965
8966
8967
8968
# File 'lib/aws-sdk-glue/types.rb', line 8961

class DeletePartitionIndexRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

Specifies the name of a table from which you want to delete a partition index.

Returns:

  • (String)


8961
8962
8963
8964
8965
8966
8967
8968
# File 'lib/aws-sdk-glue/types.rb', line 8961

class DeletePartitionIndexRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :index_name)
  SENSITIVE = []
  include Aws::Structure
end