Class: Aws::Glue::Types::DeleteRegistryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteRegistryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DeleteRegistryInput data as a hash:
{
registry_id: { # required
registry_name: "SchemaRegistryNameString",
registry_arn: "GlueResourceArn",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#registry_id ⇒ Types::RegistryId
This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
Instance Attribute Details
#registry_id ⇒ Types::RegistryId
This is a wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
8549 8550 8551 8552 8553 |
# File 'lib/aws-sdk-glue/types.rb', line 8549 class DeleteRegistryInput < Struct.new( :registry_id) SENSITIVE = [] include Aws::Structure end |