Class: Aws::Glue::Types::DeleteResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_hash_condition ⇒ String
The hash value returned when this policy was set.
-
#resource_arn ⇒ String
The ARN of the Glue resource for the resource policy to be deleted.
Instance Attribute Details
#policy_hash_condition ⇒ String
The hash value returned when this policy was set.
6677 6678 6679 6680 6681 6682 |
# File 'lib/aws-sdk-glue/types.rb', line 6677 class DeleteResourcePolicyRequest < Struct.new( :policy_hash_condition, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the Glue resource for the resource policy to be deleted.
6677 6678 6679 6680 6681 6682 |
# File 'lib/aws-sdk-glue/types.rb', line 6677 class DeleteResourcePolicyRequest < Struct.new( :policy_hash_condition, :resource_arn) SENSITIVE = [] include Aws::Structure end |