Class: Aws::Glue::Types::DescribeConnectionTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DescribeConnectionTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_type ⇒ String
The name of the connection type to be described.
Instance Attribute Details
#connection_type ⇒ String
The name of the connection type to be described.
10170 10171 10172 10173 10174 |
# File 'lib/aws-sdk-glue/types.rb', line 10170 class DescribeConnectionTypeRequest < Struct.new( :connection_type) SENSITIVE = [] include Aws::Structure end |