Class: Aws::Glue::Types::DescribeIntegrationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::IntegrationFilter>

A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.



11052
11053
11054
11055
11056
11057
11058
11059
# File 'lib/aws-sdk-glue/types.rb', line 11052

class DescribeIntegrationsRequest < Struct.new(
  :integration_identifier,
  :marker,
  :max_records,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#integration_identifierString

The Amazon Resource Name (ARN) for the integration.



11052
11053
11054
11055
11056
11057
11058
11059
# File 'lib/aws-sdk-glue/types.rb', line 11052

class DescribeIntegrationsRequest < Struct.new(
  :integration_identifier,
  :marker,
  :max_records,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request.



11052
11053
11054
11055
11056
11057
11058
11059
# File 'lib/aws-sdk-glue/types.rb', line 11052

class DescribeIntegrationsRequest < Struct.new(
  :integration_identifier,
  :marker,
  :max_records,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The total number of items to return in the output.



11052
11053
11054
11055
11056
11057
11058
11059
# File 'lib/aws-sdk-glue/types.rb', line 11052

class DescribeIntegrationsRequest < Struct.new(
  :integration_identifier,
  :marker,
  :max_records,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end