Class: Aws::Glue::Types::DevEndpointCustomLibraries

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DevEndpointCustomLibraries data as a hash:

{
  extra_python_libs_s3_path: "GenericString",
  extra_jars_s3_path: "GenericString",
}

Custom libraries to be loaded into a development endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#extra_jars_s3_pathString

The path to one or more Java `.jar` files in an S3 bucket that should be loaded in your `DevEndpoint`.

<note markdown=“1”> You can only use pure Java/Scala libraries with a `DevEndpoint`.

</note>

Returns:

  • (String)


9351
9352
9353
9354
9355
9356
# File 'lib/aws-sdk-glue/types.rb', line 9351

class DevEndpointCustomLibraries < Struct.new(
  :extra_python_libs_s3_path,
  :extra_jars_s3_path)
  SENSITIVE = []
  include Aws::Structure
end

#extra_python_libs_s3_pathString

The paths to one or more Python libraries in an Amazon Simple Storage Service (Amazon S3) bucket that should be loaded in your `DevEndpoint`. Multiple values must be complete paths separated by a comma.

<note markdown=“1”> You can only use pure Python libraries with a `DevEndpoint`. Libraries that rely on C extensions, such as the [pandas] Python data analysis library, are not currently supported.

</note>

[1]: pandas.pydata.org/

Returns:

  • (String)


9351
9352
9353
9354
9355
9356
# File 'lib/aws-sdk-glue/types.rb', line 9351

class DevEndpointCustomLibraries < Struct.new(
  :extra_python_libs_s3_path,
  :extra_jars_s3_path)
  SENSITIVE = []
  include Aws::Structure
end