Class: Aws::Glue::Types::DirectKafkaSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies an Apache Kafka data store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_preview_optionsTypes::StreamingDataPreviewOptions

Specifies options related to data preview for viewing a sample of your data.



8394
8395
8396
8397
8398
8399
8400
8401
8402
# File 'lib/aws-sdk-glue/types.rb', line 8394

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#detect_schemaBoolean

Whether to automatically determine the schema from the incoming data.

Returns:

  • (Boolean)


8394
8395
8396
8397
8398
8399
8400
8401
8402
# File 'lib/aws-sdk-glue/types.rb', line 8394

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data store.

Returns:

  • (String)


8394
8395
8396
8397
8398
8399
8400
8401
8402
# File 'lib/aws-sdk-glue/types.rb', line 8394

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_optionsTypes::KafkaStreamingSourceOptions

Specifies the streaming options.



8394
8395
8396
8397
8398
8399
8400
8401
8402
# File 'lib/aws-sdk-glue/types.rb', line 8394

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#window_sizeInteger

The amount of time to spend processing each micro batch.

Returns:

  • (Integer)


8394
8395
8396
8397
8398
8399
8400
8401
8402
# File 'lib/aws-sdk-glue/types.rb', line 8394

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end