Class: Aws::Glue::Types::DirectSchemaChangePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DirectSchemaChangePolicy data as a hash:

{
  enable_update_catalog: false,
  update_behavior: "UPDATE_IN_DATABASE", # accepts UPDATE_IN_DATABASE, LOG
  table: "EnclosedInStringProperty",
  database: "EnclosedInStringProperty",
}

A policy that specifies update behavior for the crawler.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#databaseString

Specifies the database that the schema change policy applies to.

Returns:

  • (String)


9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-glue/types.rb', line 9463

class DirectSchemaChangePolicy < Struct.new(
  :enable_update_catalog,
  :update_behavior,
  :table,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#enable_update_catalogBoolean

Whether to use the specified update behavior when the crawler finds a changed schema.

Returns:

  • (Boolean)


9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-glue/types.rb', line 9463

class DirectSchemaChangePolicy < Struct.new(
  :enable_update_catalog,
  :update_behavior,
  :table,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

Specifies the table in the database that the schema change policy applies to.

Returns:

  • (String)


9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-glue/types.rb', line 9463

class DirectSchemaChangePolicy < Struct.new(
  :enable_update_catalog,
  :update_behavior,
  :table,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#update_behaviorString

The update behavior when the crawler finds a changed schema.

Returns:

  • (String)


9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/aws-sdk-glue/types.rb', line 9463

class DirectSchemaChangePolicy < Struct.new(
  :enable_update_catalog,
  :update_behavior,
  :table,
  :database)
  SENSITIVE = []
  include Aws::Structure
end