Class: Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form.
-
#iterable_form_name ⇒ String
The name of the iterable form.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/aws-sdk-glue/types.rb', line 11516 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/aws-sdk-glue/types.rb', line 11516 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/aws-sdk-glue/types.rb', line 11516 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form. Required when
iterableFormName is specified.
11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/aws-sdk-glue/types.rb', line 11516 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form. When specified along with
itemIdentifier, the glossary terms are disassociated from an item
within the iterable form rather than the asset itself.
11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/aws-sdk-glue/types.rb', line 11516 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |