Class: Aws::Glue::Types::DisassociateGlossaryTermsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset.

Returns:

  • (String)


11545
11546
11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-glue/types.rb', line 11545

class DisassociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The remaining glossary terms associated with the asset.

Returns:

  • (Array<String>)


11545
11546
11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-glue/types.rb', line 11545

class DisassociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form, if applicable.

Returns:

  • (String)


11545
11546
11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-glue/types.rb', line 11545

class DisassociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form, if the disassociation targets an item.

Returns:

  • (String)


11545
11546
11547
11548
11549
11550
11551
11552
# File 'lib/aws-sdk-glue/types.rb', line 11545

class DisassociateGlossaryTermsResponse < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :glossary_terms)
  SENSITIVE = []
  include Aws::Structure
end