Class: Aws::Glue::Types::DistributionData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The distribution data for a statistic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bin_edgesArray<String>

The bin edge values for the distribution.

Returns:

  • (Array<String>)


11478
11479
11480
11481
11482
11483
11484
# File 'lib/aws-sdk-glue/types.rb', line 11478

class DistributionData < Struct.new(
  :bin_edges,
  :count,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#countArray<Integer>

The frequency count for each bin in the distribution.

Returns:

  • (Array<Integer>)


11478
11479
11480
11481
11482
11483
11484
# File 'lib/aws-sdk-glue/types.rb', line 11478

class DistributionData < Struct.new(
  :bin_edges,
  :count,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

The data type of the column for the distribution.

Returns:

  • (String)


11478
11479
11480
11481
11482
11483
11484
# File 'lib/aws-sdk-glue/types.rb', line 11478

class DistributionData < Struct.new(
  :bin_edges,
  :count,
  :data_type)
  SENSITIVE = []
  include Aws::Structure
end