Class: Aws::Glue::Types::DropDuplicates

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DropDuplicates data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  columns: [
    ["GenericLimitedString"],
  ],
}

Specifies a transform that removes rows of repeating data from a data set.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#columnsArray<Array<String>>

The name of the columns to be merged or removed if repeating.

Returns:

  • (Array<Array<String>>)


9601
9602
9603
9604
9605
9606
9607
# File 'lib/aws-sdk-glue/types.rb', line 9601

class DropDuplicates < Struct.new(
  :name,
  :inputs,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The data inputs identified by their node names.

Returns:

  • (Array<String>)


9601
9602
9603
9604
9605
9606
9607
# File 'lib/aws-sdk-glue/types.rb', line 9601

class DropDuplicates < Struct.new(
  :name,
  :inputs,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


9601
9602
9603
9604
9605
9606
9607
# File 'lib/aws-sdk-glue/types.rb', line 9601

class DropDuplicates < Struct.new(
  :name,
  :inputs,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end