Class: Aws::Glue::Types::DropFields
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DropFields
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DropFields data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
paths: [ # required
["EnclosedInStringProperty"],
],
}
Specifies a transform that chooses the data property keys that you want to drop.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
9653 9654 9655 9656 9657 9658 9659 |
# File 'lib/aws-sdk-glue/types.rb', line 9653 class DropFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
9653 9654 9655 9656 9657 9658 9659 |
# File 'lib/aws-sdk-glue/types.rb', line 9653 class DropFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
9653 9654 9655 9656 9657 9658 9659 |
# File 'lib/aws-sdk-glue/types.rb', line 9653 class DropFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |