Class: Aws::Glue::Types::DynamicTransform
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DynamicTransform
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass DynamicTransform data as a hash:
{
name: "EnclosedInStringProperty", # required
transform_name: "EnclosedInStringProperty", # required
inputs: ["NodeId"], # required
parameters: [
{
name: "EnclosedInStringProperty", # required
type: "str", # required, accepts str, int, float, complex, bool, list, null
validation_rule: "EnclosedInStringProperty",
validation_message: "EnclosedInStringProperty",
value: ["EnclosedInStringProperty"],
list_type: "str", # accepts str, int, float, complex, bool, list, null
is_optional: false,
},
],
function_name: "EnclosedInStringProperty", # required
path: "EnclosedInStringProperty", # required
version: "EnclosedInStringProperty",
}
Specifies the set of parameters needed to perform the dynamic transform.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
Specifies the name of the function of the dynamic transform.
-
#inputs ⇒ Array<String>
Specifies the inputs for the dynamic transform that are required.
-
#name ⇒ String
Specifies the name of the dynamic transform.
-
#parameters ⇒ Array<Types::TransformConfigParameter>
Specifies the parameters of the dynamic transform.
-
#path ⇒ String
Specifies the path of the dynamic transform source and config files.
-
#transform_name ⇒ String
Specifies the name of the dynamic transform as it appears in the Glue Studio visual editor.
-
#version ⇒ String
This field is not used and will be deprecated in future release.
Instance Attribute Details
#function_name ⇒ String
Specifies the name of the function of the dynamic transform.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
Specifies the inputs for the dynamic transform that are required.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies the name of the dynamic transform.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::TransformConfigParameter>
Specifies the parameters of the dynamic transform.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
Specifies the path of the dynamic transform source and config files.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#transform_name ⇒ String
Specifies the name of the dynamic transform as it appears in the Glue Studio visual editor.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
This field is not used and will be deprecated in future release.
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 |
# File 'lib/aws-sdk-glue/types.rb', line 9853 class DynamicTransform < Struct.new( :name, :transform_name, :inputs, :parameters, :function_name, :path, :version) SENSITIVE = [] include Aws::Structure end |