Class: Aws::Glue::Types::DynamoDBCatalogSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DynamoDBCatalogSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a DynamoDB data source in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Types::DDBELTCatalogAdditionalOptions
Specifies additional connection options for the DynamoDB data source.
-
#database ⇒ String
The name of the database to read from.
-
#name ⇒ String
The name of the data source.
-
#pitr_enabled ⇒ Boolean
Specifies whether Point-in-Time Recovery (PITR) is enabled for the DynamoDB table.
-
#table ⇒ String
The name of the table in the database to read from.
Instance Attribute Details
#additional_options ⇒ Types::DDBELTCatalogAdditionalOptions
Specifies additional connection options for the DynamoDB data source.
11796 11797 11798 11799 11800 11801 11802 11803 11804 |
# File 'lib/aws-sdk-glue/types.rb', line 11796 class DynamoDBCatalogSource < Struct.new( :name, :database, :table, :pitr_enabled, :additional_options) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to read from.
11796 11797 11798 11799 11800 11801 11802 11803 11804 |
# File 'lib/aws-sdk-glue/types.rb', line 11796 class DynamoDBCatalogSource < Struct.new( :name, :database, :table, :pitr_enabled, :additional_options) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data source.
11796 11797 11798 11799 11800 11801 11802 11803 11804 |
# File 'lib/aws-sdk-glue/types.rb', line 11796 class DynamoDBCatalogSource < Struct.new( :name, :database, :table, :pitr_enabled, :additional_options) SENSITIVE = [] include Aws::Structure end |
#pitr_enabled ⇒ Boolean
Specifies whether Point-in-Time Recovery (PITR) is enabled for the
DynamoDB table. When set to true, allows reading from a specific
point in time. The default value is false.
11796 11797 11798 11799 11800 11801 11802 11803 11804 |
# File 'lib/aws-sdk-glue/types.rb', line 11796 class DynamoDBCatalogSource < Struct.new( :name, :database, :table, :pitr_enabled, :additional_options) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table in the database to read from.
11796 11797 11798 11799 11800 11801 11802 11803 11804 |
# File 'lib/aws-sdk-glue/types.rb', line 11796 class DynamoDBCatalogSource < Struct.new( :name, :database, :table, :pitr_enabled, :additional_options) SENSITIVE = [] include Aws::Structure end |