Class: Aws::Glue::Types::Edge

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An edge represents a directed connection between two Glue components that are part of the workflow the edge belongs to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_idString

The unique of the node within the workflow where the edge ends.

Returns:

  • (String)


10218
10219
10220
10221
10222
10223
# File 'lib/aws-sdk-glue/types.rb', line 10218

class Edge < Struct.new(
  :source_id,
  :destination_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_idString

The unique of the node within the workflow where the edge starts.

Returns:

  • (String)


10218
10219
10220
10221
10222
10223
# File 'lib/aws-sdk-glue/types.rb', line 10218

class Edge < Struct.new(
  :source_id,
  :destination_id)
  SENSITIVE = []
  include Aws::Structure
end