Class: Aws::Glue::Types::EventBatchingCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::EventBatchingCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass EventBatchingCondition data as a hash:
{
batch_size: 1, # required
batch_window: 1,
}
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_size ⇒ Integer
Number of events that must be received from Amazon EventBridge before EventBridge event trigger fires.
-
#batch_window ⇒ Integer
Window of time in seconds after which EventBridge event trigger fires.
Instance Attribute Details
#batch_size ⇒ Integer
Number of events that must be received from Amazon EventBridge before EventBridge event trigger fires.
7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-glue/types.rb', line 7071 class EventBatchingCondition < Struct.new( :batch_size, :batch_window) SENSITIVE = [] include Aws::Structure end |
#batch_window ⇒ Integer
Window of time in seconds after which EventBridge event trigger fires. Window starts when first event is received.
7071 7072 7073 7074 7075 7076 |
# File 'lib/aws-sdk-glue/types.rb', line 7071 class EventBatchingCondition < Struct.new( :batch_size, :batch_window) SENSITIVE = [] include Aws::Structure end |