Class: Aws::Glue::Types::ExtractedParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Parameter extraction configuration that defines how to extract and map values from API responses to request parameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_valueString

The default value to use if the parameter cannot be extracted from the response.

Returns:

  • (String)


11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-glue/types.rb', line 11486

class ExtractedParameter < Struct.new(
  :key,
  :default_value,
  :property_location,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The parameter key name that will be used in subsequent requests.

Returns:

  • (String)


11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-glue/types.rb', line 11486

class ExtractedParameter < Struct.new(
  :key,
  :default_value,
  :property_location,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#property_locationString

Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.

Returns:

  • (String)


11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-glue/types.rb', line 11486

class ExtractedParameter < Struct.new(
  :key,
  :default_value,
  :property_location,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueTypes::ResponseExtractionMapping

The JSON path or extraction mapping that defines how to extract the parameter value from API responses.



11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-glue/types.rb', line 11486

class ExtractedParameter < Struct.new(
  :key,
  :default_value,
  :property_location,
  :value)
  SENSITIVE = []
  include Aws::Structure
end