Class: Aws::Glue::Types::FederatedDatabase
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::FederatedDatabase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A database that points to an entity outside the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to the external metastore.
-
#identifier ⇒ String
A unique identifier for the federated database.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to the external metastore.
8602 8603 8604 8605 8606 8607 |
# File 'lib/aws-sdk-glue/types.rb', line 8602 class FederatedDatabase < Struct.new( :identifier, :connection_name) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
A unique identifier for the federated database.
8602 8603 8604 8605 8606 8607 |
# File 'lib/aws-sdk-glue/types.rb', line 8602 class FederatedDatabase < Struct.new( :identifier, :connection_name) SENSITIVE = [] include Aws::Structure end |