Class: Aws::Glue::Types::Field

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The ‘Field` object has information about the different properties associated with a field in the connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_propertiesHash<String,String>

Optional map of keys which may be returned.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#field_nameString

A unique identifier for the field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#field_typeString

The type of data in the field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_createableBoolean

Indicates whether this field can be created as part of a destination write.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_default_on_createBoolean

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_filterableBoolean

Indicates whether this field can used in a filter clause (‘WHERE` clause) of a SQL statement when querying data.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_nullableBoolean

Indicates whether this field can be nullable or not.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_partitionableBoolean

Indicates whether a given field can be used in partitioning the query made to SaaS.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_primary_keyBoolean

Indicates whether this field can used as a primary key for the given entity.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_retrievableBoolean

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_updateableBoolean

Indicates whether this field can be updated as part of a destination write.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_upsertableBoolean

Indicates whether this field can be upserted as part of a destination write.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#labelString

A readable label used for the field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#native_data_typeString

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#parent_fieldString

A parent field name for a nested field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#supported_filter_operatorsArray<String>

Indicates the support filter operators for this field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#supported_valuesArray<String>

A list of supported values for the field.



11324
11325
11326
11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
# File 'lib/aws-sdk-glue/types.rb', line 11324

class Field < Struct.new(
  :field_name,
  :label,
  :description,
  :field_type,
  :is_primary_key,
  :is_nullable,
  :is_retrievable,
  :is_filterable,
  :is_partitionable,
  :is_createable,
  :is_updateable,
  :is_upsertable,
  :is_default_on_create,
  :supported_values,
  :supported_filter_operators,
  :parent_field,
  :native_data_type,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end