Class: Aws::Glue::Types::FieldDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a field in an entity schema for REST connector data sources, specifying the field name and data type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_data_typeString

The data type of the field.

Returns:

  • (String)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#filter_overridesTypes::FilterOverrides

Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.



12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#is_nullableBoolean

Indicates whether this field can contain null values.

Returns:

  • (Boolean)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#is_orderableBoolean

Indicates whether this field can be used for ordering results.

Returns:

  • (Boolean)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#is_partitionableBoolean

Indicates whether this field can be used for partitioning queries to the data source.

Returns:

  • (Boolean)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#is_queryableBoolean

Indicates whether this field can be used in filter predicates when querying data.

Returns:

  • (Boolean)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the field in the entity schema.

Returns:

  • (String)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#response_date_formatString

The format pattern for parsing date values from API responses. Required when the API uses a non-ISO-8601 format. Accepts Java DateTimeFormatter patterns (for example, EEE, d MMM yyyy HH:mm:ss Z), EPOCH_SECONDS for Unix epoch seconds, or EPOCH_MILLIS for Unix epoch milliseconds.

Returns:

  • (String)


12524
12525
12526
12527
12528
12529
12530
12531
12532
12533
12534
12535
# File 'lib/aws-sdk-glue/types.rb', line 12524

class FieldDefinition < Struct.new(
  :name,
  :field_data_type,
  :response_date_format,
  :is_partitionable,
  :is_nullable,
  :is_queryable,
  :is_orderable,
  :filter_overrides)
  SENSITIVE = []
  include Aws::Structure
end