Class: Aws::Glue::Types::FillMissingValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass FillMissingValues data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  imputed_path: "EnclosedInStringProperty", # required
  filled_path: "EnclosedInStringProperty",
}

Specifies a transform that locates records in the dataset that have missing values and adds a new field with a value determined by imputation. The input data set is used to train the machine learning model that determines what the missing value should be.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filled_pathString

A JSON path to a variable in the data structure for the dataset that is filled.

Returns:

  • (String)


10037
10038
10039
10040
10041
10042
10043
10044
# File 'lib/aws-sdk-glue/types.rb', line 10037

class FillMissingValues < Struct.new(
  :name,
  :inputs,
  :imputed_path,
  :filled_path)
  SENSITIVE = []
  include Aws::Structure
end

#imputed_pathString

A JSON path to a variable in the data structure for the dataset that is imputed.

Returns:

  • (String)


10037
10038
10039
10040
10041
10042
10043
10044
# File 'lib/aws-sdk-glue/types.rb', line 10037

class FillMissingValues < Struct.new(
  :name,
  :inputs,
  :imputed_path,
  :filled_path)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The data inputs identified by their node names.

Returns:

  • (Array<String>)


10037
10038
10039
10040
10041
10042
10043
10044
# File 'lib/aws-sdk-glue/types.rb', line 10037

class FillMissingValues < Struct.new(
  :name,
  :inputs,
  :imputed_path,
  :filled_path)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


10037
10038
10039
10040
10041
10042
10043
10044
# File 'lib/aws-sdk-glue/types.rb', line 10037

class FillMissingValues < Struct.new(
  :name,
  :inputs,
  :imputed_path,
  :filled_path)
  SENSITIVE = []
  include Aws::Structure
end