Class: Aws::Glue::Types::GetBlueprintRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetBlueprintRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetBlueprintRequest data as a hash:
{
name: "NameString", # required
include_blueprint: false,
include_parameter_spec: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include_blueprint ⇒ Boolean
Specifies whether or not to include the blueprint in the response.
-
#include_parameter_spec ⇒ Boolean
Specifies whether or not to include the parameter specification.
-
#name ⇒ String
The name of the blueprint.
Instance Attribute Details
#include_blueprint ⇒ Boolean
Specifies whether or not to include the blueprint in the response.
10159 10160 10161 10162 10163 10164 10165 |
# File 'lib/aws-sdk-glue/types.rb', line 10159 class GetBlueprintRequest < Struct.new( :name, :include_blueprint, :include_parameter_spec) SENSITIVE = [] include Aws::Structure end |
#include_parameter_spec ⇒ Boolean
Specifies whether or not to include the parameter specification.
10159 10160 10161 10162 10163 10164 10165 |
# File 'lib/aws-sdk-glue/types.rb', line 10159 class GetBlueprintRequest < Struct.new( :name, :include_blueprint, :include_parameter_spec) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the blueprint.
10159 10160 10161 10162 10163 10164 10165 |
# File 'lib/aws-sdk-glue/types.rb', line 10159 class GetBlueprintRequest < Struct.new( :name, :include_blueprint, :include_parameter_spec) SENSITIVE = [] include Aws::Structure end |