Class: Aws::Glue::Types::GetBlueprintRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetBlueprintRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetBlueprintRunRequest data as a hash:
{
blueprint_name: "OrchestrationNameString", # required
run_id: "IdString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprint_name ⇒ String
The name of the blueprint.
-
#run_id ⇒ String
The run ID for the blueprint run you want to retrieve.
Instance Attribute Details
#blueprint_name ⇒ String
The name of the blueprint.
10406 10407 10408 10409 10410 10411 |
# File 'lib/aws-sdk-glue/types.rb', line 10406 class GetBlueprintRunRequest < Struct.new( :blueprint_name, :run_id) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The run ID for the blueprint run you want to retrieve.
10406 10407 10408 10409 10410 10411 |
# File 'lib/aws-sdk-glue/types.rb', line 10406 class GetBlueprintRunRequest < Struct.new( :blueprint_name, :run_id) SENSITIVE = [] include Aws::Structure end |