Class: Aws::Glue::Types::GetCatalogRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCatalogRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
13278 13279 13280 13281 13282 |
# File 'lib/aws-sdk-glue/types.rb', line 13278 class GetCatalogRequest < Struct.new( :catalog_id) SENSITIVE = [] include Aws::Structure end |