Class: Aws::Glue::Types::GetCatalogsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#has_databasesBoolean

When true, the response only includes catalogs that can contain databases. Some catalogs are organizational containers that hold only other catalogs, not databases. When this parameter is set to true, those container-only catalogs are excluded, and only catalogs capable of containing databases are returned. Defaults to false.

Returns:

  • (Boolean)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end

#include_rootBoolean

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

Returns:

  • (Boolean)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of catalogs to return in one response.

Returns:

  • (Integer)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end

#parent_catalog_idString

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

Returns:

  • (String)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end

#recursiveBoolean

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

Returns:

  • (Boolean)


13340
13341
13342
13343
13344
13345
13346
13347
13348
13349
# File 'lib/aws-sdk-glue/types.rb', line 13340

class GetCatalogsRequest < Struct.new(
  :parent_catalog_id,
  :next_token,
  :max_results,
  :recursive,
  :include_root,
  :has_databases)
  SENSITIVE = []
  include Aws::Structure
end