Class: Aws::Glue::Types::GetCatalogsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_listArray<Types::Catalog>

An array of Catalog objects. A list of Catalog objects from the specified parent catalog.

Returns:



11790
11791
11792
11793
11794
11795
# File 'lib/aws-sdk-glue/types.rb', line 11790

class GetCatalogsResponse < Struct.new(
  :catalog_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.

Returns:

  • (String)


11790
11791
11792
11793
11794
11795
# File 'lib/aws-sdk-glue/types.rb', line 11790

class GetCatalogsResponse < Struct.new(
  :catalog_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end