Class: Aws::Glue::Types::GetCrawlersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCrawlersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetCrawlersRequest data as a hash:
{
max_results: 1,
next_token: "Token",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The number of crawlers to return on each call.
-
#next_token ⇒ String
A continuation token, if this is a continuation request.
Instance Attribute Details
#max_results ⇒ Integer
The number of crawlers to return on each call.
11118 11119 11120 11121 11122 11123 |
# File 'lib/aws-sdk-glue/types.rb', line 11118 class GetCrawlersRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation request.
11118 11119 11120 11121 11122 11123 |
# File 'lib/aws-sdk-glue/types.rb', line 11118 class GetCrawlersRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |