Class: Aws::Glue::Types::GetCustomEntityTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCustomEntityTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetCustomEntityTypeRequest data as a hash:
{
name: "NameString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the custom pattern that you want to retrieve.
Instance Attribute Details
#name ⇒ String
The name of the custom pattern that you want to retrieve.
11040 11041 11042 11043 11044 |
# File 'lib/aws-sdk-glue/types.rb', line 11040 class GetCustomEntityTypeRequest < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |