Class: Aws::Glue::Types::GetDashboardUrlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDashboardUrlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#request_origin ⇒ String
The origin of the request.
-
#resource_id ⇒ String
The unique identifier of the resource for which to retrieve the dashboard URL.
-
#resource_type ⇒ String
The type of the resource.
Instance Attribute Details
#request_origin ⇒ String
The origin of the request.
13340 13341 13342 13343 13344 13345 13346 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetDashboardUrlRequest < Struct.new( :resource_id, :resource_type, :request_origin) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier of the resource for which to retrieve the dashboard URL.
13340 13341 13342 13343 13344 13345 13346 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetDashboardUrlRequest < Struct.new( :resource_id, :resource_type, :request_origin) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource. Valid values are ‘SESSION` and `JOB`.
13340 13341 13342 13343 13344 13345 13346 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetDashboardUrlRequest < Struct.new( :resource_id, :resource_type, :request_origin) SENSITIVE = [] include Aws::Structure end |