Class: Aws::Glue::Types::GetDataCatalogEncryptionSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDataCatalogEncryptionSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog to retrieve the security configuration for.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog to retrieve the security configuration for. If none is provided, the Amazon Web Services account ID is used by default.
13932 13933 13934 13935 13936 |
# File 'lib/aws-sdk-glue/types.rb', line 13932 class GetDataCatalogEncryptionSettingsRequest < Struct.new( :catalog_id) SENSITIVE = [] include Aws::Structure end |