Class: Aws::Glue::Types::GetDatabasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDatabasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass GetDatabasesRequest data as a hash:
{
catalog_id: "CatalogIdString",
next_token: "Token",
max_results: 1,
resource_share_type: "FOREIGN", # accepts FOREIGN, ALL
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog from which to retrieve `Databases`.
-
#max_results ⇒ Integer
The maximum number of databases to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#resource_share_type ⇒ String
Allows you to specify that you want to list the databases shared with your account.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog from which to retrieve `Databases`. If none is provided, the Amazon Web Services account ID is used by default.
7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-glue/types.rb', line 7810 class GetDatabasesRequest < Struct.new( :catalog_id, :next_token, :max_results, :resource_share_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of databases to return in one response.
7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-glue/types.rb', line 7810 class GetDatabasesRequest < Struct.new( :catalog_id, :next_token, :max_results, :resource_share_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-glue/types.rb', line 7810 class GetDatabasesRequest < Struct.new( :catalog_id, :next_token, :max_results, :resource_share_type) SENSITIVE = [] include Aws::Structure end |
#resource_share_type ⇒ String
Allows you to specify that you want to list the databases shared with your account. The allowable values are `FOREIGN` or `ALL`.
-
If set to `FOREIGN`, will list the databases shared with your account.
-
If set to `ALL`, will list the databases shared with your account, as well as the databases in yor local account.
7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-glue/types.rb', line 7810 class GetDatabasesRequest < Struct.new( :catalog_id, :next_token, :max_results, :resource_share_type) SENSITIVE = [] include Aws::Structure end |