Class: Aws::Glue::Types::GetDatabasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDatabasesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_list ⇒ Array<Types::Database>
A list of `Database` objects from the specified catalog.
-
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Instance Attribute Details
#database_list ⇒ Array<Types::Database>
A list of `Database` objects from the specified catalog.
11159 11160 11161 11162 11163 11164 |
# File 'lib/aws-sdk-glue/types.rb', line 11159 class GetDatabasesResponse < Struct.new( :database_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
11159 11160 11161 11162 11163 11164 |
# File 'lib/aws-sdk-glue/types.rb', line 11159 class GetDatabasesResponse < Struct.new( :database_list, :next_token) SENSITIVE = [] include Aws::Structure end |