Class: Aws::Glue::Types::GetEntityRecordsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection that contains the connection type credentials.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#connection_optionsHash<String,String>

Connector options that are required to query the data.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#data_store_api_versionString

The API version of the SaaS connector.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

Name of the entity that we want to query the preview data from the given connection type.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#filter_predicateString

A filter predicate that you can apply in the query request.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

Limits the number of records fetched with the request.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, included if this is a continuation call.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#order_byString

A parameter that orders the response preview data.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end

#selected_fieldsArray<String>

List of fields that we want to fetch as part of preview data.



13444
13445
13446
13447
13448
13449
13450
13451
13452
13453
13454
13455
13456
13457
# File 'lib/aws-sdk-glue/types.rb', line 13444

class GetEntityRecordsRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :entity_name,
  :next_token,
  :data_store_api_version,
  :connection_options,
  :filter_predicate,
  :limit,
  :order_by,
  :selected_fields)
  SENSITIVE = []
  include Aws::Structure
end