Class: Aws::Glue::Types::GetGlossaryTermRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetGlossaryTermRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The unique identifier of the glossary term to retrieve.
Instance Attribute Details
#identifier ⇒ String
The unique identifier of the glossary term to retrieve.
14726 14727 14728 14729 14730 |
# File 'lib/aws-sdk-glue/types.rb', line 14726 class GetGlossaryTermRequest < Struct.new( :identifier) SENSITIVE = [] include Aws::Structure end |