Class: Aws::Glue::Types::GetIntegrationTablePropertiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetIntegrationTablePropertiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties.
-
#table_name ⇒ String
The name of the table to be replicated.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
14924 14925 14926 14927 14928 14929 |
# File 'lib/aws-sdk-glue/types.rb', line 14924 class GetIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table to be replicated.
14924 14925 14926 14927 14928 14929 |
# File 'lib/aws-sdk-glue/types.rb', line 14924 class GetIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name) SENSITIVE = [] include Aws::Structure end |