Class: Aws::Glue::Types::GetJobRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetJobRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_name ⇒ String
Name of the job definition being run.
-
#predecessors_included ⇒ Boolean
True if a list of predecessor runs should be returned.
-
#run_id ⇒ String
The ID of the job run.
Instance Attribute Details
#job_name ⇒ String
Name of the job definition being run.
10644 10645 10646 10647 10648 10649 10650 |
# File 'lib/aws-sdk-glue/types.rb', line 10644 class GetJobRunRequest < Struct.new( :job_name, :run_id, :predecessors_included) SENSITIVE = [] include Aws::Structure end |
#predecessors_included ⇒ Boolean
True if a list of predecessor runs should be returned.
10644 10645 10646 10647 10648 10649 10650 |
# File 'lib/aws-sdk-glue/types.rb', line 10644 class GetJobRunRequest < Struct.new( :job_name, :run_id, :predecessors_included) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The ID of the job run.
10644 10645 10646 10647 10648 10649 10650 |
# File 'lib/aws-sdk-glue/types.rb', line 10644 class GetJobRunRequest < Struct.new( :job_name, :run_id, :predecessors_included) SENSITIVE = [] include Aws::Structure end |