Class: Aws::Glue::Types::GetMLTaskRunResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_onTime

The date and time when this task run was completed.

Returns:

  • (Time)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#error_stringString

The error strings that are associated with the task run.

Returns:

  • (String)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#execution_timeInteger

The amount of time (in seconds) that the task run consumed resources.

Returns:

  • (Integer)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The date and time when this task run was last modified.

Returns:

  • (Time)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The names of the log groups that are associated with the task run.

Returns:

  • (String)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesTypes::TaskRunProperties

The list of properties that are associated with the task run.



8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#started_onTime

The date and time when this task run started.

Returns:

  • (Time)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status for this task run.

Returns:

  • (String)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#task_run_idString

The unique run identifier associated with this run.

Returns:

  • (String)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end

#transform_idString

The unique identifier of the task run.

Returns:

  • (String)


8953
8954
8955
8956
8957
8958
8959
8960
8961
8962
8963
8964
8965
8966
# File 'lib/aws-sdk-glue/types.rb', line 8953

class GetMLTaskRunResponse < Struct.new(
  :transform_id,
  :task_run_id,
  :status,
  :log_group_name,
  :properties,
  :error_string,
  :started_on,
  :last_modified_on,
  :completed_on,
  :execution_time)
  SENSITIVE = []
  include Aws::Structure
end