Class: Aws::Glue::Types::GetMLTransformRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetMLTransformRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
Instance Attribute Details
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
10407 10408 10409 10410 10411 |
# File 'lib/aws-sdk-glue/types.rb', line 10407 class GetMLTransformRequest < Struct.new( :transform_id) SENSITIVE = [] include Aws::Structure end |