Class: Aws::Glue::Types::GetPlanRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_plan_options_mapHash<String,String>

A map to hold additional optional key-value parameters.

Currently, these key-value pairs are supported:

  • inferSchema  —  Specifies whether to set inferSchema to true or false for the default script generated by an Glue job. For example, to set inferSchema to true, pass the following key value pair:

    --additional-plan-options-map '{"inferSchema":"true"}'

Returns:

  • (Hash<String,String>)


15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end

#languageString

The programming language of the code to perform the mapping.

Returns:

  • (String)


15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The parameters for the mapping.

Returns:



15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end

#mappingArray<Types::MappingEntry>

The list of mappings from a source table to target tables.

Returns:



15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end

#sinksArray<Types::CatalogEntry>

The target tables.

Returns:



15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end

#sourceTypes::CatalogEntry

The source table.

Returns:



15827
15828
15829
15830
15831
15832
15833
15834
15835
15836
# File 'lib/aws-sdk-glue/types.rb', line 15827

class GetPlanRequest < Struct.new(
  :mapping,
  :source,
  :sinks,
  :location,
  :language,
  :additional_plan_options_map)
  SENSITIVE = []
  include Aws::Structure
end