Class: Aws::Glue::Types::GetSchemaVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetSchemaVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_time ⇒ String
The date and time the schema version was created.
-
#data_format ⇒ String
The data format of the schema definition.
-
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
-
#schema_definition ⇒ String
The schema definition for the schema ID.
-
#schema_version_id ⇒ String
The `SchemaVersionId` of the schema version.
-
#status ⇒ String
The status of the schema version.
-
#version_number ⇒ Integer
The version number of the schema.
Instance Attribute Details
#created_time ⇒ String
The date and time the schema version was created.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#data_format ⇒ String
The data format of the schema definition. Currently `AVRO`, `JSON` and `PROTOBUF` are supported.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#schema_definition ⇒ String
The schema definition for the schema ID.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#schema_version_id ⇒ String
The `SchemaVersionId` of the schema version.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the schema version.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version number of the schema.
12772 12773 12774 12775 12776 12777 12778 12779 12780 12781 12782 |
# File 'lib/aws-sdk-glue/types.rb', line 12772 class GetSchemaVersionResponse < Struct.new( :schema_version_id, :schema_definition, :data_format, :schema_arn, :version_number, :status, :created_time) SENSITIVE = [] include Aws::Structure end |