Class: Aws::Glue::Types::GetTableVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A continuation token, if the list of available versions does not include the last one.

Returns:

  • (String)


13192
13193
13194
13195
13196
13197
# File 'lib/aws-sdk-glue/types.rb', line 13192

class GetTableVersionsResponse < Struct.new(
  :table_versions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#table_versionsArray<Types::TableVersion>

A list of strings identifying available versions of the specified table.

Returns:



13192
13193
13194
13195
13196
13197
# File 'lib/aws-sdk-glue/types.rb', line 13192

class GetTableVersionsResponse < Struct.new(
  :table_versions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end