Class: Aws::Glue::Types::GetTablesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTablesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A continuation token, present if the current list segment is not the last.
-
#table_list ⇒ Array<Types::Table>
A list of the requested `Table` objects.
Instance Attribute Details
#next_token ⇒ String
A continuation token, present if the current list segment is not the last.
10341 10342 10343 10344 10345 10346 |
# File 'lib/aws-sdk-glue/types.rb', line 10341 class GetTablesResponse < Struct.new( :table_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#table_list ⇒ Array<Types::Table>
A list of the requested `Table` objects.
10341 10342 10343 10344 10345 10346 |
# File 'lib/aws-sdk-glue/types.rb', line 10341 class GetTablesResponse < Struct.new( :table_list, :next_token) SENSITIVE = [] include Aws::Structure end |