Class: Aws::Glue::Types::GetUnfilteredPartitionMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUnfilteredPartitionMetadataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing Lake Formation audit context information.
-
#catalog_id ⇒ String
The catalog ID where the partition resides.
-
#database_name ⇒ String
(Required) Specifies the name of a database that contains the partition.
-
#partition_values ⇒ Array<String>
(Required) A list of partition key values.
-
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue.
-
#region ⇒ String
Specified only if the base tables belong to a different Amazon Web Services Region.
-
#supported_permission_types ⇒ Array<String>
(Required) A list of supported permission types.
-
#table_name ⇒ String
(Required) Specifies the name of a table that contains the partition.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing Lake Formation audit context information.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The catalog ID where the partition resides.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
(Required) Specifies the name of a database that contains the partition.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
(Required) A list of partition key values.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request’s authorization context.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
Specified only if the base tables belong to a different Amazon Web Services Region.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#supported_permission_types ⇒ Array<String>
(Required) A list of supported permission types.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
(Required) Specifies the name of a table that contains the partition.
15041 15042 15043 15044 15045 15046 15047 15048 15049 15050 15051 15052 |
# File 'lib/aws-sdk-glue/types.rb', line 15041 class GetUnfilteredPartitionMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :partition_values, :audit_context, :supported_permission_types, :query_session_context) SENSITIVE = [] include Aws::Structure end |