Class: Aws::Glue::Types::GetUnfilteredPartitionsMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUnfilteredPartitionsMetadataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing Lake Formation audit context information.
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#expression ⇒ String
An expression that filters the partitions to be returned.
-
#max_results ⇒ Integer
The maximum number of partitions to return in a single response.
-
#next_token ⇒ String
A continuation token, if this is not the first call to retrieve these partitions.
-
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue.
-
#region ⇒ String
Specified only if the base tables belong to a different Amazon Web Services Region.
-
#segment ⇒ Types::Segment
The segment of the table’s partitions to scan in this request.
-
#supported_permission_types ⇒ Array<String>
A list of supported permission types.
-
#table_name ⇒ String
The name of the table that contains the partition.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing Lake Formation audit context information.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is provided, the AWS account ID is used by default.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ String
An expression that filters the partitions to be returned.
The expression uses SQL syntax similar to the SQL WHERE filter clause. The SQL statement parser [JSQLParser] parses the expression.
Operators: The following are the operators that you can use in the Expression API call:
: Checks whether the values of the two operands are equal; if yes,
then the condition becomes true.
Example: Assume 'variable a' holds 10 and 'variable b' holds
20.
(a = b) is not true.
< >
: Checks whether the values of two operands are equal; if the values
are not equal, then the condition becomes true.
Example: (a < > b) is true.
>
: Checks whether the value of the left operand is greater than the
value of the right operand; if yes, then the condition becomes
true.
Example: (a > b) is not true.
<
: Checks whether the value of the left operand is less than the
value of the right operand; if yes, then the condition becomes
true.
Example: (a < b) is true.
>=
: Checks whether the value of the left operand is greater than or
equal to the value of the right operand; if yes, then the
condition becomes true.
Example: (a >= b) is not true.
<=
: Checks whether the value of the left operand is less than or equal
to the value of the right operand; if yes, then the condition
becomes true.
Example: (a <= b) is true.
AND, OR, IN, BETWEEN, LIKE, NOT, IS NULL
: Logical operators.
*Supported Partition Key Types*: The following are the supported partition keys.
-
string -
date -
timestamp -
int -
bigint -
long -
tinyint -
smallint -
decimal
If an type is encountered that is not valid, an exception is thrown.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of partitions to return in a single response.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is not the first call to retrieve these partitions.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request’s authorization context.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
Specified only if the base tables belong to a different Amazon Web Services Region.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#segment ⇒ Types::Segment
The segment of the table’s partitions to scan in this request.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#supported_permission_types ⇒ Array<String>
A list of supported permission types.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that contains the partition.
15640 15641 15642 15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-glue/types.rb', line 15640 class GetUnfilteredPartitionsMetadataRequest < Struct.new( :region, :catalog_id, :database_name, :table_name, :expression, :audit_context, :supported_permission_types, :next_token, :segment, :max_results, :query_session_context) SENSITIVE = [] include Aws::Structure end |