Class: Aws::Glue::Types::GetUnfilteredTableMetadataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audit_contextTypes::AuditContext

A structure containing Lake Formation audit context information.

Returns:



15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#catalog_idString

The catalog ID where the table resides.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

(Required) Specifies the name of a database that contains the table.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

(Required) Specifies the name of a table for which you are requesting metadata.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#parent_resource_arnString

The resource ARN of the view.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsArray<String>

The Lake Formation data permissions of the caller on the table. Used to authorize the call when no view context is found.

Returns:

  • (Array<String>)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#query_session_contextTypes::QuerySessionContext

A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request’s authorization context.



15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

Specified only if the base tables belong to a different Amazon Web Services Region.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#root_resource_arnString

The resource ARN of the root view in a chain of nested views.

Returns:

  • (String)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#supported_dialectTypes::SupportedDialect

A structure specifying the dialect and dialect version used by the query engine.



15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end

#supported_permission_typesArray<String>

Indicates the level of filtering a third-party analytical engine is capable of enforcing when calling the GetUnfilteredTableMetadata API operation. Accepted values are:

  • COLUMN_PERMISSION - Column permissions ensure that users can access only specific columns in the table. If there are particular columns contain sensitive data, data lake administrators can define column filters that exclude access to specific columns.

  • CELL_FILTER_PERMISSION - Cell-level filtering combines column filtering (include or exclude columns) and row filter expressions to restrict access to individual elements in the table.

  • NESTED_PERMISSION - Nested permissions combines cell-level filtering and nested column filtering to restrict access to columns and/or nested columns in specific rows based on row filter expressions.

  • NESTED_CELL_PERMISSION - Nested cell permissions combines nested permission with nested cell-level filtering. This allows different subsets of nested columns to be restricted based on an array of row filter expressions.

Note: Each of these permission types follows a hierarchical order where each subsequent permission type includes all permission of the previous type.

Important: If you provide a supported permission type that doesn’t match the user’s level of permissions on the table, then Lake Formation raises an exception. For example, if the third-party engine calling the GetUnfilteredTableMetadata operation can enforce only column-level filtering, and the user has nested cell filtering applied on the table, Lake Formation throws an exception, and will not return unfiltered table metadata and data access credentials.

Returns:

  • (Array<String>)


15761
15762
15763
15764
15765
15766
15767
15768
15769
15770
15771
15772
15773
15774
15775
# File 'lib/aws-sdk-glue/types.rb', line 15761

class GetUnfilteredTableMetadataRequest < Struct.new(
  :region,
  :catalog_id,
  :database_name,
  :name,
  :audit_context,
  :supported_permission_types,
  :parent_resource_arn,
  :root_resource_arn,
  :supported_dialect,
  :permissions,
  :query_session_context)
  SENSITIVE = []
  include Aws::Structure
end