Class: Aws::Glue::Types::GetWorkflowRunPropertiesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetWorkflowRunPropertiesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#run_properties ⇒ Hash<String,String>
The workflow run properties which were set during the specified run.
Instance Attribute Details
#run_properties ⇒ Hash<String,String>
The workflow run properties which were set during the specified run.
17459 17460 17461 17462 17463 |
# File 'lib/aws-sdk-glue/types.rb', line 17459 class GetWorkflowRunPropertiesResponse < Struct.new( :run_properties) SENSITIVE = [] include Aws::Structure end |