Class: Aws::Glue::Types::GetWorkflowRunsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_graphBoolean

Specifies whether to include the workflow graph in response or not.

Returns:

  • (Boolean)


17390
17391
17392
17393
17394
17395
17396
17397
# File 'lib/aws-sdk-glue/types.rb', line 17390

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of workflow runs to be included in the response.

Returns:

  • (Integer)


17390
17391
17392
17393
17394
17395
17396
17397
# File 'lib/aws-sdk-glue/types.rb', line 17390

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the workflow whose metadata of runs should be returned.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
# File 'lib/aws-sdk-glue/types.rb', line 17390

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The maximum size of the response.

Returns:

  • (String)


17390
17391
17392
17393
17394
17395
17396
17397
# File 'lib/aws-sdk-glue/types.rb', line 17390

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end