Class: Aws::Glue::Types::GlueSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass GlueSchema data as a hash:

{
  columns: [
    {
      name: "GlueStudioColumnNameString", # required
      type: "ColumnTypeString",
    },
  ],
}

Specifies a user-defined schema when a schema cannot be determined by AWS Glue.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#columnsArray<Types::GlueStudioSchemaColumn>

Specifies the column definitions that make up a Glue schema.

Returns:



13958
13959
13960
13961
13962
# File 'lib/aws-sdk-glue/types.rb', line 13958

class GlueSchema < Struct.new(
  :columns)
  SENSITIVE = []
  include Aws::Structure
end