Class: Aws::Glue::Types::GlueStudioSchemaColumn

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass GlueStudioSchemaColumn data as a hash:

{
  name: "GlueStudioColumnNameString", # required
  type: "ColumnTypeString",
}

Specifies a single column in a Glue schema definition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the column in the Glue Studio schema.

Returns:

  • (String)


13984
13985
13986
13987
13988
13989
# File 'lib/aws-sdk-glue/types.rb', line 13984

class GlueStudioSchemaColumn < Struct.new(
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The hive type for this column in the Glue Studio schema.

Returns:

  • (String)


13984
13985
13986
13987
13988
13989
# File 'lib/aws-sdk-glue/types.rb', line 13984

class GlueStudioSchemaColumn < Struct.new(
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end