Class: Aws::Glue::Types::IcebergEncryptedKey
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergEncryptedKey
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Encryption key structure used for Iceberg table encryption. Contains the key ID, encrypted key metadata, optional reference to the encrypting key, and additional properties for the table’s encryption scheme.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encrypted_by_id ⇒ String
Optional ID of the key used to encrypt or wrap the key metadata in Iceberg table encryption.
-
#encrypted_key_metadata ⇒ String
Encrypted key and metadata, base64 encoded.
-
#key_id ⇒ String
Unique identifier of the encryption key used for Iceberg table encryption.
-
#properties ⇒ Hash<String,String>
A string to string map of additional metadata used by the table’s encryption scheme.
Instance Attribute Details
#encrypted_by_id ⇒ String
Optional ID of the key used to encrypt or wrap the key metadata in Iceberg table encryption. This field references another encryption key that was used to encrypt the current key’s metadata.
16606 16607 16608 16609 16610 16611 16612 16613 |
# File 'lib/aws-sdk-glue/types.rb', line 16606 class IcebergEncryptedKey < Struct.new( :key_id, :encrypted_key_metadata, :encrypted_by_id, :properties) SENSITIVE = [] include Aws::Structure end |
#encrypted_key_metadata ⇒ String
Encrypted key and metadata, base64 encoded. The format of encrypted key metadata is determined by the table’s encryption scheme and can be a wrapped format specific to the table’s KMS provider.
16606 16607 16608 16609 16610 16611 16612 16613 |
# File 'lib/aws-sdk-glue/types.rb', line 16606 class IcebergEncryptedKey < Struct.new( :key_id, :encrypted_key_metadata, :encrypted_by_id, :properties) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
Unique identifier of the encryption key used for Iceberg table encryption. This ID is used to reference the key in table metadata and track which key was used to encrypt specific data.
16606 16607 16608 16609 16610 16611 16612 16613 |
# File 'lib/aws-sdk-glue/types.rb', line 16606 class IcebergEncryptedKey < Struct.new( :key_id, :encrypted_key_metadata, :encrypted_by_id, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,String>
A string to string map of additional metadata used by the table’s encryption scheme. These properties provide additional context and configuration for the encryption key implementation.
16606 16607 16608 16609 16610 16611 16612 16613 |
# File 'lib/aws-sdk-glue/types.rb', line 16606 class IcebergEncryptedKey < Struct.new( :key_id, :encrypted_key_metadata, :encrypted_by_id, :properties) SENSITIVE = [] include Aws::Structure end |