Class: Aws::Glue::Types::IcebergOptimizationProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergOptimizationProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that specifies Iceberg table optimization properties for the catalog, including configurations for compaction, retention, and orphan file deletion operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compaction ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
-
#orphan_file_deletion ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
-
#retention ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that will be assumed to perform Iceberg table optimization operations.
Instance Attribute Details
#compaction ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
17980 17981 17982 17983 17984 17985 17986 17987 |
# File 'lib/aws-sdk-glue/types.rb', line 17980 class IcebergOptimizationProperties < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
17980 17981 17982 17983 17984 17985 17986 17987 |
# File 'lib/aws-sdk-glue/types.rb', line 17980 class IcebergOptimizationProperties < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
17980 17981 17982 17983 17984 17985 17986 17987 |
# File 'lib/aws-sdk-glue/types.rb', line 17980 class IcebergOptimizationProperties < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that will be assumed to perform Iceberg table optimization operations.
17980 17981 17982 17983 17984 17985 17986 17987 |
# File 'lib/aws-sdk-glue/types.rb', line 17980 class IcebergOptimizationProperties < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion) SENSITIVE = [] include Aws::Structure end |