Class: Aws::Glue::Types::IcebergPartitionSpec

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines the partitioning specification for an Iceberg table, determining how table data will be organized and partitioned for optimal query performance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::IcebergPartitionField>

The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.

Returns:



16394
16395
16396
16397
16398
16399
# File 'lib/aws-sdk-glue/types.rb', line 16394

class IcebergPartitionSpec < Struct.new(
  :fields,
  :spec_id)
  SENSITIVE = []
  include Aws::Structure
end

#spec_idInteger

The unique identifier for this partition specification within the Iceberg table’s metadata history.

Returns:

  • (Integer)


16394
16395
16396
16397
16398
16399
# File 'lib/aws-sdk-glue/types.rb', line 16394

class IcebergPartitionSpec < Struct.new(
  :fields,
  :spec_id)
  SENSITIVE = []
  include Aws::Structure
end