Class: Aws::Glue::Types::IcebergRetentionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergRetentionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The configuration for an Iceberg snapshot retention optimizer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clean_expired_files ⇒ Boolean
If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.
-
#number_of_snapshots_to_retain ⇒ Integer
The number of Iceberg snapshots to retain within the retention period.
-
#run_rate_in_hours ⇒ Integer
The interval in hours between retention job runs.
-
#snapshot_retention_period_in_days ⇒ Integer
The number of days to retain the Iceberg snapshots.
Instance Attribute Details
#clean_expired_files ⇒ Boolean
If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.
17991 17992 17993 17994 17995 17996 17997 17998 |
# File 'lib/aws-sdk-glue/types.rb', line 17991 class IcebergRetentionConfiguration < Struct.new( :snapshot_retention_period_in_days, :number_of_snapshots_to_retain, :clean_expired_files, :run_rate_in_hours) SENSITIVE = [] include Aws::Structure end |
#number_of_snapshots_to_retain ⇒ Integer
The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.
17991 17992 17993 17994 17995 17996 17997 17998 |
# File 'lib/aws-sdk-glue/types.rb', line 17991 class IcebergRetentionConfiguration < Struct.new( :snapshot_retention_period_in_days, :number_of_snapshots_to_retain, :clean_expired_files, :run_rate_in_hours) SENSITIVE = [] include Aws::Structure end |
#run_rate_in_hours ⇒ Integer
The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.
17991 17992 17993 17994 17995 17996 17997 17998 |
# File 'lib/aws-sdk-glue/types.rb', line 17991 class IcebergRetentionConfiguration < Struct.new( :snapshot_retention_period_in_days, :number_of_snapshots_to_retain, :clean_expired_files, :run_rate_in_hours) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_period_in_days ⇒ Integer
The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.
17991 17992 17993 17994 17995 17996 17997 17998 |
# File 'lib/aws-sdk-glue/types.rb', line 17991 class IcebergRetentionConfiguration < Struct.new( :snapshot_retention_period_in_days, :number_of_snapshots_to_retain, :clean_expired_files, :run_rate_in_hours) SENSITIVE = [] include Aws::Structure end |