Class: Aws::Glue::Types::IcebergSortField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a single field within an Iceberg sort order specification, including the source field, transformation, sort direction, and null value ordering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#directionString

The sort direction for this field, either ascending or descending.

Returns:

  • (String)


16507
16508
16509
16510
16511
16512
16513
16514
# File 'lib/aws-sdk-glue/types.rb', line 16507

class IcebergSortField < Struct.new(
  :source_id,
  :transform,
  :direction,
  :null_order)
  SENSITIVE = []
  include Aws::Structure
end

#null_orderString

The ordering behavior for null values in this field, specifying whether nulls should appear first or last in the sort order.

Returns:

  • (String)


16507
16508
16509
16510
16511
16512
16513
16514
# File 'lib/aws-sdk-glue/types.rb', line 16507

class IcebergSortField < Struct.new(
  :source_id,
  :transform,
  :direction,
  :null_order)
  SENSITIVE = []
  include Aws::Structure
end

#source_idInteger

The identifier of the source field from the table schema that this sort field is based on.

Returns:

  • (Integer)


16507
16508
16509
16510
16511
16512
16513
16514
# File 'lib/aws-sdk-glue/types.rb', line 16507

class IcebergSortField < Struct.new(
  :source_id,
  :transform,
  :direction,
  :null_order)
  SENSITIVE = []
  include Aws::Structure
end

#transformString

The transformation function applied to the source field before sorting, such as identity, bucket, or truncate.

Returns:

  • (String)


16507
16508
16509
16510
16511
16512
16513
16514
# File 'lib/aws-sdk-glue/types.rb', line 16507

class IcebergSortField < Struct.new(
  :source_id,
  :transform,
  :direction,
  :null_order)
  SENSITIVE = []
  include Aws::Structure
end