Class: Aws::Glue::Types::IntegrationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Properties associated with the integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#continuous_syncBoolean

Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.

Returns:

  • (Boolean)


17461
17462
17463
17464
17465
17466
17467
# File 'lib/aws-sdk-glue/types.rb', line 17461

class IntegrationConfig < Struct.new(
  :refresh_interval,
  :source_properties,
  :continuous_sync)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_intervalString

Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).

Returns:

  • (String)


17461
17462
17463
17464
17465
17466
17467
# File 'lib/aws-sdk-glue/types.rb', line 17461

class IntegrationConfig < Struct.new(
  :refresh_interval,
  :source_properties,
  :continuous_sync)
  SENSITIVE = []
  include Aws::Structure
end

#source_propertiesHash<String,String>

A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.

Returns:

  • (Hash<String,String>)


17461
17462
17463
17464
17465
17466
17467
# File 'lib/aws-sdk-glue/types.rb', line 17461

class IntegrationConfig < Struct.new(
  :refresh_interval,
  :source_properties,
  :continuous_sync)
  SENSITIVE = []
  include Aws::Structure
end