Class: Aws::Glue::Types::IntegrationTableProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The properties of a single integration table, including the resource ARN, the table name, and the source or target table configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The connection ARN of the source, or the database ARN of the target.

Returns:

  • (String)


19191
19192
19193
19194
19195
19196
19197
19198
# File 'lib/aws-sdk-glue/types.rb', line 19191

class IntegrationTableProperties < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_configTypes::SourceTableConfig

A structure for the source table configuration.



19191
19192
19193
19194
19195
19196
19197
19198
# File 'lib/aws-sdk-glue/types.rb', line 19191

class IntegrationTableProperties < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the source table to be replicated.

Returns:

  • (String)


19191
19192
19193
19194
19195
19196
19197
19198
# File 'lib/aws-sdk-glue/types.rb', line 19191

class IntegrationTableProperties < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#target_table_configTypes::TargetTableConfig

A structure for the target table configuration.



19191
19192
19193
19194
19195
19196
19197
19198
# File 'lib/aws-sdk-glue/types.rb', line 19191

class IntegrationTableProperties < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end