Class: Aws::Glue::Types::IterableFormItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A full iterable form item with its forms.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachmentsHash<String,Types::AssetFormEntry>

Additional attachments on the item for more context, keyed by attachment name.

Returns:



18694
18695
18696
18697
18698
18699
18700
18701
18702
# File 'lib/aws-sdk-glue/types.rb', line 18694

class IterableFormItem < Struct.new(
  :item_id,
  :item_name,
  :glossary_terms,
  :forms,
  :attachments)
  SENSITIVE = []
  include Aws::Structure
end

#formsHash<String,Types::AssetFormEntry>

The forms on the item, keyed by form name.

Returns:



18694
18695
18696
18697
18698
18699
18700
18701
18702
# File 'lib/aws-sdk-glue/types.rb', line 18694

class IterableFormItem < Struct.new(
  :item_id,
  :item_name,
  :glossary_terms,
  :forms,
  :attachments)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The identifiers of the glossary terms associated with the item.

Returns:

  • (Array<String>)


18694
18695
18696
18697
18698
18699
18700
18701
18702
# File 'lib/aws-sdk-glue/types.rb', line 18694

class IterableFormItem < Struct.new(
  :item_id,
  :item_name,
  :glossary_terms,
  :forms,
  :attachments)
  SENSITIVE = []
  include Aws::Structure
end

#item_idString

The unique identifier of the item.

Returns:

  • (String)


18694
18695
18696
18697
18698
18699
18700
18701
18702
# File 'lib/aws-sdk-glue/types.rb', line 18694

class IterableFormItem < Struct.new(
  :item_id,
  :item_name,
  :glossary_terms,
  :forms,
  :attachments)
  SENSITIVE = []
  include Aws::Structure
end

#item_nameString

The name of the item.

Returns:

  • (String)


18694
18695
18696
18697
18698
18699
18700
18701
18702
# File 'lib/aws-sdk-glue/types.rb', line 18694

class IterableFormItem < Struct.new(
  :item_id,
  :item_name,
  :glossary_terms,
  :forms,
  :attachments)
  SENSITIVE = []
  include Aws::Structure
end