Class: Aws::Glue::Types::JDBCConnectorTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass JDBCConnectorTarget data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  connection_name: "EnclosedInStringProperty", # required
  connection_table: "EnclosedInStringPropertyWithQuote", # required
  connector_name: "EnclosedInStringProperty", # required
  connection_type: "EnclosedInStringProperty", # required
  additional_options: {
    "EnclosedInStringProperty" => "EnclosedInStringProperty",
  },
  output_schemas: [
    {
      columns: [
        {
          name: "GlueStudioColumnNameString", # required
          type: "ColumnTypeString",
        },
      ],
    },
  ],
}

Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsHash<String,String>

Additional connection options for the connector.

Returns:

  • (Hash<String,String>)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection that is associated with the connector.

Returns:

  • (String)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_tableString

The name of the table in the data target.

Returns:

  • (String)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data target.

Returns:

  • (String)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connector_nameString

The name of a connector that will be used.

Returns:

  • (String)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the JDBC target.

Returns:



14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
# File 'lib/aws-sdk-glue/types.rb', line 14555

class JDBCConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connection_table,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end