Class: Aws::Glue::Types::JdbcTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JdbcTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a JDBC data store to crawl.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to use to connect to the JDBC target.
-
#enable_additional_metadata ⇒ Array<String>
Specify a value of
RAWTYPESorCOMMENTSto enable additional metadata in table responses. -
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl.
-
#path ⇒ String
The path of the JDBC target.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to use to connect to the JDBC target.
17482 17483 17484 17485 17486 17487 17488 17489 |
# File 'lib/aws-sdk-glue/types.rb', line 17482 class JdbcTarget < Struct.new( :connection_name, :path, :exclusions, :enable_additional_metadata) SENSITIVE = [] include Aws::Structure end |
#enable_additional_metadata ⇒ Array<String>
Specify a value of RAWTYPES or COMMENTS to enable additional metadata in table responses. RAWTYPES provides the native-level datatype. COMMENTS provides comments associated with a column or table in the database.
If you do not need additional metadata, keep the field empty.
17482 17483 17484 17485 17486 17487 17488 17489 |
# File 'lib/aws-sdk-glue/types.rb', line 17482 class JdbcTarget < Struct.new( :connection_name, :path, :exclusions, :enable_additional_metadata) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl. For more information, see [Catalog Tables with a Crawler].
17482 17483 17484 17485 17486 17487 17488 17489 |
# File 'lib/aws-sdk-glue/types.rb', line 17482 class JdbcTarget < Struct.new( :connection_name, :path, :exclusions, :enable_additional_metadata) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path of the JDBC target.
17482 17483 17484 17485 17486 17487 17488 17489 |
# File 'lib/aws-sdk-glue/types.rb', line 17482 class JdbcTarget < Struct.new( :connection_name, :path, :exclusions, :enable_additional_metadata) SENSITIVE = [] include Aws::Structure end |