Class: Aws::Glue::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a job definition.

Constant Summary collapse

SENSITIVE =
[:code_gen_configuration_nodes]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_capacityInteger

This field is deprecated. Use `MaxCapacity` instead.

The number of Glue data processing units (DPUs) allocated to runs of this job. You can allocate a minimum of 2 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Integer)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#code_gen_configuration_nodesHash<String,Types::CodeGenConfigurationNode>

The representation of a directed acyclic graph on which both the Glue Studio visual component and Glue Studio code generation is based.

Returns:



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#commandTypes::JobCommand

The `JobCommand` that runs this job.

Returns:



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#connectionsTypes::ConnectionsList

The connections used for this job.



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#created_onTime

The time and date that this job definition was created.

Returns:

  • (Time)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#default_argumentsHash<String,String>

The default arguments for this job, specified as name-value pairs.

You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.

For information about how to specify and consume your own Job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.

For information about the key-value pairs that Glue consumes to set up your job, see the [Special Parameters Used by Glue] topic in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html

Returns:

  • (Hash<String,String>)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#descriptionString

A description of the job.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#execution_classString

Indicates whether the job is run with a standard or flexible execution class. The standard execution class is ideal for time-sensitive workloads that require fast job startup and dedicated resources.

The flexible execution class is appropriate for time-insensitive jobs whose start and completion times may vary.

Only jobs with Glue version 3.0 and above and command type `glueetl` will be allowed to set `ExecutionClass` to `FLEX`. The flexible execution class is available for Spark jobs.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#execution_propertyTypes::ExecutionProperty

An `ExecutionProperty` specifying the maximum number of concurrent runs allowed for this job.



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#glue_versionString

Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for jobs of type Spark.

For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.

Jobs that are created without specifying a Glue version default to Glue 0.9.

[1]: docs.aws.amazon.com/glue/latest/dg/add-job.html

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#last_modified_onTime

The last point in time when this job definition was modified.

Returns:

  • (Time)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#log_uriString

This field is reserved for future use.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#max_capacityFloat

For Glue version 1.0 or earlier jobs, using the standard worker type, the number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

Do not set `Max Capacity` if using `WorkerType` and `NumberOfWorkers`.

The value that can be allocated for `MaxCapacity` depends on whether you are running a Python shell job, an Apache Spark ETL job, or an Apache Spark streaming ETL job:

  • When you specify a Python shell job (`JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.

  • When you specify an Apache Spark ETL job (`JobCommand.Name`=“glueetl”) or Apache Spark streaming ETL job (`JobCommand.Name`=“gluestreaming”), you can allocate a minimum of 2 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.

For Glue version 2.0 jobs, you cannot instead specify a `Maximum capacity`. Instead, you should specify a `Worker type` and the `Number of workers`.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry this job after a JobRun fails.

Returns:

  • (Integer)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#nameString

The name you assign to this job definition.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#non_overridable_argumentsHash<String,String>

Non-overridable arguments for this job, specified as name-value pairs.

Returns:

  • (Hash<String,String>)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#notification_propertyTypes::NotificationProperty

Specifies configuration properties of a job notification.



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined `workerType` that are allocated when a job runs.

Returns:

  • (Integer)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role associated with this job.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#security_configurationString

The name of the `SecurityConfiguration` structure to be used with this job.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#source_control_detailsTypes::SourceControlDetails

The details for a source control configuration for a job, allowing synchronization of job artifacts to or from a remote repository.



14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#timeoutInteger

The job timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. The default is 2,880 minutes (48 hours).

Returns:

  • (Integer)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, G.2X, or G.025X.

  • For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the `G.1X` worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the `G.2X` worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the `G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.

Returns:

  • (String)


14826
14827
14828
14829
14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
14840
14841
14842
14843
14844
14845
14846
14847
14848
14849
14850
14851
14852
# File 'lib/aws-sdk-glue/types.rb', line 14826

class Job < Struct.new(
  :name,
  :description,
  :log_uri,
  :role,
  :created_on,
  :last_modified_on,
  :execution_property,
  :command,
  :default_arguments,
  :non_overridable_arguments,
  :connections,
  :max_retries,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :notification_property,
  :glue_version,
  :code_gen_configuration_nodes,
  :execution_class,
  :source_control_details)
  SENSITIVE = [:code_gen_configuration_nodes]
  include Aws::Structure
end