Class: Aws::Glue::Types::JobCommand

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies code that runs when a job is run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the job command. For an Apache Spark ETL job, this must be glueetl. For a Python shell job, it must be pythonshell. For an Apache Spark streaming ETL job, this must be gluestreaming. For a Ray job, this must be glueray.

Returns:

  • (String)


19892
19893
19894
19895
19896
19897
19898
19899
# File 'lib/aws-sdk-glue/types.rb', line 19892

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#python_versionString

The Python version being used to run a Python shell job. Allowed values are 2 or 3.

Returns:

  • (String)


19892
19893
19894
19895
19896
19897
19898
19899
# File 'lib/aws-sdk-glue/types.rb', line 19892

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

In Ray jobs, Runtime is used to specify the versions of Ray, Python and additional libraries available in your environment. This field is not used in other job types. For supported runtime environment values, see Supported Ray runtime environments in the Glue Developer Guide.

Returns:

  • (String)


19892
19893
19894
19895
19896
19897
19898
19899
# File 'lib/aws-sdk-glue/types.rb', line 19892

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#script_locationString

Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.

Returns:

  • (String)


19892
19893
19894
19895
19896
19897
19898
19899
# File 'lib/aws-sdk-glue/types.rb', line 19892

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end