Class: Aws::Glue::Types::JobRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Contains information about a job run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_capacityInteger

This field is deprecated. Use ‘MaxCapacity` instead.

The number of Glue data processing units (DPUs) allocated to this JobRun. From 2 to 100 DPUs can be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Integer)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#argumentsHash<String,String>

The job arguments associated with this run. For this job run, they replace the default arguments set in the job definition itself.

You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.

Job arguments may be logged. Do not pass plaintext secrets as arguments. Retrieve secrets from a Glue Connection, Secrets Manager or other secret management mechanism if you intend to keep them within the Job.

For information about how to specify and consume your own Job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.

For information about the arguments you can provide to this field when configuring Spark jobs, see the [Special Parameters Used by Glue] topic in the developer guide.

For information about the arguments you can provide to this field when configuring Ray jobs, see [Using job parameters in Ray jobs] in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html [3]: docs.aws.amazon.com/glue/latest/dg/author-job-ray-job-parameters.html

Returns:

  • (Hash<String,String>)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#attemptInteger

The number of the attempt to run this job.

Returns:

  • (Integer)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#completed_onTime

The date and time that this job run completed.

Returns:

  • (Time)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#dpu_secondsFloat

This field populates only for Auto Scaling job runs, and represents the total time each executor ran during the lifecycle of a job run in seconds, multiplied by a DPU factor (1 for ‘G.1X`, 2 for `G.2X`, or 0.25 for `G.025X` workers). This value may be different than the `executionEngineRuntime` * `MaxCapacity` as in the case of Auto Scaling jobs, as the number of executors running at a given time may be less than the `MaxCapacity`. Therefore, it is possible that the value of `DPUSeconds` is less than `executionEngineRuntime` * `MaxCapacity`.

Returns:

  • (Float)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

An error message associated with this job run.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#execution_classString

Indicates whether the job is run with a standard or flexible execution class. The standard execution-class is ideal for time-sensitive workloads that require fast job startup and dedicated resources.

The flexible execution class is appropriate for time-insensitive jobs whose start and completion times may vary.

Only jobs with Glue version 3.0 and above and command type ‘glueetl` will be allowed to set `ExecutionClass` to `FLEX`. The flexible execution class is available for Spark jobs.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#execution_timeInteger

The amount of time (in seconds) that the job run consumed resources.

Returns:

  • (Integer)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

In Spark jobs, ‘GlueVersion` determines the versions of Apache Spark and Python that Glue available in a job. The Python version indicates the version supported for jobs of type Spark.

Ray jobs should set ‘GlueVersion` to `4.0` or greater. However, the versions of Ray, Python and additional libraries available in your Ray job are determined by the `Runtime` parameter of the Job command.

For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.

Jobs that are created without specifying a Glue version default to Glue 0.9.

[1]: docs.aws.amazon.com/glue/latest/dg/add-job.html

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of this job run.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job definition being used in this run.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#job_run_stateString

The current state of the job run. For more information about the statuses of jobs that have terminated abnormally, see [Glue Job Run Statuses].

[1]: docs.aws.amazon.com/glue/latest/dg/job-run-statuses.html

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The last time that this job run was modified.

Returns:

  • (Time)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group for secure logging that can be server-side encrypted in Amazon CloudWatch using KMS. This name can be ‘/aws-glue/jobs/`, in which case the default encryption is `NONE`. If you add a role name and `SecurityConfiguration` name (in other words, `/aws-glue/jobs-yourRoleName-yourSecurityConfigurationName/`), then that security configuration is used to encrypt the log group.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

For Glue version 1.0 or earlier jobs, using the standard worker type, the number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [ Glue pricing page].

For Glue version 2.0+ jobs, you cannot specify a ‘Maximum capacity`. Instead, you should specify a `Worker type` and the `Number of workers`.

Do not set ‘MaxCapacity` if using `WorkerType` and `NumberOfWorkers`.

The value that can be allocated for ‘MaxCapacity` depends on whether you are running a Python shell job, an Apache Spark ETL job, or an Apache Spark streaming ETL job:

  • When you specify a Python shell job (‘JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.

  • When you specify an Apache Spark ETL job (‘JobCommand.Name`=“glueetl”) or Apache Spark streaming ETL job (`JobCommand.Name`=“gluestreaming”), you can allocate from 2 to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#notification_propertyTypes::NotificationProperty

Specifies configuration properties of a job run notification.



12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined ‘workerType` that are allocated when a job runs.

Returns:

  • (Integer)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#predecessor_runsArray<Types::Predecessor>

A list of predecessors to this job run.

Returns:



12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#previous_run_idString

The ID of the previous run of this job. For example, the ‘JobRunId` specified in the `StartJobRun` action.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the ‘SecurityConfiguration` structure to be used with this job run.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#started_onTime

The date and time at which this job run was started.

Returns:

  • (Time)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The ‘JobRun` timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. This value overrides the timeout value set in the parent job.

Streaming jobs do not have a timeout. The default for non-streaming jobs is 2,880 minutes (48 hours).

Returns:

  • (Integer)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_nameString

The name of the trigger that started this job run.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, G.2X, or G.025X for Spark jobs. Accepts the value Z.2X for Ray jobs.

  • For the ‘Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the ‘G.1X` worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the ‘G.2X` worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the ‘G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.

  • For the ‘Z.2X` worker type, each worker maps to 2 M-DPU (8vCPU, 64 GB of m emory, 128 GB disk), and provides up to 8 Ray workers (one per vCPU) based on the autoscaler.

Returns:

  • (String)


12789
12790
12791
12792
12793
12794
12795
12796
12797
12798
12799
12800
12801
12802
12803
12804
12805
12806
12807
12808
12809
12810
12811
12812
12813
12814
12815
12816
# File 'lib/aws-sdk-glue/types.rb', line 12789

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version,
  :dpu_seconds,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end