Class: Aws::Glue::Types::LakeFormationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::LakeFormationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass LakeFormationConfiguration data as a hash:
{
use_lake_formation_credentials: false,
account_id: "AccountId",
}
Specifies Lake Formation configuration settings for the crawler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Required for cross account crawls.
-
#use_lake_formation_credentials ⇒ Boolean
Specifies whether to use Lake Formation credentials for the crawler instead of the IAM role credentials.
Instance Attribute Details
#account_id ⇒ String
Required for cross account crawls. For same account crawls as the target data, this can be left as null.
16597 16598 16599 16600 16601 16602 |
# File 'lib/aws-sdk-glue/types.rb', line 16597 class LakeFormationConfiguration < Struct.new( :use_lake_formation_credentials, :account_id) SENSITIVE = [] include Aws::Structure end |
#use_lake_formation_credentials ⇒ Boolean
Specifies whether to use Lake Formation credentials for the crawler instead of the IAM role credentials.
16597 16598 16599 16600 16601 16602 |
# File 'lib/aws-sdk-glue/types.rb', line 16597 class LakeFormationConfiguration < Struct.new( :use_lake_formation_credentials, :account_id) SENSITIVE = [] include Aws::Structure end |