Class: Aws::Glue::Types::ListDataQualityStatisticsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListDataQualityStatisticsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token to request the next page of results.
-
#statistics ⇒ Array<Types::StatisticSummary>
A
StatisticSummaryList.
Instance Attribute Details
#next_token ⇒ String
A pagination token to request the next page of results.
21842 21843 21844 21845 21846 21847 |
# File 'lib/aws-sdk-glue/types.rb', line 21842 class ListDataQualityStatisticsResponse < Struct.new( :statistics, :next_token) SENSITIVE = [] include Aws::Structure end |
#statistics ⇒ Array<Types::StatisticSummary>
A StatisticSummaryList.
21842 21843 21844 21845 21846 21847 |
# File 'lib/aws-sdk-glue/types.rb', line 21842 class ListDataQualityStatisticsResponse < Struct.new( :statistics, :next_token) SENSITIVE = [] include Aws::Structure end |