Class: Aws::Glue::Types::ListEntitiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.

Returns:

  • (String)


20188
20189
20190
20191
20192
20193
20194
20195
20196
# File 'lib/aws-sdk-glue/types.rb', line 20188

class ListEntitiesRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :parent_entity_name,
  :next_token,
  :data_store_api_version)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

A name for the connection that has required credentials to query any connection type.

Returns:

  • (String)


20188
20189
20190
20191
20192
20193
20194
20195
20196
# File 'lib/aws-sdk-glue/types.rb', line 20188

class ListEntitiesRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :parent_entity_name,
  :next_token,
  :data_store_api_version)
  SENSITIVE = []
  include Aws::Structure
end

#data_store_api_versionString

The API version of the SaaS connector.

Returns:

  • (String)


20188
20189
20190
20191
20192
20193
20194
20195
20196
# File 'lib/aws-sdk-glue/types.rb', line 20188

class ListEntitiesRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :parent_entity_name,
  :next_token,
  :data_store_api_version)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, included if this is a continuation call.

Returns:

  • (String)


20188
20189
20190
20191
20192
20193
20194
20195
20196
# File 'lib/aws-sdk-glue/types.rb', line 20188

class ListEntitiesRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :parent_entity_name,
  :next_token,
  :data_store_api_version)
  SENSITIVE = []
  include Aws::Structure
end

#parent_entity_nameString

Name of the parent entity for which you want to list the children. This parameter takes a fully-qualified path of the entity in order to list the child entities.

Returns:

  • (String)


20188
20189
20190
20191
20192
20193
20194
20195
20196
# File 'lib/aws-sdk-glue/types.rb', line 20188

class ListEntitiesRequest < Struct.new(
  :connection_name,
  :catalog_id,
  :parent_entity_name,
  :next_token,
  :data_store_api_version)
  SENSITIVE = []
  include Aws::Structure
end