Class: Aws::Glue::Types::ListEntitiesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListEntitiesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entities ⇒ Array<Types::Entity>
A list of
Entityobjects. -
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
Instance Attribute Details
#entities ⇒ Array<Types::Entity>
A list of Entity objects.
19732 19733 19734 19735 19736 19737 |
# File 'lib/aws-sdk-glue/types.rb', line 19732 class ListEntitiesResponse < Struct.new( :entities, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
19732 19733 19734 19735 19736 19737 |
# File 'lib/aws-sdk-glue/types.rb', line 19732 class ListEntitiesResponse < Struct.new( :entities, :next_token) SENSITIVE = [] include Aws::Structure end |