Class: Aws::Glue::Types::ListGlossariesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListGlossariesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::GlossaryItem>
The list of glossary items.
-
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
Instance Attribute Details
#items ⇒ Array<Types::GlossaryItem>
The list of glossary items.
21956 21957 21958 21959 21960 21961 |
# File 'lib/aws-sdk-glue/types.rb', line 21956 class ListGlossariesResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
21956 21957 21958 21959 21960 21961 |
# File 'lib/aws-sdk-glue/types.rb', line 21956 class ListGlossariesResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |