Class: Aws::Glue::Types::ListGlossaryTermsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#glossary_identifierString

The unique identifier of the glossary whose terms to list.

Returns:

  • (String)


22029
22030
22031
22032
22033
22034
22035
# File 'lib/aws-sdk-glue/types.rb', line 22029

class ListGlossaryTermsRequest < Struct.new(
  :glossary_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:

  • (Integer)


22029
22030
22031
22032
22033
22034
22035
# File 'lib/aws-sdk-glue/types.rb', line 22029

class ListGlossaryTermsRequest < Struct.new(
  :glossary_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


22029
22030
22031
22032
22033
22034
22035
# File 'lib/aws-sdk-glue/types.rb', line 22029

class ListGlossaryTermsRequest < Struct.new(
  :glossary_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end