Class: Aws::Glue::Types::ListGlossaryTermsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListGlossaryTermsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::GlossaryTermItem>
The list of glossary term items.
-
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
Instance Attribute Details
#items ⇒ Array<Types::GlossaryTermItem>
The list of glossary term items.
22048 22049 22050 22051 22052 22053 |
# File 'lib/aws-sdk-glue/types.rb', line 22048 class ListGlossaryTermsResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
22048 22049 22050 22051 22052 22053 |
# File 'lib/aws-sdk-glue/types.rb', line 22048 class ListGlossaryTermsResponse < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |