Class: Aws::Glue::Types::ListIntegrationResourcePropertiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::IntegrationResourcePropertyFilter>

A list of filters, supported filter Key is SourceArn and TargetArn.



22070
22071
22072
22073
22074
22075
22076
# File 'lib/aws-sdk-glue/types.rb', line 22070

class ListIntegrationResourcePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

This is the pagination token for next page, initial value is null.

Returns:

  • (String)


22070
22071
22072
22073
22074
22075
22076
# File 'lib/aws-sdk-glue/types.rb', line 22070

class ListIntegrationResourcePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

This is total number of items to be evaluated.

Returns:

  • (Integer)


22070
22071
22072
22073
22074
22075
22076
# File 'lib/aws-sdk-glue/types.rb', line 22070

class ListIntegrationResourcePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end