Class: Aws::Glue::Types::ListIntegrationTablePropertiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::IntegrationTablePropertiesFilter>

A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.



22111
22112
22113
22114
22115
22116
22117
# File 'lib/aws-sdk-glue/types.rb', line 22111

class ListIntegrationTablePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The pagination token for the next page of results. The initial value is null.

Returns:

  • (String)


22111
22112
22113
22114
22115
22116
22117
# File 'lib/aws-sdk-glue/types.rb', line 22111

class ListIntegrationTablePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to return in the response.

Returns:

  • (Integer)


22111
22112
22113
22114
22115
22116
22117
# File 'lib/aws-sdk-glue/types.rb', line 22111

class ListIntegrationTablePropertiesRequest < Struct.new(
  :marker,
  :filters,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end