Class: Aws::Glue::Types::ListIntegrationTablePropertiesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListIntegrationTablePropertiesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_table_properties_list ⇒ Array<Types::IntegrationTableProperties>
A list of integration table properties meeting the filter criteria.
-
#marker ⇒ String
The pagination token for the next page.
Instance Attribute Details
#integration_table_properties_list ⇒ Array<Types::IntegrationTableProperties>
A list of integration table properties meeting the filter criteria.
22130 22131 22132 22133 22134 22135 |
# File 'lib/aws-sdk-glue/types.rb', line 22130 class ListIntegrationTablePropertiesResponse < Struct.new( :integration_table_properties_list, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The pagination token for the next page. Returns null if there are
no more results.
22130 22131 22132 22133 22134 22135 |
# File 'lib/aws-sdk-glue/types.rb', line 22130 class ListIntegrationTablePropertiesResponse < Struct.new( :integration_table_properties_list, :marker) SENSITIVE = [] include Aws::Structure end |