Class: Aws::Glue::Types::ListMaterializedViewRefreshTaskRunsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListMaterializedViewRefreshTaskRunsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The database where the table resides.
-
#max_results ⇒ Integer
The maximum size of the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#table_name ⇒ String
The name of the materialized view.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
22299 22300 22301 22302 22303 22304 22305 22306 22307 |
# File 'lib/aws-sdk-glue/types.rb', line 22299 class ListMaterializedViewRefreshTaskRunsRequest < Struct.new( :catalog_id, :database_name, :table_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database where the table resides.
22299 22300 22301 22302 22303 22304 22305 22306 22307 |
# File 'lib/aws-sdk-glue/types.rb', line 22299 class ListMaterializedViewRefreshTaskRunsRequest < Struct.new( :catalog_id, :database_name, :table_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of the response.
22299 22300 22301 22302 22303 22304 22305 22306 22307 |
# File 'lib/aws-sdk-glue/types.rb', line 22299 class ListMaterializedViewRefreshTaskRunsRequest < Struct.new( :catalog_id, :database_name, :table_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
22299 22300 22301 22302 22303 22304 22305 22306 22307 |
# File 'lib/aws-sdk-glue/types.rb', line 22299 class ListMaterializedViewRefreshTaskRunsRequest < Struct.new( :catalog_id, :database_name, :table_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the materialized view.
22299 22300 22301 22302 22303 22304 22305 22306 22307 |
# File 'lib/aws-sdk-glue/types.rb', line 22299 class ListMaterializedViewRefreshTaskRunsRequest < Struct.new( :catalog_id, :database_name, :table_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |