Class: Aws::Glue::Types::ListRegistriesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListRegistriesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
-
#registries ⇒ Array<Types::RegistryListItem>
An array of
RegistryDetailedListItemobjects containing minimal details of each registry.
Instance Attribute Details
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-glue/types.rb', line 22357 class ListRegistriesResponse < Struct.new( :registries, :next_token) SENSITIVE = [] include Aws::Structure end |
#registries ⇒ Array<Types::RegistryListItem>
An array of RegistryDetailedListItem objects containing minimal
details of each registry.
22357 22358 22359 22360 22361 22362 |
# File 'lib/aws-sdk-glue/types.rb', line 22357 class ListRegistriesResponse < Struct.new( :registries, :next_token) SENSITIVE = [] include Aws::Structure end |