Class: Aws::Glue::Types::ListSchemasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListSchemasResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
-
#schemas ⇒ Array<Types::SchemaListItem>
An array of
SchemaListItemobjects containing details of each schema.
Instance Attribute Details
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
20047 20048 20049 20050 20051 20052 |
# File 'lib/aws-sdk-glue/types.rb', line 20047 class ListSchemasResponse < Struct.new( :schemas, :next_token) SENSITIVE = [] include Aws::Structure end |
#schemas ⇒ Array<Types::SchemaListItem>
An array of SchemaListItem objects containing details of each schema.
20047 20048 20049 20050 20051 20052 |
# File 'lib/aws-sdk-glue/types.rb', line 20047 class ListSchemasResponse < Struct.new( :schemas, :next_token) SENSITIVE = [] include Aws::Structure end |