Class: Aws::Glue::Types::ListTableOptimizerRunsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The Catalog ID of the table.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database in the catalog in which the table resides.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of optimizer runs to return on each call.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of table optimizer.



20087
20088
20089
20090
20091
20092
20093
20094
20095
20096
# File 'lib/aws-sdk-glue/types.rb', line 20087

class ListTableOptimizerRunsRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :type,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end