Class: Aws::Glue::Types::ListTableOptimizerRunsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListTableOptimizerRunsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The Catalog ID of the table.
-
#database_name ⇒ String
The name of the database in the catalog in which the table resides.
-
#next_token ⇒ String
A continuation token for paginating the returned list of optimizer runs, returned if the current segment of the list is not the last.
-
#table_name ⇒ String
The name of the table.
-
#table_optimizer_runs ⇒ Array<Types::TableOptimizerRun>
A list of the optimizer runs associated with a table.
Instance Attribute Details
#catalog_id ⇒ String
The Catalog ID of the table.
20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-glue/types.rb', line 20689 class ListTableOptimizerRunsResponse < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :table_optimizer_runs) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database in the catalog in which the table resides.
20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-glue/types.rb', line 20689 class ListTableOptimizerRunsResponse < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :table_optimizer_runs) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token for paginating the returned list of optimizer runs, returned if the current segment of the list is not the last.
20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-glue/types.rb', line 20689 class ListTableOptimizerRunsResponse < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :table_optimizer_runs) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table.
20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-glue/types.rb', line 20689 class ListTableOptimizerRunsResponse < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :table_optimizer_runs) SENSITIVE = [] include Aws::Structure end |
#table_optimizer_runs ⇒ Array<Types::TableOptimizerRun>
A list of the optimizer runs associated with a table.
20689 20690 20691 20692 20693 20694 20695 20696 20697 |
# File 'lib/aws-sdk-glue/types.rb', line 20689 class ListTableOptimizerRunsResponse < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :table_optimizer_runs) SENSITIVE = [] include Aws::Structure end |