Class: Aws::Glue::Types::ListTriggersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListTriggersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependent_job_name ⇒ String
The name of the job for which to retrieve triggers.
-
#max_results ⇒ Integer
The maximum size of a list to return.
-
#next_token ⇒ String
A continuation token, if this is a continuation request.
-
#tags ⇒ Hash<String,String>
Specifies to return only these tagged resources.
Instance Attribute Details
#dependent_job_name ⇒ String
The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned.
22637 22638 22639 22640 22641 22642 22643 22644 |
# File 'lib/aws-sdk-glue/types.rb', line 22637 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of a list to return.
22637 22638 22639 22640 22641 22642 22643 22644 |
# File 'lib/aws-sdk-glue/types.rb', line 22637 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation request.
22637 22638 22639 22640 22641 22642 22643 22644 |
# File 'lib/aws-sdk-glue/types.rb', line 22637 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Specifies to return only these tagged resources.
22637 22638 22639 22640 22641 22642 22643 22644 |
# File 'lib/aws-sdk-glue/types.rb', line 22637 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |