Class: Aws::Glue::Types::MLTransform

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure for a machine learning transform.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_onTime

A timestamp. The time and date that this machine learning transform was created.

Returns:

  • (Time)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A user-defined, long-form description text for the machine learning transform. Descriptions are not guaranteed to be unique and can be changed at any time.

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_metricsTypes::EvaluationMetrics

An ‘EvaluationMetrics` object. Evaluation metrics provide an estimate of the quality of your machine learning transform.



14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#input_record_tablesArray<Types::GlueTable>

A list of Glue table definitions used by the transform.

Returns:



14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#label_countInteger

A count identifier for the labeling files generated by Glue for this transform. As you create a better transform, you can iteratively download, label, and upload the labeling file.

Returns:

  • (Integer)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

A timestamp. The last point in time when this machine learning transform was modified.

Returns:

  • (Time)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

‘MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.

  • If either ‘NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.

  • If ‘MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.

  • If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

  • ‘MaxCapacity` and `NumberOfWorkers` must both be at least 1.

When the ‘WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry after an ‘MLTaskRun` of the machine learning transform fails.

Returns:

  • (Integer)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A user-defined name for the machine learning transform. Names are not guaranteed unique and can be changed at any time.

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined ‘workerType` that are allocated when a task of the transform runs.

If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

Returns:

  • (Integer)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::TransformParameters

A ‘TransformParameters` object. You can use parameters to tune (customize) the behavior of the machine learning transform by specifying what data it learns from and your preference on various tradeoffs (such as precious vs. recall, or accuracy vs. cost).



14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role with the required permissions. The required permissions include both Glue service role permissions to Glue resources, and Amazon S3 permissions required by the transform.

  • This role needs Glue service role permissions to allow access to resources in Glue. See [Attach a Policy to IAM Users That Access Glue].

  • This role needs permission to your Amazon Simple Storage Service (Amazon S3) sources, targets, temporary directory, scripts, and any libraries used by the task run for this transform.

[1]: docs.aws.amazon.com/glue/latest/dg/attach-policy-iam-user.html

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#schemaArray<Types::SchemaColumn>

A map of key-value pairs representing the columns and data types that this transform can run against. Has an upper bound of 100 columns.

Returns:



14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the machine learning transform.

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The timeout in minutes of the machine learning transform.

Returns:

  • (Integer)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#transform_encryptionTypes::TransformEncryption

The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.



14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#transform_idString

The unique transform ID that is generated for the machine learning transform. The ID is guaranteed to be unique and does not change.

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a task of this transform runs. Accepts a value of Standard, G.1X, or G.2X.

  • For the ‘Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the ‘G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the ‘G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

‘MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.

  • If either ‘NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.

  • If ‘MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.

  • If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).

  • ‘MaxCapacity` and `NumberOfWorkers` must both be at least 1.

Returns:

  • (String)


14917
14918
14919
14920
14921
14922
14923
14924
14925
14926
14927
14928
14929
14930
14931
14932
14933
14934
14935
14936
14937
14938
14939
# File 'lib/aws-sdk-glue/types.rb', line 14917

class MLTransform < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end