Class: Aws::Glue::Types::MaterializedViewRefreshTaskRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::MaterializedViewRefreshTaskRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The object that shows the details of the materialized view refresh task run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#creation_time ⇒ Time
The time that this task was created.
-
#customer_id ⇒ String
The Amazon Web Services account ID.
-
#database_name ⇒ String
The database where the table resides.
-
#dpu_seconds ⇒ Float
The calculated DPU usage in seconds for all autoscaled workers.
-
#end_time ⇒ Time
The end time of the task.
-
#error_message ⇒ String
The error message for the job.
-
#last_updated ⇒ Time
The last point in time when this task was modified.
-
#materialized_view_refresh_task_run_id ⇒ String
The identifier of the materialized view refresh task run.
-
#processed_bytes ⇒ Integer
The number of bytes the refresh task run has scanned to refresh the materialized view.
-
#refresh_type ⇒ String
The type of the refresh task run.
-
#role ⇒ String
The IAM role that the service assumes to run the materialized view refresh task.
-
#start_time ⇒ Time
The start time of the task.
-
#status ⇒ String
The status of the task run.
-
#table_name ⇒ String
The name of the materialized view.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that this task was created.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#customer_id ⇒ String
The Amazon Web Services account ID.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database where the table resides.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#dpu_seconds ⇒ Float
The calculated DPU usage in seconds for all autoscaled workers.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the task.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message for the job.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The last point in time when this task was modified.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#materialized_view_refresh_task_run_id ⇒ String
The identifier of the materialized view refresh task run.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#processed_bytes ⇒ Integer
The number of bytes the refresh task run has scanned to refresh the materialized view.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#refresh_type ⇒ String
The type of the refresh task run. Either FULL or INCREMENTAL.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The IAM role that the service assumes to run the materialized view refresh task.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the task.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the task run.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the materialized view.
23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 23211 23212 23213 23214 23215 23216 23217 23218 23219 |
# File 'lib/aws-sdk-glue/types.rb', line 23201 class MaterializedViewRefreshTaskRun < Struct.new( :customer_id, :materialized_view_refresh_task_run_id, :database_name, :table_name, :catalog_id, :role, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds, :refresh_type, :processed_bytes) SENSITIVE = [] include Aws::Structure end |