Class: Aws::Glue::Types::Merge
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Merge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that merges a DynamicFrame with a staging DynamicFrame based on the specified primary keys to identify records. Duplicate records (records with the same primary keys) are not de-duplicated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
-
#source ⇒ String
The source
DynamicFramethat will be merged with a stagingDynamicFrame.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
20867 20868 20869 20870 20871 20872 20873 20874 |
# File 'lib/aws-sdk-glue/types.rb', line 20867 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
20867 20868 20869 20870 20871 20872 20873 20874 |
# File 'lib/aws-sdk-glue/types.rb', line 20867 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
20867 20868 20869 20870 20871 20872 20873 20874 |
# File 'lib/aws-sdk-glue/types.rb', line 20867 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |