Class: Aws::Glue::Types::Node

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A node represents an Glue component (trigger, crawler, or job) on a workflow graph.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#crawler_detailsTypes::CrawlerNodeDetails

Details of the crawler when the node represents a crawler.



13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end

#job_detailsTypes::JobNodeDetails

Details of the Job when the node represents a Job.



13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Glue component represented by the node.

Returns:

  • (String)


13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_detailsTypes::TriggerNodeDetails

Details of the Trigger when the node represents a Trigger.



13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of Glue component represented by the node.

Returns:

  • (String)


13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end

#unique_idString

The unique Id assigned to the node within the workflow.

Returns:

  • (String)


13235
13236
13237
13238
13239
13240
13241
13242
13243
13244
# File 'lib/aws-sdk-glue/types.rb', line 13235

class Node < Struct.new(
  :type,
  :name,
  :unique_id,
  :trigger_details,
  :job_details,
  :crawler_details)
  SENSITIVE = []
  include Aws::Structure
end