Class: Aws::Glue::Types::NotificationProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::NotificationProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass NotificationProperty data as a hash:
{
notify_delay_after: 1,
}
Specifies configuration properties of a notification.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#notify_delay_after ⇒ Integer
After a job run starts, the number of minutes to wait before sending a job run delay notification.
Instance Attribute Details
#notify_delay_after ⇒ Integer
After a job run starts, the number of minutes to wait before sending a job run delay notification.
13249 13250 13251 13252 13253 |
# File 'lib/aws-sdk-glue/types.rb', line 13249 class NotificationProperty < Struct.new( :notify_delay_after) SENSITIVE = [] include Aws::Structure end |