Class: Aws::Glue::Types::NullValueField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass NullValueField data as a hash:

{
  value: "EnclosedInStringProperty", # required
  datatype: { # required
    id: "GenericLimitedString", # required
    label: "GenericLimitedString", # required
  },
}

Represents a custom null value such as a zeros or other value being used as a null placeholder unique to the dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#datatypeTypes::Datatype

The datatype of the value.

Returns:



18323
18324
18325
18326
18327
18328
# File 'lib/aws-sdk-glue/types.rb', line 18323

class NullValueField < Struct.new(
  :value,
  :datatype)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the null placeholder.

Returns:

  • (String)


18323
18324
18325
18326
18327
18328
# File 'lib/aws-sdk-glue/types.rb', line 18323

class NullValueField < Struct.new(
  :value,
  :datatype)
  SENSITIVE = []
  include Aws::Structure
end