Class: Aws::Glue::Types::OtherMetadataValueListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure containing other metadata for a schema version belonging to the same metadata key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timeString

The time at which the entry was created.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
# File 'lib/aws-sdk-glue/types.rb', line 24000

class OtherMetadataValueListItem < Struct.new(
  :metadata_value,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_valueString

The metadata key’s corresponding value for the other metadata belonging to the same metadata key.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
# File 'lib/aws-sdk-glue/types.rb', line 24000

class OtherMetadataValueListItem < Struct.new(
  :metadata_value,
  :created_time)
  SENSITIVE = []
  include Aws::Structure
end