Class: Aws::Glue::Types::PutAssetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutAssetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which the asset was created.
-
#description ⇒ String
The description of the asset.
-
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms attached to the asset, keyed by form name.
-
#id ⇒ String
The unique identifier of the asset.
-
#name ⇒ String
The name of the asset.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which the asset was created.
24342 24343 24344 24345 24346 24347 24348 24349 24350 |
# File 'lib/aws-sdk-glue/types.rb', line 24342 class PutAssetResponse < Struct.new( :id, :name, :description, :created_at, :forms) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the asset.
24342 24343 24344 24345 24346 24347 24348 24349 24350 |
# File 'lib/aws-sdk-glue/types.rb', line 24342 class PutAssetResponse < Struct.new( :id, :name, :description, :created_at, :forms) SENSITIVE = [] include Aws::Structure end |
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms attached to the asset, keyed by form name.
24342 24343 24344 24345 24346 24347 24348 24349 24350 |
# File 'lib/aws-sdk-glue/types.rb', line 24342 class PutAssetResponse < Struct.new( :id, :name, :description, :created_at, :forms) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the asset.
24342 24343 24344 24345 24346 24347 24348 24349 24350 |
# File 'lib/aws-sdk-glue/types.rb', line 24342 class PutAssetResponse < Struct.new( :id, :name, :description, :created_at, :forms) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset.
24342 24343 24344 24345 24346 24347 24348 24349 24350 |
# File 'lib/aws-sdk-glue/types.rb', line 24342 class PutAssetResponse < Struct.new( :id, :name, :description, :created_at, :forms) SENSITIVE = [] include Aws::Structure end |