Class: Aws::Glue::Types::PutAssetTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutAssetTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#forms ⇒ Hash<String,Types::AssetTypeFormReference>
The forms that make up the asset type, keyed by form name.
-
#name ⇒ String
The name of the asset type.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24565 class PutAssetTypeRequest < Struct.new( :name, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#forms ⇒ Hash<String,Types::AssetTypeFormReference>
The forms that make up the asset type, keyed by form name. Each entry references the form type that defines the form's schema.
24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24565 class PutAssetTypeRequest < Struct.new( :name, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24565 class PutAssetTypeRequest < Struct.new( :name, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |