Class: Aws::Glue::Types::PutAssetTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutAssetTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#forms ⇒ Hash<String,Types::AssetTypeFormReference>
The forms that make up the asset type, keyed by form name.
-
#id ⇒ String
The identifier of the asset type.
-
#name ⇒ String
The name of the asset type.
Instance Attribute Details
#forms ⇒ Hash<String,Types::AssetTypeFormReference>
The forms that make up the asset type, keyed by form name.
24393 24394 24395 24396 24397 24398 24399 |
# File 'lib/aws-sdk-glue/types.rb', line 24393 class PutAssetTypeResponse < Struct.new( :id, :name, :forms) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the asset type.
24393 24394 24395 24396 24397 24398 24399 |
# File 'lib/aws-sdk-glue/types.rb', line 24393 class PutAssetTypeResponse < Struct.new( :id, :name, :forms) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
24393 24394 24395 24396 24397 24398 24399 |
# File 'lib/aws-sdk-glue/types.rb', line 24393 class PutAssetTypeResponse < Struct.new( :id, :name, :forms) SENSITIVE = [] include Aws::Structure end |