Class: Aws::Glue::Types::PutAttachmentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The unique identifier of the asset.

Returns:

  • (String)


24127
24128
24129
24130
24131
24132
24133
24134
24135
# File 'lib/aws-sdk-glue/types.rb', line 24127

class PutAttachmentResponse < Struct.new(
  :asset_id,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :form_type_id)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_nameString

The name of the attachment.

Returns:

  • (String)


24127
24128
24129
24130
24131
24132
24133
24134
24135
# File 'lib/aws-sdk-glue/types.rb', line 24127

class PutAttachmentResponse < Struct.new(
  :asset_id,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :form_type_id)
  SENSITIVE = []
  include Aws::Structure
end

#form_type_idString

The identifier of the form type for this attachment.

Returns:

  • (String)


24127
24128
24129
24130
24131
24132
24133
24134
24135
# File 'lib/aws-sdk-glue/types.rb', line 24127

class PutAttachmentResponse < Struct.new(
  :asset_id,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :form_type_id)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form, if applicable.

Returns:

  • (String)


24127
24128
24129
24130
24131
24132
24133
24134
24135
# File 'lib/aws-sdk-glue/types.rb', line 24127

class PutAttachmentResponse < Struct.new(
  :asset_id,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :form_type_id)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form, if the attachment targets an item.

Returns:

  • (String)


24127
24128
24129
24130
24131
24132
24133
24134
24135
# File 'lib/aws-sdk-glue/types.rb', line 24127

class PutAttachmentResponse < Struct.new(
  :asset_id,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :form_type_id)
  SENSITIVE = []
  include Aws::Structure
end