Class: Aws::Glue::Types::PutDataCatalogEncryptionSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutDataCatalogEncryptionSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog to set the security configuration for.
-
#data_catalog_encryption_settings ⇒ Types::DataCatalogEncryptionSettings
The security configuration to set.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog to set the security configuration for. If none is provided, the Amazon Web Services account ID is used by default.
24914 24915 24916 24917 24918 24919 |
# File 'lib/aws-sdk-glue/types.rb', line 24914 class PutDataCatalogEncryptionSettingsRequest < Struct.new( :catalog_id, :data_catalog_encryption_settings) SENSITIVE = [] include Aws::Structure end |
#data_catalog_encryption_settings ⇒ Types::DataCatalogEncryptionSettings
The security configuration to set.
24914 24915 24916 24917 24918 24919 |
# File 'lib/aws-sdk-glue/types.rb', line 24914 class PutDataCatalogEncryptionSettingsRequest < Struct.new( :catalog_id, :data_catalog_encryption_settings) SENSITIVE = [] include Aws::Structure end |