Class: Aws::Glue::Types::PutFormTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutFormTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#name ⇒ String
The name of the form type.
-
#schema ⇒ String
The Smithy IDL schema definition for the form type.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
24547 24548 24549 24550 24551 24552 24553 |
# File 'lib/aws-sdk-glue/types.rb', line 24547 class PutFormTypeRequest < Struct.new( :name, :schema, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the form type. Must start with an uppercase letter.
24547 24548 24549 24550 24551 24552 24553 |
# File 'lib/aws-sdk-glue/types.rb', line 24547 class PutFormTypeRequest < Struct.new( :name, :schema, :client_token) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ String
The Smithy IDL schema definition for the form type.
24547 24548 24549 24550 24551 24552 24553 |
# File 'lib/aws-sdk-glue/types.rb', line 24547 class PutFormTypeRequest < Struct.new( :name, :schema, :client_token) SENSITIVE = [] include Aws::Structure end |