Class: Aws::Glue::Types::PutResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_hybrid ⇒ String
If ‘’TRUE’‘, indicates that you are using both methods to grant cross-account access to Data Catalog resources:.
-
#policy_exists_condition ⇒ String
A value of
MUST_EXISTis used to update a policy. -
#policy_hash_condition ⇒ String
The hash value returned when the previous policy was set using
PutResourcePolicy. -
#policy_in_json ⇒ String
Contains the policy document to set, in JSON format.
-
#resource_arn ⇒ String
Do not use.
Instance Attribute Details
#enable_hybrid ⇒ String
If ‘’TRUE’‘, indicates that you are using both methods to grant cross-account access to Data Catalog resources:
-
By directly updating the resource policy with
PutResourePolicy -
By using the **Grant permissions** command on the Amazon Web Services Management Console.
Must be set to ‘’TRUE’‘ if you have already used the Management Console to grant cross-account access, otherwise the call fails. Default is ’FALSE’.
22271 22272 22273 22274 22275 22276 22277 22278 22279 |
# File 'lib/aws-sdk-glue/types.rb', line 22271 class PutResourcePolicyRequest < Struct.new( :policy_in_json, :resource_arn, :policy_hash_condition, :policy_exists_condition, :enable_hybrid) SENSITIVE = [] include Aws::Structure end |
#policy_exists_condition ⇒ String
A value of MUST_EXIST is used to update a policy. A value of NOT_EXIST is used to create a new policy. If a value of NONE or a null value is used, the call does not depend on the existence of a policy.
22271 22272 22273 22274 22275 22276 22277 22278 22279 |
# File 'lib/aws-sdk-glue/types.rb', line 22271 class PutResourcePolicyRequest < Struct.new( :policy_in_json, :resource_arn, :policy_hash_condition, :policy_exists_condition, :enable_hybrid) SENSITIVE = [] include Aws::Structure end |
#policy_hash_condition ⇒ String
The hash value returned when the previous policy was set using PutResourcePolicy. Its purpose is to prevent concurrent modifications of a policy. Do not use this parameter if no previous policy has been set.
22271 22272 22273 22274 22275 22276 22277 22278 22279 |
# File 'lib/aws-sdk-glue/types.rb', line 22271 class PutResourcePolicyRequest < Struct.new( :policy_in_json, :resource_arn, :policy_hash_condition, :policy_exists_condition, :enable_hybrid) SENSITIVE = [] include Aws::Structure end |
#policy_in_json ⇒ String
Contains the policy document to set, in JSON format.
22271 22272 22273 22274 22275 22276 22277 22278 22279 |
# File 'lib/aws-sdk-glue/types.rb', line 22271 class PutResourcePolicyRequest < Struct.new( :policy_in_json, :resource_arn, :policy_hash_condition, :policy_exists_condition, :enable_hybrid) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
Do not use. For internal use only.
22271 22272 22273 22274 22275 22276 22277 22278 22279 |
# File 'lib/aws-sdk-glue/types.rb', line 22271 class PutResourcePolicyRequest < Struct.new( :policy_in_json, :resource_arn, :policy_hash_condition, :policy_exists_condition, :enable_hybrid) SENSITIVE = [] include Aws::Structure end |