Class: Aws::Glue::Types::Recipe

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A Glue Studio node that uses a Glue DataBrew recipe in Glue jobs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputsArray<String>

The nodes that are inputs to the recipe node, identified by id.

Returns:

  • (Array<String>)


25059
25060
25061
25062
25063
25064
25065
25066
# File 'lib/aws-sdk-glue/types.rb', line 25059

class Recipe < Struct.new(
  :name,
  :inputs,
  :recipe_reference,
  :recipe_steps)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Glue Studio node.

Returns:

  • (String)


25059
25060
25061
25062
25063
25064
25065
25066
# File 'lib/aws-sdk-glue/types.rb', line 25059

class Recipe < Struct.new(
  :name,
  :inputs,
  :recipe_reference,
  :recipe_steps)
  SENSITIVE = []
  include Aws::Structure
end

#recipe_referenceTypes::RecipeReference

A reference to the DataBrew recipe used by the node.



25059
25060
25061
25062
25063
25064
25065
25066
# File 'lib/aws-sdk-glue/types.rb', line 25059

class Recipe < Struct.new(
  :name,
  :inputs,
  :recipe_reference,
  :recipe_steps)
  SENSITIVE = []
  include Aws::Structure
end

#recipe_stepsArray<Types::RecipeStep>

Transform steps used in the recipe node.

Returns:



25059
25060
25061
25062
25063
25064
25065
25066
# File 'lib/aws-sdk-glue/types.rb', line 25059

class Recipe < Struct.new(
  :name,
  :inputs,
  :recipe_reference,
  :recipe_steps)
  SENSITIVE = []
  include Aws::Structure
end