Class: Aws::Glue::Types::RedshiftSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RedshiftSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass RedshiftSource data as a hash:
{
name: "NodeName", # required
database: "EnclosedInStringProperty", # required
table: "EnclosedInStringProperty", # required
redshift_tmp_dir: "EnclosedInStringProperty",
tmp_dir_iam_role: "EnclosedInStringProperty",
}
Specifies an Amazon Redshift data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database ⇒ String
The database to read from.
-
#name ⇒ String
The name of the Amazon Redshift data store.
-
#redshift_tmp_dir ⇒ String
The Amazon S3 path where temporary data can be staged when copying out of the database.
-
#table ⇒ String
The database table to read from.
-
#tmp_dir_iam_role ⇒ String
The IAM role with permissions.
Instance Attribute Details
#database ⇒ String
The database to read from.
19531 19532 19533 19534 19535 19536 19537 19538 19539 |
# File 'lib/aws-sdk-glue/types.rb', line 19531 class RedshiftSource < Struct.new( :name, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon Redshift data store.
19531 19532 19533 19534 19535 19536 19537 19538 19539 |
# File 'lib/aws-sdk-glue/types.rb', line 19531 class RedshiftSource < Struct.new( :name, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role) SENSITIVE = [] include Aws::Structure end |
#redshift_tmp_dir ⇒ String
The Amazon S3 path where temporary data can be staged when copying out of the database.
19531 19532 19533 19534 19535 19536 19537 19538 19539 |
# File 'lib/aws-sdk-glue/types.rb', line 19531 class RedshiftSource < Struct.new( :name, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The database table to read from.
19531 19532 19533 19534 19535 19536 19537 19538 19539 |
# File 'lib/aws-sdk-glue/types.rb', line 19531 class RedshiftSource < Struct.new( :name, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role) SENSITIVE = [] include Aws::Structure end |
#tmp_dir_iam_role ⇒ String
The IAM role with permissions.
19531 19532 19533 19534 19535 19536 19537 19538 19539 |
# File 'lib/aws-sdk-glue/types.rb', line 19531 class RedshiftSource < Struct.new( :name, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role) SENSITIVE = [] include Aws::Structure end |