Class: Aws::Glue::Types::RedshiftTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RedshiftTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass RedshiftTarget data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
database: "EnclosedInStringProperty", # required
table: "EnclosedInStringProperty", # required
redshift_tmp_dir: "EnclosedInStringProperty",
tmp_dir_iam_role: "EnclosedInStringProperty",
upsert_redshift_options: {
table_location: "EnclosedInStringProperty",
connection_name: "EnclosedInStringProperty",
upsert_keys: ["EnclosedInStringProperty"],
},
}
Specifies a target that uses Amazon Redshift.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#redshift_tmp_dir ⇒ String
The Amazon S3 path where temporary data can be staged when copying out of the database.
-
#table ⇒ String
The name of the table in the database to write to.
-
#tmp_dir_iam_role ⇒ String
The IAM role with permissions.
-
#upsert_redshift_options ⇒ Types::UpsertRedshiftTargetOptions
The set of options to configure an upsert operation when writing to a Redshift target.
Instance Attribute Details
#database ⇒ String
The name of the database to write to.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#redshift_tmp_dir ⇒ String
The Amazon S3 path where temporary data can be staged when copying out of the database.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table in the database to write to.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#tmp_dir_iam_role ⇒ String
The IAM role with permissions.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |
#upsert_redshift_options ⇒ Types::UpsertRedshiftTargetOptions
The set of options to configure an upsert operation when writing to a Redshift target.
19551 19552 19553 19554 19555 19556 19557 19558 19559 19560 19561 |
# File 'lib/aws-sdk-glue/types.rb', line 19551 class RedshiftTarget < Struct.new( :name, :inputs, :database, :table, :redshift_tmp_dir, :tmp_dir_iam_role, :upsert_redshift_options) SENSITIVE = [] include Aws::Structure end |