Class: Aws::Glue::Types::RenameField
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RenameField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass RenameField data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
source_path: ["EnclosedInStringProperty"], # required
target_path: ["EnclosedInStringProperty"], # required
}
Specifies a transform that renames a single data property key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#source_path ⇒ Array<String>
A JSON path to a variable in the data structure for the source data.
-
#target_path ⇒ Array<String>
A JSON path to a variable in the data structure for the target data.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
19877 19878 19879 19880 19881 19882 19883 19884 |
# File 'lib/aws-sdk-glue/types.rb', line 19877 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
19877 19878 19879 19880 19881 19882 19883 19884 |
# File 'lib/aws-sdk-glue/types.rb', line 19877 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#source_path ⇒ Array<String>
A JSON path to a variable in the data structure for the source data.
19877 19878 19879 19880 19881 19882 19883 19884 |
# File 'lib/aws-sdk-glue/types.rb', line 19877 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#target_path ⇒ Array<String>
A JSON path to a variable in the data structure for the target data.
19877 19878 19879 19880 19881 19882 19883 19884 |
# File 'lib/aws-sdk-glue/types.rb', line 19877 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |