Class: Aws::Glue::Types::ResponseExtractionMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Configuration that defines how to extract values from HTTP response content or headers for use in subsequent requests or parameter mapping.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_pathString

A JSON path expression that specifies how to extract a value from the response body content.

Returns:



23675
23676
23677
23678
23679
23680
# File 'lib/aws-sdk-glue/types.rb', line 23675

class ResponseExtractionMapping < Struct.new(
  :content_path,
  :header_key)
  SENSITIVE = []
  include Aws::Structure
end

#header_keyString

The name of an HTTP response header from which to extract the value.

Returns:



23675
23676
23677
23678
23679
23680
# File 'lib/aws-sdk-glue/types.rb', line 23675

class ResponseExtractionMapping < Struct.new(
  :content_path,
  :header_key)
  SENSITIVE = []
  include Aws::Structure
end