Class: Aws::Glue::Types::RowLevelResultsOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The configuration for writing row-level evaluation results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_table_configTypes::CatalogTableConfigOptions

The Glue Data Catalog table configuration for storing the results.



25628
25629
25630
25631
25632
25633
25634
# File 'lib/aws-sdk-glue/types.rb', line 25628

class RowLevelResultsOptions < Struct.new(
  :max_rows_to_write,
  :result_type,
  :catalog_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#max_rows_to_writeInteger

The maximum number of rows to write in the results.

Returns:

  • (Integer)


25628
25629
25630
25631
25632
25633
25634
# File 'lib/aws-sdk-glue/types.rb', line 25628

class RowLevelResultsOptions < Struct.new(
  :max_rows_to_write,
  :result_type,
  :catalog_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#result_typeString

The result type to include in the row-level results output.

Returns:

  • (String)


25628
25629
25630
25631
25632
25633
25634
# File 'lib/aws-sdk-glue/types.rb', line 25628

class RowLevelResultsOptions < Struct.new(
  :max_rows_to_write,
  :result_type,
  :catalog_table_config)
  SENSITIVE = []
  include Aws::Structure
end