Class: Aws::Glue::Types::RunStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RunStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The statement code to be run.
-
#request_origin ⇒ String
The origin of the request.
-
#session_id ⇒ String
The Session Id of the statement to be run.
Instance Attribute Details
#code ⇒ String
The statement code to be run.
17106 17107 17108 17109 17110 17111 17112 |
# File 'lib/aws-sdk-glue/types.rb', line 17106 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |
#request_origin ⇒ String
The origin of the request.
17106 17107 17108 17109 17110 17111 17112 |
# File 'lib/aws-sdk-glue/types.rb', line 17106 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The Session Id of the statement to be run.
17106 17107 17108 17109 17110 17111 17112 |
# File 'lib/aws-sdk-glue/types.rb', line 17106 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |