Class: Aws::Glue::Types::S3CatalogDeltaSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a Delta Lake data source that is registered in the Glue Data Catalog. The data source must be stored in Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_delta_optionsHash<String,String>

Specifies additional connection options.

Returns:

  • (Hash<String,String>)


26215
26216
26217
26218
26219
26220
26221
26222
26223
# File 'lib/aws-sdk-glue/types.rb', line 26215

class S3CatalogDeltaSource < Struct.new(
  :name,
  :database,
  :table,
  :additional_delta_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database to read from.

Returns:

  • (String)


26215
26216
26217
26218
26219
26220
26221
26222
26223
# File 'lib/aws-sdk-glue/types.rb', line 26215

class S3CatalogDeltaSource < Struct.new(
  :name,
  :database,
  :table,
  :additional_delta_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Delta Lake data source.

Returns:

  • (String)


26215
26216
26217
26218
26219
26220
26221
26222
26223
# File 'lib/aws-sdk-glue/types.rb', line 26215

class S3CatalogDeltaSource < Struct.new(
  :name,
  :database,
  :table,
  :additional_delta_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the Delta Lake source.

Returns:



26215
26216
26217
26218
26219
26220
26221
26222
26223
# File 'lib/aws-sdk-glue/types.rb', line 26215

class S3CatalogDeltaSource < Struct.new(
  :name,
  :database,
  :table,
  :additional_delta_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

The name of the table in the database to read from.

Returns:

  • (String)


26215
26216
26217
26218
26219
26220
26221
26222
26223
# File 'lib/aws-sdk-glue/types.rb', line 26215

class S3CatalogDeltaSource < Struct.new(
  :name,
  :database,
  :table,
  :additional_delta_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end