Class: Aws::Glue::Types::S3CatalogTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a data target that writes to Amazon S3 using the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_data_qualityTypes::AutoDataQuality

Specifies whether to automatically enable data quality evaluation for the S3 catalog target. When set to true, data quality checks are performed automatically during the write operation.



26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database to write to.

Returns:

  • (String)


26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Array<String>>

Specifies native partitioning using a sequence of keys.

Returns:

  • (Array<Array<String>>)


26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::CatalogSchemaChangePolicy

A policy that specifies update behavior for the crawler.



26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

The name of the table in the database to write to.

Returns:

  • (String)


26366
26367
26368
26369
26370
26371
26372
26373
26374
26375
26376
# File 'lib/aws-sdk-glue/types.rb', line 26366

class S3CatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end