Class: Aws::Glue::Types::S3DirectSourceAdditionalOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DirectSourceAdditionalOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass S3DirectSourceAdditionalOptions data as a hash:
{
bounded_size: 1,
bounded_files: 1,
enable_sample_path: false,
sample_path: "EnclosedInStringProperty",
}
Specifies additional connection options for the Amazon S3 data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bounded_files ⇒ Integer
Sets the upper limit for the target number of files that will be processed.
-
#bounded_size ⇒ Integer
Sets the upper limit for the target size of the dataset in bytes that will be processed.
-
#enable_sample_path ⇒ Boolean
Sets option to enable a sample path.
-
#sample_path ⇒ String
If enabled, specifies the sample path.
Instance Attribute Details
#bounded_files ⇒ Integer
Sets the upper limit for the target number of files that will be processed.
20305 20306 20307 20308 20309 20310 20311 20312 |
# File 'lib/aws-sdk-glue/types.rb', line 20305 class S3DirectSourceAdditionalOptions < Struct.new( :bounded_size, :bounded_files, :enable_sample_path, :sample_path) SENSITIVE = [] include Aws::Structure end |
#bounded_size ⇒ Integer
Sets the upper limit for the target size of the dataset in bytes that will be processed.
20305 20306 20307 20308 20309 20310 20311 20312 |
# File 'lib/aws-sdk-glue/types.rb', line 20305 class S3DirectSourceAdditionalOptions < Struct.new( :bounded_size, :bounded_files, :enable_sample_path, :sample_path) SENSITIVE = [] include Aws::Structure end |
#enable_sample_path ⇒ Boolean
Sets option to enable a sample path.
20305 20306 20307 20308 20309 20310 20311 20312 |
# File 'lib/aws-sdk-glue/types.rb', line 20305 class S3DirectSourceAdditionalOptions < Struct.new( :bounded_size, :bounded_files, :enable_sample_path, :sample_path) SENSITIVE = [] include Aws::Structure end |
#sample_path ⇒ String
If enabled, specifies the sample path.
20305 20306 20307 20308 20309 20310 20311 20312 |
# File 'lib/aws-sdk-glue/types.rb', line 20305 class S3DirectSourceAdditionalOptions < Struct.new( :bounded_size, :bounded_files, :enable_sample_path, :sample_path) SENSITIVE = [] include Aws::Structure end |