Class: Aws::Glue::Types::S3HudiCatalogTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a target that writes to a Hudi data source in the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsHash<String,String>

Specifies additional connection options for the connector.

Returns:

  • (Hash<String,String>)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#auto_data_qualityTypes::AutoDataQuality

Specifies whether to automatically enable data quality evaluation for the S3 Hudi catalog target. When set to true, data quality checks are performed automatically during the write operation.



26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database to write to.

Returns:

  • (String)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the S3 Hudi catalog target.

Returns:



26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Array<String>>

Specifies native partitioning using a sequence of keys.

Returns:

  • (Array<Array<String>>)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::CatalogSchemaChangePolicy

A policy that specifies update behavior for the crawler.



26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

The name of the table in the database to write to.

Returns:

  • (String)


26959
26960
26961
26962
26963
26964
26965
26966
26967
26968
26969
26970
26971
# File 'lib/aws-sdk-glue/types.rb', line 26959

class S3HudiCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end