Class: Aws::Glue::Types::S3IcebergCatalogTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies an Apache Iceberg catalog target that writes data to Amazon S3 and registers the table in the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsHash<String,String>

Specifies additional connection options for the Iceberg catalog target.

Returns:

  • (Hash<String,String>)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#auto_data_qualityTypes::AutoDataQuality

Specifies whether to automatically enable data quality evaluation for the S3 Iceberg catalog target. When set to true, data quality checks are performed automatically during the write operation.



27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database to write to.

Returns:

  • (String)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The input connection for the Iceberg catalog target.

Returns:

  • (Array<String>)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Iceberg catalog target.

Returns:

  • (String)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Array<String>>

A list of partition keys for the Iceberg table.

Returns:

  • (Array<Array<String>>)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::CatalogSchemaChangePolicy

The policy for handling schema changes in the catalog target.



27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

The name of the table to write to in the catalog.

Returns:

  • (String)


27073
27074
27075
27076
27077
27078
27079
27080
27081
27082
27083
27084
# File 'lib/aws-sdk-glue/types.rb', line 27073

class S3IcebergCatalogTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :table,
  :database,
  :additional_options,
  :schema_change_policy,
  :auto_data_quality)
  SENSITIVE = []
  include Aws::Structure
end