Class: Aws::Glue::Types::S3SourceAdditionalOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass S3SourceAdditionalOptions data as a hash:

{
  bounded_size: 1,
  bounded_files: 1,
}

Specifies additional connection options for the Amazon S3 data store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bounded_filesInteger

Sets the upper limit for the target number of files that will be processed.

Returns:

  • (Integer)


20752
20753
20754
20755
20756
20757
# File 'lib/aws-sdk-glue/types.rb', line 20752

class S3SourceAdditionalOptions < Struct.new(
  :bounded_size,
  :bounded_files)
  SENSITIVE = []
  include Aws::Structure
end

#bounded_sizeInteger

Sets the upper limit for the target size of the dataset in bytes that will be processed.

Returns:

  • (Integer)


20752
20753
20754
20755
20756
20757
# File 'lib/aws-sdk-glue/types.rb', line 20752

class S3SourceAdditionalOptions < Struct.new(
  :bounded_size,
  :bounded_files)
  SENSITIVE = []
  include Aws::Structure
end