Class: Aws::Glue::Types::SchemaChangePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SchemaChangePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A policy that specifies update and deletion behaviors for the crawler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_behavior ⇒ String
The deletion behavior when the crawler finds a deleted object.
-
#update_behavior ⇒ String
The update behavior when the crawler finds a changed schema.
Instance Attribute Details
#delete_behavior ⇒ String
The deletion behavior when the crawler finds a deleted object.
27488 27489 27490 27491 27492 27493 |
# File 'lib/aws-sdk-glue/types.rb', line 27488 class SchemaChangePolicy < Struct.new( :update_behavior, :delete_behavior) SENSITIVE = [] include Aws::Structure end |
#update_behavior ⇒ String
The update behavior when the crawler finds a changed schema.
27488 27489 27490 27491 27492 27493 |
# File 'lib/aws-sdk-glue/types.rb', line 27488 class SchemaChangePolicy < Struct.new( :update_behavior, :delete_behavior) SENSITIVE = [] include Aws::Structure end |