Class: Aws::Glue::Types::SchemaListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An object that contains minimal details for a schema.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timeString

The date and time that a schema was created.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the schema.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#registry_nameString

the name of the registry where the schema resides.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schema_arnString

The Amazon Resource Name (ARN) for the schema.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schema_nameString

The name of the schema.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schema_statusString

The status of the schema.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#updated_timeString

The date and time that a schema was updated.

Returns:

  • (String)


27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
# File 'lib/aws-sdk-glue/types.rb', line 27668

class SchemaListItem < Struct.new(
  :registry_name,
  :schema_name,
  :schema_arn,
  :description,
  :schema_status,
  :created_time,
  :updated_time)
  SENSITIVE = []
  include Aws::Structure
end