Class: Aws::Glue::Types::SchemaVersionErrorItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An object that contains the error details for an operation on a schema version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_detailsTypes::ErrorDetails

The details of the error for the schema version.

Returns:



25425
25426
25427
25428
25429
25430
# File 'lib/aws-sdk-glue/types.rb', line 25425

class SchemaVersionErrorItem < Struct.new(
  :version_number,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#version_numberInteger

The version number of the schema.

Returns:

  • (Integer)


25425
25426
25427
25428
25429
25430
# File 'lib/aws-sdk-glue/types.rb', line 25425

class SchemaVersionErrorItem < Struct.new(
  :version_number,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end