Class: Aws::Glue::Types::SearchAssetsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_clauseTypes::SearchFilterClause

The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.



26978
26979
26980
26981
26982
26983
26984
26985
26986
# File 'lib/aws-sdk-glue/types.rb', line 26978

class SearchAssetsInput < Struct.new(
  :search_text,
  :max_results,
  :next_token,
  :sort,
  :filter_clause)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:

  • (Integer)


26978
26979
26980
26981
26982
26983
26984
26985
26986
# File 'lib/aws-sdk-glue/types.rb', line 26978

class SearchAssetsInput < Struct.new(
  :search_text,
  :max_results,
  :next_token,
  :sort,
  :filter_clause)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


26978
26979
26980
26981
26982
26983
26984
26985
26986
# File 'lib/aws-sdk-glue/types.rb', line 26978

class SearchAssetsInput < Struct.new(
  :search_text,
  :max_results,
  :next_token,
  :sort,
  :filter_clause)
  SENSITIVE = []
  include Aws::Structure
end

#search_textString

The text to search for. At least one of ‘searchText` or `filterClause` must be provided.

Returns:

  • (String)


26978
26979
26980
26981
26982
26983
26984
26985
26986
# File 'lib/aws-sdk-glue/types.rb', line 26978

class SearchAssetsInput < Struct.new(
  :search_text,
  :max_results,
  :next_token,
  :sort,
  :filter_clause)
  SENSITIVE = []
  include Aws::Structure
end

#sortTypes::SearchSort

The sort criteria for the search results.

Returns:



26978
26979
26980
26981
26982
26983
26984
26985
26986
# File 'lib/aws-sdk-glue/types.rb', line 26978

class SearchAssetsInput < Struct.new(
  :search_text,
  :max_results,
  :next_token,
  :sort,
  :filter_clause)
  SENSITIVE = []
  include Aws::Structure
end