Class: Aws::Glue::Types::SearchOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SearchOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#items ⇒ Array<Types::SearchResultItem>
The list of assets matching the search criteria.
-
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
Instance Attribute Details
#items ⇒ Array<Types::SearchResultItem>
The list of assets matching the search criteria.
27126 27127 27128 27129 27130 27131 |
# File 'lib/aws-sdk-glue/types.rb', line 27126 class SearchOutput < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, present if the current segment is not the last.
27126 27127 27128 27129 27130 27131 |
# File 'lib/aws-sdk-glue/types.rb', line 27126 class SearchOutput < Struct.new( :items, :next_token) SENSITIVE = [] include Aws::Structure end |