Class: Aws::Glue::Types::SelectFields
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SelectFields
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that chooses the data property keys that you want to keep.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
18014 18015 18016 18017 18018 18019 18020 |
# File 'lib/aws-sdk-glue/types.rb', line 18014 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
18014 18015 18016 18017 18018 18019 18020 |
# File 'lib/aws-sdk-glue/types.rb', line 18014 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
18014 18015 18016 18017 18018 18019 18020 |
# File 'lib/aws-sdk-glue/types.rb', line 18014 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |