Class: Aws::Glue::Types::SnowflakeNodeData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies configuration for Snowflake nodes in Glue Studio.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Specifies what action to take when writing to a table with preexisting data. Valid values: ‘ append`, merge, truncate, drop.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#additional_optionsHash<String,String>

Specifies additional options passed to the Snowflake connector. If options are specified elsewhere in this node, this will take precedence.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#auto_pushdownBoolean

Specifies whether automatic query pushdown is enabled. If pushdown is enabled, then when a query is run on Spark, if part of the query can be “pushed down” to the Snowflake server, it is pushed down. This improves performance of some queries.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#connectionTypes::Option

Specifies a Glue Data Catalog Connection to a Snowflake endpoint.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

Specifies a Snowflake database for your node to use.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#iam_roleTypes::Option

Not currently used.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#merge_actionString

Specifies a merge action. Valid values: simple, custom. If simple, merge behavior is defined by MergeWhenMatched and ‘ MergeWhenNotMatched`. If custom, defined by MergeClause.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#merge_clauseString

A SQL statement that specifies a custom merge behavior.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#merge_when_matchedString

Specifies how to resolve records that match preexisting data when merging. Valid values: ‘ update`, delete.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#merge_when_not_matchedString

Specifies how to process records that do not match preexisting data when merging. Valid values: insert, none.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#post_actionString

A SQL string run after the Snowflake connector performs its standard actions.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#pre_actionString

A SQL string run before the Snowflake connector performs its standard actions.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#sample_queryString

A SQL string used to retrieve data with the query sourcetype.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#schemaString

Specifies a Snowflake database schema for your node to use.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#selected_columnsArray<Types::Option>

Specifies the columns combined to identify a record when detecting matches for merges and upserts. A list of structures with value, label and ‘ description` keys. Each structure describes a column.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

Specifies how retrieved data is specified. Valid values: ‘“table”`, ` “query”`.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#staging_tableString

The name of a staging table used when performing merge or upsert append actions. Data is written to this table, then moved to table by a generated postaction.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

Specifies a Snowflake table for your node to use.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#table_schemaArray<Types::Option>

Manually defines the target schema for the node. A list of structures with value , label and description keys. Each structure defines a column.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#temp_dirString

Not currently used.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end

#upsertBoolean

Used when Action is append. Specifies the resolution behavior when a row already exists. If true, preexisting rows will be updated. If false, those rows will be inserted.



25291
25292
25293
25294
25295
25296
25297
25298
25299
25300
25301
25302
25303
25304
25305
25306
25307
25308
25309
25310
25311
25312
25313
25314
25315
# File 'lib/aws-sdk-glue/types.rb', line 25291

class SnowflakeNodeData < Struct.new(
  :source_type,
  :connection,
  :schema,
  :table,
  :database,
  :temp_dir,
  :iam_role,
  :additional_options,
  :sample_query,
  :pre_action,
  :post_action,
  :action,
  :upsert,
  :merge_action,
  :merge_when_matched,
  :merge_when_not_matched,
  :merge_clause,
  :staging_table,
  :selected_columns,
  :auto_pushdown,
  :table_schema)
  SENSITIVE = []
  include Aws::Structure
end