Class: Aws::Glue::Types::SourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Configuration that defines how to make requests to endpoints, including request methods, paths, parameters, and response handling.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pagination_configuration ⇒ Types::PaginationConfiguration
Configuration for handling paginated responses from the REST API, supporting both cursor-based and offset-based pagination strategies.
-
#request_method ⇒ String
The HTTP method to use for requests to this endpoint, such as GET, POST.
-
#request_parameters ⇒ Array<Types::ConnectorProperty>
Configuration for request parameters that should be included in API calls, such as query parameters, headers, or body content.
-
#request_path ⇒ String
The URL path for the REST endpoint, which may include parameter placeholders that will be replaced with actual values during requests.
-
#response_configuration ⇒ Types::ResponseConfiguration
Configuration that defines how to parse and extract data from API responses, including success and error handling.
Instance Attribute Details
#pagination_configuration ⇒ Types::PaginationConfiguration
Configuration for handling paginated responses from the REST API, supporting both cursor-based and offset-based pagination strategies.
27847 27848 27849 27850 27851 27852 27853 27854 27855 |
# File 'lib/aws-sdk-glue/types.rb', line 27847 class SourceConfiguration < Struct.new( :request_method, :request_path, :request_parameters, :response_configuration, :pagination_configuration) SENSITIVE = [] include Aws::Structure end |
#request_method ⇒ String
The HTTP method to use for requests to this endpoint, such as GET, POST.
27847 27848 27849 27850 27851 27852 27853 27854 27855 |
# File 'lib/aws-sdk-glue/types.rb', line 27847 class SourceConfiguration < Struct.new( :request_method, :request_path, :request_parameters, :response_configuration, :pagination_configuration) SENSITIVE = [] include Aws::Structure end |
#request_parameters ⇒ Array<Types::ConnectorProperty>
Configuration for request parameters that should be included in API calls, such as query parameters, headers, or body content.
27847 27848 27849 27850 27851 27852 27853 27854 27855 |
# File 'lib/aws-sdk-glue/types.rb', line 27847 class SourceConfiguration < Struct.new( :request_method, :request_path, :request_parameters, :response_configuration, :pagination_configuration) SENSITIVE = [] include Aws::Structure end |
#request_path ⇒ String
The URL path for the REST endpoint, which may include parameter placeholders that will be replaced with actual values during requests.
27847 27848 27849 27850 27851 27852 27853 27854 27855 |
# File 'lib/aws-sdk-glue/types.rb', line 27847 class SourceConfiguration < Struct.new( :request_method, :request_path, :request_parameters, :response_configuration, :pagination_configuration) SENSITIVE = [] include Aws::Structure end |
#response_configuration ⇒ Types::ResponseConfiguration
Configuration that defines how to parse and extract data from API responses, including success and error handling.
27847 27848 27849 27850 27851 27852 27853 27854 27855 |
# File 'lib/aws-sdk-glue/types.rb', line 27847 class SourceConfiguration < Struct.new( :request_method, :request_path, :request_parameters, :response_configuration, :pagination_configuration) SENSITIVE = [] include Aws::Structure end |