Class: Aws::Glue::Types::SourceControlDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SourceControlDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The details for a source control configuration for a job, allowing synchronization of job artifacts to or from a remote repository.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_strategy ⇒ String
The type of authentication, which can be an authentication token stored in Amazon Web Services Secrets Manager, or a personal access token.
-
#auth_token ⇒ String
The value of an authorization token.
-
#branch ⇒ String
An optional branch in the remote repository.
-
#folder ⇒ String
An optional folder in the remote repository.
-
#last_commit_id ⇒ String
The last commit ID for a commit in the remote repository.
-
#owner ⇒ String
The owner of the remote repository that contains the job artifacts.
-
#provider ⇒ String
The provider for the remote repository.
-
#repository ⇒ String
The name of the remote repository that contains the job artifacts.
Instance Attribute Details
#auth_strategy ⇒ String
The type of authentication, which can be an authentication token stored in Amazon Web Services Secrets Manager, or a personal access token.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#auth_token ⇒ String
The value of an authorization token.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#branch ⇒ String
An optional branch in the remote repository.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#folder ⇒ String
An optional folder in the remote repository.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#last_commit_id ⇒ String
The last commit ID for a commit in the remote repository.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the remote repository that contains the job artifacts.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The provider for the remote repository.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |
#repository ⇒ String
The name of the remote repository that contains the job artifacts.
27896 27897 27898 27899 27900 27901 27902 27903 27904 27905 27906 27907 |
# File 'lib/aws-sdk-glue/types.rb', line 27896 class SourceControlDetails < Struct.new( :provider, :repository, :owner, :branch, :folder, :last_commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |