Class: Aws::Glue::Types::SourceTableConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Properties used by the source leg to process data from the source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<String>

A list of fields used for column-level filtering. Currently unsupported.



26179
26180
26181
26182
26183
26184
26185
26186
# File 'lib/aws-sdk-glue/types.rb', line 26179

class SourceTableConfig < Struct.new(
  :fields,
  :filter_predicate,
  :primary_key,
  :record_update_field)
  SENSITIVE = []
  include Aws::Structure
end

#filter_predicateString

A condition clause used for row-level filtering. Currently unsupported.



26179
26180
26181
26182
26183
26184
26185
26186
# File 'lib/aws-sdk-glue/types.rb', line 26179

class SourceTableConfig < Struct.new(
  :fields,
  :filter_predicate,
  :primary_key,
  :record_update_field)
  SENSITIVE = []
  include Aws::Structure
end

#primary_keyArray<String>

Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.



26179
26180
26181
26182
26183
26184
26185
26186
# File 'lib/aws-sdk-glue/types.rb', line 26179

class SourceTableConfig < Struct.new(
  :fields,
  :filter_predicate,
  :primary_key,
  :record_update_field)
  SENSITIVE = []
  include Aws::Structure
end

#record_update_fieldString

Incremental pull timestamp-based field. Currently unsupported.



26179
26180
26181
26182
26183
26184
26185
26186
# File 'lib/aws-sdk-glue/types.rb', line 26179

class SourceTableConfig < Struct.new(
  :fields,
  :filter_predicate,
  :primary_key,
  :record_update_field)
  SENSITIVE = []
  include Aws::Structure
end