Class: Aws::Glue::Types::SparkConnectorSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass SparkConnectorSource data as a hash:

{
  name: "NodeName", # required
  connection_name: "EnclosedInStringProperty", # required
  connector_name: "EnclosedInStringProperty", # required
  connection_type: "EnclosedInStringProperty", # required
  additional_options: {
    "EnclosedInStringProperty" => "EnclosedInStringProperty",
  },
  output_schemas: [
    {
      columns: [
        {
          name: "GlueStudioColumnNameString", # required
          type: "ColumnTypeString",
        },
      ],
    },
  ],
}

Specifies a connector to an Apache Spark data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsHash<String,String>

Additional connection options for the connector.

Returns:

  • (Hash<String,String>)


21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection that is associated with the connector.

Returns:

  • (String)


21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of connection, such as marketplace.spark or custom.spark, designating a connection to an Apache Spark data store.

Returns:

  • (String)


21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connector_nameString

The name of a connector that assists with accessing the data store in Glue Studio.

Returns:

  • (String)


21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies data schema for the custom spark source.

Returns:



21786
21787
21788
21789
21790
21791
21792
21793
21794
21795
# File 'lib/aws-sdk-glue/types.rb', line 21786

class SparkConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end