Class: Aws::Glue::Types::SparkConnectorTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a target that uses an Apache Spark connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsHash<String,String>

Additional connection options for the connector.

Returns:

  • (Hash<String,String>)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of a connection for an Apache Spark connector.

Returns:

  • (String)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of connection, such as marketplace.spark or custom.spark, designating a connection to an Apache Spark data store.

Returns:

  • (String)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connector_nameString

The name of an Apache Spark connector.

Returns:

  • (String)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the custom spark target.

Returns:



18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
# File 'lib/aws-sdk-glue/types.rb', line 18684

class SparkConnectorTarget < Struct.new(
  :name,
  :inputs,
  :connection_name,
  :connector_name,
  :connection_type,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end