Class: Aws::Glue::Types::Spigot
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Spigot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass Spigot data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
path: "EnclosedInStringProperty", # required
topk: 1,
prob: 1.0,
}
Specifies a transform that writes samples of the data to an Amazon S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#path ⇒ String
A path in Amazon S3 where the transform will write a subset of records from the dataset to a JSON file in an Amazon S3 bucket.
-
#prob ⇒ Float
The probability (a decimal value with a maximum value of 1) of picking any given record.
-
#topk ⇒ Integer
Specifies a number of records to write starting from the beginning of the dataset.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
21961 21962 21963 21964 21965 21966 21967 21968 21969 |
# File 'lib/aws-sdk-glue/types.rb', line 21961 class Spigot < Struct.new( :name, :inputs, :path, :topk, :prob) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
21961 21962 21963 21964 21965 21966 21967 21968 21969 |
# File 'lib/aws-sdk-glue/types.rb', line 21961 class Spigot < Struct.new( :name, :inputs, :path, :topk, :prob) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A path in Amazon S3 where the transform will write a subset of records from the dataset to a JSON file in an Amazon S3 bucket.
21961 21962 21963 21964 21965 21966 21967 21968 21969 |
# File 'lib/aws-sdk-glue/types.rb', line 21961 class Spigot < Struct.new( :name, :inputs, :path, :topk, :prob) SENSITIVE = [] include Aws::Structure end |
#prob ⇒ Float
The probability (a decimal value with a maximum value of 1) of picking any given record. A value of 1 indicates that each row read from the dataset should be included in the sample output.
21961 21962 21963 21964 21965 21966 21967 21968 21969 |
# File 'lib/aws-sdk-glue/types.rb', line 21961 class Spigot < Struct.new( :name, :inputs, :path, :topk, :prob) SENSITIVE = [] include Aws::Structure end |
#topk ⇒ Integer
Specifies a number of records to write starting from the beginning of the dataset.
21961 21962 21963 21964 21965 21966 21967 21968 21969 |
# File 'lib/aws-sdk-glue/types.rb', line 21961 class Spigot < Struct.new( :name, :inputs, :path, :topk, :prob) SENSITIVE = [] include Aws::Structure end |