Class: Aws::Glue::Types::SplitFields

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass SplitFields data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  paths: [ # required
    ["EnclosedInStringProperty"],
  ],
}

Specifies a transform that splits data property keys into two `DynamicFrames`. The output is a collection of `DynamicFrames`: one with selected data property keys, and one with the remaining data property keys.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputsArray<String>

The data inputs identified by their node names.

Returns:

  • (Array<String>)


21747
21748
21749
21750
21751
21752
21753
# File 'lib/aws-sdk-glue/types.rb', line 21747

class SplitFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


21747
21748
21749
21750
21751
21752
21753
# File 'lib/aws-sdk-glue/types.rb', line 21747

class SplitFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end

#pathsArray<Array<String>>

A JSON path to a variable in the data structure.

Returns:

  • (Array<Array<String>>)


21747
21748
21749
21750
21751
21752
21753
# File 'lib/aws-sdk-glue/types.rb', line 21747

class SplitFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end