Class: Aws::Glue::Types::SqlAlias
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SqlAlias
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Represents a single entry in the list of values for SqlAliases.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
A temporary name given to a table, or a column in a table.
-
#from ⇒ String
A table, or a column in a table.
Instance Attribute Details
#alias ⇒ String
A temporary name given to a table, or a column in a table.
26397 26398 26399 26400 26401 26402 |
# File 'lib/aws-sdk-glue/types.rb', line 26397 class SqlAlias < Struct.new( :from, :alias) SENSITIVE = [] include Aws::Structure end |
#from ⇒ String
A table, or a column in a table.
26397 26398 26399 26400 26401 26402 |
# File 'lib/aws-sdk-glue/types.rb', line 26397 class SqlAlias < Struct.new( :from, :alias) SENSITIVE = [] include Aws::Structure end |