Class: Aws::Glue::Types::StartDataQualityRulesetEvaluationRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartDataQualityRulesetEvaluationRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_data_sources ⇒ Hash<String,Types::DataSource>
A map of reference strings to additional data sources you can specify for an evaluation run.
-
#additional_run_options ⇒ Types::DataQualityEvaluationRunAdditionalRunOptions
Additional run options you can specify for an evaluation run.
-
#client_token ⇒ String
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
-
#data_source ⇒ Types::DataSource
The data source (Glue table) associated with this run.
-
#number_of_workers ⇒ Integer
The number of
G.1Xworkers to be used in the run. -
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
-
#ruleset_names ⇒ Array<String>
A list of ruleset names.
-
#timeout ⇒ Integer
The timeout for a run in minutes.
Instance Attribute Details
#additional_data_sources ⇒ Hash<String,Types::DataSource>
A map of reference strings to additional data sources you can specify for an evaluation run.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#additional_run_options ⇒ Types::DataQualityEvaluationRunAdditionalRunOptions
Additional run options you can specify for an evaluation run.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The data source (Glue table) associated with this run.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of G.1X workers to be used in the run. The default is
5.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#ruleset_names ⇒ Array<String>
A list of ruleset names.
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a run in minutes. This is the maximum time that a
run can consume resources before it is terminated and enters
TIMEOUT status. The default is 2,880 minutes (48 hours).
29107 29108 29109 29110 29111 29112 29113 29114 29115 29116 29117 29118 |
# File 'lib/aws-sdk-glue/types.rb', line 29107 class StartDataQualityRulesetEvaluationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :client_token, :additional_run_options, :ruleset_names, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |