Class: Aws::Glue::Types::StartWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workflow to start.
-
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
Instance Attribute Details
#name ⇒ String
The name of the workflow to start.
20514 20515 20516 20517 20518 20519 |
# File 'lib/aws-sdk-glue/types.rb', line 20514 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
20514 20515 20516 20517 20518 20519 |
# File 'lib/aws-sdk-glue/types.rb', line 20514 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |