Class: Aws::Glue::Types::StopCrawlerScheduleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StopCrawlerScheduleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass StopCrawlerScheduleRequest data as a hash:
{
crawler_name: "NameString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawler_name ⇒ String
Name of the crawler whose schedule state to set.
Instance Attribute Details
#crawler_name ⇒ String
Name of the crawler whose schedule state to set.
22452 22453 22454 22455 22456 |
# File 'lib/aws-sdk-glue/types.rb', line 22452 class StopCrawlerScheduleRequest < Struct.new( :crawler_name) SENSITIVE = [] include Aws::Structure end |