Class: Aws::Glue::Types::StorageDescriptor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Describes the physical storage of table data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_locationsArray<String>

A list of locations that point to the path where a Delta table is located.

Returns:

  • (Array<String>)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_columnsArray<String>

A list of reducer grouping columns, clustering columns, and bucketing columns in the table.

Returns:

  • (Array<String>)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#columnsArray<Types::Column>

A list of the Columns in the table.

Returns:



30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#compressedBoolean

True if the data in the table is compressed, or False if not.

Returns:

  • (Boolean)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#input_formatString

The input format: SequenceFileInputFormat (binary), or TextInputFormat, or a custom format.

Returns:

  • (String)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The physical location of the table. By default, this takes the form of the warehouse location, followed by the database location in the warehouse, followed by the table name.

Returns:

  • (String)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_bucketsInteger

Must be specified if the table contains any dimension columns.

Returns:

  • (Integer)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#output_formatString

The output format: SequenceFileOutputFormat (binary), or IgnoreKeyTextOutputFormat, or a custom format.

Returns:

  • (String)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

The user-supplied properties in key-value form.

Returns:

  • (Hash<String,String>)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#schema_referenceTypes::SchemaReference

An object that references a schema stored in the Glue Schema Registry.

When creating a table, you can pass an empty list of columns for the schema, and instead use a schema reference.



30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#serde_infoTypes::SerDeInfo

The serialization/deserialization (SerDe) information.

Returns:



30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#skewed_infoTypes::SkewedInfo

The information about values that appear frequently in a column (skewed values).

Returns:



30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#sort_columnsArray<Types::Order>

A list specifying the sort order of each bucket in the table.

Returns:



30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end

#stored_as_sub_directoriesBoolean

True if the table data is stored in subdirectories, or False if not.

Returns:

  • (Boolean)


30271
30272
30273
30274
30275
30276
30277
30278
30279
30280
30281
30282
30283
30284
30285
30286
30287
30288
# File 'lib/aws-sdk-glue/types.rb', line 30271

class StorageDescriptor < Struct.new(
  :columns,
  :location,
  :additional_locations,
  :input_format,
  :output_format,
  :compressed,
  :number_of_buckets,
  :serde_info,
  :bucket_columns,
  :sort_columns,
  :parameters,
  :skewed_info,
  :stored_as_sub_directories,
  :schema_reference)
  SENSITIVE = []
  include Aws::Structure
end