Class: Aws::Glue::Types::TableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure used to define a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the table.
-
#last_access_time ⇒ Time
The last time that the table was accessed.
-
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
-
#name ⇒ String
The table name.
-
#owner ⇒ String
The table owner.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
-
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned.
-
#retention ⇒ Integer
The retention time for this table.
-
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
-
#table_type ⇒ String
The type of this table.
-
#target_table ⇒ Types::TableIdentifier
A
TableIdentifierstructure that describes a target table for resource linking. -
#view_definition ⇒ Types::ViewDefinitionInput
A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.
-
#view_expanded_text ⇒ String
Included for Apache Hive compatibility.
-
#view_original_text ⇒ String
Included for Apache Hive compatibility.
Instance Attribute Details
#description ⇒ String
A description of the table.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#last_access_time ⇒ Time
The last time that the table was accessed.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The table name. For Hive compatibility, this is folded to lowercase when it is stored.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The table owner. Included for Apache Hive compatibility. Not used in the normal course of Glue operations.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.
When you create a table used by Amazon Athena, and you do not specify any partitionKeys, you must at least set the value of partitionKeys to an empty list. For example:
‘“PartitionKeys”: []`
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Integer
The retention time for this table.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#table_type ⇒ String
The type of this table. Glue will create tables with the EXTERNAL_TABLE type. Other services, such as Athena, may create tables with additional table types.
Glue related table types:
EXTERNAL_TABLE
: Hive compatible attribute - indicates a non-Hive managed table.
GOVERNED
: Used by Lake Formation. The Glue Data Catalog understands
`GOVERNED`.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#target_table ⇒ Types::TableIdentifier
A TableIdentifier structure that describes a target table for resource linking.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#view_definition ⇒ Types::ViewDefinitionInput
A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal course of Glue operations.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a VIRTUAL_VIEW, certain Athena configuration encoded in base64.
28058 28059 28060 28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 |
# File 'lib/aws-sdk-glue/types.rb', line 28058 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table, :view_definition) SENSITIVE = [] include Aws::Structure end |