Class: Aws::Glue::Types::TableOptimizer
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableOptimizer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains details about an optimizer associated with a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::TableOptimizerConfiguration
A ‘TableOptimizerConfiguration` object that was specified when creating or updating a table optimizer.
-
#configuration_source ⇒ String
Specifies the source of the optimizer configuration.
-
#last_run ⇒ Types::TableOptimizerRun
A ‘TableOptimizerRun` object representing the last run of the table optimizer.
-
#type ⇒ String
The type of table optimizer.
Instance Attribute Details
#configuration ⇒ Types::TableOptimizerConfiguration
A ‘TableOptimizerConfiguration` object that was specified when creating or updating a table optimizer.
29865 29866 29867 29868 29869 29870 29871 29872 |
# File 'lib/aws-sdk-glue/types.rb', line 29865 class TableOptimizer < Struct.new( :type, :configuration, :last_run, :configuration_source) SENSITIVE = [] include Aws::Structure end |
#configuration_source ⇒ String
Specifies the source of the optimizer configuration. This indicates how the table optimizer was configured and which entity or service initiated the configuration.
29865 29866 29867 29868 29869 29870 29871 29872 |
# File 'lib/aws-sdk-glue/types.rb', line 29865 class TableOptimizer < Struct.new( :type, :configuration, :last_run, :configuration_source) SENSITIVE = [] include Aws::Structure end |
#last_run ⇒ Types::TableOptimizerRun
A ‘TableOptimizerRun` object representing the last run of the table optimizer.
29865 29866 29867 29868 29869 29870 29871 29872 |
# File 'lib/aws-sdk-glue/types.rb', line 29865 class TableOptimizer < Struct.new( :type, :configuration, :last_run, :configuration_source) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of table optimizer. The valid values are:
-
‘compaction`: for managing compaction with a table optimizer.
-
‘retention`: for managing the retention of snapshot with a table optimizer.
-
‘orphan_file_deletion`: for managing the deletion of orphan files with a table optimizer.
29865 29866 29867 29868 29869 29870 29871 29872 |
# File 'lib/aws-sdk-glue/types.rb', line 29865 class TableOptimizer < Struct.new( :type, :configuration, :last_run, :configuration_source) SENSITIVE = [] include Aws::Structure end |