Class: Aws::Glue::Types::TableOptimizerConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableOptimizerConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains details on the configuration of a table optimizer. You pass this configuration when creating or updating a table optimizer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether table optimization is enabled.
-
#orphan_file_deletion_configuration ⇒ Types::OrphanFileDeletionConfiguration
The configuration for an orphan file deletion optimizer.
-
#retention_configuration ⇒ Types::RetentionConfiguration
The configuration for a snapshot retention optimizer.
-
#role_arn ⇒ String
A role passed by the caller which gives the service permission to update the resources associated with the optimizer on the caller’s behalf.
-
#vpc_configuration ⇒ Types::TableOptimizerVpcConfiguration
A ‘TableOptimizerVpcConfiguration` object representing the VPC configuration for a table optimizer.
Instance Attribute Details
#enabled ⇒ Boolean
Whether table optimization is enabled.
25689 25690 25691 25692 25693 25694 25695 25696 25697 |
# File 'lib/aws-sdk-glue/types.rb', line 25689 class TableOptimizerConfiguration < Struct.new( :role_arn, :enabled, :vpc_configuration, :retention_configuration, :orphan_file_deletion_configuration) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion_configuration ⇒ Types::OrphanFileDeletionConfiguration
The configuration for an orphan file deletion optimizer.
25689 25690 25691 25692 25693 25694 25695 25696 25697 |
# File 'lib/aws-sdk-glue/types.rb', line 25689 class TableOptimizerConfiguration < Struct.new( :role_arn, :enabled, :vpc_configuration, :retention_configuration, :orphan_file_deletion_configuration) SENSITIVE = [] include Aws::Structure end |
#retention_configuration ⇒ Types::RetentionConfiguration
The configuration for a snapshot retention optimizer.
25689 25690 25691 25692 25693 25694 25695 25696 25697 |
# File 'lib/aws-sdk-glue/types.rb', line 25689 class TableOptimizerConfiguration < Struct.new( :role_arn, :enabled, :vpc_configuration, :retention_configuration, :orphan_file_deletion_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
A role passed by the caller which gives the service permission to update the resources associated with the optimizer on the caller’s behalf.
25689 25690 25691 25692 25693 25694 25695 25696 25697 |
# File 'lib/aws-sdk-glue/types.rb', line 25689 class TableOptimizerConfiguration < Struct.new( :role_arn, :enabled, :vpc_configuration, :retention_configuration, :orphan_file_deletion_configuration) SENSITIVE = [] include Aws::Structure end |
#vpc_configuration ⇒ Types::TableOptimizerVpcConfiguration
A ‘TableOptimizerVpcConfiguration` object representing the VPC configuration for a table optimizer.
This configuration is necessary to perform optimization on tables that are in a customer VPC.
25689 25690 25691 25692 25693 25694 25695 25696 25697 |
# File 'lib/aws-sdk-glue/types.rb', line 25689 class TableOptimizerConfiguration < Struct.new( :role_arn, :enabled, :vpc_configuration, :retention_configuration, :orphan_file_deletion_configuration) SENSITIVE = [] include Aws::Structure end |