Class: Aws::Glue::Types::TableOptimizerRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableOptimizerRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains details for a table optimizer run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
-
#compaction_strategy ⇒ String
The strategy used for the compaction run.
-
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
-
#error ⇒ String
An error that occured during the optimizer run.
-
#event_type ⇒ String
An event type representing the status of the table optimizer run.
-
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
-
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
-
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
-
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
Instance Attribute Details
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#compaction_strategy ⇒ String
The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:
-
‘binpack`: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.
-
‘sort`: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the `sort_order` table property.
-
‘z-order`: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the `sort_order` table property.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#error ⇒ String
An error that occured during the optimizer run.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
An event type representing the status of the table optimizer run.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
30003 30004 30005 30006 30007 30008 30009 30010 30011 30012 30013 30014 30015 |
# File 'lib/aws-sdk-glue/types.rb', line 30003 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :compaction_strategy, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |