Class: Aws::Glue::Types::TransformConfigParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies the parameters in the config file of the dynamic transform.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_optionalBoolean

Specifies whether the parameter is optional or not in the config file of the dynamic transform.

Returns:

  • (Boolean)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#list_typeString

Specifies the list type of the parameter in the config file of the dynamic transform.

Returns:

  • (String)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specifies the name of the parameter in the config file of the dynamic transform.

Returns:

  • (String)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies the parameter type in the config file of the dynamic transform.

Returns:

  • (String)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#validation_messageString

Specifies the validation message in the config file of the dynamic transform.

Returns:

  • (String)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#validation_ruleString

Specifies the validation rule in the config file of the dynamic transform.

Returns:

  • (String)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end

#valueArray<String>

Specifies the value of the parameter in the config file of the dynamic transform.

Returns:

  • (Array<String>)


23117
23118
23119
23120
23121
23122
23123
23124
23125
23126
23127
# File 'lib/aws-sdk-glue/types.rb', line 23117

class TransformConfigParameter < Struct.new(
  :name,
  :type,
  :validation_rule,
  :validation_message,
  :value,
  :list_type,
  :is_optional)
  SENSITIVE = []
  include Aws::Structure
end