Class: Aws::Glue::Types::TransformParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The algorithm-specific parameters that are associated with the machine learning transform.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#find_matches_parametersTypes::FindMatchesParameters

The parameters for the find matches algorithm.



31097
31098
31099
31100
31101
31102
# File 'lib/aws-sdk-glue/types.rb', line 31097

class TransformParameters < Struct.new(
  :transform_type,
  :find_matches_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#transform_typeString

The type of machine learning transform.

For information about the types of machine learning transforms, see Creating Machine Learning Transforms.

Returns:

  • (String)


31097
31098
31099
31100
31101
31102
# File 'lib/aws-sdk-glue/types.rb', line 31097

class TransformParameters < Struct.new(
  :transform_type,
  :find_matches_parameters)
  SENSITIVE = []
  include Aws::Structure
end