Class: Aws::Glue::Types::TriggerNodeDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TriggerNodeDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The details of a Trigger node present in the workflow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#trigger ⇒ Types::Trigger
The information of the trigger represented by the trigger node.
Instance Attribute Details
#trigger ⇒ Types::Trigger
The information of the trigger represented by the trigger node.
18719 18720 18721 18722 18723 |
# File 'lib/aws-sdk-glue/types.rb', line 18719 class TriggerNodeDetails < Struct.new( :trigger) SENSITIVE = [] include Aws::Structure end |