Class: Aws::Glue::Types::Union

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a transform that combines the rows from two or more datasets into a single result.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputsArray<String>

The node ID inputs to the transform.

Returns:

  • (Array<String>)


31686
31687
31688
31689
31690
31691
31692
# File 'lib/aws-sdk-glue/types.rb', line 31686

class Union < Struct.new(
  :name,
  :inputs,
  :union_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


31686
31687
31688
31689
31690
31691
31692
# File 'lib/aws-sdk-glue/types.rb', line 31686

class Union < Struct.new(
  :name,
  :inputs,
  :union_type)
  SENSITIVE = []
  include Aws::Structure
end

#union_typeString

Indicates the type of Union transform.

Specify ALL to join all rows from data sources to the resulting DynamicFrame. The resulting union does not remove duplicate rows.

Specify DISTINCT to remove duplicate rows in the resulting DynamicFrame.

Returns:

  • (String)


31686
31687
31688
31689
31690
31691
31692
# File 'lib/aws-sdk-glue/types.rb', line 31686

class Union < Struct.new(
  :name,
  :inputs,
  :union_type)
  SENSITIVE = []
  include Aws::Structure
end