Class: Aws::Glue::Types::UpdateAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The new description of the asset.
-
#identifier ⇒ String
The unique identifier of the asset to update.
-
#name ⇒ String
The new name of the asset.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
30989 30990 30991 30992 30993 30994 30995 30996 |
# File 'lib/aws-sdk-glue/types.rb', line 30989 class UpdateAssetRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description of the asset.
30989 30990 30991 30992 30993 30994 30995 30996 |
# File 'lib/aws-sdk-glue/types.rb', line 30989 class UpdateAssetRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the asset to update.
30989 30990 30991 30992 30993 30994 30995 30996 |
# File 'lib/aws-sdk-glue/types.rb', line 30989 class UpdateAssetRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new name of the asset.
30989 30990 30991 30992 30993 30994 30995 30996 |
# File 'lib/aws-sdk-glue/types.rb', line 30989 class UpdateAssetRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |