Class: Aws::Glue::Types::UpdateDataQualityRulesetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateDataQualityRulesetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the ruleset.
-
#name ⇒ String
The name of the data quality ruleset.
-
#ruleset ⇒ String
A Data Quality Definition Language (DQDL) ruleset.
-
#updated_name ⇒ String
The new name of the ruleset, if you are renaming it.
Instance Attribute Details
#description ⇒ String
A description of the ruleset.
18996 18997 18998 18999 19000 19001 19002 19003 |
# File 'lib/aws-sdk-glue/types.rb', line 18996 class UpdateDataQualityRulesetRequest < Struct.new( :name, :updated_name, :description, :ruleset) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data quality ruleset.
18996 18997 18998 18999 19000 19001 19002 19003 |
# File 'lib/aws-sdk-glue/types.rb', line 18996 class UpdateDataQualityRulesetRequest < Struct.new( :name, :updated_name, :description, :ruleset) SENSITIVE = [] include Aws::Structure end |
#ruleset ⇒ String
A Data Quality Definition Language (DQDL) ruleset. For more information, see the Glue developer guide.
18996 18997 18998 18999 19000 19001 19002 19003 |
# File 'lib/aws-sdk-glue/types.rb', line 18996 class UpdateDataQualityRulesetRequest < Struct.new( :name, :updated_name, :description, :ruleset) SENSITIVE = [] include Aws::Structure end |
#updated_name ⇒ String
The new name of the ruleset, if you are renaming it.
18996 18997 18998 18999 19000 19001 19002 19003 |
# File 'lib/aws-sdk-glue/types.rb', line 18996 class UpdateDataQualityRulesetRequest < Struct.new( :name, :updated_name, :description, :ruleset) SENSITIVE = [] include Aws::Structure end |