Class: Aws::Glue::Types::UpdateDevEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateDevEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass UpdateDevEndpointRequest data as a hash:
{
endpoint_name: "GenericString", # required
public_key: "GenericString",
add_public_keys: ["GenericString"],
delete_public_keys: ["GenericString"],
custom_libraries: {
extra_python_libs_s3_path: "GenericString",
extra_jars_s3_path: "GenericString",
},
update_etl_libraries: false,
delete_arguments: ["GenericString"],
add_arguments: {
"GenericString" => "GenericString",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_arguments ⇒ Hash<String,String>
The map of arguments to add the map of arguments used to configure the `DevEndpoint`.
-
#add_public_keys ⇒ Array<String>
The list of public keys for the `DevEndpoint` to use.
-
#custom_libraries ⇒ Types::DevEndpointCustomLibraries
Custom Python or Java libraries to be loaded in the `DevEndpoint`.
-
#delete_arguments ⇒ Array<String>
The list of argument keys to be deleted from the map of arguments used to configure the `DevEndpoint`.
-
#delete_public_keys ⇒ Array<String>
The list of public keys to be deleted from the `DevEndpoint`.
-
#endpoint_name ⇒ String
The name of the `DevEndpoint` to be updated.
-
#public_key ⇒ String
The public key for the `DevEndpoint` to use.
-
#update_etl_libraries ⇒ Boolean
`True` if the list of custom libraries to be loaded in the development endpoint needs to be updated, or `False` if otherwise.
Instance Attribute Details
#add_arguments ⇒ Hash<String,String>
The map of arguments to add the map of arguments used to configure the `DevEndpoint`.
Valid arguments are:
-
`“–enable-glue-datacatalog”: “”`
^
You can specify a version of Python support for development endpoints by using the `Arguments` parameter in the `CreateDevEndpoint` or `UpdateDevEndpoint` APIs. If no arguments are provided, the version defaults to Python 2.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#add_public_keys ⇒ Array<String>
The list of public keys for the `DevEndpoint` to use.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#custom_libraries ⇒ Types::DevEndpointCustomLibraries
Custom Python or Java libraries to be loaded in the `DevEndpoint`.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#delete_arguments ⇒ Array<String>
The list of argument keys to be deleted from the map of arguments used to configure the `DevEndpoint`.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#delete_public_keys ⇒ Array<String>
The list of public keys to be deleted from the `DevEndpoint`.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the `DevEndpoint` to be updated.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#public_key ⇒ String
The public key for the `DevEndpoint` to use.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |
#update_etl_libraries ⇒ Boolean
`True` if the list of custom libraries to be loaded in the development endpoint needs to be updated, or `False` if otherwise.
18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 |
# File 'lib/aws-sdk-glue/types.rb', line 18013 class UpdateDevEndpointRequest < Struct.new( :endpoint_name, :public_key, :add_public_keys, :delete_public_keys, :custom_libraries, :update_etl_libraries, :delete_arguments, :add_arguments) SENSITIVE = [] include Aws::Structure end |