Class: Aws::Glue::Types::UpdateGlossaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateGlossaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The updated description of the glossary.
-
#identifier ⇒ String
The unique identifier of the glossary to update.
-
#name ⇒ String
The updated name of the glossary.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
31636 31637 31638 31639 31640 31641 31642 31643 |
# File 'lib/aws-sdk-glue/types.rb', line 31636 class UpdateGlossaryRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The updated description of the glossary.
31636 31637 31638 31639 31640 31641 31642 31643 |
# File 'lib/aws-sdk-glue/types.rb', line 31636 class UpdateGlossaryRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the glossary to update.
31636 31637 31638 31639 31640 31641 31642 31643 |
# File 'lib/aws-sdk-glue/types.rb', line 31636 class UpdateGlossaryRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the glossary.
31636 31637 31638 31639 31640 31641 31642 31643 |
# File 'lib/aws-sdk-glue/types.rb', line 31636 class UpdateGlossaryRequest < Struct.new( :identifier, :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |