Class: Aws::Glue::Types::UpdateGlossaryTermRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


31693
31694
31695
31696
31697
31698
31699
31700
31701
# File 'lib/aws-sdk-glue/types.rb', line 31693

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the glossary term to update.

Returns:

  • (String)


31693
31694
31695
31696
31697
31698
31699
31700
31701
# File 'lib/aws-sdk-glue/types.rb', line 31693

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#long_descriptionString

The updated long description of the glossary term.

Returns:

  • (String)


31693
31694
31695
31696
31697
31698
31699
31700
31701
# File 'lib/aws-sdk-glue/types.rb', line 31693

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated name of the glossary term.

Returns:

  • (String)


31693
31694
31695
31696
31697
31698
31699
31700
31701
# File 'lib/aws-sdk-glue/types.rb', line 31693

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#short_descriptionString

The updated short description of the glossary term.

Returns:

  • (String)


31693
31694
31695
31696
31697
31698
31699
31700
31701
# File 'lib/aws-sdk-glue/types.rb', line 31693

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end