Class: Aws::Glue::Types::UpdateGlueIdentityCenterConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateGlueIdentityCenterConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Request to update an existing Glue Identity Center configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scopes ⇒ Array<String>
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
-
#user_background_sessions_enabled ⇒ Boolean
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Instance Attribute Details
#scopes ⇒ Array<String>
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
29075 29076 29077 29078 29079 29080 |
# File 'lib/aws-sdk-glue/types.rb', line 29075 class UpdateGlueIdentityCenterConfigurationRequest < Struct.new( :scopes, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |
#user_background_sessions_enabled ⇒ Boolean
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
29075 29076 29077 29078 29079 29080 |
# File 'lib/aws-sdk-glue/types.rb', line 29075 class UpdateGlueIdentityCenterConfigurationRequest < Struct.new( :scopes, :user_background_sessions_enabled) SENSITIVE = [] include Aws::Structure end |