Class: Aws::Glue::Types::UpdateIcebergTableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateIcebergTableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains the update operations to be applied to an existing Iceberg table in AWS Glue Data Catalog, defining the new state of the table metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#updates ⇒ Array<Types::IcebergTableUpdate>
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Instance Attribute Details
#updates ⇒ Array<Types::IcebergTableUpdate>
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
28317 28318 28319 28320 28321 |
# File 'lib/aws-sdk-glue/types.rb', line 28317 class UpdateIcebergTableInput < Struct.new( :updates) SENSITIVE = [] include Aws::Structure end |