Class: Aws::Glue::Types::UpdateJobFromSourceControlRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass UpdateJobFromSourceControlRequest data as a hash:

{
  job_name: "NameString",
  provider: "GITHUB", # accepts GITHUB, AWS_CODE_COMMIT
  repository_name: "NameString",
  repository_owner: "NameString",
  branch_name: "NameString",
  folder: "NameString",
  commit_id: "CommitIdString",
  auth_strategy: "PERSONAL_ACCESS_TOKEN", # accepts PERSONAL_ACCESS_TOKEN, AWS_SECRETS_MANAGER
  auth_token: "AuthTokenString",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_strategyString

The type of authentication, which can be an authentication token stored in Amazon Web Services Secrets Manager, or a personal access token.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#auth_tokenString

The value of the authorization token.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#branch_nameString

An optional branch in the remote repository.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#commit_idString

A commit ID for a commit in the remote repository.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#folderString

An optional folder in the remote repository.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the Glue job to be synchronized to or from the remote repository.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#providerString

The provider for the remote repository.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the remote repository that contains the job artifacts.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#repository_ownerString

The owner of the remote repository that contains the job artifacts.

Returns:

  • (String)


24916
24917
24918
24919
24920
24921
24922
24923
24924
24925
24926
24927
24928
# File 'lib/aws-sdk-glue/types.rb', line 24916

class UpdateJobFromSourceControlRequest < Struct.new(
  :job_name,
  :provider,
  :repository_name,
  :repository_owner,
  :branch_name,
  :folder,
  :commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end