Class: Aws::Glue::Types::UpdateMLTransformRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateMLTransformRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the transform.
-
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform.
-
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
-
#name ⇒ String
The unique name that you gave the transform when you created it.
-
#number_of_workers ⇒ Integer
The number of workers of a defined
workerTypethat are allocated when this task runs. -
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the transform type (algorithm) used.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
-
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes.
-
#transform_id ⇒ String
A unique identifier that was generated when the transform was created.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs.
Instance Attribute Details
#description ⇒ String
A description of the transform. The default is an empty string.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
When the WorkerType field is set to a value other than Standard, the MaxCapacity field is set automatically and becomes read-only.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name that you gave the transform when you created it.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined workerType that are allocated when this task runs.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the transform type (algorithm) used. Conditionally dependent on the transform type.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#transform_id ⇒ String
A unique identifier that was generated when the transform was created.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.
-
For the
Standardworker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker. -
For the
G.1Xworker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker. -
For the
G.2Xworker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.
30150 30151 30152 30153 30154 30155 30156 30157 30158 30159 30160 30161 30162 30163 30164 |
# File 'lib/aws-sdk-glue/types.rb', line 30150 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |