Class: Aws::Glue::Types::UpdateSchemaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateSchemaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#registry_name ⇒ String
The name of the registry that contains the schema.
-
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
-
#schema_name ⇒ String
The name of the schema.
Instance Attribute Details
#registry_name ⇒ String
The name of the registry that contains the schema.
18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-glue/types.rb', line 18744 class UpdateSchemaResponse < Struct.new( :schema_arn, :schema_name, :registry_name) SENSITIVE = [] include Aws::Structure end |
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-glue/types.rb', line 18744 class UpdateSchemaResponse < Struct.new( :schema_arn, :schema_name, :registry_name) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the schema.
18744 18745 18746 18747 18748 18749 18750 |
# File 'lib/aws-sdk-glue/types.rb', line 18744 class UpdateSchemaResponse < Struct.new( :schema_arn, :schema_name, :registry_name) SENSITIVE = [] include Aws::Structure end |