Class: Aws::Glue::Types::UpdateTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the trigger to update.
-
#trigger_update ⇒ Types::TriggerUpdate
The new values with which to update the trigger.
Instance Attribute Details
#name ⇒ String
The name of the trigger to update.
32489 32490 32491 32492 32493 32494 |
# File 'lib/aws-sdk-glue/types.rb', line 32489 class UpdateTriggerRequest < Struct.new( :name, :trigger_update) SENSITIVE = [] include Aws::Structure end |
#trigger_update ⇒ Types::TriggerUpdate
The new values with which to update the trigger.
32489 32490 32491 32492 32493 32494 |
# File 'lib/aws-sdk-glue/types.rb', line 32489 class UpdateTriggerRequest < Struct.new( :name, :trigger_update) SENSITIVE = [] include Aws::Structure end |