Class: Aws::Glue::Types::UpdateWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workflow which was specified in input.
Instance Attribute Details
#name ⇒ String
The name of the workflow which was specified in input.
30833 30834 30835 30836 30837 |
# File 'lib/aws-sdk-glue/types.rb', line 30833 class UpdateWorkflowResponse < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |