Class: Aws::Glue::Types::UserDefinedFunction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Represents the equivalent of a Hive user-defined function (UDF) definition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the function resides.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#class_nameString

The Java class that contains the function code.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the function was created.

Returns:

  • (Time)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database that contains the function.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the function.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#function_typeString

The type of the function.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_nameString

The owner of the function.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#owner_typeString

The owner type.

Returns:

  • (String)


32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_urisArray<Types::ResourceUri>

The resource URIs for the function.

Returns:



32751
32752
32753
32754
32755
32756
32757
32758
32759
32760
32761
32762
32763
# File 'lib/aws-sdk-glue/types.rb', line 32751

class UserDefinedFunction < Struct.new(
  :function_name,
  :database_name,
  :class_name,
  :owner_name,
  :function_type,
  :owner_type,
  :create_time,
  :resource_uris,
  :catalog_id)
  SENSITIVE = []
  include Aws::Structure
end