Class: Aws::Glue::Types::ViewDefinitionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure containing details for creating or updating an Glue view.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definerString

The definer of a view in SQL.

Returns:

  • (String)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#is_protectedBoolean

You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.

Returns:

  • (Boolean)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#last_refresh_typeString

The type of the materialized view's last refresh. Valid values: Full, Incremental.

Returns:

  • (String)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_secondsInteger

Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.

Returns:

  • (Integer)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#representationsArray<Types::ViewRepresentationInput>

A list of structures that contains the dialect of the view, and the query that defines the view.

Returns:



33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#sub_object_version_idsArray<Integer>

List of the Apache Iceberg table versions referenced by the materialized view.

Returns:

  • (Array<Integer>)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#sub_objectsArray<String>

A list of base table ARNs that make up the view.

Returns:

  • (Array<String>)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#view_version_idInteger

The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.

Returns:

  • (Integer)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end

#view_version_tokenString

The version ID of the Apache Iceberg table.

Returns:

  • (String)


33791
33792
33793
33794
33795
33796
33797
33798
33799
33800
33801
33802
33803
# File 'lib/aws-sdk-glue/types.rb', line 33791

class ViewDefinitionInput < Struct.new(
  :is_protected,
  :definer,
  :representations,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids)
  SENSITIVE = []
  include Aws::Structure
end