Class: Aws::Glue::Types::ViewRepresentation
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ViewRepresentation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that contains the dialect of the view, and the query that defines the view.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dialect ⇒ String
The dialect of the query engine.
-
#dialect_version ⇒ String
The version of the dialect of the query engine.
-
#is_stale ⇒ Boolean
Dialects marked as stale are no longer valid and must be updated before they can be queried in their respective query engines.
-
#validation_connection ⇒ String
The name of the connection to be used to validate the specific representation of the view.
-
#view_expanded_text ⇒ String
The expanded SQL for the view.
-
#view_original_text ⇒ String
The
SELECTquery provided by the customer duringCREATE VIEW DDL.
Instance Attribute Details
#dialect ⇒ String
The dialect of the query engine.
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |
#dialect_version ⇒ String
The version of the dialect of the query engine. For example, 3.0.0.
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |
#is_stale ⇒ Boolean
Dialects marked as stale are no longer valid and must be updated before they can be queried in their respective query engines.
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |
#validation_connection ⇒ String
The name of the connection to be used to validate the specific representation of the view.
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
The expanded SQL for the view. This SQL is used by engines while
processing a query on a view. Engines may perform operations during
view creation to transform ViewOriginalText to ViewExpandedText.
For example:
- Fully qualified identifiers:
SELECT * from table1 -> SELECT * from db1.table1
^
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
The SELECT query provided by the customer during CREATE VIEW DDL. This SQL is not used during a query on a view
(ViewExpandedText is used instead). ViewOriginalText is used for
cases like SHOW CREATE VIEW where users want to see the original
DDL command that created the view.
33366 33367 33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/aws-sdk-glue/types.rb', line 33366 class ViewRepresentation < Struct.new( :dialect, :dialect_version, :view_original_text, :view_expanded_text, :validation_connection, :is_stale) SENSITIVE = [] include Aws::Structure end |