Class: Aws::Glue::Types::Workflow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A workflow is a collection of multiple dependent Glue jobs and crawlers that are run to complete a complex ETL task. A workflow manages the execution and monitoring of all its jobs and crawlers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blueprint_detailsTypes::BlueprintDetails

This structure indicates the details of the blueprint that this particular workflow is created from.



33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#created_onTime

The date and time when the workflow was created.

Returns:

  • (Time)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#default_run_propertiesHash<String,String>

A collection of properties to be used as part of each execution of the workflow. The run properties are made available to each job in the workflow. A job can modify the properties for the next jobs in the flow.

Returns:

  • (Hash<String,String>)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the workflow.

Returns:

  • (String)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#graphTypes::WorkflowGraph

The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.



33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The date and time when the workflow was last modified.

Returns:

  • (Time)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#last_runTypes::WorkflowRun

The information about the last execution of the workflow.

Returns:



33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrent_runsInteger

You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.

Returns:

  • (Integer)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workflow.

Returns:

  • (String)


33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
# File 'lib/aws-sdk-glue/types.rb', line 33822

class Workflow < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :created_on,
  :last_modified_on,
  :last_run,
  :graph,
  :max_concurrent_runs,
  :blueprint_details)
  SENSITIVE = []
  include Aws::Structure
end