Class: Aws::Glue::Types::XMLClassifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A classifier for `XML` content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classificationString

An identifier of the data format that the classifier matches.

Returns:

  • (String)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that this classifier was registered.

Returns:

  • (Time)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The time that this classifier was last updated.

Returns:

  • (Time)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the classifier.

Returns:

  • (String)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end

#row_tagString

The XML tag designating the element that contains each record in an XML document being parsed. This can't identify a self-closing element (closed by `/>`). An empty row element that contains only attributes can be parsed as long as it ends with a closing tag (for example, `<row item_a=“A” item_b=“B”></row>` is okay, but `<row item_a=“A” item_b=“B” />` is not).

Returns:

  • (String)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of this classifier.

Returns:

  • (Integer)


26442
26443
26444
26445
26446
26447
26448
26449
26450
26451
# File 'lib/aws-sdk-glue/types.rb', line 26442

class XMLClassifier < Struct.new(
  :name,
  :classification,
  :creation_time,
  :last_updated,
  :version,
  :row_tag)
  SENSITIVE = []
  include Aws::Structure
end