Class: Aws::Glue::Types::Aggregate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass Aggregate data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  groups: [ # required
    ["EnclosedInStringProperty"],
  ],
  aggs: [ # required
    {
      column: ["EnclosedInStringProperty"], # required
      agg_func: "avg", # required, accepts avg, countDistinct, count, first, last, kurtosis, max, min, skewness, stddev_samp, stddev_pop, sum, sumDistinct, var_samp, var_pop
    },
  ],
}

Specifies a transform that groups rows by chosen fields and computes the aggregated value by specified function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggsArray<Types::AggregateOperation>

Specifies the aggregate functions to be performed on specified fields.

Returns:



143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-glue/types.rb', line 143

class Aggregate < Struct.new(
  :name,
  :inputs,
  :groups,
  :aggs)
  SENSITIVE = []
  include Aws::Structure
end

#groupsArray<Array<String>>

Specifies the fields to group by.

Returns:

  • (Array<Array<String>>)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-glue/types.rb', line 143

class Aggregate < Struct.new(
  :name,
  :inputs,
  :groups,
  :aggs)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

Specifies the fields and rows to use as inputs for the aggregate transform.

Returns:

  • (Array<String>)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-glue/types.rb', line 143

class Aggregate < Struct.new(
  :name,
  :inputs,
  :groups,
  :aggs)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-glue/types.rb', line 143

class Aggregate < Struct.new(
  :name,
  :inputs,
  :groups,
  :aggs)
  SENSITIVE = []
  include Aws::Structure
end