Class: Aws::Glue::Types::AssociateGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AssociateGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset to associate glossary terms with.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to associate with the asset.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form.
-
#iterable_form_name ⇒ String
The name of the iterable form.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset to associate glossary terms with.
540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-glue/types.rb', line 540 class AssociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-glue/types.rb', line 540 class AssociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to associate with the asset.
540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-glue/types.rb', line 540 class AssociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form. Required when
iterableFormName is specified.
540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-glue/types.rb', line 540 class AssociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form. When specified along with
itemIdentifier, the glossary terms are associated with an item
within the iterable form rather than the asset itself.
540 541 542 543 544 545 546 547 548 |
# File 'lib/aws-sdk-glue/types.rb', line 540 class AssociateGlossaryTermsRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |