Class: Aws::Glue::Types::AssociateGlossaryTermsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-glue/types.rb', line 529

class AssociateGlossaryTermsRequest < Struct.new(
  :identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_term_identifiersArray<String>

The list of glossary term identifiers to associate with the asset.

Returns:

  • (Array<String>)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-glue/types.rb', line 529

class AssociateGlossaryTermsRequest < Struct.new(
  :identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the asset to associate glossary terms with.

Returns:

  • (String)


529
530
531
532
533
534
535
# File 'lib/aws-sdk-glue/types.rb', line 529

class AssociateGlossaryTermsRequest < Struct.new(
  :identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end