Class: Aws::Glue::Types::AssociateGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AssociateGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to associate with the asset.
-
#identifier ⇒ String
The unique identifier of the asset to associate glossary terms with.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
529 530 531 532 533 534 535 |
# File 'lib/aws-sdk-glue/types.rb', line 529 class AssociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to associate with the asset.
529 530 531 532 533 534 535 |
# File 'lib/aws-sdk-glue/types.rb', line 529 class AssociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the asset to associate glossary terms with.
529 530 531 532 533 534 535 |
# File 'lib/aws-sdk-glue/types.rb', line 529 class AssociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |