Class: Aws::Glue::Types::AssociateGlossaryTermsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AssociateGlossaryTermsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset.
-
#glossary_terms ⇒ Array<String>
The glossary terms now associated with the asset.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
-
#iterable_form_name ⇒ String
The name of the iterable form, if the association targets an item.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset.
568 569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-glue/types.rb', line 568 class AssociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms now associated with the asset.
568 569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-glue/types.rb', line 568 class AssociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
568 569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-glue/types.rb', line 568 class AssociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form, if the association targets an item.
568 569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-glue/types.rb', line 568 class AssociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |