Class: Aws::Glue::Types::AthenaConnectorSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass AthenaConnectorSource data as a hash:

{
  name: "NodeName", # required
  connection_name: "EnclosedInStringProperty", # required
  connector_name: "EnclosedInStringProperty", # required
  connection_type: "EnclosedInStringProperty", # required
  connection_table: "EnclosedInStringPropertyWithQuote",
  schema_name: "EnclosedInStringProperty", # required
  output_schemas: [
    {
      columns: [
        {
          name: "GlueStudioColumnNameString", # required
          type: "ColumnTypeString",
        },
      ],
    },
  ],
}

Specifies a connector to an Amazon Athena data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_nameString

The name of the connection that is associated with the connector.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_tableString

The name of the table in the data source.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of connection, such as marketplace.athena or custom.athena, designating a connection to an Amazon Athena data store.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#connector_nameString

The name of a connector that assists with accessing the data store in Glue Studio.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the custom Athena source.

Returns:



304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#schema_nameString

The name of the Cloudwatch log group to read from. For example, `/aws-glue/jobs/output`.

Returns:

  • (String)


304
305
306
307
308
309
310
311
312
313
314
# File 'lib/aws-sdk-glue/types.rb', line 304

class AthenaConnectorSource < Struct.new(
  :name,
  :connection_name,
  :connector_name,
  :connection_type,
  :connection_table,
  :schema_name,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end