Class: Aws::Glue::Types::AuthenticationConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::AuthenticationConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure containing the authentication configuration in the CreateConnection request.
Constant Summary collapse
- SENSITIVE =
[:custom_authentication_credentials]
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
A structure containing the authentication configuration in the CreateConnection request.
-
#basic_authentication_credentials ⇒ Types::BasicAuthenticationCredentials
The credentials used when the authentication type is basic authentication.
-
#custom_authentication_credentials ⇒ Hash<String,String>
The credentials used when the authentication type is custom authentication.
-
#kms_key_arn ⇒ String
The ARN of the KMS key used to encrypt the connection.
-
#o_auth_2_properties ⇒ Types::OAuth2PropertiesInput
The properties for OAuth2 authentication in the CreateConnection request.
-
#secret_arn ⇒ String
The secret manager ARN to store credentials in the CreateConnection request.
Instance Attribute Details
#authentication_type ⇒ String
A structure containing the authentication configuration in the CreateConnection request.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |
#basic_authentication_credentials ⇒ Types::BasicAuthenticationCredentials
The credentials used when the authentication type is basic authentication.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |
#custom_authentication_credentials ⇒ Hash<String,String>
The credentials used when the authentication type is custom authentication.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |
#o_auth_2_properties ⇒ Types::OAuth2PropertiesInput
The properties for OAuth2 authentication in the CreateConnection request.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |
#secret_arn ⇒ String
The secret manager ARN to store credentials in the CreateConnection request.
730 731 732 733 734 735 736 737 738 739 |
# File 'lib/aws-sdk-glue/types.rb', line 730 class AuthenticationConfigurationInput < Struct.new( :authentication_type, :o_auth_2_properties, :secret_arn, :kms_key_arn, :basic_authentication_credentials, :custom_authentication_credentials) SENSITIVE = [:custom_authentication_credentials] include Aws::Structure end |