Class: Aws::Glue::Types::BatchDeleteConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeleteConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside.
-
#connection_name_list ⇒ Array<String>
A list of names of the connections to delete.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default.
986 987 988 989 990 991 |
# File 'lib/aws-sdk-glue/types.rb', line 986 class BatchDeleteConnectionRequest < Struct.new( :catalog_id, :connection_name_list) SENSITIVE = [] include Aws::Structure end |
#connection_name_list ⇒ Array<String>
A list of names of the connections to delete.
986 987 988 989 990 991 |
# File 'lib/aws-sdk-glue/types.rb', line 986 class BatchDeleteConnectionRequest < Struct.new( :catalog_id, :connection_name_list) SENSITIVE = [] include Aws::Structure end |