Class: Aws::Glue::Types::BatchDeleteConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeleteConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchDeleteConnectionRequest data as a hash:
{
catalog_id: "CatalogIdString",
connection_name_list: ["NameString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside.
-
#connection_name_list ⇒ Array<String>
A list of names of the connections to delete.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default.
323 324 325 326 327 328 |
# File 'lib/aws-sdk-glue/types.rb', line 323 class BatchDeleteConnectionRequest < Struct.new( :catalog_id, :connection_name_list) SENSITIVE = [] include Aws::Structure end |
#connection_name_list ⇒ Array<String>
A list of names of the connections to delete.
323 324 325 326 327 328 |
# File 'lib/aws-sdk-glue/types.rb', line 323 class BatchDeleteConnectionRequest < Struct.new( :catalog_id, :connection_name_list) SENSITIVE = [] include Aws::Structure end |