Class: Aws::Glue::Types::BatchDeletePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeletePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partitions_to_delete ⇒ Array<Types::PartitionValueList>
A list of ‘PartitionInput` structures that define the partitions to be deleted.
-
#table_name ⇒ String
The name of the table that contains the partitions to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default.
1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/aws-sdk-glue/types.rb', line 1011 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/aws-sdk-glue/types.rb', line 1011 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#partitions_to_delete ⇒ Array<Types::PartitionValueList>
A list of ‘PartitionInput` structures that define the partitions to be deleted.
1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/aws-sdk-glue/types.rb', line 1011 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that contains the partitions to be deleted.
1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/aws-sdk-glue/types.rb', line 1011 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |