Class: Aws::Glue::Types::BatchDeletePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeletePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchDeletePartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partitions_to_delete: [ # required
{
values: ["ValueString"], # required
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partitions_to_delete ⇒ Array<Types::PartitionValueList>
A list of `PartitionInput` structures that define the partitions to be deleted.
-
#table_name ⇒ String
The name of the table that contains the partitions to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default.
370 371 372 373 374 375 376 377 |
# File 'lib/aws-sdk-glue/types.rb', line 370 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
370 371 372 373 374 375 376 377 |
# File 'lib/aws-sdk-glue/types.rb', line 370 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#partitions_to_delete ⇒ Array<Types::PartitionValueList>
A list of `PartitionInput` structures that define the partitions to be deleted.
370 371 372 373 374 375 376 377 |
# File 'lib/aws-sdk-glue/types.rb', line 370 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that contains the partitions to be deleted.
370 371 372 373 374 375 376 377 |
# File 'lib/aws-sdk-glue/types.rb', line 370 class BatchDeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_delete) SENSITIVE = [] include Aws::Structure end |