Class: Aws::Glue::Types::BatchDeleteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeleteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the catalog database in which the tables to delete reside.
-
#tables_to_delete ⇒ Array<String>
A list of the table to delete.
-
#transaction_id ⇒ String
The transaction ID at which to delete the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-glue/types.rb', line 1053 class BatchDeleteTableRequest < Struct.new( :catalog_id, :database_name, :tables_to_delete, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the tables to delete reside. For Hive compatibility, this name is entirely lowercase.
1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-glue/types.rb', line 1053 class BatchDeleteTableRequest < Struct.new( :catalog_id, :database_name, :tables_to_delete, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#tables_to_delete ⇒ Array<String>
A list of the table to delete.
1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-glue/types.rb', line 1053 class BatchDeleteTableRequest < Struct.new( :catalog_id, :database_name, :tables_to_delete, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to delete the table contents.
1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-glue/types.rb', line 1053 class BatchDeleteTableRequest < Struct.new( :catalog_id, :database_name, :tables_to_delete, :transaction_id) SENSITIVE = [] include Aws::Structure end |