Class: Aws::Glue::Types::BatchDeleteTableVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchDeleteTableVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog in which the table resides.
-
#table_name ⇒ String
The name of the table.
-
#version_ids ⇒ Array<String>
A list of the IDs of versions to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
517 518 519 520 521 522 523 524 |
# File 'lib/aws-sdk-glue/types.rb', line 517 class BatchDeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_ids) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
517 518 519 520 521 522 523 524 |
# File 'lib/aws-sdk-glue/types.rb', line 517 class BatchDeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_ids) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table. For Hive compatibility, this name is entirely lowercase.
517 518 519 520 521 522 523 524 |
# File 'lib/aws-sdk-glue/types.rb', line 517 class BatchDeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_ids) SENSITIVE = [] include Aws::Structure end |
#version_ids ⇒ Array<String>
A list of the IDs of versions to be deleted. A `VersionId` is a string representation of an integer. Each version is incremented by 1.
517 518 519 520 521 522 523 524 |
# File 'lib/aws-sdk-glue/types.rb', line 517 class BatchDeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_ids) SENSITIVE = [] include Aws::Structure end |