Class: Aws::Glue::Types::BatchGetBlueprintsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass BatchGetBlueprintsRequest data as a hash:

{
  names: ["OrchestrationNameString"], # required
  include_blueprint: false,
  include_parameter_spec: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_blueprintBoolean

Specifies whether or not to include the blueprint in the response.

Returns:

  • (Boolean)


523
524
525
526
527
528
529
# File 'lib/aws-sdk-glue/types.rb', line 523

class BatchGetBlueprintsRequest < Struct.new(
  :names,
  :include_blueprint,
  :include_parameter_spec)
  SENSITIVE = []
  include Aws::Structure
end

#include_parameter_specBoolean

Specifies whether or not to include the parameters, as a JSON string, for the blueprint in the response.

Returns:

  • (Boolean)


523
524
525
526
527
528
529
# File 'lib/aws-sdk-glue/types.rb', line 523

class BatchGetBlueprintsRequest < Struct.new(
  :names,
  :include_blueprint,
  :include_parameter_spec)
  SENSITIVE = []
  include Aws::Structure
end

#namesArray<String>

A list of blueprint names.

Returns:

  • (Array<String>)


523
524
525
526
527
528
529
# File 'lib/aws-sdk-glue/types.rb', line 523

class BatchGetBlueprintsRequest < Struct.new(
  :names,
  :include_blueprint,
  :include_parameter_spec)
  SENSITIVE = []
  include Aws::Structure
end