Class: Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#run_ids ⇒ Array<String>
A list of unique run identifiers for the evaluation runs to retrieve.
Instance Attribute Details
#run_ids ⇒ Array<String>
A list of unique run identifiers for the evaluation runs to retrieve.
1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class BatchGetDataQualityRulesetEvaluationRunRequest < Struct.new( :run_ids) SENSITIVE = [] include Aws::Structure end |