Class: Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetDataQualityRulesetEvaluationRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#runs ⇒ Array<Types::DataQualityRulesetEvaluationRun>
A list of evaluation run details for the requested run IDs.
-
#runs_not_found ⇒ Array<String>
A list of run IDs that were not found.
Instance Attribute Details
#runs ⇒ Array<Types::DataQualityRulesetEvaluationRun>
A list of evaluation run details for the requested run IDs.
1273 1274 1275 1276 1277 1278 |
# File 'lib/aws-sdk-glue/types.rb', line 1273 class BatchGetDataQualityRulesetEvaluationRunResponse < Struct.new( :runs, :runs_not_found) SENSITIVE = [] include Aws::Structure end |
#runs_not_found ⇒ Array<String>
A list of run IDs that were not found.
1273 1274 1275 1276 1277 1278 |
# File 'lib/aws-sdk-glue/types.rb', line 1273 class BatchGetDataQualityRulesetEvaluationRunResponse < Struct.new( :runs, :runs_not_found) SENSITIVE = [] include Aws::Structure end |