Class: Aws::Glue::Types::BatchGetIterableFormsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetIterableFormsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Array<Types::ItemError>
The list of errors for items that could not be retrieved.
-
#items ⇒ Array<Types::IterableFormItem>
The list of retrieved iterable form items.
Instance Attribute Details
#errors ⇒ Array<Types::ItemError>
The list of errors for items that could not be retrieved.
1313 1314 1315 1316 1317 1318 |
# File 'lib/aws-sdk-glue/types.rb', line 1313 class BatchGetIterableFormsResponse < Struct.new( :items, :errors) SENSITIVE = [] include Aws::Structure end |
#items ⇒ Array<Types::IterableFormItem>
The list of retrieved iterable form items.
1313 1314 1315 1316 1317 1318 |
# File 'lib/aws-sdk-glue/types.rb', line 1313 class BatchGetIterableFormsResponse < Struct.new( :items, :errors) SENSITIVE = [] include Aws::Structure end |