Class: Aws::Glue::Types::BatchGetPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partitions_to_get ⇒ Array<Types::PartitionValueList>
A list of partition values identifying the partitions to retrieve.
-
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#partitions_to_get ⇒ Array<Types::PartitionValueList>
A list of partition values identifying the partitions to retrieve.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#query_session_context ⇒ Types::QuerySessionContext
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request’s authorization context.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-glue/types.rb', line 1381 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get, :audit_context, :query_session_context) SENSITIVE = [] include Aws::Structure end |