Class: Aws::Glue::Types::BatchGetPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchGetPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchGetPartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partitions_to_get: [ # required
{
values: ["ValueString"], # required
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partitions_to_get ⇒ Array<Types::PartitionValueList>
A list of partition values identifying the partitions to retrieve.
-
#table_name ⇒ String
The name of the partitions' table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
745 746 747 748 749 750 751 752 |
# File 'lib/aws-sdk-glue/types.rb', line 745 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
745 746 747 748 749 750 751 752 |
# File 'lib/aws-sdk-glue/types.rb', line 745 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get) SENSITIVE = [] include Aws::Structure end |
#partitions_to_get ⇒ Array<Types::PartitionValueList>
A list of partition values identifying the partitions to retrieve.
745 746 747 748 749 750 751 752 |
# File 'lib/aws-sdk-glue/types.rb', line 745 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions' table.
745 746 747 748 749 750 751 752 |
# File 'lib/aws-sdk-glue/types.rb', line 745 class BatchGetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partitions_to_get) SENSITIVE = [] include Aws::Structure end |