Class: Aws::Glue::Types::BatchStopJobRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchStopJobRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Array<Types::BatchStopJobRunError>
A list of the errors that were encountered in trying to stop
JobRuns, including theJobRunIdfor which each error was encountered and details about the error. -
#successful_submissions ⇒ Array<Types::BatchStopJobRunSuccessfulSubmission>
A list of the JobRuns that were successfully submitted for stopping.
Instance Attribute Details
#errors ⇒ Array<Types::BatchStopJobRunError>
A list of the errors that were encountered in trying to stop
JobRuns, including the JobRunId for which each error was
encountered and details about the error.
1690 1691 1692 1693 1694 1695 |
# File 'lib/aws-sdk-glue/types.rb', line 1690 class BatchStopJobRunResponse < Struct.new( :successful_submissions, :errors) SENSITIVE = [] include Aws::Structure end |
#successful_submissions ⇒ Array<Types::BatchStopJobRunSuccessfulSubmission>
A list of the JobRuns that were successfully submitted for stopping.
1690 1691 1692 1693 1694 1695 |
# File 'lib/aws-sdk-glue/types.rb', line 1690 class BatchStopJobRunResponse < Struct.new( :successful_submissions, :errors) SENSITIVE = [] include Aws::Structure end |