Class: Aws::Glue::Types::BatchUpdatePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::BatchUpdatePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass BatchUpdatePartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
entries: [ # required
{
partition_value_list: ["ValueString"], # required
partition_input: { # required
values: ["ValueString"],
last_access_time: Time.now,
storage_descriptor: {
columns: [
{
name: "NameString", # required
type: "ColumnTypeString",
comment: "CommentString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
],
location: "LocationString",
additional_locations: ["LocationString"],
input_format: "FormatString",
output_format: "FormatString",
compressed: false,
number_of_buckets: 1,
serde_info: {
name: "NameString",
serialization_library: "NameString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
bucket_columns: ["NameString"],
sort_columns: [
{
column: "NameString", # required
sort_order: 1, # required
},
],
parameters: {
"KeyString" => "ParametersMapValue",
},
skewed_info: {
skewed_column_names: ["NameString"],
skewed_column_values: ["ColumnValuesString"],
skewed_column_value_location_maps: {
"ColumnValuesString" => "ColumnValuesString",
},
},
stored_as_sub_directories: false,
schema_reference: {
schema_id: {
schema_arn: "GlueResourceArn",
schema_name: "SchemaRegistryNameString",
registry_name: "SchemaRegistryNameString",
},
schema_version_id: "SchemaVersionIdString",
schema_version_number: 1,
},
},
parameters: {
"KeyString" => "ParametersMapValue",
},
last_analyzed_time: Time.now,
},
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be updated.
-
#database_name ⇒ String
The name of the metadata database in which the partition is to be updated.
-
#entries ⇒ Array<Types::BatchUpdatePartitionRequestEntry>
A list of up to 100 `BatchUpdatePartitionRequestEntry` objects to update.
-
#table_name ⇒ String
The name of the metadata table in which the partition is to be updated.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the catalog in which the partition is to be updated. Currently, this should be the Amazon Web Services account ID.
1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/aws-sdk-glue/types.rb', line 1021 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the metadata database in which the partition is to be updated.
1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/aws-sdk-glue/types.rb', line 1021 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#entries ⇒ Array<Types::BatchUpdatePartitionRequestEntry>
A list of up to 100 `BatchUpdatePartitionRequestEntry` objects to update.
1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/aws-sdk-glue/types.rb', line 1021 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the metadata table in which the partition is to be updated.
1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/aws-sdk-glue/types.rb', line 1021 class BatchUpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :entries) SENSITIVE = [] include Aws::Structure end |