Class: Aws::Glue::Types::Blueprint
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Blueprint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The details of a blueprint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprint_location ⇒ String
Specifies the path in Amazon S3 where the blueprint is published.
-
#blueprint_service_location ⇒ String
Specifies a path in Amazon S3 where the blueprint is copied when you call `CreateBlueprint/UpdateBlueprint` to register the blueprint in Glue.
-
#created_on ⇒ Time
The date and time the blueprint was registered.
-
#description ⇒ String
The description of the blueprint.
-
#error_message ⇒ String
An error message.
-
#last_active_definition ⇒ Types::LastActiveDefinition
When there are multiple versions of a blueprint and the latest version has some errors, this attribute indicates the last successful blueprint definition that is available with the service.
-
#last_modified_on ⇒ Time
The date and time the blueprint was last modified.
-
#name ⇒ String
The name of the blueprint.
-
#parameter_spec ⇒ String
A JSON string that indicates the list of parameter specifications for the blueprint.
-
#status ⇒ String
The status of the blueprint registration.
Instance Attribute Details
#blueprint_location ⇒ String
Specifies the path in Amazon S3 where the blueprint is published.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#blueprint_service_location ⇒ String
Specifies a path in Amazon S3 where the blueprint is copied when you call `CreateBlueprint/UpdateBlueprint` to register the blueprint in Glue.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#created_on ⇒ Time
The date and time the blueprint was registered.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the blueprint.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#last_active_definition ⇒ Types::LastActiveDefinition
When there are multiple versions of a blueprint and the latest version has some errors, this attribute indicates the last successful blueprint definition that is available with the service.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
The date and time the blueprint was last modified.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the blueprint.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#parameter_spec ⇒ String
A JSON string that indicates the list of parameter specifications for the blueprint.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the blueprint registration.
-
Creating — The blueprint registration is in progress.
-
Active — The blueprint has been successfully registered.
-
Updating — An update to the blueprint registration is in progress.
-
Failed — The blueprint registration failed.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/aws-sdk-glue/types.rb', line 1257 class Blueprint < Struct.new( :name, :description, :created_on, :last_modified_on, :parameter_spec, :blueprint_location, :blueprint_service_location, :status, :error_message, :last_active_definition) SENSITIVE = [] include Aws::Structure end |