Class: Aws::Glue::Types::Blueprint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The details of a blueprint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blueprint_locationString

Specifies the path in Amazon S3 where the blueprint is published.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#blueprint_service_locationString

Specifies a path in Amazon S3 where the blueprint is copied when you call `CreateBlueprint/UpdateBlueprint` to register the blueprint in Glue.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#created_onTime

The date and time the blueprint was registered.

Returns:

  • (Time)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the blueprint.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

An error message.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#last_active_definitionTypes::LastActiveDefinition

When there are multiple versions of a blueprint and the latest version has some errors, this attribute indicates the last successful blueprint definition that is available with the service.



1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The date and time the blueprint was last modified.

Returns:

  • (Time)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the blueprint.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_specString

A JSON string that indicates the list of parameter specifications for the blueprint.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the blueprint registration.

  • Creating — The blueprint registration is in progress.

  • Active — The blueprint has been successfully registered.

  • Updating — An update to the blueprint registration is in progress.

  • Failed — The blueprint registration failed.

Returns:

  • (String)


1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
# File 'lib/aws-sdk-glue/types.rb', line 1253

class Blueprint < Struct.new(
  :name,
  :description,
  :created_on,
  :last_modified_on,
  :parameter_spec,
  :blueprint_location,
  :blueprint_service_location,
  :status,
  :error_message,
  :last_active_definition)
  SENSITIVE = []
  include Aws::Structure
end