Class: Aws::Glue::Types::CatalogProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CatalogProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that specifies data lake access properties and other custom properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_properties ⇒ Hash<String,String>
Additional key-value properties for the catalog, such as column statistics optimizations.
-
#data_lake_access_properties ⇒ Types::DataLakeAccessProperties
A
DataLakeAccessPropertiesobject that specifies properties to configure data lake access for your catalog resource in the Glue Data Catalog. -
#iceberg_optimization_properties ⇒ Types::IcebergOptimizationProperties
A structure that specifies Iceberg table optimization properties for the catalog.
Instance Attribute Details
#custom_properties ⇒ Hash<String,String>
Additional key-value properties for the catalog, such as column statistics optimizations.
2400 2401 2402 2403 2404 2405 2406 |
# File 'lib/aws-sdk-glue/types.rb', line 2400 class CatalogProperties < Struct.new( :data_lake_access_properties, :iceberg_optimization_properties, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#data_lake_access_properties ⇒ Types::DataLakeAccessProperties
A DataLakeAccessProperties object that specifies properties to configure data lake access for your catalog resource in the Glue Data Catalog.
2400 2401 2402 2403 2404 2405 2406 |
# File 'lib/aws-sdk-glue/types.rb', line 2400 class CatalogProperties < Struct.new( :data_lake_access_properties, :iceberg_optimization_properties, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#iceberg_optimization_properties ⇒ Types::IcebergOptimizationProperties
A structure that specifies Iceberg table optimization properties for the catalog. This includes configuration for compaction, retention, and orphan file deletion operations that can be applied to Iceberg tables in this catalog.
2400 2401 2402 2403 2404 2405 2406 |
# File 'lib/aws-sdk-glue/types.rb', line 2400 class CatalogProperties < Struct.new( :data_lake_access_properties, :iceberg_optimization_properties, :custom_properties) SENSITIVE = [] include Aws::Structure end |