Class: Aws::Glue::Types::CatalogTableConfigOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CatalogTableConfigOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The configuration for a Glue Data Catalog table used to store data quality results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
A unique identifier for the Glue Data Catalog.
-
#database_name ⇒ String
The name of the database in the Glue Data Catalog.
-
#s3_location ⇒ String
The Amazon S3 location for storing the results.
-
#table_name ⇒ String
The name of the table in the Glue Data Catalog.
Instance Attribute Details
#catalog_id ⇒ String
A unique identifier for the Glue Data Catalog.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-glue/types.rb', line 2754 class CatalogTableConfigOptions < Struct.new( :database_name, :table_name, :s3_location, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database in the Glue Data Catalog.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-glue/types.rb', line 2754 class CatalogTableConfigOptions < Struct.new( :database_name, :table_name, :s3_location, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#s3_location ⇒ String
The Amazon S3 location for storing the results.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-glue/types.rb', line 2754 class CatalogTableConfigOptions < Struct.new( :database_name, :table_name, :s3_location, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table in the Glue Data Catalog.
2754 2755 2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-glue/types.rb', line 2754 class CatalogTableConfigOptions < Struct.new( :database_name, :table_name, :s3_location, :catalog_id) SENSITIVE = [] include Aws::Structure end |