Class: Aws::Glue::Types::CheckSchemaVersionValidityInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CheckSchemaVersionValidityInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CheckSchemaVersionValidityInput data as a hash:
{
data_format: "AVRO", # required, accepts AVRO, JSON, PROTOBUF
schema_definition: "SchemaDefinitionString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_format ⇒ String
The data format of the schema definition.
-
#schema_definition ⇒ String
The definition of the schema that has to be validated.
Instance Attribute Details
#data_format ⇒ String
The data format of the schema definition. Currently `AVRO`, `JSON` and `PROTOBUF` are supported.
2060 2061 2062 2063 2064 2065 |
# File 'lib/aws-sdk-glue/types.rb', line 2060 class CheckSchemaVersionValidityInput < Struct.new( :data_format, :schema_definition) SENSITIVE = [] include Aws::Structure end |
#schema_definition ⇒ String
The definition of the schema that has to be validated.
2060 2061 2062 2063 2064 2065 |
# File 'lib/aws-sdk-glue/types.rb', line 2060 class CheckSchemaVersionValidityInput < Struct.new( :data_format, :schema_definition) SENSITIVE = [] include Aws::Structure end |