Class: Aws::Glue::Types::Classifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Classifiers are triggered during a crawl task. A classifier checks whether a given file is in a format it can handle. If it is, the classifier creates a schema in the form of a `StructType` object that matches that data format.

You can use the standard classifiers that Glue provides, or you can write your own classifiers to best categorize your data sources and specify the appropriate schemas to use for them. A classifier can be a `grok` classifier, an `XML` classifier, a `JSON` classifier, or a custom `CSV` classifier, as specified in one of the fields in the `Classifier` object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#csv_classifierTypes::CsvClassifier

A classifier for comma-separated values (CSV).



1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/aws-sdk-glue/types.rb', line 1641

class Classifier < Struct.new(
  :grok_classifier,
  :xml_classifier,
  :json_classifier,
  :csv_classifier)
  SENSITIVE = []
  include Aws::Structure
end

#grok_classifierTypes::GrokClassifier

A classifier that uses `grok`.



1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/aws-sdk-glue/types.rb', line 1641

class Classifier < Struct.new(
  :grok_classifier,
  :xml_classifier,
  :json_classifier,
  :csv_classifier)
  SENSITIVE = []
  include Aws::Structure
end

#json_classifierTypes::JsonClassifier

A classifier for JSON content.



1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/aws-sdk-glue/types.rb', line 1641

class Classifier < Struct.new(
  :grok_classifier,
  :xml_classifier,
  :json_classifier,
  :csv_classifier)
  SENSITIVE = []
  include Aws::Structure
end

#xml_classifierTypes::XMLClassifier

A classifier for XML content.



1641
1642
1643
1644
1645
1646
1647
1648
# File 'lib/aws-sdk-glue/types.rb', line 1641

class Classifier < Struct.new(
  :grok_classifier,
  :xml_classifier,
  :json_classifier,
  :csv_classifier)
  SENSITIVE = []
  include Aws::Structure
end