Class: Aws::Glue::Types::ColumnStatisticsTaskRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ColumnStatisticsTaskRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The object that shows the details of the column stats run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#column_name_list ⇒ Array<String>
A list of the column names.
-
#column_statistics_task_run_id ⇒ String
The identifier for the particular column statistics task run.
-
#computation_type ⇒ String
The type of column statistics computation.
-
#creation_time ⇒ Time
The time that this task was created.
-
#customer_id ⇒ String
The Amazon Web Services account ID.
-
#database_name ⇒ String
The database where the table resides.
-
#dpu_seconds ⇒ Float
The calculated DPU usage in seconds for all autoscaled workers.
-
#end_time ⇒ Time
The end time of the task.
-
#error_message ⇒ String
The error message for the job.
-
#last_updated ⇒ Time
The last point in time when this task was modified.
-
#number_of_workers ⇒ Integer
The number of workers used to generate column statistics.
-
#role ⇒ String
The IAM role that the service assumes to generate statistics.
-
#sample_size ⇒ Float
The percentage of rows used to generate statistics.
-
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs for the column stats task run.
-
#start_time ⇒ Time
The start time of the task.
-
#status ⇒ String
The status of the task run.
-
#table_name ⇒ String
The name of the table for which column statistics is generated.
-
#worker_type ⇒ String
The type of workers being used for generating stats.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is supplied, the Amazon Web Services account ID is used by default.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#column_name_list ⇒ Array<String>
A list of the column names. If none is supplied, all column names for the table will be used by default.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#column_statistics_task_run_id ⇒ String
The identifier for the particular column statistics task run.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#computation_type ⇒ String
The type of column statistics computation.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that this task was created.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#customer_id ⇒ String
The Amazon Web Services account ID.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database where the table resides.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#dpu_seconds ⇒ Float
The calculated DPU usage in seconds for all autoscaled workers.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end time of the task.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message for the job.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The last point in time when this task was modified.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers used to generate column statistics. The job is preconfigured to autoscale up to 25 instances.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The IAM role that the service assumes to generate statistics.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#sample_size ⇒ Float
The percentage of rows used to generate statistics. If none is supplied, the entire table will be used to generate stats.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs for the column stats task run.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the task.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the task run.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table for which column statistics is generated.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of workers being used for generating stats. The default is
g.1x.
3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-glue/types.rb', line 3773 class ColumnStatisticsTaskRun < Struct.new( :customer_id, :column_statistics_task_run_id, :database_name, :table_name, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :number_of_workers, :worker_type, :computation_type, :status, :creation_time, :last_updated, :start_time, :end_time, :error_message, :dpu_seconds) SENSITIVE = [] include Aws::Structure end |