Class: Aws::Glue::Types::ColumnStatisticsTaskSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ColumnStatisticsTaskSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The settings for a column statistics task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#column_name_list ⇒ Array<String>
A list of column names for which to run statistics.
-
#database_name ⇒ String
The name of the database where the table resides.
-
#last_execution_attempt ⇒ Types::ExecutionAttempt
The last
ExecutionAttemptfor the column statistics task run. -
#role ⇒ String
The role used for running the column statistics.
-
#sample_size ⇒ Float
The percentage of data to sample.
-
#schedule ⇒ Types::Schedule
A schedule for running the column statistics, specified in CRON syntax.
-
#schedule_type ⇒ String
The type of schedule for a column statistics task.
-
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs.
-
#setting_source ⇒ String
The source of setting the column statistics task.
-
#table_name ⇒ String
The name of the table for which to generate column statistics.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#column_name_list ⇒ Array<String>
A list of column names for which to run statistics.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database where the table resides.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#last_execution_attempt ⇒ Types::ExecutionAttempt
The last ExecutionAttempt for the column statistics task run.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The role used for running the column statistics.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#sample_size ⇒ Float
The percentage of data to sample.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::Schedule
A schedule for running the column statistics, specified in CRON syntax.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#schedule_type ⇒ String
The type of schedule for a column statistics task. Possible values
may be CRON or AUTO.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#setting_source ⇒ String
The source of setting the column statistics task. Possible values
may be CATALOG or TABLE.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table for which to generate column statistics.
3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 |
# File 'lib/aws-sdk-glue/types.rb', line 3754 class ColumnStatisticsTaskSettings < Struct.new( :database_name, :table_name, :schedule, :column_name_list, :catalog_id, :role, :sample_size, :security_configuration, :schedule_type, :setting_source, :last_execution_attempt) SENSITIVE = [] include Aws::Structure end |