Class: Aws::Glue::Types::Condition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Condition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass Condition data as a hash:
{
logical_operator: "EQUALS", # accepts EQUALS
job_name: "NameString",
state: "STARTING", # accepts STARTING, RUNNING, STOPPING, STOPPED, SUCCEEDED, FAILED, TIMEOUT, ERROR, WAITING
crawler_name: "NameString",
crawl_state: "RUNNING", # accepts RUNNING, CANCELLING, CANCELLED, SUCCEEDED, FAILED, ERROR
}
Defines a condition under which a trigger fires.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawl_state ⇒ String
The state of the crawler to which this condition applies.
-
#crawler_name ⇒ String
The name of the crawler to which this condition applies.
-
#job_name ⇒ String
The name of the job whose `JobRuns` this condition applies to, and on which this trigger waits.
-
#logical_operator ⇒ String
A logical operator.
-
#state ⇒ String
The condition state.
Instance Attribute Details
#crawl_state ⇒ String
The state of the crawler to which this condition applies.
3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-glue/types.rb', line 3606 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#crawler_name ⇒ String
The name of the crawler to which this condition applies.
3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-glue/types.rb', line 3606 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job whose `JobRuns` this condition applies to, and on which this trigger waits.
3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-glue/types.rb', line 3606 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#logical_operator ⇒ String
A logical operator.
3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-glue/types.rb', line 3606 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The condition state. Currently, the only job states that a trigger can listen for are `SUCCEEDED`, `STOPPED`, `FAILED`, and `TIMEOUT`. The only crawler states that a trigger can listen for are `SUCCEEDED`, `FAILED`, and `CANCELLED`.
3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/aws-sdk-glue/types.rb', line 3606 class Condition < Struct.new( :logical_operator, :job_name, :state, :crawler_name, :crawl_state) SENSITIVE = [] include Aws::Structure end |