Class: Aws::Glue::Types::ConfusionMatrix
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConfusionMatrix
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The confusion matrix shows you what your transform is predicting accurately and what types of errors it is making.
For more information, see Confusion matrix in Wikipedia.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#num_false_negatives ⇒ Integer
The number of matches in the data that the transform didn't find, in the confusion matrix for your transform.
-
#num_false_positives ⇒ Integer
The number of nonmatches in the data that the transform incorrectly classified as a match, in the confusion matrix for your transform.
-
#num_true_negatives ⇒ Integer
The number of nonmatches in the data that the transform correctly rejected, in the confusion matrix for your transform.
-
#num_true_positives ⇒ Integer
The number of matches in the data that the transform correctly found, in the confusion matrix for your transform.
Instance Attribute Details
#num_false_negatives ⇒ Integer
The number of matches in the data that the transform didn't find, in the confusion matrix for your transform.
4054 4055 4056 4057 4058 4059 4060 4061 |
# File 'lib/aws-sdk-glue/types.rb', line 4054 class ConfusionMatrix < Struct.new( :num_true_positives, :num_false_positives, :num_true_negatives, :num_false_negatives) SENSITIVE = [] include Aws::Structure end |
#num_false_positives ⇒ Integer
The number of nonmatches in the data that the transform incorrectly classified as a match, in the confusion matrix for your transform.
4054 4055 4056 4057 4058 4059 4060 4061 |
# File 'lib/aws-sdk-glue/types.rb', line 4054 class ConfusionMatrix < Struct.new( :num_true_positives, :num_false_positives, :num_true_negatives, :num_false_negatives) SENSITIVE = [] include Aws::Structure end |
#num_true_negatives ⇒ Integer
The number of nonmatches in the data that the transform correctly rejected, in the confusion matrix for your transform.
4054 4055 4056 4057 4058 4059 4060 4061 |
# File 'lib/aws-sdk-glue/types.rb', line 4054 class ConfusionMatrix < Struct.new( :num_true_positives, :num_false_positives, :num_true_negatives, :num_false_negatives) SENSITIVE = [] include Aws::Structure end |
#num_true_positives ⇒ Integer
The number of matches in the data that the transform correctly found, in the confusion matrix for your transform.
4054 4055 4056 4057 4058 4059 4060 4061 |
# File 'lib/aws-sdk-glue/types.rb', line 4054 class ConfusionMatrix < Struct.new( :num_true_positives, :num_false_positives, :num_true_negatives, :num_false_negatives) SENSITIVE = [] include Aws::Structure end |