Class: Aws::Glue::Types::ConnectionTypeBrief
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectionTypeBrief
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Brief information about a supported connection type returned by the ‘ListConnectionTypes` API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
-
#categories ⇒ Array<String>
A list of categories that this connection type belongs to.
-
#connection_type ⇒ String
The name of the connection type.
-
#connection_type_variants ⇒ Array<Types::ConnectionTypeVariant>
A list of variants available for this connection type.
-
#description ⇒ String
A description of the connection type.
-
#display_name ⇒ String
The human-readable name for the connection type that is displayed in the Glue console.
-
#logo_url ⇒ String
The URL of the logo associated with a connection type.
-
#vendor ⇒ String
The name of the vendor or provider that created or maintains this connection type.
Instance Attribute Details
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#categories ⇒ Array<String>
A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The name of the connection type.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#connection_type_variants ⇒ Array<Types::ConnectionTypeVariant>
A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the connection type.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The human-readable name for the connection type that is displayed in the Glue console.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#logo_url ⇒ String
The URL of the logo associated with a connection type.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |
#vendor ⇒ String
The name of the vendor or provider that created or maintains this connection type.
4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 |
# File 'lib/aws-sdk-glue/types.rb', line 4627 class ConnectionTypeBrief < Struct.new( :connection_type, :display_name, :vendor, :description, :categories, :capabilities, :logo_url, :connection_type_variants) SENSITIVE = [] include Aws::Structure end |