Class: Aws::Glue::Types::ConnectorAuthorizationCodeProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorAuthorizationCodeProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
OAuth2 authorization code configuration that defines the properties needed for the Authorization Code grant type flow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization_code ⇒ Types::ConnectorProperty
The authorization code received from the authorization server after user consent.
-
#authorization_code_url ⇒ Types::ConnectorProperty
The authorization endpoint URL where users will be redirected to grant authorization.
-
#client_id ⇒ Types::ConnectorProperty
The OAuth2 client identifier provided by the authorization server.
-
#client_secret ⇒ Types::ConnectorProperty
The OAuth2 client secret provided by the authorization server.
-
#content_type ⇒ String
The content type to use for token exchange requests, such as application/x-www-form-urlencoded or application/json.
-
#prompt ⇒ Types::ConnectorProperty
The OAuth2 prompt parameter that controls the authorization server’s behavior during user authentication.
-
#redirect_uri ⇒ Types::ConnectorProperty
The redirect URI that must match the URI registered with the authorization server.
-
#request_method ⇒ String
The HTTP method to use when making token exchange requests, typically POST.
-
#scope ⇒ Types::ConnectorProperty
The OAuth2 scope that defines the level of access requested for the authorization code flow.
-
#token_url ⇒ Types::ConnectorProperty
The token endpoint URL where the authorization code will be exchanged for an access token.
-
#token_url_parameters ⇒ Array<Types::ConnectorProperty>
Additional parameters to include in token URL requests as key-value pairs.
Instance Attribute Details
#authorization_code ⇒ Types::ConnectorProperty
The authorization code received from the authorization server after user consent.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#authorization_code_url ⇒ Types::ConnectorProperty
The authorization endpoint URL where users will be redirected to grant authorization.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#client_id ⇒ Types::ConnectorProperty
The OAuth2 client identifier provided by the authorization server.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#client_secret ⇒ Types::ConnectorProperty
The OAuth2 client secret provided by the authorization server.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
The content type to use for token exchange requests, such as application/x-www-form-urlencoded or application/json.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#prompt ⇒ Types::ConnectorProperty
The OAuth2 prompt parameter that controls the authorization server’s behavior during user authentication.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#redirect_uri ⇒ Types::ConnectorProperty
The redirect URI that must match the URI registered with the authorization server.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#request_method ⇒ String
The HTTP method to use when making token exchange requests, typically POST.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ Types::ConnectorProperty
The OAuth2 scope that defines the level of access requested for the authorization code flow.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#token_url ⇒ Types::ConnectorProperty
The token endpoint URL where the authorization code will be exchanged for an access token.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |
#token_url_parameters ⇒ Array<Types::ConnectorProperty>
Additional parameters to include in token URL requests as key-value pairs.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 |
# File 'lib/aws-sdk-glue/types.rb', line 4644 class ConnectorAuthorizationCodeProperties < Struct.new( :authorization_code_url, :authorization_code, :redirect_uri, :token_url, :request_method, :content_type, :client_id, :client_secret, :scope, :prompt, :token_url_parameters) SENSITIVE = [] include Aws::Structure end |