Class: Aws::Glue::Types::ConnectorDataSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorDataSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a source generated with standard connection options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_type ⇒ String
The
connectionType, as provided to the underlying Glue library. -
#data ⇒ Hash<String,String>
A map specifying connection options for the node.
-
#name ⇒ String
The name of this source node.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for this source.
Instance Attribute Details
#connection_type ⇒ String
The connectionType, as provided to the underlying Glue library.
This node type supports the following connection types:
-
opensearch -
azuresql -
azurecosmos -
bigquery -
saphana -
teradata -
vertica
4839 4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-glue/types.rb', line 4839 class ConnectorDataSource < Struct.new( :name, :connection_type, :data, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#data ⇒ Hash<String,String>
A map specifying connection options for the node. You can find standard connection options for the corresponding connection type in the Connection parameters section of the Glue documentation.
4839 4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-glue/types.rb', line 4839 class ConnectorDataSource < Struct.new( :name, :connection_type, :data, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of this source node.
4839 4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-glue/types.rb', line 4839 class ConnectorDataSource < Struct.new( :name, :connection_type, :data, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for this source.
4839 4840 4841 4842 4843 4844 4845 4846 |
# File 'lib/aws-sdk-glue/types.rb', line 4839 class ConnectorDataSource < Struct.new( :name, :connection_type, :data, :output_schemas) SENSITIVE = [] include Aws::Structure end |