Class: Aws::Glue::Types::ConnectorOAuth2Properties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorOAuth2Properties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
OAuth2 configuration container that defines the authentication properties and flow-specific configurations for OAuth2-based connections.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization_code_properties ⇒ Types::ConnectorAuthorizationCodeProperties
Configuration properties specific to the OAuth2 Authorization Code grant type flow.
-
#client_credentials_properties ⇒ Types::ClientCredentialsProperties
Configuration properties specific to the OAuth2 Client Credentials grant type flow.
-
#jwt_bearer_properties ⇒ Types::JWTBearerProperties
Configuration properties specific to the OAuth2 JWT Bearer grant type flow.
-
#o_auth_2_grant_type ⇒ String
The OAuth2 grant type to use for authentication, such as CLIENT_CREDENTIALS, JWT_BEARER, or AUTHORIZATION_CODE.
Instance Attribute Details
#authorization_code_properties ⇒ Types::ConnectorAuthorizationCodeProperties
Configuration properties specific to the OAuth2 Authorization Code grant type flow.
4786 4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-glue/types.rb', line 4786 class ConnectorOAuth2Properties < Struct.new( :o_auth_2_grant_type, :client_credentials_properties, :jwt_bearer_properties, :authorization_code_properties) SENSITIVE = [] include Aws::Structure end |
#client_credentials_properties ⇒ Types::ClientCredentialsProperties
Configuration properties specific to the OAuth2 Client Credentials grant type flow.
4786 4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-glue/types.rb', line 4786 class ConnectorOAuth2Properties < Struct.new( :o_auth_2_grant_type, :client_credentials_properties, :jwt_bearer_properties, :authorization_code_properties) SENSITIVE = [] include Aws::Structure end |
#jwt_bearer_properties ⇒ Types::JWTBearerProperties
Configuration properties specific to the OAuth2 JWT Bearer grant type flow.
4786 4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-glue/types.rb', line 4786 class ConnectorOAuth2Properties < Struct.new( :o_auth_2_grant_type, :client_credentials_properties, :jwt_bearer_properties, :authorization_code_properties) SENSITIVE = [] include Aws::Structure end |
#o_auth_2_grant_type ⇒ String
The OAuth2 grant type to use for authentication, such as CLIENT_CREDENTIALS, JWT_BEARER, or AUTHORIZATION_CODE.
4786 4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-glue/types.rb', line 4786 class ConnectorOAuth2Properties < Struct.new( :o_auth_2_grant_type, :client_credentials_properties, :jwt_bearer_properties, :authorization_code_properties) SENSITIVE = [] include Aws::Structure end |