Class: Aws::Glue::Types::ConnectorProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a property configuration for connection types, default values, and where the property should be used in requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
A list of
AllowedValueobjects representing the values allowed for the property. -
#default_value ⇒ String
The default value for the property.
-
#format ⇒ String
A format template for the property value that defines how the value should be formatted before sending it in API requests.
-
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
-
#name ⇒ String
The name of the property.
-
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
-
#property_type ⇒ String
The data type of this property.
-
#required ⇒ Boolean
Indicates whether the property is required.
Instance Attribute Details
#allowed_values ⇒ Array<String>
A list of AllowedValue objects representing the values allowed for
the property.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ String
The default value for the property.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
A format template for the property value that defines how the value
should be formatted before sending it in API requests. Use {value}
as a placeholder for the actual property value (for example, SSWS {value}).
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the property.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#property_type ⇒ String
The data type of this property
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |
#required ⇒ Boolean
Indicates whether the property is required.
5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 |
# File 'lib/aws-sdk-glue/types.rb', line 5063 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type, :format) SENSITIVE = [] include Aws::Structure end |