Class: Aws::Glue::Types::ConnectorProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ConnectorProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a property configuration for connection types, default values, and where the property should be used in requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
A list of
AllowedValueobjects representing the values allowed for the property. -
#default_value ⇒ String
The default value for the property.
-
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
-
#name ⇒ String
The name of the property.
-
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
-
#property_type ⇒ String
The data type of this property.
-
#required ⇒ Boolean
Indicates whether the property is required.
Instance Attribute Details
#allowed_values ⇒ Array<String>
A list of AllowedValue objects representing the values allowed for
the property.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ String
The default value for the property.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the property.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#property_type ⇒ String
The data type of this property
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |
#required ⇒ Boolean
Indicates whether the property is required.
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 |
# File 'lib/aws-sdk-glue/types.rb', line 5029 class ConnectorProperty < Struct.new( :name, :key_override, :required, :default_value, :allowed_values, :property_location, :property_type) SENSITIVE = [] include Aws::Structure end |