Class: Aws::Glue::Types::ConnectorProperty

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a property configuration for connection types, default values, and where the property should be used in requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesArray<String>

A list of ‘AllowedValue` objects representing the values allowed for the property.

Returns:

  • (Array<String>)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueString

The default value for the property.

Returns:

  • (String)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#key_overrideString

A key name to use when sending this property in API requests, if different from the display name.

Returns:

  • (String)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the property.

Returns:

  • (String)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#property_locationString

Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.

Returns:

  • (String)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#property_typeString

The data type of this property

Returns:

  • (String)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end

#requiredBoolean

Indicates whether the property is required.

Returns:

  • (Boolean)


4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
# File 'lib/aws-sdk-glue/types.rb', line 4831

class ConnectorProperty < Struct.new(
  :name,
  :key_override,
  :required,
  :default_value,
  :allowed_values,
  :property_location,
  :property_type)
  SENSITIVE = []
  include Aws::Structure
end