Class: Aws::Glue::Types::Crawler
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Crawler
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a crawler program that examines a data source and uses classifiers to try to determine its schema. If successful, the crawler records metadata concerning the data source in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classifiers ⇒ Array<String>
A list of UTF-8 strings that specify the custom classifiers that are associated with the crawler.
-
#configuration ⇒ String
Crawler configuration information.
-
#crawl_elapsed_time ⇒ Integer
If the crawler is running, contains the total time elapsed since the last crawl began.
-
#crawler_security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used by this crawler.
-
#creation_time ⇒ Time
The time that the crawler was created.
-
#database_name ⇒ String
The name of the database in which the crawler's output is stored.
-
#description ⇒ String
A description of the crawler.
-
#lake_formation_configuration ⇒ Types::LakeFormationConfiguration
Specifies whether the crawler should use Lake Formation credentials for the crawler instead of the IAM role credentials.
-
#last_crawl ⇒ Types::LastCrawlInfo
The status of the last crawl, and potentially error information if an error occurred.
-
#last_updated ⇒ Time
The time that the crawler was last updated.
-
#lineage_configuration ⇒ Types::LineageConfiguration
A configuration that specifies whether data lineage is enabled for the crawler.
-
#name ⇒ String
The name of the crawler.
-
#recrawl_policy ⇒ Types::RecrawlPolicy
A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run.
-
#role ⇒ String
The Amazon Resource Name (ARN) of an IAM role that's used to access customer resources, such as Amazon Simple Storage Service (Amazon S3) data.
-
#schedule ⇒ Types::Schedule
For scheduled crawlers, the schedule when the crawler runs.
-
#schema_change_policy ⇒ Types::SchemaChangePolicy
The policy that specifies update and delete behaviors for the crawler.
-
#state ⇒ String
Indicates whether the crawler is running, or whether a run is pending.
-
#table_prefix ⇒ String
The prefix added to the names of tables that are created.
-
#targets ⇒ Types::CrawlerTargets
A collection of targets to crawl.
-
#version ⇒ Integer
The version of the crawler.
Instance Attribute Details
#classifiers ⇒ Array<String>
A list of UTF-8 strings that specify the custom classifiers that are associated with the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ String
Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler's behavior. For more information, see [Setting crawler configuration options].
[1]: docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#crawl_elapsed_time ⇒ Integer
If the crawler is running, contains the total time elapsed since the last crawl began.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#crawler_security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used by this crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that the crawler was created.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database in which the crawler's output is stored.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#lake_formation_configuration ⇒ Types::LakeFormationConfiguration
Specifies whether the crawler should use Lake Formation credentials for the crawler instead of the IAM role credentials.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#last_crawl ⇒ Types::LastCrawlInfo
The status of the last crawl, and potentially error information if an error occurred.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The time that the crawler was last updated.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#lineage_configuration ⇒ Types::LineageConfiguration
A configuration that specifies whether data lineage is enabled for the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#recrawl_policy ⇒ Types::RecrawlPolicy
A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The Amazon Resource Name (ARN) of an IAM role that's used to access customer resources, such as Amazon Simple Storage Service (Amazon S3) data.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::Schedule
For scheduled crawlers, the schedule when the crawler runs.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::SchemaChangePolicy
The policy that specifies update and delete behaviors for the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Indicates whether the crawler is running, or whether a run is pending.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#table_prefix ⇒ String
The prefix added to the names of tables that are created.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#targets ⇒ Types::CrawlerTargets
A collection of targets to crawl.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the crawler.
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 |
# File 'lib/aws-sdk-glue/types.rb', line 4186 class Crawler < Struct.new( :name, :role, :targets, :database_name, :description, :classifiers, :recrawl_policy, :schema_change_policy, :lineage_configuration, :state, :table_prefix, :schedule, :crawl_elapsed_time, :creation_time, :last_updated, :last_crawl, :version, :configuration, :crawler_security_configuration, :lake_formation_configuration) SENSITIVE = [] include Aws::Structure end |