Class: Aws::Glue::Types::CrawlerHistory
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CrawlerHistory
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains the information for a run of a crawler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawl_id ⇒ String
A UUID identifier for each crawl.
-
#dpu_hour ⇒ Float
The number of data processing units (DPU) used in hours for the crawl.
-
#end_time ⇒ Time
The date and time on which the crawl ended.
-
#error_message ⇒ String
If an error occurred, the error message associated with the crawl.
-
#log_group ⇒ String
The log group associated with the crawl.
-
#log_stream ⇒ String
The log stream associated with the crawl.
-
#message_prefix ⇒ String
The prefix for a CloudWatch message about this crawl.
-
#start_time ⇒ Time
The date and time on which the crawl started.
-
#state ⇒ String
The state of the crawl.
-
#summary ⇒ String
A run summary for the specific crawl in JSON.
Instance Attribute Details
#crawl_id ⇒ String
A UUID identifier for each crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#dpu_hour ⇒ Float
The number of data processing units (DPU) used in hours for the crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time on which the crawl ended.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
If an error occurred, the error message associated with the crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#log_group ⇒ String
The log group associated with the crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#log_stream ⇒ String
The log stream associated with the crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#message_prefix ⇒ String
The prefix for a CloudWatch message about this crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time on which the crawl started.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the crawl.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ String
A run summary for the specific crawl in JSON. Contains the catalog tables and partitions that were added, updated, or deleted.
4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-glue/types.rb', line 4243 class CrawlerHistory < Struct.new( :crawl_id, :state, :start_time, :end_time, :summary, :error_message, :log_group, :log_stream, :message_prefix, :dpu_hour) SENSITIVE = [] include Aws::Structure end |