Class: Aws::Glue::Types::CreateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the connection.
-
#connection_input ⇒ Types::ConnectionInput
A ‘ConnectionInput` object defining the connection to create.
-
#tags ⇒ Hash<String,String>
The tags you assign to the connection.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the connection. If none is provided, the Amazon Web Services account ID is used by default.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-glue/types.rb', line 3619 class CreateConnectionRequest < Struct.new( :catalog_id, :connection_input, :tags) SENSITIVE = [] include Aws::Structure end |
#connection_input ⇒ Types::ConnectionInput
A ‘ConnectionInput` object defining the connection to create.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-glue/types.rb', line 3619 class CreateConnectionRequest < Struct.new( :catalog_id, :connection_input, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags you assign to the connection.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-glue/types.rb', line 3619 class CreateConnectionRequest < Struct.new( :catalog_id, :connection_input, :tags) SENSITIVE = [] include Aws::Structure end |