Class: Aws::Glue::Types::CreateCsvClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateCsvClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a custom CSV classifier for `CreateClassifier` to create.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
-
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
-
#custom_datatype_configured ⇒ Boolean
Enables the configuration of custom datatypes.
-
#custom_datatypes ⇒ Array<String>
Creates a list of supported custom datatypes.
-
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
-
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values.
-
#header ⇒ Array<String>
A list of strings representing column names.
-
#name ⇒ String
The name of the classifier.
-
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value.
Instance Attribute Details
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatype_configured ⇒ Boolean
Enables the configuration of custom datatypes.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatypes ⇒ Array<String>
Creates a list of supported custom datatypes.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values. The default value is true.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Array<String>
A list of strings representing column names.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value. Must be different from the column delimiter.
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/aws-sdk-glue/types.rb', line 3399 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |