Class: Aws::Glue::Types::CreateCsvClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateCsvClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass CreateCsvClassifierRequest data as a hash:
{
name: "NameString", # required
delimiter: "CsvColumnDelimiter",
quote_symbol: "CsvQuoteSymbol",
contains_header: "UNKNOWN", # accepts UNKNOWN, PRESENT, ABSENT
header: ["NameString"],
disable_value_trimming: false,
allow_single_column: false,
custom_datatype_configured: false,
custom_datatypes: ["NameString"],
}
Specifies a custom CSV classifier for `CreateClassifier` to create.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
-
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
-
#custom_datatype_configured ⇒ Boolean
Enables the configuration of custom datatypes.
-
#custom_datatypes ⇒ Array<String>
Creates a list of supported custom datatypes.
-
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
-
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values.
-
#header ⇒ Array<String>
A list of strings representing column names.
-
#name ⇒ String
The name of the classifier.
-
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value.
Instance Attribute Details
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatype_configured ⇒ Boolean
Enables the configuration of custom datatypes.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatypes ⇒ Array<String>
Creates a list of supported custom datatypes.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values. The default value is true.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Array<String>
A list of strings representing column names.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value. Must be different from the column delimiter.
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-glue/types.rb', line 4945 class CreateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |