Class: Aws::Glue::Types::CreateCustomEntityTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateCustomEntityTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_words ⇒ Array<String>
A list of context words.
-
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later.
-
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
-
#tags ⇒ Hash<String,String>
A list of tags applied to the custom entity type.
Instance Attribute Details
#context_words ⇒ Array<String>
A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
If no context words are passed only a regular expression is checked.
5201 5202 5203 5204 5205 5206 5207 5208 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.
5201 5202 5203 5204 5205 5206 5207 5208 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words, :tags) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
5201 5202 5203 5204 5205 5206 5207 5208 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of tags applied to the custom entity type.
5201 5202 5203 5204 5205 5206 5207 5208 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words, :tags) SENSITIVE = [] include Aws::Structure end |