Class: Aws::Glue::Types::CreateCustomEntityTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_wordsArray<String>

A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.

If no context words are passed only a regular expression is checked.

Returns:

  • (Array<String>)


4479
4480
4481
4482
4483
4484
4485
4486
# File 'lib/aws-sdk-glue/types.rb', line 4479

class CreateCustomEntityTypeRequest < Struct.new(
  :name,
  :regex_string,
  :context_words,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.

Returns:

  • (String)


4479
4480
4481
4482
4483
4484
4485
4486
# File 'lib/aws-sdk-glue/types.rb', line 4479

class CreateCustomEntityTypeRequest < Struct.new(
  :name,
  :regex_string,
  :context_words,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#regex_stringString

A regular expression string that is used for detecting sensitive data in a custom pattern.

Returns:

  • (String)


4479
4480
4481
4482
4483
4484
4485
4486
# File 'lib/aws-sdk-glue/types.rb', line 4479

class CreateCustomEntityTypeRequest < Struct.new(
  :name,
  :regex_string,
  :context_words,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of tags applied to the custom entity type.

Returns:

  • (Hash<String,String>)


4479
4480
4481
4482
4483
4484
4485
4486
# File 'lib/aws-sdk-glue/types.rb', line 4479

class CreateCustomEntityTypeRequest < Struct.new(
  :name,
  :regex_string,
  :context_words,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end