Class: Aws::Glue::Types::CreateCustomEntityTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateCustomEntityTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CreateCustomEntityTypeRequest data as a hash:
{
name: "NameString", # required
regex_string: "NameString", # required
context_words: ["NameString"],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_words ⇒ Array<String>
A list of context words.
-
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later.
-
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
Instance Attribute Details
#context_words ⇒ Array<String>
A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
If no context words are passed only a regular expression is checked.
3374 3375 3376 3377 3378 3379 3380 |
# File 'lib/aws-sdk-glue/types.rb', line 3374 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.
3374 3375 3376 3377 3378 3379 3380 |
# File 'lib/aws-sdk-glue/types.rb', line 3374 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
3374 3375 3376 3377 3378 3379 3380 |
# File 'lib/aws-sdk-glue/types.rb', line 3374 class CreateCustomEntityTypeRequest < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |