Class: Aws::Glue::Types::CreateDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the database.
-
#database_input ⇒ Types::DatabaseInput
The metadata for the database.
-
#tags ⇒ Hash<String,String>
The tags you assign to the database.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the database. If none is provided, the Amazon Web Services account ID is used by default.
3886 3887 3888 3889 3890 3891 3892 |
# File 'lib/aws-sdk-glue/types.rb', line 3886 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |
#database_input ⇒ Types::DatabaseInput
The metadata for the database.
3886 3887 3888 3889 3890 3891 3892 |
# File 'lib/aws-sdk-glue/types.rb', line 3886 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags you assign to the database.
3886 3887 3888 3889 3890 3891 3892 |
# File 'lib/aws-sdk-glue/types.rb', line 3886 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |