Class: Aws::Glue::Types::CreateDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass CreateDatabaseRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_input: { # required
name: "NameString", # required
description: "DescriptionString",
location_uri: "URI",
parameters: {
"KeyString" => "ParametersMapValue",
},
create_table_default_permissions: [
{
principal: {
data_lake_principal_identifier: "DataLakePrincipalString",
},
permissions: ["ALL"], # accepts ALL, SELECT, ALTER, DROP, DELETE, INSERT, CREATE_DATABASE, CREATE_TABLE, DATA_LOCATION_ACCESS
},
],
target_database: {
catalog_id: "CatalogIdString",
database_name: "NameString",
},
},
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the database.
-
#database_input ⇒ Types::DatabaseInput
The metadata for the database.
-
#tags ⇒ Hash<String,String>
The tags you assign to the database.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the database. If none is provided, the Amazon Web Services account ID is used by default.
5054 5055 5056 5057 5058 5059 5060 |
# File 'lib/aws-sdk-glue/types.rb', line 5054 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |
#database_input ⇒ Types::DatabaseInput
The metadata for the database.
5054 5055 5056 5057 5058 5059 5060 |
# File 'lib/aws-sdk-glue/types.rb', line 5054 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags you assign to the database.
5054 5055 5056 5057 5058 5059 5060 |
# File 'lib/aws-sdk-glue/types.rb', line 5054 class CreateDatabaseRequest < Struct.new( :catalog_id, :database_input, :tags) SENSITIVE = [] include Aws::Structure end |