Class: Aws::Glue::Types::CreateDevEndpointResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#argumentsHash<String,String>

The map of arguments used to configure this DevEndpoint.

Valid arguments are:

  • "--enable-glue-datacatalog": ""

^

You can specify a version of Python support for development endpoints by using the Arguments parameter in the CreateDevEndpoint or UpdateDevEndpoint APIs. If no arguments are provided, the version defaults to Python 2.

Returns:

  • (Hash<String,String>)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Amazon Web Services Availability Zone where this DevEndpoint is located.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestampTime

The point in time at which this DevEndpoint was created.

Returns:

  • (Time)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The name assigned to the new DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#extra_jars_s3_pathString

Path to one or more Java .jar files in an S3 bucket that will be loaded in your DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#extra_python_libs_s3_pathString

The paths to one or more Python libraries in an S3 bucket that will be loaded in your DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason for a current failure in this DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for running your ETL scripts on development endpoints.

For more information about the available Glue versions and corresponding Spark and Python versions, see Glue version in the developer guide.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_nodesInteger

The number of Glue Data Processing Units (DPUs) allocated to this DevEndpoint.

Returns:

  • (Integer)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined workerType that are allocated to the development endpoint.

Returns:

  • (Integer)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role assigned to the new DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the SecurityConfiguration structure being used with this DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The security groups assigned to the new DevEndpoint.

Returns:

  • (Array<String>)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the new DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idString

The subnet ID assigned to the new DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the virtual private cloud (VPC) used by this DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated to the development endpoint. May be a value of Standard, G.1X, or G.2X.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#yarn_endpoint_addressString

The address of the YARN endpoint used by this DevEndpoint.

Returns:

  • (String)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end

#zeppelin_remote_spark_interpreter_portInteger

The Apache Zeppelin port for the remote Apache Spark interpreter.

Returns:

  • (Integer)


6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
6316
6317
6318
6319
6320
# File 'lib/aws-sdk-glue/types.rb', line 6298

class CreateDevEndpointResponse < Struct.new(
  :endpoint_name,
  :status,
  :security_group_ids,
  :subnet_id,
  :role_arn,
  :yarn_endpoint_address,
  :zeppelin_remote_spark_interpreter_port,
  :number_of_nodes,
  :worker_type,
  :glue_version,
  :number_of_workers,
  :availability_zone,
  :vpc_id,
  :extra_python_libs_s3_path,
  :extra_jars_s3_path,
  :failure_reason,
  :security_configuration,
  :created_timestamp,
  :arguments)
  SENSITIVE = []
  include Aws::Structure
end