Class: Aws::Glue::Types::CreateDevEndpointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateDevEndpointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arguments ⇒ Hash<String,String>
The map of arguments used to configure this ‘DevEndpoint`.
-
#availability_zone ⇒ String
The Amazon Web Services Availability Zone where this ‘DevEndpoint` is located.
-
#created_timestamp ⇒ Time
The point in time at which this ‘DevEndpoint` was created.
-
#endpoint_name ⇒ String
The name assigned to the new ‘DevEndpoint`.
-
#extra_jars_s3_path ⇒ String
Path to one or more Java ‘.jar` files in an S3 bucket that will be loaded in your `DevEndpoint`.
-
#extra_python_libs_s3_path ⇒ String
The paths to one or more Python libraries in an S3 bucket that will be loaded in your ‘DevEndpoint`.
-
#failure_reason ⇒ String
The reason for a current failure in this ‘DevEndpoint`.
-
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#number_of_nodes ⇒ Integer
The number of Glue Data Processing Units (DPUs) allocated to this DevEndpoint.
-
#number_of_workers ⇒ Integer
The number of workers of a defined ‘workerType` that are allocated to the development endpoint.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role assigned to the new ‘DevEndpoint`.
-
#security_configuration ⇒ String
The name of the ‘SecurityConfiguration` structure being used with this `DevEndpoint`.
-
#security_group_ids ⇒ Array<String>
The security groups assigned to the new ‘DevEndpoint`.
-
#status ⇒ String
The current status of the new ‘DevEndpoint`.
-
#subnet_id ⇒ String
The subnet ID assigned to the new ‘DevEndpoint`.
-
#vpc_id ⇒ String
The ID of the virtual private cloud (VPC) used by this ‘DevEndpoint`.
-
#worker_type ⇒ String
The type of predefined worker that is allocated to the development endpoint.
-
#yarn_endpoint_address ⇒ String
The address of the YARN endpoint used by this ‘DevEndpoint`.
-
#zeppelin_remote_spark_interpreter_port ⇒ Integer
The Apache Zeppelin port for the remote Apache Spark interpreter.
Instance Attribute Details
#arguments ⇒ Hash<String,String>
The map of arguments used to configure this ‘DevEndpoint`.
Valid arguments are:
-
‘“–enable-glue-datacatalog”: “”`
^
You can specify a version of Python support for development endpoints by using the ‘Arguments` parameter in the `CreateDevEndpoint` or `UpdateDevEndpoint` APIs. If no arguments are provided, the version defaults to Python 2.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Amazon Web Services Availability Zone where this ‘DevEndpoint` is located.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The point in time at which this ‘DevEndpoint` was created.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name assigned to the new ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#extra_jars_s3_path ⇒ String
Path to one or more Java ‘.jar` files in an S3 bucket that will be loaded in your `DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#extra_python_libs_s3_path ⇒ String
The paths to one or more Python libraries in an S3 bucket that will be loaded in your ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason for a current failure in this ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for running your ETL scripts on development endpoints.
For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#number_of_nodes ⇒ Integer
The number of Glue Data Processing Units (DPUs) allocated to this DevEndpoint.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined ‘workerType` that are allocated to the development endpoint.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role assigned to the new ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The name of the ‘SecurityConfiguration` structure being used with this `DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security groups assigned to the new ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the new ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The subnet ID assigned to the new ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the virtual private cloud (VPC) used by this ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated to the development endpoint. May be a value of Standard, G.1X, or G.2X.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#yarn_endpoint_address ⇒ String
The address of the YARN endpoint used by this ‘DevEndpoint`.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |
#zeppelin_remote_spark_interpreter_port ⇒ Integer
The Apache Zeppelin port for the remote Apache Spark interpreter.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 |
# File 'lib/aws-sdk-glue/types.rb', line 4208 class CreateDevEndpointResponse < Struct.new( :endpoint_name, :status, :security_group_ids, :subnet_id, :role_arn, :yarn_endpoint_address, :zeppelin_remote_spark_interpreter_port, :number_of_nodes, :worker_type, :glue_version, :number_of_workers, :availability_zone, :vpc_id, :extra_python_libs_s3_path, :extra_jars_s3_path, :failure_reason, :security_configuration, :created_timestamp, :arguments) SENSITIVE = [] include Aws::Structure end |