Class: Aws::Glue::Types::CreateGlossaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateGlossaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the glossary.
-
#name ⇒ String
The name of the glossary.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6222 6223 6224 6225 6226 6227 6228 |
# File 'lib/aws-sdk-glue/types.rb', line 6222 class CreateGlossaryRequest < Struct.new( :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the glossary.
6222 6223 6224 6225 6226 6227 6228 |
# File 'lib/aws-sdk-glue/types.rb', line 6222 class CreateGlossaryRequest < Struct.new( :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the glossary.
6222 6223 6224 6225 6226 6227 6228 |
# File 'lib/aws-sdk-glue/types.rb', line 6222 class CreateGlossaryRequest < Struct.new( :name, :description, :client_token) SENSITIVE = [] include Aws::Structure end |