Class: Aws::Glue::Types::CreateGlossaryTermRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateGlossaryTermRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_identifier ⇒ String
The unique identifier of the glossary in which to create the term.
-
#long_description ⇒ String
A long description of the glossary term.
-
#name ⇒ String
The name of the glossary term.
-
#short_description ⇒ String
A short description of the glossary term.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-glue/types.rb', line 6278 class CreateGlossaryTermRequest < Struct.new( :glossary_identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_identifier ⇒ String
The unique identifier of the glossary in which to create the term.
6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-glue/types.rb', line 6278 class CreateGlossaryTermRequest < Struct.new( :glossary_identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#long_description ⇒ String
A long description of the glossary term.
6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-glue/types.rb', line 6278 class CreateGlossaryTermRequest < Struct.new( :glossary_identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the glossary term.
6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-glue/types.rb', line 6278 class CreateGlossaryTermRequest < Struct.new( :glossary_identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#short_description ⇒ String
A short description of the glossary term.
6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-glue/types.rb', line 6278 class CreateGlossaryTermRequest < Struct.new( :glossary_identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |