Class: Aws::Glue::Types::CreateGrokClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateGrokClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a ‘grok` classifier for `CreateClassifier` to create.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, Amazon CloudWatch Logs, and so on.
-
#custom_patterns ⇒ String
Optional custom grok patterns used by this classifier.
-
#grok_pattern ⇒ String
The grok pattern used by this classifier.
-
#name ⇒ String
The name of the new classifier.
Instance Attribute Details
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, Amazon CloudWatch Logs, and so on.
4934 4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4934 class CreateGrokClassifierRequest < Struct.new( :classification, :name, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#custom_patterns ⇒ String
Optional custom grok patterns used by this classifier.
4934 4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4934 class CreateGrokClassifierRequest < Struct.new( :classification, :name, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#grok_pattern ⇒ String
The grok pattern used by this classifier.
4934 4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4934 class CreateGrokClassifierRequest < Struct.new( :classification, :name, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the new classifier.
4934 4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4934 class CreateGrokClassifierRequest < Struct.new( :classification, :name, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |