Class: Aws::Glue::Types::CreateIntegrationTablePropertiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

Returns:

  • (String)


6759
6760
6761
6762
6763
6764
6765
6766
# File 'lib/aws-sdk-glue/types.rb', line 6759

class CreateIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_configTypes::SourceTableConfig

A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.



6759
6760
6761
6762
6763
6764
6765
6766
# File 'lib/aws-sdk-glue/types.rb', line 6759

class CreateIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table to be replicated.

Returns:

  • (String)


6759
6760
6761
6762
6763
6764
6765
6766
# File 'lib/aws-sdk-glue/types.rb', line 6759

class CreateIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end

#target_table_configTypes::TargetTableConfig

A structure for the target table configuration.



6759
6760
6761
6762
6763
6764
6765
6766
# File 'lib/aws-sdk-glue/types.rb', line 6759

class CreateIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name,
  :source_table_config,
  :target_table_config)
  SENSITIVE = []
  include Aws::Structure
end