Class: Aws::Glue::Types::CreateIntegrationTablePropertiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateIntegrationTablePropertiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to create integration table properties.
-
#source_table_config ⇒ Types::SourceTableConfig
A structure for the source table configuration.
-
#table_name ⇒ String
The name of the table to be replicated.
-
#target_table_config ⇒ Types::TargetTableConfig
A structure for the target table configuration.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
6664 6665 6666 6667 6668 6669 6670 6671 |
# File 'lib/aws-sdk-glue/types.rb', line 6664 class CreateIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#source_table_config ⇒ Types::SourceTableConfig
A structure for the source table configuration. See the ‘SourceTableConfig` structure to see list of supported source properties.
6664 6665 6666 6667 6668 6669 6670 6671 |
# File 'lib/aws-sdk-glue/types.rb', line 6664 class CreateIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table to be replicated.
6664 6665 6666 6667 6668 6669 6670 6671 |
# File 'lib/aws-sdk-glue/types.rb', line 6664 class CreateIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#target_table_config ⇒ Types::TargetTableConfig
A structure for the target table configuration.
6664 6665 6666 6667 6668 6669 6670 6671 |
# File 'lib/aws-sdk-glue/types.rb', line 6664 class CreateIntegrationTablePropertiesRequest < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |