Class: Aws::Glue::Types::CreateRegistryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateRegistryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the registry.
-
#registry_name ⇒ String
Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark.
-
#tags ⇒ Hash<String,String>
Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API.
Instance Attribute Details
#description ⇒ String
A description of the registry. If description is not provided, there will not be any default value for this.
5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark. No whitespace.
5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API.
5201 5202 5203 5204 5205 5206 5207 |
# File 'lib/aws-sdk-glue/types.rb', line 5201 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |