Class: Aws::Glue::Types::CreateRegistryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateRegistryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the registry.
-
#registry_name ⇒ String
Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark.
-
#tags ⇒ Hash<String,String>
Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API.
Instance Attribute Details
#description ⇒ String
A description of the registry. If description is not provided, there will not be any default value for this.
4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-glue/types.rb', line 4389 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark. No whitespace.
4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-glue/types.rb', line 4389 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API.
4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-glue/types.rb', line 4389 class CreateRegistryInput < Struct.new( :registry_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |