Class: Aws::Glue::Types::CreateRegistryInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass CreateRegistryInput data as a hash:

{
  registry_name: "SchemaRegistryNameString", # required
  description: "DescriptionString",
  tags: {
    "TagKey" => "TagValue",
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the registry. If description is not provided, there will not be any default value for this.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
# File 'lib/aws-sdk-glue/types.rb', line 6818

class CreateRegistryInput < Struct.new(
  :registry_name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#registry_nameString

Name of the registry to be created of max length of 255, and may only contain letters, numbers, hyphen, underscore, dollar sign, or hash mark. No whitespace.

Returns:

  • (String)


6818
6819
6820
6821
6822
6823
6824
# File 'lib/aws-sdk-glue/types.rb', line 6818

class CreateRegistryInput < Struct.new(
  :registry_name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Amazon Web Services tags that contain a key value pair and may be searched by console, command line, or API.

Returns:

  • (Hash<String,String>)


6818
6819
6820
6821
6822
6823
6824
# File 'lib/aws-sdk-glue/types.rb', line 6818

class CreateRegistryInput < Struct.new(
  :registry_name,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end