Class: Aws::Glue::Types::CreateSchemaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateSchemaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatibility ⇒ String
The schema compatibility mode.
-
#data_format ⇒ String
The data format of the schema definition.
-
#description ⇒ String
A description of the schema if specified when created.
-
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
-
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
-
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
-
#registry_name ⇒ String
The name of the registry.
-
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
-
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
-
#schema_name ⇒ String
The name of the schema.
-
#schema_status ⇒ String
The status of the schema.
-
#schema_version_id ⇒ String
The unique identifier of the first schema version.
-
#schema_version_status ⇒ String
The status of the first schema version created.
-
#tags ⇒ Hash<String,String>
The tags for the schema.
Instance Attribute Details
#compatibility ⇒ String
The schema compatibility mode.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#data_format ⇒ String
The data format of the schema definition. Currently ‘AVRO`, `JSON` and `PROTOBUF` are supported.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the schema if specified when created.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
The name of the registry.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the schema.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_status ⇒ String
The status of the schema.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_version_id ⇒ String
The unique identifier of the first schema version.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_version_status ⇒ String
The status of the first schema version created.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for the schema.
4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-glue/types.rb', line 4972 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |