Class: Aws::Glue::Types::CreateSchemaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateSchemaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatibility ⇒ String
The schema compatibility mode.
-
#data_format ⇒ String
The data format of the schema definition.
-
#description ⇒ String
A description of the schema if specified when created.
-
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
-
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
-
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
-
#registry_name ⇒ String
The name of the registry.
-
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
-
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
-
#schema_name ⇒ String
The name of the schema.
-
#schema_status ⇒ String
The status of the schema.
-
#schema_version_id ⇒ String
The unique identifier of the first schema version.
-
#schema_version_status ⇒ String
The status of the first schema version created.
-
#tags ⇒ Hash<String,String>
The tags for the schema.
Instance Attribute Details
#compatibility ⇒ String
The schema compatibility mode.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#data_format ⇒ String
The data format of the schema definition. Currently `AVRO`, `JSON` and `PROTOBUF` are supported.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the schema if specified when created.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
The name of the registry.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the schema.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_status ⇒ String
The status of the schema.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_version_id ⇒ String
The unique identifier of the first schema version.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#schema_version_status ⇒ String
The status of the first schema version created.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags for the schema.
6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 6968 6969 6970 6971 6972 |
# File 'lib/aws-sdk-glue/types.rb', line 6955 class CreateSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :tags, :schema_version_id, :schema_version_status) SENSITIVE = [] include Aws::Structure end |