Class: Aws::Glue::Types::CreateSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Request to create a new session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandTypes::SessionCommand

The `SessionCommand` that runs the job.



4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#connectionsTypes::ConnectionsList

The number of connections to use for the session.



4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#default_argumentsHash<String,String>

A map array of key-value pairs. Max is 75 pairs.

Returns:

  • (Hash<String,String>)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the session.

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

The Glue version determines the versions of Apache Spark and Python that Glue supports. The GlueVersion must be greater than 2.0.

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the session request.

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeoutInteger

The number of seconds when idle before request times out.

Returns:

  • (Integer)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.

Returns:

  • (Float)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined `WorkerType` to use for the session.

Returns:

  • (Integer)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#request_originString

The origin of the request.

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The IAM Role ARN

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the SecurityConfiguration structure to be used with the session

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The map of key value pairs (tags) belonging to the session.

Returns:

  • (Hash<String,String>)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The number of seconds before request times out.

Returns:

  • (Integer)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated to use for the session. Accepts a value of Standard, G.1X, G.2X, or G.025X.

  • For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the `G.1X` worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the `G.2X` worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.

  • For the `G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.

Returns:

  • (String)


4759
4760
4761
4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
4777
# File 'lib/aws-sdk-glue/types.rb', line 4759

class CreateSessionRequest < Struct.new(
  :id,
  :description,
  :role,
  :command,
  :timeout,
  :idle_timeout,
  :default_arguments,
  :connections,
  :max_capacity,
  :number_of_workers,
  :worker_type,
  :security_configuration,
  :glue_version,
  :tags,
  :request_origin)
  SENSITIVE = []
  include Aws::Structure
end