Class: Aws::Glue::Types::CreateSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass CreateSessionRequest data as a hash:
{
id: "NameString", # required
description: "DescriptionString",
role: "OrchestrationRoleArn", # required
command: { # required
name: "NameString",
python_version: "PythonVersionString",
},
timeout: 1,
idle_timeout: 1,
default_arguments: {
"OrchestrationNameString" => "OrchestrationArgumentsValue",
},
connections: {
connections: ["GenericString"],
},
max_capacity: 1.0,
number_of_workers: 1,
worker_type: "Standard", # accepts Standard, G.1X, G.2X, G.025X
security_configuration: "NameString",
glue_version: "GlueVersionString",
tags: {
"TagKey" => "TagValue",
},
request_origin: "OrchestrationNameString",
}
Request to create a new session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ Types::SessionCommand
The `SessionCommand` that runs the job.
-
#connections ⇒ Types::ConnectionsList
The number of connections to use for the session.
-
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs.
-
#description ⇒ String
The description of the session.
-
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#id ⇒ String
The ID of the session request.
-
#idle_timeout ⇒ Integer
The number of seconds when idle before request times out.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs.
-
#number_of_workers ⇒ Integer
The number of workers of a defined `WorkerType` to use for the session.
-
#request_origin ⇒ String
The origin of the request.
-
#role ⇒ String
The IAM Role ARN.
-
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session.
-
#tags ⇒ Hash<String,String>
The map of key value pairs (tags) belonging to the session.
-
#timeout ⇒ Integer
The number of seconds before request times out.
-
#worker_type ⇒ String
The type of predefined worker that is allocated to use for the session.
Instance Attribute Details
#command ⇒ Types::SessionCommand
The `SessionCommand` that runs the job.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#connections ⇒ Types::ConnectionsList
The number of connections to use for the session.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs. Max is 75 pairs.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the session.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports. The GlueVersion must be greater than 2.0.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the session request.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#idle_timeout ⇒ Integer
The number of seconds when idle before request times out.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined `WorkerType` to use for the session.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#request_origin ⇒ String
The origin of the request.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The IAM Role ARN
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The map of key value pairs (tags) belonging to the session.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The number of seconds before request times out.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated to use for the session. Accepts a value of Standard, G.1X, G.2X, or G.025X.
-
For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.
-
For the `G.1X` worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.
-
For the `G.2X` worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.
-
For the `G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 |
# File 'lib/aws-sdk-glue/types.rb', line 7258 class CreateSessionRequest < Struct.new( :id, :description, :role, :command, :timeout, :idle_timeout, :default_arguments, :connections, :max_capacity, :number_of_workers, :worker_type, :security_configuration, :glue_version, :tags, :request_origin) SENSITIVE = [] include Aws::Structure end |