Class: Aws::Glue::Types::CreateTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the ‘Table`.
-
#database_name ⇒ String
The catalog database in which to create the new table.
-
#name ⇒ String
The unique identifier for the table within the specified database that will be created in the Glue Data Catalog.
-
#open_table_format_input ⇒ Types::OpenTableFormatInput
Specifies an ‘OpenTableFormatInput` structure when creating an open format table.
-
#partition_indexes ⇒ Array<Types::PartitionIndex>
A list of partition indexes, ‘PartitionIndex` structures, to create in the table.
-
#table_input ⇒ Types::TableInput
The ‘TableInput` object that defines the metadata table to create in the catalog.
-
#transaction_id ⇒ String
The ID of the transaction.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the ‘Table`. If none is supplied, the Amazon Web Services account ID is used by default.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The catalog database in which to create the new table. For Hive compatibility, this name is entirely lowercase.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique identifier for the table within the specified database that will be created in the Glue Data Catalog.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#open_table_format_input ⇒ Types::OpenTableFormatInput
Specifies an ‘OpenTableFormatInput` structure when creating an open format table.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#partition_indexes ⇒ Array<Types::PartitionIndex>
A list of partition indexes, ‘PartitionIndex` structures, to create in the table.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#table_input ⇒ Types::TableInput
The ‘TableInput` object that defines the metadata table to create in the catalog.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The ID of the transaction.
7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 |
# File 'lib/aws-sdk-glue/types.rb', line 7111 class CreateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :partition_indexes, :transaction_id, :open_table_format_input) SENSITIVE = [] include Aws::Structure end |