Class: Aws::Glue::Types::CreateTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger when it fires.
-
#description ⇒ String
A description of the new trigger.
-
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
-
#name ⇒ String
The name of the trigger.
-
#predicate ⇒ Types::Predicate
A predicate to specify when the new trigger should fire.
-
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
-
#start_on_creation ⇒ Boolean
Set to ‘true` to start `SCHEDULED` and `CONDITIONAL` triggers when created.
-
#tags ⇒ Hash<String,String>
The tags to use with this trigger.
-
#type ⇒ String
The type of the new trigger.
-
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger when it fires.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the new trigger.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the trigger.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#predicate ⇒ Types::Predicate
A predicate to specify when the new trigger should fire.
This field is required when the trigger type is ‘CONDITIONAL`.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
This field is required when the trigger type is SCHEDULED.
[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#start_on_creation ⇒ Boolean
Set to ‘true` to start `SCHEDULED` and `CONDITIONAL` triggers when created. True is not supported for `ON_DEMAND` triggers.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to use with this trigger. You may use tags to limit access to the trigger. For more information about tags in Glue, see [Amazon Web Services Tags in Glue] in the developer guide.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the new trigger.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
7141 7142 7143 7144 7145 7146 7147 7148 7149 7150 7151 7152 7153 7154 |
# File 'lib/aws-sdk-glue/types.rb', line 7141 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |