Class: Aws::Glue::Types::CreateTriggerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateTriggerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass CreateTriggerRequest data as a hash:
{
name: "NameString", # required
workflow_name: "NameString",
type: "SCHEDULED", # required, accepts SCHEDULED, CONDITIONAL, ON_DEMAND, EVENT
schedule: "GenericString",
predicate: {
logical: "AND", # accepts AND, ANY
conditions: [
{
logical_operator: "EQUALS", # accepts EQUALS
job_name: "NameString",
state: "STARTING", # accepts STARTING, RUNNING, STOPPING, STOPPED, SUCCEEDED, FAILED, TIMEOUT, ERROR, WAITING
crawler_name: "NameString",
crawl_state: "RUNNING", # accepts RUNNING, CANCELLING, CANCELLED, SUCCEEDED, FAILED, ERROR
},
],
},
actions: [ # required
{
job_name: "NameString",
arguments: {
"GenericString" => "GenericString",
},
timeout: 1,
security_configuration: "NameString",
notification_property: {
notify_delay_after: 1,
},
crawler_name: "NameString",
},
],
description: "DescriptionString",
start_on_creation: false,
tags: {
"TagKey" => "TagValue",
},
event_batching_condition: {
batch_size: 1, # required
batch_window: 1,
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger when it fires.
-
#description ⇒ String
A description of the new trigger.
-
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
-
#name ⇒ String
The name of the trigger.
-
#predicate ⇒ Types::Predicate
A predicate to specify when the new trigger should fire.
-
#schedule ⇒ String
A `cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
-
#start_on_creation ⇒ Boolean
Set to `true` to start `SCHEDULED` and `CONDITIONAL` triggers when created.
-
#tags ⇒ Hash<String,String>
The tags to use with this trigger.
-
#type ⇒ String
The type of the new trigger.
-
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger when it fires.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the new trigger.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the trigger.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#predicate ⇒ Types::Predicate
A predicate to specify when the new trigger should fire.
This field is required when the trigger type is `CONDITIONAL`.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
A `cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
This field is required when the trigger type is SCHEDULED.
[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#start_on_creation ⇒ Boolean
Set to `true` to start `SCHEDULED` and `CONDITIONAL` triggers when created. True is not supported for `ON_DEMAND` triggers.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to use with this trigger. You may use tags to limit access to the trigger. For more information about tags in Glue, see [Amazon Web Services Tags in Glue] in the developer guide.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the new trigger.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
7563 7564 7565 7566 7567 7568 7569 7570 7571 7572 7573 7574 7575 7576 |
# File 'lib/aws-sdk-glue/types.rb', line 7563 class CreateTriggerRequest < Struct.new( :name, :workflow_name, :type, :schedule, :predicate, :actions, :description, :start_on_creation, :tags, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |