Class: Aws::Glue::Types::CreateUserDefinedFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateUserDefinedFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the function.
-
#database_name ⇒ String
The name of the catalog database in which to create the function.
-
#function_input ⇒ Types::UserDefinedFunctionInput
A `FunctionInput` object that defines the function to create in the Data Catalog.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which to create the function. If none is provided, the Amazon Web Services account ID is used by default.
4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4935 class CreateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which to create the function.
4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4935 class CreateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#function_input ⇒ Types::UserDefinedFunctionInput
A `FunctionInput` object that defines the function to create in the Data Catalog.
4935 4936 4937 4938 4939 4940 4941 |
# File 'lib/aws-sdk-glue/types.rb', line 4935 class CreateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_input) SENSITIVE = [] include Aws::Structure end |