Class: Aws::Glue::Types::CreateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CreateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow.
-
#description ⇒ String
A description of the workflow.
-
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs.
-
#name ⇒ String
The name to be assigned to the workflow.
-
#tags ⇒ Hash<String,String>
The tags to be used with this workflow.
Instance Attribute Details
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow.
6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-glue/types.rb', line 6209 class CreateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :tags, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-glue/types.rb', line 6209 class CreateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :tags, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.
6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-glue/types.rb', line 6209 class CreateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :tags, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name to be assigned to the workflow. It should be unique within your account.
6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-glue/types.rb', line 6209 class CreateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :tags, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be used with this workflow.
6209 6210 6211 6212 6213 6214 6215 6216 6217 |
# File 'lib/aws-sdk-glue/types.rb', line 6209 class CreateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :tags, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |