Class: Aws::Glue::Types::CreateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_run_propertiesHash<String,String>

A collection of properties to be used as part of each execution of the workflow.

Returns:

  • (Hash<String,String>)


5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-glue/types.rb', line 5859

class CreateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :tags,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the workflow.

Returns:

  • (String)


5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-glue/types.rb', line 5859

class CreateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :tags,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrent_runsInteger

You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.

Returns:

  • (Integer)


5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-glue/types.rb', line 5859

class CreateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :tags,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to be assigned to the workflow. It should be unique within your account.

Returns:

  • (String)


5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-glue/types.rb', line 5859

class CreateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :tags,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be used with this workflow.

Returns:

  • (Hash<String,String>)


5859
5860
5861
5862
5863
5864
5865
5866
5867
# File 'lib/aws-sdk-glue/types.rb', line 5859

class CreateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :tags,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end