Class: Aws::Glue::Types::CsvClassifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A classifier for custom CSV content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_single_columnBoolean

Enables the processing of files that contain only one column.

Returns:

  • (Boolean)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#contains_headerString

Indicates whether the CSV file contains a header.

Returns:

  • (String)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that this classifier was registered.

Returns:

  • (Time)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#custom_datatype_configuredBoolean

Enables the custom datatype to be configured.

Returns:

  • (Boolean)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#custom_datatypesArray<String>

A list of custom datatypes including "BINARY", "BOOLEAN", "DATE", "DECIMAL", "DOUBLE", "FLOAT", "INT", "LONG", "SHORT", "STRING", "TIMESTAMP".

Returns:

  • (Array<String>)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#delimiterString

A custom symbol to denote what separates each column entry in the row.

Returns:

  • (String)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#disable_value_trimmingBoolean

Specifies not to trim values before identifying the type of column values. The default value is true.

Returns:

  • (Boolean)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#headerArray<String>

A list of strings representing column names.

Returns:

  • (Array<String>)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The time that this classifier was last updated.

Returns:

  • (Time)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the classifier.

Returns:

  • (String)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#quote_symbolString

A custom symbol to denote what combines content into a single column value. It must be different from the column delimiter.

Returns:

  • (String)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#serdeString

Sets the SerDe for processing CSV in the classifier, which will be applied in the Data Catalog. Valid values are OpenCSVSerDe, LazySimpleSerDe, and None. You can specify the None value when you want the crawler to do the detection.

Returns:

  • (String)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of this classifier.

Returns:

  • (Integer)


8136
8137
8138
8139
8140
8141
8142
8143
8144
8145
8146
8147
8148
8149
8150
8151
8152
# File 'lib/aws-sdk-glue/types.rb', line 8136

class CsvClassifier < Struct.new(
  :name,
  :creation_time,
  :last_updated,
  :version,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end