Class: Aws::Glue::Types::CsvClassifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CsvClassifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A classifier for custom ‘CSV` content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
-
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
-
#creation_time ⇒ Time
The time that this classifier was registered.
-
#custom_datatype_configured ⇒ Boolean
Enables the custom datatype to be configured.
-
#custom_datatypes ⇒ Array<String>
A list of custom datatypes including “BINARY”, “BOOLEAN”, “DATE”, “DECIMAL”, “DOUBLE”, “FLOAT”, “INT”, “LONG”, “SHORT”, “STRING”, “TIMESTAMP”.
-
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
-
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values.
-
#header ⇒ Array<String>
A list of strings representing column names.
-
#last_updated ⇒ Time
The time that this classifier was last updated.
-
#name ⇒ String
The name of the classifier.
-
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value.
-
#version ⇒ Integer
The version of this classifier.
Instance Attribute Details
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that this classifier was registered.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatype_configured ⇒ Boolean
Enables the custom datatype to be configured.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatypes ⇒ Array<String>
A list of custom datatypes including “BINARY”, “BOOLEAN”, “DATE”, “DECIMAL”, “DOUBLE”, “FLOAT”, “INT”, “LONG”, “SHORT”, “STRING”, “TIMESTAMP”.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values. The default value is ‘true`.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Array<String>
A list of strings representing column names.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The time that this classifier was last updated.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value. It must be different from the column delimiter.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of this classifier.
5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 |
# File 'lib/aws-sdk-glue/types.rb', line 5491 class CsvClassifier < Struct.new( :name, :creation_time, :last_updated, :version, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |