Class: Aws::Glue::Types::CustomEntityType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An object representing a custom pattern for detecting sensitive data across the columns and rows of your structured data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_wordsArray<String>

A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.

If no context words are passed only a regular expression is checked.

Returns:

  • (Array<String>)


8251
8252
8253
8254
8255
8256
8257
# File 'lib/aws-sdk-glue/types.rb', line 8251

class CustomEntityType < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
# File 'lib/aws-sdk-glue/types.rb', line 8251

class CustomEntityType < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end

#regex_stringString

A regular expression string that is used for detecting sensitive data in a custom pattern.

Returns:

  • (String)


8251
8252
8253
8254
8255
8256
8257
# File 'lib/aws-sdk-glue/types.rb', line 8251

class CustomEntityType < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end