Class: Aws::Glue::Types::CustomEntityType
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::CustomEntityType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An object representing a custom pattern for detecting sensitive data across the columns and rows of your structured data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_words ⇒ Array<String>
A list of context words.
-
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later.
-
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
Instance Attribute Details
#context_words ⇒ Array<String>
A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
If no context words are passed only a regular expression is checked.
7817 7818 7819 7820 7821 7822 7823 |
# File 'lib/aws-sdk-glue/types.rb', line 7817 class CustomEntityType < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.
7817 7818 7819 7820 7821 7822 7823 |
# File 'lib/aws-sdk-glue/types.rb', line 7817 class CustomEntityType < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
7817 7818 7819 7820 7821 7822 7823 |
# File 'lib/aws-sdk-glue/types.rb', line 7817 class CustomEntityType < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |