Class: Aws::Glue::Types::DataQualityAnalyzerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityAnalyzerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Describes the result of the evaluation of a data quality analyzer.
Constant Summary collapse
- SENSITIVE =
[:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the data quality analyzer.
-
#evaluated_distributions ⇒ Hash<String,Types::DistributionData>
A map of distribution metrics associated with the evaluation of the analyzer.
-
#evaluated_metrics ⇒ Hash<String,Float>
A map of metrics associated with the evaluation of the analyzer.
-
#evaluation_message ⇒ String
An evaluation message.
-
#name ⇒ String
The name of the data quality analyzer.
Instance Attribute Details
#description ⇒ String
A description of the data quality analyzer.
8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-glue/types.rb', line 8650 class DataQualityAnalyzerResult < Struct.new( :name, :description, :evaluation_message, :evaluated_metrics, :evaluated_distributions) SENSITIVE = [:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions] include Aws::Structure end |
#evaluated_distributions ⇒ Hash<String,Types::DistributionData>
A map of distribution metrics associated with the evaluation of the analyzer.
8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-glue/types.rb', line 8650 class DataQualityAnalyzerResult < Struct.new( :name, :description, :evaluation_message, :evaluated_metrics, :evaluated_distributions) SENSITIVE = [:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions] include Aws::Structure end |
#evaluated_metrics ⇒ Hash<String,Float>
A map of metrics associated with the evaluation of the analyzer.
8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-glue/types.rb', line 8650 class DataQualityAnalyzerResult < Struct.new( :name, :description, :evaluation_message, :evaluated_metrics, :evaluated_distributions) SENSITIVE = [:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions] include Aws::Structure end |
#evaluation_message ⇒ String
An evaluation message.
8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-glue/types.rb', line 8650 class DataQualityAnalyzerResult < Struct.new( :name, :description, :evaluation_message, :evaluated_metrics, :evaluated_distributions) SENSITIVE = [:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions] include Aws::Structure end |
#name ⇒ String
The name of the data quality analyzer.
8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-glue/types.rb', line 8650 class DataQualityAnalyzerResult < Struct.new( :name, :description, :evaluation_message, :evaluated_metrics, :evaluated_distributions) SENSITIVE = [:description, :evaluation_message, :evaluated_metrics, :evaluated_distributions] include Aws::Structure end |