Class: Aws::Glue::Types::DataQualityEvaluationRunAdditionalRunOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DataQualityEvaluationRunAdditionalRunOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Additional run options you can specify for an evaluation run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_metrics_enabled ⇒ Boolean
Whether or not to enable CloudWatch metrics.
-
#composite_rule_evaluation_method ⇒ String
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN.
-
#custom_log_group_prefix ⇒ String
A custom prefix for the CloudWatch log group names.
-
#data_quality_rule_results ⇒ Types::DataQualityRuleResultsOptions
The configuration for writing rule results to a Glue Data Catalog table.
-
#observation_mode ⇒ String
The observation mode for the evaluation run.
-
#observation_results ⇒ Types::ObservationResultsOptions
The configuration for writing observation results to a Glue Data Catalog table.
-
#observation_scope ⇒ String
The scope of the observation for the evaluation run.
-
#profiling_results ⇒ Types::ProfilingResultsOptions
The configuration for writing profiling results to a Glue Data Catalog table.
-
#results_s3_prefix ⇒ String
Prefix for Amazon S3 to store results.
-
#row_level_results ⇒ Types::RowLevelResultsOptions
The configuration for writing row-level evaluation results to a Glue Data Catalog table.
Instance Attribute Details
#cloud_watch_metrics_enabled ⇒ Boolean
Whether or not to enable CloudWatch metrics.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#composite_rule_evaluation_method ⇒ String
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#custom_log_group_prefix ⇒ String
A custom prefix for the CloudWatch log group names. When specified,
evaluation run logs are written to <CustomLogGroupPrefix>/error
and <CustomLogGroupPrefix>/output instead of the default
/aws-glue/data-quality/error and /aws-glue/data-quality/output
log groups.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#data_quality_rule_results ⇒ Types::DataQualityRuleResultsOptions
The configuration for writing rule results to a Glue Data Catalog table.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#observation_mode ⇒ String
The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#observation_results ⇒ Types::ObservationResultsOptions
The configuration for writing observation results to a Glue Data Catalog table.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#observation_scope ⇒ String
The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#profiling_results ⇒ Types::ProfilingResultsOptions
The configuration for writing profiling results to a Glue Data Catalog table.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#results_s3_prefix ⇒ String
Prefix for Amazon S3 to store results.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |
#row_level_results ⇒ Types::RowLevelResultsOptions
The configuration for writing row-level evaluation results to a Glue Data Catalog table.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-glue/types.rb', line 8740 class DataQualityEvaluationRunAdditionalRunOptions < Struct.new( :cloud_watch_metrics_enabled, :results_s3_prefix, :composite_rule_evaluation_method, :custom_log_group_prefix, :row_level_results, :profiling_results, :observation_scope, :observation_mode, :data_quality_rule_results, :observation_results) SENSITIVE = [] include Aws::Structure end |