Class: Aws::Glue::Types::DataQualityEvaluationRunAdditionalRunOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Additional run options you can specify for an evaluation run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_metrics_enabledBoolean

Whether or not to enable CloudWatch metrics.

Returns:

  • (Boolean)


8384
8385
8386
8387
8388
8389
8390
8391
# File 'lib/aws-sdk-glue/types.rb', line 8384

class DataQualityEvaluationRunAdditionalRunOptions < Struct.new(
  :cloud_watch_metrics_enabled,
  :results_s3_prefix,
  :composite_rule_evaluation_method,
  :custom_log_group_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#composite_rule_evaluation_methodString

Set the evaluation method for composite rules in the ruleset to ROW/COLUMN

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
# File 'lib/aws-sdk-glue/types.rb', line 8384

class DataQualityEvaluationRunAdditionalRunOptions < Struct.new(
  :cloud_watch_metrics_enabled,
  :results_s3_prefix,
  :composite_rule_evaluation_method,
  :custom_log_group_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#custom_log_group_prefixString

A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to ‘<CustomLogGroupPrefix>/error` and `<CustomLogGroupPrefix>/output` instead of the default `/aws-glue/data-quality/error` and `/aws-glue/data-quality/output` log groups.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
# File 'lib/aws-sdk-glue/types.rb', line 8384

class DataQualityEvaluationRunAdditionalRunOptions < Struct.new(
  :cloud_watch_metrics_enabled,
  :results_s3_prefix,
  :composite_rule_evaluation_method,
  :custom_log_group_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#results_s3_prefixString

Prefix for Amazon S3 to store results.

Returns:

  • (String)


8384
8385
8386
8387
8388
8389
8390
8391
# File 'lib/aws-sdk-glue/types.rb', line 8384

class DataQualityEvaluationRunAdditionalRunOptions < Struct.new(
  :cloud_watch_metrics_enabled,
  :results_s3_prefix,
  :composite_rule_evaluation_method,
  :custom_log_group_prefix)
  SENSITIVE = []
  include Aws::Structure
end