Class: Aws::Glue::Types::Database
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Database
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The ‘Database` object represents a logical grouping of tables that might reside in a Hive metastore or an RDBMS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#create_table_default_permissions ⇒ Array<Types::PrincipalPermissions>
Creates a set of default permissions on the table for principals.
-
#create_time ⇒ Time
The time at which the metadata database was created in the catalog.
-
#description ⇒ String
A description of the database.
-
#federated_database ⇒ Types::FederatedDatabase
A ‘FederatedDatabase` structure that references an entity outside the Glue Data Catalog.
-
#location_uri ⇒ String
The location of the database (for example, an HDFS path).
-
#name ⇒ String
The name of the database.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define parameters and properties of the database.
-
#target_database ⇒ Types::DatabaseIdentifier
A ‘DatabaseIdentifier` structure that describes a target database for resource linking.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#create_table_default_permissions ⇒ Array<Types::PrincipalPermissions>
Creates a set of default permissions on the table for principals. Used by Lake Formation. Not used in the normal course of Glue operations.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the metadata database was created in the catalog.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the database.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#federated_database ⇒ Types::FederatedDatabase
A ‘FederatedDatabase` structure that references an entity outside the Glue Data Catalog.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The location of the database (for example, an HDFS path).
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database. For Hive compatibility, this is folded to lowercase when it is stored.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define parameters and properties of the database.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |
#target_database ⇒ Types::DatabaseIdentifier
A ‘DatabaseIdentifier` structure that describes a target database for resource linking.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 |
# File 'lib/aws-sdk-glue/types.rb', line 6913 class Database < Struct.new( :name, :description, :location_uri, :parameters, :create_time, :create_table_default_permissions, :target_database, :catalog_id, :federated_database) SENSITIVE = [] include Aws::Structure end |