Class: Aws::Glue::Types::DatabaseIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DatabaseIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that describes a target database for resource linking.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#database_name ⇒ String
The name of the catalog database.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
6109 6110 6111 6112 6113 6114 |
# File 'lib/aws-sdk-glue/types.rb', line 6109 class DatabaseIdentifier < Struct.new( :catalog_id, :database_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database.
6109 6110 6111 6112 6113 6114 |
# File 'lib/aws-sdk-glue/types.rb', line 6109 class DatabaseIdentifier < Struct.new( :catalog_id, :database_name) SENSITIVE = [] include Aws::Structure end |