Class: Aws::Glue::Types::DatabaseIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure that describes a target database for resource linking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides.

Returns:

  • (String)


5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-glue/types.rb', line 5669

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database.

Returns:

  • (String)


5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-glue/types.rb', line 5669

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end