Class: Aws::Glue::Types::DatabaseIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DatabaseIdentifier data as a hash:

{
  catalog_id: "CatalogIdString",
  database_name: "NameString",
}

A structure that describes a target database for resource linking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides.

Returns:

  • (String)


8079
8080
8081
8082
8083
8084
# File 'lib/aws-sdk-glue/types.rb', line 8079

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database.

Returns:

  • (String)


8079
8080
8081
8082
8083
8084
# File 'lib/aws-sdk-glue/types.rb', line 8079

class DatabaseIdentifier < Struct.new(
  :catalog_id,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end