Class: Aws::Glue::Types::DatabaseIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DatabaseIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DatabaseIdentifier data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString",
}
A structure that describes a target database for resource linking.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#database_name ⇒ String
The name of the catalog database.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-glue/types.rb', line 5578 class DatabaseIdentifier < Struct.new( :catalog_id, :database_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database.
5578 5579 5580 5581 5582 5583 |
# File 'lib/aws-sdk-glue/types.rb', line 5578 class DatabaseIdentifier < Struct.new( :catalog_id, :database_name) SENSITIVE = [] include Aws::Structure end |