Class: Aws::Glue::Types::DatabaseInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DatabaseInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The structure used to create or update a database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_table_default_permissions ⇒ Array<Types::PrincipalPermissions>
Creates a set of default permissions on the table for principals.
-
#description ⇒ String
A description of the database.
-
#federated_database ⇒ Types::FederatedDatabase
A ‘FederatedDatabase` structure that references an entity outside the Glue Data Catalog.
-
#location_uri ⇒ String
The location of the database (for example, an HDFS path).
-
#name ⇒ String
The name of the database.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define parameters and properties of the database.
-
#target_database ⇒ Types::DatabaseIdentifier
A ‘DatabaseIdentifier` structure that describes a target database for resource linking.
Instance Attribute Details
#create_table_default_permissions ⇒ Array<Types::PrincipalPermissions>
Creates a set of default permissions on the table for principals. Used by Lake Formation. Not used in the normal course of Glue operations.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the database.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#federated_database ⇒ Types::FederatedDatabase
A ‘FederatedDatabase` structure that references an entity outside the Glue Data Catalog.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#location_uri ⇒ String
The location of the database (for example, an HDFS path).
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database. For Hive compatibility, this is folded to lowercase when it is stored.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define parameters and properties of the database.
These key-value pairs define parameters and properties of the database.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |
#target_database ⇒ Types::DatabaseIdentifier
A ‘DatabaseIdentifier` structure that describes a target database for resource linking.
6986 6987 6988 6989 6990 6991 6992 6993 6994 6995 6996 |
# File 'lib/aws-sdk-glue/types.rb', line 6986 class DatabaseInput < Struct.new( :name, :description, :location_uri, :parameters, :create_table_default_permissions, :target_database, :federated_database) SENSITIVE = [] include Aws::Structure end |