Class: Aws::Glue::Types::DatabaseInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The structure used to create or update a database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_table_default_permissionsArray<Types::PrincipalPermissions>

Creates a set of default permissions on the table for principals.

Returns:



5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the database.

Returns:

  • (String)


5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end

#location_uriString

The location of the database (for example, an HDFS path).

Returns:

  • (String)


5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database. For Hive compatibility, this is folded to lowercase when it is stored.

Returns:

  • (String)


5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

These key-value pairs define parameters and properties of the database.

These key-value pairs define parameters and properties of the database.

Returns:

  • (Hash<String,String>)


5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end

#target_databaseTypes::DatabaseIdentifier

A ‘DatabaseIdentifier` structure that describes a target database for resource linking.



5772
5773
5774
5775
5776
5777
5778
5779
5780
5781
# File 'lib/aws-sdk-glue/types.rb', line 5772

class DatabaseInput < Struct.new(
  :name,
  :description,
  :location_uri,
  :parameters,
  :create_table_default_permissions,
  :target_database)
  SENSITIVE = []
  include Aws::Structure
end