Class: Aws::Glue::Types::DeleteAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset from which to delete the attachment.
-
#attachment_name ⇒ String
The name of the attachment to delete.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form.
-
#iterable_form_name ⇒ String
The name of the iterable form.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset from which to delete the attachment.
9527 9528 9529 9530 9531 9532 9533 9534 |
# File 'lib/aws-sdk-glue/types.rb', line 9527 class DeleteAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name) SENSITIVE = [] include Aws::Structure end |
#attachment_name ⇒ String
The name of the attachment to delete.
9527 9528 9529 9530 9531 9532 9533 9534 |
# File 'lib/aws-sdk-glue/types.rb', line 9527 class DeleteAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form. Required when
iterableFormName is specified.
9527 9528 9529 9530 9531 9532 9533 9534 |
# File 'lib/aws-sdk-glue/types.rb', line 9527 class DeleteAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form. When specified along with
itemIdentifier, the attachment is deleted from an item within the
iterable form rather than from the asset itself.
9527 9528 9529 9530 9531 9532 9533 9534 |
# File 'lib/aws-sdk-glue/types.rb', line 9527 class DeleteAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name) SENSITIVE = [] include Aws::Structure end |