Class: Aws::Glue::Types::DeleteAttachmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteAttachmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
-
#iterable_form_name ⇒ String
The name of the iterable form, if the deletion targets an item.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset.
9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-glue/types.rb', line 9842 class DeleteAttachmentResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-glue/types.rb', line 9842 class DeleteAttachmentResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form, if the deletion targets an item.
9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-glue/types.rb', line 9842 class DeleteAttachmentResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier) SENSITIVE = [] include Aws::Structure end |