Class: Aws::Glue::Types::DeleteColumnStatisticsForPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteColumnStatisticsForPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_name ⇒ String
Name of the column.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
6385 6386 6387 6388 6389 6390 6391 6392 6393 |
# File 'lib/aws-sdk-glue/types.rb', line 6385 class DeleteColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_name) SENSITIVE = [] include Aws::Structure end |
#column_name ⇒ String
Name of the column.
6385 6386 6387 6388 6389 6390 6391 6392 6393 |
# File 'lib/aws-sdk-glue/types.rb', line 6385 class DeleteColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
6385 6386 6387 6388 6389 6390 6391 6392 6393 |
# File 'lib/aws-sdk-glue/types.rb', line 6385 class DeleteColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_name) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
6385 6386 6387 6388 6389 6390 6391 6392 6393 |
# File 'lib/aws-sdk-glue/types.rb', line 6385 class DeleteColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
6385 6386 6387 6388 6389 6390 6391 6392 6393 |
# File 'lib/aws-sdk-glue/types.rb', line 6385 class DeleteColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_name) SENSITIVE = [] include Aws::Structure end |