Class: Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_name ⇒ String
The name of the column.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
6408 6409 6410 6411 6412 6413 6414 6415 |
# File 'lib/aws-sdk-glue/types.rb', line 6408 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#column_name ⇒ String
The name of the column.
6408 6409 6410 6411 6412 6413 6414 6415 |
# File 'lib/aws-sdk-glue/types.rb', line 6408 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
6408 6409 6410 6411 6412 6413 6414 6415 |
# File 'lib/aws-sdk-glue/types.rb', line 6408 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
6408 6409 6410 6411 6412 6413 6414 6415 |
# File 'lib/aws-sdk-glue/types.rb', line 6408 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |