Class: Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_name ⇒ String
The name of the column.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-glue/types.rb', line 5979 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#column_name ⇒ String
The name of the column.
5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-glue/types.rb', line 5979 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-glue/types.rb', line 5979 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
5979 5980 5981 5982 5983 5984 5985 5986 |
# File 'lib/aws-sdk-glue/types.rb', line 5979 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |