Class: Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DeleteColumnStatisticsForTableRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
column_name: "NameString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_name ⇒ String
The name of the column.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions' table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
8340 8341 8342 8343 8344 8345 8346 8347 |
# File 'lib/aws-sdk-glue/types.rb', line 8340 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#column_name ⇒ String
The name of the column.
8340 8341 8342 8343 8344 8345 8346 8347 |
# File 'lib/aws-sdk-glue/types.rb', line 8340 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
8340 8341 8342 8343 8344 8345 8346 8347 |
# File 'lib/aws-sdk-glue/types.rb', line 8340 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions' table.
8340 8341 8342 8343 8344 8345 8346 8347 |
# File 'lib/aws-sdk-glue/types.rb', line 8340 class DeleteColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_name) SENSITIVE = [] include Aws::Structure end |