Class: Aws::Glue::Types::DeleteConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides.
-
#connection_name ⇒ String
The name of the connection to delete.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.
6443 6444 6445 6446 6447 6448 |
# File 'lib/aws-sdk-glue/types.rb', line 6443 class DeleteConnectionRequest < Struct.new( :catalog_id, :connection_name) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection to delete.
6443 6444 6445 6446 6447 6448 |
# File 'lib/aws-sdk-glue/types.rb', line 6443 class DeleteConnectionRequest < Struct.new( :catalog_id, :connection_name) SENSITIVE = [] include Aws::Structure end |