Class: Aws::Glue::Types::DeleteConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DeleteConnectionRequest data as a hash:
{
catalog_id: "CatalogIdString",
connection_name: "NameString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides.
-
#connection_name ⇒ String
The name of the connection to delete.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.
8372 8373 8374 8375 8376 8377 |
# File 'lib/aws-sdk-glue/types.rb', line 8372 class DeleteConnectionRequest < Struct.new( :catalog_id, :connection_name) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection to delete.
8372 8373 8374 8375 8376 8377 |
# File 'lib/aws-sdk-glue/types.rb', line 8372 class DeleteConnectionRequest < Struct.new( :catalog_id, :connection_name) SENSITIVE = [] include Aws::Structure end |