Class: Aws::Glue::Types::DeleteDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#name ⇒ String
The name of the database to delete.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.
7545 7546 7547 7548 7549 7550 |
# File 'lib/aws-sdk-glue/types.rb', line 7545 class DeleteDatabaseRequest < Struct.new( :catalog_id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database to delete. For Hive compatibility, this must be all lowercase.
7545 7546 7547 7548 7549 7550 |
# File 'lib/aws-sdk-glue/types.rb', line 7545 class DeleteDatabaseRequest < Struct.new( :catalog_id, :name) SENSITIVE = [] include Aws::Structure end |