Class: Aws::Glue::Types::DeleteDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DeleteDatabaseRequest data as a hash:

{
  catalog_id: "CatalogIdString",
  name: "NameString", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


5714
5715
5716
5717
5718
5719
# File 'lib/aws-sdk-glue/types.rb', line 5714

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database to delete. For Hive compatibility, this must be all lowercase.

Returns:

  • (String)


5714
5715
5716
5717
5718
5719
# File 'lib/aws-sdk-glue/types.rb', line 5714

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end