Class: Aws::Glue::Types::DeleteDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.



9092
9093
9094
9095
9096
9097
# File 'lib/aws-sdk-glue/types.rb', line 9092

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database to delete. For Hive compatibility, this must be all lowercase.



9092
9093
9094
9095
9096
9097
# File 'lib/aws-sdk-glue/types.rb', line 9092

class DeleteDatabaseRequest < Struct.new(
  :catalog_id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end