Class: Aws::Glue::Types::DeletePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeletePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partition_values ⇒ Array<String>
The values that define the partition.
-
#table_name ⇒ String
The name of the table that contains the partition to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default.
7659 7660 7661 7662 7663 7664 7665 7666 |
# File 'lib/aws-sdk-glue/types.rb', line 7659 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
7659 7660 7661 7662 7663 7664 7665 7666 |
# File 'lib/aws-sdk-glue/types.rb', line 7659 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
The values that define the partition.
7659 7660 7661 7662 7663 7664 7665 7666 |
# File 'lib/aws-sdk-glue/types.rb', line 7659 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that contains the partition to be deleted.
7659 7660 7661 7662 7663 7664 7665 7666 |
# File 'lib/aws-sdk-glue/types.rb', line 7659 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |