Class: Aws::Glue::Types::DeletePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeletePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DeletePartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partition_values: ["ValueString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partition_values ⇒ Array<String>
The values that define the partition.
-
#table_name ⇒ String
The name of the table that contains the partition to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be deleted resides. If none is provided, the Amazon Web Services account ID is used by default.
8715 8716 8717 8718 8719 8720 8721 8722 |
# File 'lib/aws-sdk-glue/types.rb', line 8715 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
8715 8716 8717 8718 8719 8720 8721 8722 |
# File 'lib/aws-sdk-glue/types.rb', line 8715 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
The values that define the partition.
8715 8716 8717 8718 8719 8720 8721 8722 |
# File 'lib/aws-sdk-glue/types.rb', line 8715 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that contains the partition to be deleted.
8715 8716 8717 8718 8719 8720 8721 8722 |
# File 'lib/aws-sdk-glue/types.rb', line 8715 class DeletePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |