Class: Aws::Glue::Types::DeleteTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the catalog database in which the table resides.
-
#name ⇒ String
The name of the table to be deleted.
-
#transaction_id ⇒ String
The transaction ID at which to delete the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
7487 7488 7489 7490 7491 7492 7493 7494 |
# File 'lib/aws-sdk-glue/types.rb', line 7487 class DeleteTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
7487 7488 7489 7490 7491 7492 7493 7494 |
# File 'lib/aws-sdk-glue/types.rb', line 7487 class DeleteTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the table to be deleted. For Hive compatibility, this name is entirely lowercase.
7487 7488 7489 7490 7491 7492 7493 7494 |
# File 'lib/aws-sdk-glue/types.rb', line 7487 class DeleteTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to delete the table contents.
7487 7488 7489 7490 7491 7492 7493 7494 |
# File 'lib/aws-sdk-glue/types.rb', line 7487 class DeleteTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id) SENSITIVE = [] include Aws::Structure end |