Class: Aws::Glue::Types::DeleteTableVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteTableVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog in which the table resides.
-
#table_name ⇒ String
The name of the table.
-
#version_id ⇒ String
The ID of the table version to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-glue/types.rb', line 10019 class DeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-glue/types.rb', line 10019 class DeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table. For Hive compatibility, this name is entirely lowercase.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-glue/types.rb', line 10019 class DeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of the table version to be deleted. A ‘VersionID` is a string representation of an integer. Each version is incremented by 1.
10019 10020 10021 10022 10023 10024 10025 10026 |
# File 'lib/aws-sdk-glue/types.rb', line 10019 class DeleteTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id) SENSITIVE = [] include Aws::Structure end |