Class: Aws::Glue::Types::DeleteUserDefinedFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeleteUserDefinedFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be deleted is located.
-
#database_name ⇒ String
The name of the catalog database where the function is located.
-
#function_name ⇒ String
The name of the function definition to be deleted.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be deleted is located. If none is supplied, the Amazon Web Services account ID is used by default.
10458 10459 10460 10461 10462 10463 10464 |
# File 'lib/aws-sdk-glue/types.rb', line 10458 class DeleteUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the function is located.
10458 10459 10460 10461 10462 10463 10464 |
# File 'lib/aws-sdk-glue/types.rb', line 10458 class DeleteUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function definition to be deleted.
10458 10459 10460 10461 10462 10463 10464 |
# File 'lib/aws-sdk-glue/types.rb', line 10458 class DeleteUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |