Class: Aws::Glue::Types::DeltaTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeltaTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a Delta data store to crawl one or more Delta tables.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to use to connect to the Delta table target.
-
#create_native_delta_table ⇒ Boolean
Specifies whether the crawler will create native tables, to allow integration with query engines that support querying of the Delta transaction log directly.
-
#delta_tables ⇒ Array<String>
A list of the Amazon S3 paths to the Delta tables.
-
#write_manifest ⇒ Boolean
Specifies whether to write the manifest files to the Delta table path.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to use to connect to the Delta table target.
7520 7521 7522 7523 7524 7525 7526 7527 |
# File 'lib/aws-sdk-glue/types.rb', line 7520 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest, :create_native_delta_table) SENSITIVE = [] include Aws::Structure end |
#create_native_delta_table ⇒ Boolean
Specifies whether the crawler will create native tables, to allow integration with query engines that support querying of the Delta transaction log directly.
7520 7521 7522 7523 7524 7525 7526 7527 |
# File 'lib/aws-sdk-glue/types.rb', line 7520 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest, :create_native_delta_table) SENSITIVE = [] include Aws::Structure end |
#delta_tables ⇒ Array<String>
A list of the Amazon S3 paths to the Delta tables.
7520 7521 7522 7523 7524 7525 7526 7527 |
# File 'lib/aws-sdk-glue/types.rb', line 7520 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest, :create_native_delta_table) SENSITIVE = [] include Aws::Structure end |
#write_manifest ⇒ Boolean
Specifies whether to write the manifest files to the Delta table path.
7520 7521 7522 7523 7524 7525 7526 7527 |
# File 'lib/aws-sdk-glue/types.rb', line 7520 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest, :create_native_delta_table) SENSITIVE = [] include Aws::Structure end |