Class: Aws::Glue::Types::DeltaTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DeltaTarget data as a hash:

{
  delta_tables: ["Path"],
  connection_name: "ConnectionName",
  write_manifest: false,
}

Specifies a Delta data store to crawl one or more Delta tables.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_nameString

The name of the connection to use to connect to the Delta table target.

Returns:

  • (String)


9171
9172
9173
9174
9175
9176
9177
# File 'lib/aws-sdk-glue/types.rb', line 9171

class DeltaTarget < Struct.new(
  :delta_tables,
  :connection_name,
  :write_manifest)
  SENSITIVE = []
  include Aws::Structure
end

#delta_tablesArray<String>

A list of the Amazon S3 paths to the Delta tables.

Returns:

  • (Array<String>)


9171
9172
9173
9174
9175
9176
9177
# File 'lib/aws-sdk-glue/types.rb', line 9171

class DeltaTarget < Struct.new(
  :delta_tables,
  :connection_name,
  :write_manifest)
  SENSITIVE = []
  include Aws::Structure
end

#write_manifestBoolean

Specifies whether to write the manifest files to the Delta table path.

Returns:

  • (Boolean)


9171
9172
9173
9174
9175
9176
9177
# File 'lib/aws-sdk-glue/types.rb', line 9171

class DeltaTarget < Struct.new(
  :delta_tables,
  :connection_name,
  :write_manifest)
  SENSITIVE = []
  include Aws::Structure
end