Class: Aws::Glue::Types::DeltaTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DeltaTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DeltaTarget data as a hash:
{
delta_tables: ["Path"],
connection_name: "ConnectionName",
write_manifest: false,
}
Specifies a Delta data store to crawl one or more Delta tables.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to use to connect to the Delta table target.
-
#delta_tables ⇒ Array<String>
A list of the Amazon S3 paths to the Delta tables.
-
#write_manifest ⇒ Boolean
Specifies whether to write the manifest files to the Delta table path.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to use to connect to the Delta table target.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-glue/types.rb', line 9083 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest) SENSITIVE = [] include Aws::Structure end |
#delta_tables ⇒ Array<String>
A list of the Amazon S3 paths to the Delta tables.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-glue/types.rb', line 9083 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest) SENSITIVE = [] include Aws::Structure end |
#write_manifest ⇒ Boolean
Specifies whether to write the manifest files to the Delta table path.
9083 9084 9085 9086 9087 9088 9089 |
# File 'lib/aws-sdk-glue/types.rb', line 9083 class DeltaTarget < Struct.new( :delta_tables, :connection_name, :write_manifest) SENSITIVE = [] include Aws::Structure end |