Class: Aws::Glue::Types::DescribeConnectionTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DescribeConnectionTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Athena compute environment.
-
#authentication_configuration ⇒ Types::AuthConfiguration
The type of authentication used for the connection.
-
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
-
#compute_environment_configurations ⇒ Hash<String,Types::ComputeEnvironmentConfiguration>
The compute environments that are supported by the connection.
-
#connection_options ⇒ Hash<String,Types::Property>
Returns properties that can be set when creating a connection in the ‘ConnectionInput.ConnectionProperties`.
-
#connection_properties ⇒ Hash<String,Types::Property>
Connection properties which are common across compute environments.
-
#connection_type ⇒ String
The name of the connection type.
-
#description ⇒ String
A description of the connection type.
-
#physical_connection_requirements ⇒ Hash<String,Types::Property>
Physical requirements for a connection, such as VPC, Subnet and Security Group specifications.
-
#python_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Python compute environment.
-
#rest_configuration ⇒ Types::RestConfiguration
HTTP request and response configuration, validation endpoint, and entity configurations for REST based data source.
-
#spark_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Spark compute environment.
Instance Attribute Details
#athena_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Athena compute environment.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#authentication_configuration ⇒ Types::AuthConfiguration
The type of authentication used for the connection.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#compute_environment_configurations ⇒ Hash<String,Types::ComputeEnvironmentConfiguration>
The compute environments that are supported by the connection.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_options ⇒ Hash<String,Types::Property>
Returns properties that can be set when creating a connection in the ‘ConnectionInput.ConnectionProperties`. `ConnectionOptions` defines parameters that can be set in a Spark ETL script in the connection options map passed to a dataframe.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_properties ⇒ Hash<String,Types::Property>
Connection properties which are common across compute environments.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The name of the connection type.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the connection type.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#physical_connection_requirements ⇒ Hash<String,Types::Property>
Physical requirements for a connection, such as VPC, Subnet and Security Group specifications.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#python_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Python compute environment.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#rest_configuration ⇒ Types::RestConfiguration
HTTP request and response configuration, validation endpoint, and entity configurations for REST based data source.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |
#spark_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Spark compute environment.
10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 |
# File 'lib/aws-sdk-glue/types.rb', line 10595 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties, :rest_configuration) SENSITIVE = [] include Aws::Structure end |