Class: Aws::Glue::Types::DescribeConnectionTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_connection_propertiesHash<String,Types::Property>

Connection properties specific to the Athena compute environment.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_configurationTypes::AuthConfiguration

The type of authentication used for the connection.



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#capabilitiesTypes::Capabilities

The supported authentication types, data interface types (compute environments), and data operations of the connector.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#compute_environment_configurationsHash<String,Types::ComputeEnvironmentConfiguration>

The compute environments that are supported by the connection.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connection_optionsHash<String,Types::Property>

Returns properties that can be set when creating a connection in the ‘ConnectionInput.ConnectionProperties`. `ConnectionOptions` defines parameters that can be set in a Spark ETL script in the connection options map passed to a dataframe.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,Types::Property>

Connection properties which are common across compute environments.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The name of the connection type.

Returns:

  • (String)


10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the connection type.

Returns:

  • (String)


10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsHash<String,Types::Property>

Physical requirements for a connection, such as VPC, Subnet and Security Group specifications.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#python_connection_propertiesHash<String,Types::Property>

Connection properties specific to the Python compute environment.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#rest_configurationTypes::RestConfiguration

HTTP request and response configuration, validation endpoint, and entity configurations for REST based data source.



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#spark_connection_propertiesHash<String,Types::Property>

Connection properties specific to the Spark compute environment.

Returns:



10225
10226
10227
10228
10229
10230
10231
10232
10233
10234
10235
10236
10237
10238
10239
10240
# File 'lib/aws-sdk-glue/types.rb', line 10225

class DescribeConnectionTypeResponse < Struct.new(
  :connection_type,
  :description,
  :capabilities,
  :connection_properties,
  :connection_options,
  :authentication_configuration,
  :compute_environment_configurations,
  :physical_connection_requirements,
  :athena_connection_properties,
  :python_connection_properties,
  :spark_connection_properties,
  :rest_configuration)
  SENSITIVE = []
  include Aws::Structure
end