Class: Aws::Glue::Types::DescribeConnectionTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DescribeConnectionTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Athena compute environment.
-
#authentication_configuration ⇒ Types::AuthConfiguration
The type of authentication used for the connection.
-
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
-
#compute_environment_configurations ⇒ Hash<String,Types::ComputeEnvironmentConfiguration>
The compute environments that are supported by the connection.
-
#connection_options ⇒ Hash<String,Types::Property>
Returns properties that can be set when creating a connection in the ‘ConnectionInput.ConnectionProperties`.
-
#connection_properties ⇒ Hash<String,Types::Property>
Connection properties which are common across compute environments.
-
#connection_type ⇒ String
The name of the connection type.
-
#description ⇒ String
A description of the connection type.
-
#physical_connection_requirements ⇒ Hash<String,Types::Property>
Physical requirements for a connection, such as VPC, Subnet and Security Group specifications.
-
#python_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Python compute environment.
-
#spark_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Spark compute environment.
Instance Attribute Details
#athena_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Athena compute environment.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#authentication_configuration ⇒ Types::AuthConfiguration
The type of authentication used for the connection.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Types::Capabilities
The supported authentication types, data interface types (compute environments), and data operations of the connector.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#compute_environment_configurations ⇒ Hash<String,Types::ComputeEnvironmentConfiguration>
The compute environments that are supported by the connection.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#connection_options ⇒ Hash<String,Types::Property>
Returns properties that can be set when creating a connection in the ‘ConnectionInput.ConnectionProperties`. `ConnectionOptions` defines parameters that can be set in a Spark ETL script in the connection options map passed to a dataframe.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#connection_properties ⇒ Hash<String,Types::Property>
Connection properties which are common across compute environments.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The name of the connection type.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the connection type.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#physical_connection_requirements ⇒ Hash<String,Types::Property>
Physical requirements for a connection, such as VPC, Subnet and Security Group specifications.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#python_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Python compute environment.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |
#spark_connection_properties ⇒ Hash<String,Types::Property>
Connection properties specific to the Spark compute environment.
9336 9337 9338 9339 9340 9341 9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-glue/types.rb', line 9336 class DescribeConnectionTypeResponse < Struct.new( :connection_type, :description, :capabilities, :connection_properties, :connection_options, :authentication_configuration, :compute_environment_configurations, :physical_connection_requirements, :athena_connection_properties, :python_connection_properties, :spark_connection_properties) SENSITIVE = [] include Aws::Structure end |