Class: Aws::Glue::Types::DescribeEntityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DescribeEntityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The catalog ID of the catalog that contains the connection.
-
#connection_name ⇒ String
The name of the connection that contains the connection type credentials.
-
#data_store_api_version ⇒ String
The version of the API used for the data store.
-
#entity_name ⇒ String
The name of the entity that you want to describe from the connection type.
-
#next_token ⇒ String
A continuation token, included if this is a continuation call.
Instance Attribute Details
#catalog_id ⇒ String
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
9778 9779 9780 9781 9782 9783 9784 9785 9786 |
# File 'lib/aws-sdk-glue/types.rb', line 9778 class DescribeEntityRequest < Struct.new( :connection_name, :catalog_id, :entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection that contains the connection type credentials.
9778 9779 9780 9781 9782 9783 9784 9785 9786 |
# File 'lib/aws-sdk-glue/types.rb', line 9778 class DescribeEntityRequest < Struct.new( :connection_name, :catalog_id, :entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#data_store_api_version ⇒ String
The version of the API used for the data store.
9778 9779 9780 9781 9782 9783 9784 9785 9786 |
# File 'lib/aws-sdk-glue/types.rb', line 9778 class DescribeEntityRequest < Struct.new( :connection_name, :catalog_id, :entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity that you want to describe from the connection type.
9778 9779 9780 9781 9782 9783 9784 9785 9786 |
# File 'lib/aws-sdk-glue/types.rb', line 9778 class DescribeEntityRequest < Struct.new( :connection_name, :catalog_id, :entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, included if this is a continuation call.
9778 9779 9780 9781 9782 9783 9784 9785 9786 |
# File 'lib/aws-sdk-glue/types.rb', line 9778 class DescribeEntityRequest < Struct.new( :connection_name, :catalog_id, :entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |