Class: Aws::Glue::Types::DescribeIntegrationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DescribeIntegrationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::IntegrationFilter>
A list of key and values, to filter down the results.
-
#integration_identifier ⇒ String
The Amazon Resource Name (ARN) for the integration.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#max_records ⇒ Integer
The total number of items to return in the output.
Instance Attribute Details
#filters ⇒ Array<Types::IntegrationFilter>
A list of key and values, to filter down the results. Supported keys are “Status”, “IntegrationName”, and “SourceArn”. IntegrationName is limited to only one value.
9861 9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/aws-sdk-glue/types.rb', line 9861 class DescribeIntegrationsRequest < Struct.new( :integration_identifier, :marker, :max_records, :filters) SENSITIVE = [] include Aws::Structure end |
#integration_identifier ⇒ String
The Amazon Resource Name (ARN) for the integration.
9861 9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/aws-sdk-glue/types.rb', line 9861 class DescribeIntegrationsRequest < Struct.new( :integration_identifier, :marker, :max_records, :filters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
9861 9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/aws-sdk-glue/types.rb', line 9861 class DescribeIntegrationsRequest < Struct.new( :integration_identifier, :marker, :max_records, :filters) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The total number of items to return in the output.
9861 9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/aws-sdk-glue/types.rb', line 9861 class DescribeIntegrationsRequest < Struct.new( :integration_identifier, :marker, :max_records, :filters) SENSITIVE = [] include Aws::Structure end |