Class: Aws::Glue::Types::DirectKafkaSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass DirectKafkaSource data as a hash:

{
  name: "NodeName", # required
  streaming_options: {
    bootstrap_servers: "EnclosedInStringProperty",
    security_protocol: "EnclosedInStringProperty",
    connection_name: "EnclosedInStringProperty",
    topic_name: "EnclosedInStringProperty",
    assign: "EnclosedInStringProperty",
    subscribe_pattern: "EnclosedInStringProperty",
    classification: "EnclosedInStringProperty",
    delimiter: "EnclosedInStringProperty",
    starting_offsets: "EnclosedInStringProperty",
    ending_offsets: "EnclosedInStringProperty",
    poll_timeout_ms: 1,
    num_retries: 1,
    retry_interval_ms: 1,
    max_offsets_per_trigger: 1,
    min_partitions: 1,
  },
  window_size: 1,
  detect_schema: false,
  data_preview_options: {
    polling_time: 1,
    record_polling_limit: 1,
  },
}

Specifies an Apache Kafka data store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_preview_optionsTypes::StreamingDataPreviewOptions

Specifies options related to data preview for viewing a sample of your data.



9456
9457
9458
9459
9460
9461
9462
9463
9464
# File 'lib/aws-sdk-glue/types.rb', line 9456

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#detect_schemaBoolean

Whether to automatically determine the schema from the incoming data.

Returns:

  • (Boolean)


9456
9457
9458
9459
9460
9461
9462
9463
9464
# File 'lib/aws-sdk-glue/types.rb', line 9456

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data store.

Returns:

  • (String)


9456
9457
9458
9459
9460
9461
9462
9463
9464
# File 'lib/aws-sdk-glue/types.rb', line 9456

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#streaming_optionsTypes::KafkaStreamingSourceOptions

Specifies the streaming options.



9456
9457
9458
9459
9460
9461
9462
9463
9464
# File 'lib/aws-sdk-glue/types.rb', line 9456

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end

#window_sizeInteger

The amount of time to spend processing each micro batch.

Returns:

  • (Integer)


9456
9457
9458
9459
9460
9461
9462
9463
9464
# File 'lib/aws-sdk-glue/types.rb', line 9456

class DirectKafkaSource < Struct.new(
  :name,
  :streaming_options,
  :window_size,
  :detect_schema,
  :data_preview_options)
  SENSITIVE = []
  include Aws::Structure
end