Class: Aws::Glue::Types::DirectKafkaSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DirectKafkaSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass DirectKafkaSource data as a hash:
{
name: "NodeName", # required
streaming_options: {
bootstrap_servers: "EnclosedInStringProperty",
security_protocol: "EnclosedInStringProperty",
connection_name: "EnclosedInStringProperty",
topic_name: "EnclosedInStringProperty",
assign: "EnclosedInStringProperty",
subscribe_pattern: "EnclosedInStringProperty",
classification: "EnclosedInStringProperty",
delimiter: "EnclosedInStringProperty",
starting_offsets: "EnclosedInStringProperty",
ending_offsets: "EnclosedInStringProperty",
poll_timeout_ms: 1,
num_retries: 1,
retry_interval_ms: 1,
max_offsets_per_trigger: 1,
min_partitions: 1,
},
window_size: 1,
detect_schema: false,
data_preview_options: {
polling_time: 1,
record_polling_limit: 1,
},
}
Specifies an Apache Kafka data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_preview_options ⇒ Types::StreamingDataPreviewOptions
Specifies options related to data preview for viewing a sample of your data.
-
#detect_schema ⇒ Boolean
Whether to automatically determine the schema from the incoming data.
-
#name ⇒ String
The name of the data store.
-
#streaming_options ⇒ Types::KafkaStreamingSourceOptions
Specifies the streaming options.
-
#window_size ⇒ Integer
The amount of time to spend processing each micro batch.
Instance Attribute Details
#data_preview_options ⇒ Types::StreamingDataPreviewOptions
Specifies options related to data preview for viewing a sample of your data.
9380 9381 9382 9383 9384 9385 9386 9387 9388 |
# File 'lib/aws-sdk-glue/types.rb', line 9380 class DirectKafkaSource < Struct.new( :name, :streaming_options, :window_size, :detect_schema, :data_preview_options) SENSITIVE = [] include Aws::Structure end |
#detect_schema ⇒ Boolean
Whether to automatically determine the schema from the incoming data.
9380 9381 9382 9383 9384 9385 9386 9387 9388 |
# File 'lib/aws-sdk-glue/types.rb', line 9380 class DirectKafkaSource < Struct.new( :name, :streaming_options, :window_size, :detect_schema, :data_preview_options) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data store.
9380 9381 9382 9383 9384 9385 9386 9387 9388 |
# File 'lib/aws-sdk-glue/types.rb', line 9380 class DirectKafkaSource < Struct.new( :name, :streaming_options, :window_size, :detect_schema, :data_preview_options) SENSITIVE = [] include Aws::Structure end |
#streaming_options ⇒ Types::KafkaStreamingSourceOptions
Specifies the streaming options.
9380 9381 9382 9383 9384 9385 9386 9387 9388 |
# File 'lib/aws-sdk-glue/types.rb', line 9380 class DirectKafkaSource < Struct.new( :name, :streaming_options, :window_size, :detect_schema, :data_preview_options) SENSITIVE = [] include Aws::Structure end |
#window_size ⇒ Integer
The amount of time to spend processing each micro batch.
9380 9381 9382 9383 9384 9385 9386 9387 9388 |
# File 'lib/aws-sdk-glue/types.rb', line 9380 class DirectKafkaSource < Struct.new( :name, :streaming_options, :window_size, :detect_schema, :data_preview_options) SENSITIVE = [] include Aws::Structure end |