Class: Aws::Glue::Types::DisassociateGlossaryTermsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset to disassociate glossary terms from.

Returns:

  • (String)


11203
11204
11205
11206
11207
11208
11209
# File 'lib/aws-sdk-glue/types.rb', line 11203

class DisassociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


11203
11204
11205
11206
11207
11208
11209
# File 'lib/aws-sdk-glue/types.rb', line 11203

class DisassociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_term_identifiersArray<String>

The list of glossary term identifiers to disassociate from the asset.

Returns:

  • (Array<String>)


11203
11204
11205
11206
11207
11208
11209
# File 'lib/aws-sdk-glue/types.rb', line 11203

class DisassociateGlossaryTermsRequest < Struct.new(
  :asset_identifier,
  :glossary_term_identifiers,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end