Class: Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-glue/types.rb', line 11203 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-glue/types.rb', line 11203 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
11203 11204 11205 11206 11207 11208 11209 |
# File 'lib/aws-sdk-glue/types.rb', line 11203 class DisassociateGlossaryTermsRequest < Struct.new( :asset_identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |