Class: Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DisassociateGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
-
#identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
11190 11191 11192 11193 11194 11195 11196 |
# File 'lib/aws-sdk-glue/types.rb', line 11190 class DisassociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#glossary_term_identifiers ⇒ Array<String>
The list of glossary term identifiers to disassociate from the asset.
11190 11191 11192 11193 11194 11195 11196 |
# File 'lib/aws-sdk-glue/types.rb', line 11190 class DisassociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the asset to disassociate glossary terms from.
11190 11191 11192 11193 11194 11195 11196 |
# File 'lib/aws-sdk-glue/types.rb', line 11190 class DisassociateGlossaryTermsRequest < Struct.new( :identifier, :glossary_term_identifiers, :client_token) SENSITIVE = [] include Aws::Structure end |