Class: Aws::Glue::Types::DisassociateGlossaryTermsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DisassociateGlossaryTermsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset.
-
#glossary_terms ⇒ Array<String>
The remaining glossary terms associated with the asset.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
-
#iterable_form_name ⇒ String
The name of the iterable form, if the disassociation targets an item.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset.
11545 11546 11547 11548 11549 11550 11551 11552 |
# File 'lib/aws-sdk-glue/types.rb', line 11545 class DisassociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The remaining glossary terms associated with the asset.
11545 11546 11547 11548 11549 11550 11551 11552 |
# File 'lib/aws-sdk-glue/types.rb', line 11545 class DisassociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form, if applicable.
11545 11546 11547 11548 11549 11550 11551 11552 |
# File 'lib/aws-sdk-glue/types.rb', line 11545 class DisassociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form, if the disassociation targets an item.
11545 11546 11547 11548 11549 11550 11551 11552 |
# File 'lib/aws-sdk-glue/types.rb', line 11545 class DisassociateGlossaryTermsResponse < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :glossary_terms) SENSITIVE = [] include Aws::Structure end |