Class: Aws::Glue::Types::DistributionData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DistributionData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The distribution data for a statistic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bin_edges ⇒ Array<String>
The bin edge values for the distribution.
-
#count ⇒ Array<Integer>
The frequency count for each bin in the distribution.
-
#data_type ⇒ String
The data type of the column for the distribution.
Instance Attribute Details
#bin_edges ⇒ Array<String>
The bin edge values for the distribution.
11478 11479 11480 11481 11482 11483 11484 |
# File 'lib/aws-sdk-glue/types.rb', line 11478 class DistributionData < Struct.new( :bin_edges, :count, :data_type) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Array<Integer>
The frequency count for each bin in the distribution.
11478 11479 11480 11481 11482 11483 11484 |
# File 'lib/aws-sdk-glue/types.rb', line 11478 class DistributionData < Struct.new( :bin_edges, :count, :data_type) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
The data type of the column for the distribution.
11478 11479 11480 11481 11482 11483 11484 |
# File 'lib/aws-sdk-glue/types.rb', line 11478 class DistributionData < Struct.new( :bin_edges, :count, :data_type) SENSITIVE = [] include Aws::Structure end |