Class: Aws::Glue::Types::DropNullFields
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::DropNullFields
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that removes columns from the dataset if all values in the column are ‘null’. By default, Glue Studio will recognize null objects, but some values such as empty strings, strings that are “null”, -1 integers or other placeholders such as zeros, are not automatically recognized as nulls.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#null_check_box_list ⇒ Types::NullCheckBoxList
A structure that represents whether certain values are recognized as null values for removal.
-
#null_text_list ⇒ Array<Types::NullValueField>
A structure that specifies a list of NullValueField structures that represent a custom null value such as zero or other value being used as a null placeholder unique to the dataset.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
8041 8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/aws-sdk-glue/types.rb', line 8041 class DropNullFields < Struct.new( :name, :inputs, :null_check_box_list, :null_text_list) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
8041 8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/aws-sdk-glue/types.rb', line 8041 class DropNullFields < Struct.new( :name, :inputs, :null_check_box_list, :null_text_list) SENSITIVE = [] include Aws::Structure end |
#null_check_box_list ⇒ Types::NullCheckBoxList
A structure that represents whether certain values are recognized as null values for removal.
8041 8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/aws-sdk-glue/types.rb', line 8041 class DropNullFields < Struct.new( :name, :inputs, :null_check_box_list, :null_text_list) SENSITIVE = [] include Aws::Structure end |
#null_text_list ⇒ Array<Types::NullValueField>
A structure that specifies a list of NullValueField structures that represent a custom null value such as zero or other value being used as a null placeholder unique to the dataset.
The ‘DropNullFields` transform removes custom null values only if both the value of the null placeholder and the datatype match the data.
8041 8042 8043 8044 8045 8046 8047 8048 |
# File 'lib/aws-sdk-glue/types.rb', line 8041 class DropNullFields < Struct.new( :name, :inputs, :null_check_box_list, :null_text_list) SENSITIVE = [] include Aws::Structure end |