Class: Aws::Glue::Types::Entity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Entity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An entity supported by a given ConnectionType.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The type of entities that are present in the response.
-
#custom_properties ⇒ Hash<String,String>
An optional map of keys which may be returned for an entity by a connector.
-
#description ⇒ String
A description of the entity.
-
#entity_name ⇒ String
The name of the entity.
-
#is_parent_entity ⇒ Boolean
A Boolean value which helps to determine whether there are sub objects that can be listed.
-
#label ⇒ String
Label used for the entity.
Instance Attribute Details
#category ⇒ String
The type of entities that are present in the response. This value
depends on the source connection. For example this is SObjects for
Salesforce and databases or schemas or tables for sources like
Amazon Redshift.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#custom_properties ⇒ Hash<String,String>
An optional map of keys which may be returned for an entity by a connector.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the entity.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#entity_name ⇒ String
The name of the entity.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_parent_entity ⇒ Boolean
A Boolean value which helps to determine whether there are sub objects that can be listed.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#label ⇒ String
Label used for the entity.
11886 11887 11888 11889 11890 11891 11892 11893 11894 11895 |
# File 'lib/aws-sdk-glue/types.rb', line 11886 class Entity < Struct.new( :entity_name, :label, :is_parent_entity, :description, :category, :custom_properties) SENSITIVE = [] include Aws::Structure end |