Class: Aws::Glue::Types::Entity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An entity supported by a given ConnectionType.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.

Returns:

  • (String)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#custom_propertiesHash<String,String>

An optional map of keys which may be returned for an entity by a connector.

Returns:

  • (Hash<String,String>)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the entity.

Returns:

  • (String)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#entity_nameString

The name of the entity.

Returns:

  • (String)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#is_parent_entityBoolean

A Boolean value which helps to determine whether there are sub objects that can be listed.

Returns:

  • (Boolean)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end

#labelString

Label used for the entity.

Returns:

  • (String)


11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
# File 'lib/aws-sdk-glue/types.rb', line 11608

class Entity < Struct.new(
  :entity_name,
  :label,
  :is_parent_entity,
  :description,
  :category,
  :custom_properties)
  SENSITIVE = []
  include Aws::Structure
end