Class: Aws::Glue::Types::ExecutionProperty

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An execution property of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_concurrent_runsInteger

The maximum number of concurrent runs allowed for the job. The default is 1. An error is returned when this threshold is reached. The maximum value you can specify is controlled by a service limit.

Returns:

  • (Integer)


8985
8986
8987
8988
8989
# File 'lib/aws-sdk-glue/types.rb', line 8985

class ExecutionProperty < Struct.new(
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end