Class: Aws::Glue::Types::ExecutionProperty

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass ExecutionProperty data as a hash:

{
  max_concurrent_runs: 1,
}

An execution property of a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_concurrent_runsInteger

The maximum number of concurrent runs allowed for the job. The default is 1. An error is returned when this threshold is reached. The maximum value you can specify is controlled by a service limit.

Returns:

  • (Integer)


9965
9966
9967
9968
9969
# File 'lib/aws-sdk-glue/types.rb', line 9965

class ExecutionProperty < Struct.new(
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end