Class: Aws::Glue::Types::ExecutionProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ExecutionProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass ExecutionProperty data as a hash:
{
max_concurrent_runs: 1,
}
An execution property of a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_concurrent_runs ⇒ Integer
The maximum number of concurrent runs allowed for the job.
Instance Attribute Details
#max_concurrent_runs ⇒ Integer
The maximum number of concurrent runs allowed for the job. The default is 1. An error is returned when this threshold is reached. The maximum value you can specify is controlled by a service limit.
6877 6878 6879 6880 6881 |
# File 'lib/aws-sdk-glue/types.rb', line 6877 class ExecutionProperty < Struct.new( :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |