Class: Aws::Glue::Types::FederatedDatabase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A database that points to an entity outside the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_nameString

The name of the connection to the external metastore.

Returns:

  • (String)


7842
7843
7844
7845
7846
7847
# File 'lib/aws-sdk-glue/types.rb', line 7842

class FederatedDatabase < Struct.new(
  :identifier,
  :connection_name)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

A unique identifier for the federated database.

Returns:

  • (String)


7842
7843
7844
7845
7846
7847
# File 'lib/aws-sdk-glue/types.rb', line 7842

class FederatedDatabase < Struct.new(
  :identifier,
  :connection_name)
  SENSITIVE = []
  include Aws::Structure
end