Class: Aws::Glue::Types::FederatedTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::FederatedTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A table that points to an entity outside the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to the external metastore.
-
#connection_type ⇒ String
The type of connection used to access the federated table, specifying the protocol or method for connecting to the external data source.
-
#database_identifier ⇒ String
A unique identifier for the federated database.
-
#identifier ⇒ String
A unique identifier for the federated table.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to the external metastore.
11041 11042 11043 11044 11045 11046 11047 11048 |
# File 'lib/aws-sdk-glue/types.rb', line 11041 class FederatedTable < Struct.new( :identifier, :database_identifier, :connection_name, :connection_type) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of connection used to access the federated table, specifying the protocol or method for connecting to the external data source.
11041 11042 11043 11044 11045 11046 11047 11048 |
# File 'lib/aws-sdk-glue/types.rb', line 11041 class FederatedTable < Struct.new( :identifier, :database_identifier, :connection_name, :connection_type) SENSITIVE = [] include Aws::Structure end |
#database_identifier ⇒ String
A unique identifier for the federated database.
11041 11042 11043 11044 11045 11046 11047 11048 |
# File 'lib/aws-sdk-glue/types.rb', line 11041 class FederatedTable < Struct.new( :identifier, :database_identifier, :connection_name, :connection_type) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
A unique identifier for the federated table.
11041 11042 11043 11044 11045 11046 11047 11048 |
# File 'lib/aws-sdk-glue/types.rb', line 11041 class FederatedTable < Struct.new( :identifier, :database_identifier, :connection_name, :connection_type) SENSITIVE = [] include Aws::Structure end |