Class: Aws::Glue::Types::Field
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Field
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The Field object has information about the different properties
associated with a field in the connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_properties ⇒ Hash<String,String>
Optional map of keys which may be returned.
-
#description ⇒ String
A description of the field.
-
#field_name ⇒ String
A unique identifier for the field.
-
#field_type ⇒ String
The type of data in the field.
-
#is_createable ⇒ Boolean
Indicates whether this field can be created as part of a destination write.
-
#is_default_on_create ⇒ Boolean
Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.
-
#is_filterable ⇒ Boolean
Indicates whether this field can used in a filter clause (
WHEREclause) of a SQL statement when querying data. -
#is_nullable ⇒ Boolean
Indicates whether this field can be nullable or not.
-
#is_partitionable ⇒ Boolean
Indicates whether a given field can be used in partitioning the query made to SaaS.
-
#is_primary_key ⇒ Boolean
Indicates whether this field can used as a primary key for the given entity.
-
#is_retrievable ⇒ Boolean
Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.
-
#is_updateable ⇒ Boolean
Indicates whether this field can be updated as part of a destination write.
-
#is_upsertable ⇒ Boolean
Indicates whether this field can be upserted as part of a destination write.
-
#label ⇒ String
A readable label used for the field.
-
#native_data_type ⇒ String
The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.
-
#parent_field ⇒ String
A parent field name for a nested field.
-
#supported_filter_operators ⇒ Array<String>
Indicates the support filter operators for this field.
-
#supported_values ⇒ Array<String>
A list of supported values for the field.
Instance Attribute Details
#custom_properties ⇒ Hash<String,String>
Optional map of keys which may be returned.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#field_name ⇒ String
A unique identifier for the field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#field_type ⇒ String
The type of data in the field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_createable ⇒ Boolean
Indicates whether this field can be created as part of a destination write.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_default_on_create ⇒ Boolean
Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_filterable ⇒ Boolean
Indicates whether this field can used in a filter clause (WHERE
clause) of a SQL statement when querying data.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_nullable ⇒ Boolean
Indicates whether this field can be nullable or not.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_partitionable ⇒ Boolean
Indicates whether a given field can be used in partitioning the query made to SaaS.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_primary_key ⇒ Boolean
Indicates whether this field can used as a primary key for the given entity.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_retrievable ⇒ Boolean
Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_updateable ⇒ Boolean
Indicates whether this field can be updated as part of a destination write.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#is_upsertable ⇒ Boolean
Indicates whether this field can be upserted as part of a destination write.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#label ⇒ String
A readable label used for the field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#native_data_type ⇒ String
The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#parent_field ⇒ String
A parent field name for a nested field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#supported_filter_operators ⇒ Array<String>
Indicates the support filter operators for this field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |
#supported_values ⇒ Array<String>
A list of supported values for the field.
12422 12423 12424 12425 12426 12427 12428 12429 12430 12431 12432 12433 12434 12435 12436 12437 12438 12439 12440 12441 12442 12443 |
# File 'lib/aws-sdk-glue/types.rb', line 12422 class Field < Struct.new( :field_name, :label, :description, :field_type, :is_primary_key, :is_nullable, :is_retrievable, :is_filterable, :is_partitionable, :is_createable, :is_updateable, :is_upsertable, :is_default_on_create, :supported_values, :supported_filter_operators, :parent_field, :native_data_type, :custom_properties) SENSITIVE = [] include Aws::Structure end |