Class: Aws::Glue::Types::FieldDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::FieldDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a field in an entity schema for REST connector data sources, specifying the field name and data type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_data_type ⇒ String
The data type of the field.
-
#filter_overrides ⇒ Types::FilterOverrides
Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.
-
#is_nullable ⇒ Boolean
Indicates whether this field can contain null values.
-
#is_orderable ⇒ Boolean
Indicates whether this field can be used for ordering results.
-
#is_partitionable ⇒ Boolean
Indicates whether this field can be used for partitioning queries to the data source.
-
#is_queryable ⇒ Boolean
Indicates whether this field can be used in filter predicates when querying data.
-
#name ⇒ String
The name of the field in the entity schema.
-
#response_date_format ⇒ String
The format pattern for parsing date values from API responses.
Instance Attribute Details
#field_data_type ⇒ String
The data type of the field.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#filter_overrides ⇒ Types::FilterOverrides
Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#is_nullable ⇒ Boolean
Indicates whether this field can contain null values.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#is_orderable ⇒ Boolean
Indicates whether this field can be used for ordering results.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#is_partitionable ⇒ Boolean
Indicates whether this field can be used for partitioning queries to the data source.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#is_queryable ⇒ Boolean
Indicates whether this field can be used in filter predicates when querying data.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the field in the entity schema.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |
#response_date_format ⇒ String
The format pattern for parsing date values from API responses.
Required when the API uses a non-ISO-8601 format. Accepts Java
DateTimeFormatter patterns (for example, EEE, d MMM yyyy HH:mm:ss Z), EPOCH_SECONDS for Unix epoch seconds, or EPOCH_MILLIS for
Unix epoch milliseconds.
12524 12525 12526 12527 12528 12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/aws-sdk-glue/types.rb', line 12524 class FieldDefinition < Struct.new( :name, :field_data_type, :response_date_format, :is_partitionable, :is_nullable, :is_queryable, :is_orderable, :filter_overrides) SENSITIVE = [] include Aws::Structure end |