Class: Aws::Glue::Types::FieldDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::FieldDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a field in an entity schema for REST connector data sources, specifying the field name and data type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_data_type ⇒ String
The data type of the field.
-
#name ⇒ String
The name of the field in the entity schema.
Instance Attribute Details
#field_data_type ⇒ String
The data type of the field.
11754 11755 11756 11757 11758 11759 |
# File 'lib/aws-sdk-glue/types.rb', line 11754 class FieldDefinition < Struct.new( :name, :field_data_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the field in the entity schema.
11754 11755 11756 11757 11758 11759 |
# File 'lib/aws-sdk-glue/types.rb', line 11754 class FieldDefinition < Struct.new( :name, :field_data_type) SENSITIVE = [] include Aws::Structure end |