Class: Aws::Glue::Types::FieldDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a field in an entity schema for REST connector data sources, specifying the field name and data type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_data_typeString

The data type of the field.

Returns:

  • (String)


11752
11753
11754
11755
11756
11757
# File 'lib/aws-sdk-glue/types.rb', line 11752

class FieldDefinition < Struct.new(
  :name,
  :field_data_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the field in the entity schema.

Returns:

  • (String)


11752
11753
11754
11755
11756
11757
# File 'lib/aws-sdk-glue/types.rb', line 11752

class FieldDefinition < Struct.new(
  :name,
  :field_data_type)
  SENSITIVE = []
  include Aws::Structure
end