Class: Aws::Glue::Types::GetAssetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetAssetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_type_id ⇒ String
The identifier of the asset type for this asset.
-
#attachments ⇒ Hash<String,Types::AssetFormEntry>
Additional attachments on the asset for more context, keyed by attachment name.
-
#created_at ⇒ Time
The timestamp at which the asset was created.
-
#description ⇒ String
The description of the asset.
-
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms on the asset, keyed by form name.
-
#glossary_terms ⇒ Array<String>
The identifiers of the glossary terms associated with the asset.
-
#id ⇒ String
The unique identifier of the asset.
-
#iterable_forms ⇒ Hash<String,Types::IterableFormEntry>
The iterable forms available on the asset, keyed by form name (for example,
columns). -
#name ⇒ String
The name of the asset.
-
#updated_at ⇒ Time
The timestamp at which the asset was last updated.
Instance Attribute Details
#asset_type_id ⇒ String
The identifier of the asset type for this asset.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#attachments ⇒ Hash<String,Types::AssetFormEntry>
Additional attachments on the asset for more context, keyed by attachment name.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp at which the asset was created.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the asset.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms on the asset, keyed by form name.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The identifiers of the glossary terms associated with the asset.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the asset.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#iterable_forms ⇒ Hash<String,Types::IterableFormEntry>
The iterable forms available on the asset, keyed by form name (for
example, columns). Use the form name with ListIterableForms or
BatchGetIterableForms to retrieve the form's items.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp at which the asset was last updated.
13035 13036 13037 13038 13039 13040 13041 13042 13043 13044 13045 13046 13047 13048 |
# File 'lib/aws-sdk-glue/types.rb', line 13035 class GetAssetOutput < Struct.new( :id, :name, :description, :created_at, :updated_at, :asset_type_id, :glossary_terms, :forms, :attachments, :iterable_forms) SENSITIVE = [] include Aws::Structure end |