Class: Aws::Glue::Types::GetAssetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_type_idString

The identifier of the asset type for this asset.

Returns:

  • (String)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#attachmentsHash<String,Types::AssetFormEntry>

Additional attachments on the asset for more context, keyed by attachment name.

Returns:



12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp at which the asset was created.

Returns:

  • (Time)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the asset.

Returns:

  • (String)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#formsHash<String,Types::AssetFormEntry>

The forms on the asset, keyed by form name.

Returns:



12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The identifiers of the glossary terms associated with the asset.

Returns:

  • (Array<String>)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the asset.

Returns:

  • (String)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_formsHash<String,Types::IterableFormEntry>

The iterable forms available on the asset, keyed by form name (for example, ‘columns`). Use the form name with `ListIterableForms` or `BatchGetIterableForms` to retrieve the form’s items.

Returns:



12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the asset.

Returns:

  • (String)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the asset was last updated.

Returns:

  • (Time)


12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
# File 'lib/aws-sdk-glue/types.rb', line 12530

class GetAssetOutput < Struct.new(
  :id,
  :name,
  :description,
  :created_at,
  :updated_at,
  :asset_type_id,
  :glossary_terms,
  :forms,
  :attachments,
  :iterable_forms)
  SENSITIVE = []
  include Aws::Structure
end