Class: Aws::Glue::Types::GetCatalogRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCatalogRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
11715 11716 11717 11718 11719 |
# File 'lib/aws-sdk-glue/types.rb', line 11715 class GetCatalogRequest < Struct.new( :catalog_id) SENSITIVE = [] include Aws::Structure end |