Class: Aws::Glue::Types::GetCatalogsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCatalogsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#has_databases ⇒ Boolean
When
true, the response only includes catalogs that can contain databases. -
#include_root ⇒ Boolean
Whether to list the default catalog in the account and region in the response.
-
#max_results ⇒ Integer
The maximum number of catalogs to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#parent_catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides.
-
#recursive ⇒ Boolean
Whether to list all catalogs across the catalog hierarchy, starting from the
ParentCatalogId.
Instance Attribute Details
#has_databases ⇒ Boolean
When true, the response only includes catalogs that can contain
databases. Some catalogs are organizational containers that hold
only other catalogs, not databases. When this parameter is set to
true, those container-only catalogs are excluded, and only
catalogs capable of containing databases are returned. Defaults to
false.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |
#include_root ⇒ Boolean
Whether to list the default catalog in the account and region in the
response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default
catalog are enumerated in the response.
When the ParentCatalogId is not equal to null, and this attribute
is passed as false or true, an InvalidInputException is
thrown.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of catalogs to return in one response.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |
#parent_catalog_id ⇒ String
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |
#recursive ⇒ Boolean
Whether to list all catalogs across the catalog hierarchy, starting
from the ParentCatalogId. Defaults to false . When true, all
catalog objects in the ParentCatalogID hierarchy are enumerated in
the response.
13340 13341 13342 13343 13344 13345 13346 13347 13348 13349 |
# File 'lib/aws-sdk-glue/types.rb', line 13340 class GetCatalogsRequest < Struct.new( :parent_catalog_id, :next_token, :max_results, :recursive, :include_root, :has_databases) SENSITIVE = [] include Aws::Structure end |