Class: Aws::Glue::Types::GetCatalogsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCatalogsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_list ⇒ Array<Types::Catalog>
An array of
Catalogobjects. -
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Instance Attribute Details
#catalog_list ⇒ Array<Types::Catalog>
An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
11790 11791 11792 11793 11794 11795 |
# File 'lib/aws-sdk-glue/types.rb', line 11790 class GetCatalogsResponse < Struct.new( :catalog_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
11790 11791 11792 11793 11794 11795 |
# File 'lib/aws-sdk-glue/types.rb', line 11790 class GetCatalogsResponse < Struct.new( :catalog_list, :next_token) SENSITIVE = [] include Aws::Structure end |