Class: Aws::Glue::Types::GetColumnStatisticsForPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetColumnStatisticsForPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_names ⇒ Array<String>
A list of the column names.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
-
#table_name ⇒ String
The name of the partitions' table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-glue/types.rb', line 7821 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#column_names ⇒ Array<String>
A list of the column names.
7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-glue/types.rb', line 7821 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-glue/types.rb', line 7821 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-glue/types.rb', line 7821 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions' table.
7821 7822 7823 7824 7825 7826 7827 7828 7829 |
# File 'lib/aws-sdk-glue/types.rb', line 7821 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |