Class: Aws::Glue::Types::GetColumnStatisticsForPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetColumnStatisticsForPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetColumnStatisticsForPartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partition_values: ["ValueString"], # required
column_names: ["NameString"], # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_names ⇒ Array<String>
A list of the column names.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
-
#table_name ⇒ String
The name of the partitions' table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-glue/types.rb', line 10677 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#column_names ⇒ Array<String>
A list of the column names.
10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-glue/types.rb', line 10677 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-glue/types.rb', line 10677 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-glue/types.rb', line 10677 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions' table.
10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-glue/types.rb', line 10677 class GetColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_names) SENSITIVE = [] include Aws::Structure end |