Class: Aws::Glue::Types::GetColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_names ⇒ Array<String>
A list of the column names.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
11818 11819 11820 11821 11822 11823 11824 11825 |
# File 'lib/aws-sdk-glue/types.rb', line 11818 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#column_names ⇒ Array<String>
A list of the column names.
11818 11819 11820 11821 11822 11823 11824 11825 |
# File 'lib/aws-sdk-glue/types.rb', line 11818 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
11818 11819 11820 11821 11822 11823 11824 11825 |
# File 'lib/aws-sdk-glue/types.rb', line 11818 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
11818 11819 11820 11821 11822 11823 11824 11825 |
# File 'lib/aws-sdk-glue/types.rb', line 11818 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |