Class: Aws::Glue::Types::GetColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_names ⇒ Array<String>
A list of the column names.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions' table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
7868 7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/aws-sdk-glue/types.rb', line 7868 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#column_names ⇒ Array<String>
A list of the column names.
7868 7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/aws-sdk-glue/types.rb', line 7868 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
7868 7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/aws-sdk-glue/types.rb', line 7868 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions' table.
7868 7869 7870 7871 7872 7873 7874 7875 |
# File 'lib/aws-sdk-glue/types.rb', line 7868 class GetColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_names) SENSITIVE = [] include Aws::Structure end |