Class: Aws::Glue::Types::GetColumnStatisticsForTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass GetColumnStatisticsForTableRequest data as a hash:

{
  catalog_id: "CatalogIdString",
  database_name: "NameString", # required
  table_name: "NameString", # required
  column_names: ["NameString"], # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


10670
10671
10672
10673
10674
10675
10676
10677
# File 'lib/aws-sdk-glue/types.rb', line 10670

class GetColumnStatisticsForTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end

#column_namesArray<String>

A list of the column names.

Returns:

  • (Array<String>)


10670
10671
10672
10673
10674
10675
10676
10677
# File 'lib/aws-sdk-glue/types.rb', line 10670

class GetColumnStatisticsForTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database where the partitions reside.

Returns:

  • (String)


10670
10671
10672
10673
10674
10675
10676
10677
# File 'lib/aws-sdk-glue/types.rb', line 10670

class GetColumnStatisticsForTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the partitions' table.

Returns:

  • (String)


10670
10671
10672
10673
10674
10675
10676
10677
# File 'lib/aws-sdk-glue/types.rb', line 10670

class GetColumnStatisticsForTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :column_names)
  SENSITIVE = []
  include Aws::Structure
end