Class: Aws::Glue::Types::GetConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides.
-
#hide_password ⇒ Boolean
Allows you to retrieve the connection metadata without returning the password.
-
#name ⇒ String
The name of the connection definition to retrieve.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.
9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-glue/types.rb', line 9188 class GetConnectionRequest < Struct.new( :catalog_id, :name, :hide_password) SENSITIVE = [] include Aws::Structure end |
#hide_password ⇒ Boolean
Allows you to retrieve the connection metadata without returning the password. For instance, the Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties.
9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-glue/types.rb', line 9188 class GetConnectionRequest < Struct.new( :catalog_id, :name, :hide_password) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connection definition to retrieve.
9188 9189 9190 9191 9192 9193 9194 |
# File 'lib/aws-sdk-glue/types.rb', line 9188 class GetConnectionRequest < Struct.new( :catalog_id, :name, :hide_password) SENSITIVE = [] include Aws::Structure end |