Class: Aws::Glue::Types::GetConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


8598
8599
8600
8601
8602
8603
8604
# File 'lib/aws-sdk-glue/types.rb', line 8598

class GetConnectionRequest < Struct.new(
  :catalog_id,
  :name,
  :hide_password)
  SENSITIVE = []
  include Aws::Structure
end

#hide_passwordBoolean

Allows you to retrieve the connection metadata without returning the password. For instance, the Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties.

Returns:

  • (Boolean)


8598
8599
8600
8601
8602
8603
8604
# File 'lib/aws-sdk-glue/types.rb', line 8598

class GetConnectionRequest < Struct.new(
  :catalog_id,
  :name,
  :hide_password)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connection definition to retrieve.

Returns:

  • (String)


8598
8599
8600
8601
8602
8603
8604
# File 'lib/aws-sdk-glue/types.rb', line 8598

class GetConnectionRequest < Struct.new(
  :catalog_id,
  :name,
  :hide_password)
  SENSITIVE = []
  include Aws::Structure
end