Class: Aws::Glue::Types::GetConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside.
-
#filter ⇒ Types::GetConnectionsFilter
A filter that controls which connections are returned.
-
#hide_password ⇒ Boolean
Allows you to retrieve the connection metadata without returning the password.
-
#max_results ⇒ Integer
The maximum number of connections to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default.
13645 13646 13647 13648 13649 13650 13651 13652 13653 |
# File 'lib/aws-sdk-glue/types.rb', line 13645 class GetConnectionsRequest < Struct.new( :catalog_id, :filter, :hide_password, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::GetConnectionsFilter
A filter that controls which connections are returned.
13645 13646 13647 13648 13649 13650 13651 13652 13653 |
# File 'lib/aws-sdk-glue/types.rb', line 13645 class GetConnectionsRequest < Struct.new( :catalog_id, :filter, :hide_password, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#hide_password ⇒ Boolean
Allows you to retrieve the connection metadata without returning the password. For instance, the Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties.
13645 13646 13647 13648 13649 13650 13651 13652 13653 |
# File 'lib/aws-sdk-glue/types.rb', line 13645 class GetConnectionsRequest < Struct.new( :catalog_id, :filter, :hide_password, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of connections to return in one response.
13645 13646 13647 13648 13649 13650 13651 13652 13653 |
# File 'lib/aws-sdk-glue/types.rb', line 13645 class GetConnectionsRequest < Struct.new( :catalog_id, :filter, :hide_password, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
13645 13646 13647 13648 13649 13650 13651 13652 13653 |
# File 'lib/aws-sdk-glue/types.rb', line 13645 class GetConnectionsRequest < Struct.new( :catalog_id, :filter, :hide_password, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |