Class: Aws::Glue::Types::GetConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the connections reside. If none is provided, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


8753
8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-glue/types.rb', line 8753

class GetConnectionsRequest < Struct.new(
  :catalog_id,
  :filter,
  :hide_password,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filterTypes::GetConnectionsFilter

A filter that controls which connections are returned.



8753
8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-glue/types.rb', line 8753

class GetConnectionsRequest < Struct.new(
  :catalog_id,
  :filter,
  :hide_password,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#hide_passwordBoolean

Allows you to retrieve the connection metadata without returning the password. For instance, the Glue console uses this flag to retrieve the connection, and does not display the password. Set this parameter when the caller might not have permission to use the KMS key to decrypt the password, but it does have permission to access the rest of the connection properties.

Returns:

  • (Boolean)


8753
8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-glue/types.rb', line 8753

class GetConnectionsRequest < Struct.new(
  :catalog_id,
  :filter,
  :hide_password,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of connections to return in one response.

Returns:

  • (Integer)


8753
8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-glue/types.rb', line 8753

class GetConnectionsRequest < Struct.new(
  :catalog_id,
  :filter,
  :hide_password,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


8753
8754
8755
8756
8757
8758
8759
8760
8761
# File 'lib/aws-sdk-glue/types.rb', line 8753

class GetConnectionsRequest < Struct.new(
  :catalog_id,
  :filter,
  :hide_password,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end