Class: Aws::Glue::Types::GetCustomEntityTypeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetCustomEntityTypeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context_words ⇒ Array<String>
A list of context words if specified when you created the custom pattern.
-
#name ⇒ String
The name of the custom pattern that you retrieved.
-
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
Instance Attribute Details
#context_words ⇒ Array<String>
A list of context words if specified when you created the custom pattern. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
13822 13823 13824 13825 13826 13827 13828 |
# File 'lib/aws-sdk-glue/types.rb', line 13822 class GetCustomEntityTypeResponse < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the custom pattern that you retrieved.
13822 13823 13824 13825 13826 13827 13828 |
# File 'lib/aws-sdk-glue/types.rb', line 13822 class GetCustomEntityTypeResponse < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
A regular expression string that is used for detecting sensitive data in a custom pattern.
13822 13823 13824 13825 13826 13827 13828 |
# File 'lib/aws-sdk-glue/types.rb', line 13822 class GetCustomEntityTypeResponse < Struct.new( :name, :regex_string, :context_words) SENSITIVE = [] include Aws::Structure end |