Class: Aws::Glue::Types::GetCustomEntityTypeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context_wordsArray<String>

A list of context words if specified when you created the custom pattern. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.

Returns:

  • (Array<String>)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-glue/types.rb', line 9000

class GetCustomEntityTypeResponse < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the custom pattern that you retrieved.

Returns:

  • (String)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-glue/types.rb', line 9000

class GetCustomEntityTypeResponse < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end

#regex_stringString

A regular expression string that is used for detecting sensitive data in a custom pattern.

Returns:

  • (String)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-glue/types.rb', line 9000

class GetCustomEntityTypeResponse < Struct.new(
  :name,
  :regex_string,
  :context_words)
  SENSITIVE = []
  include Aws::Structure
end