Class: Aws::Glue::Types::GetDataQualityResultResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDataQualityResultResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The response for the data quality result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregated_metrics ⇒ Types::DataQualityAggregatedMetrics
A summary of ‘DataQualityAggregatedMetrics` objects showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.
-
#analyzer_results ⇒ Array<Types::DataQualityAnalyzerResult>
A list of ‘DataQualityAnalyzerResult` objects representing the results for each analyzer.
-
#completed_on ⇒ Time
The date and time when the run for this data quality result was completed.
-
#data_source ⇒ Types::DataSource
The table associated with the data quality result, if any.
-
#evaluation_context ⇒ String
In the context of a job in Glue Studio, each node in the canvas is typically assigned some sort of name and data quality nodes will have names.
-
#job_name ⇒ String
The job name associated with the data quality result, if any.
-
#job_run_id ⇒ String
The job run ID associated with the data quality result, if any.
-
#observations ⇒ Array<Types::DataQualityObservation>
A list of ‘DataQualityObservation` objects representing the observations generated after evaluating the rules and analyzers.
-
#profile_id ⇒ String
The Profile ID for the data quality result.
-
#result_id ⇒ String
A unique result ID for the data quality result.
-
#rule_results ⇒ Array<Types::DataQualityRuleResult>
A list of ‘DataQualityRuleResult` objects representing the results for each rule.
-
#ruleset_evaluation_run_id ⇒ String
The unique run ID associated with the ruleset evaluation.
-
#ruleset_name ⇒ String
The name of the ruleset associated with the data quality result.
-
#score ⇒ Float
An aggregate data quality score.
-
#started_on ⇒ Time
The date and time when the run for this data quality result started.
Instance Attribute Details
#aggregated_metrics ⇒ Types::DataQualityAggregatedMetrics
A summary of ‘DataQualityAggregatedMetrics` objects showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#analyzer_results ⇒ Array<Types::DataQualityAnalyzerResult>
A list of ‘DataQualityAnalyzerResult` objects representing the results for each analyzer.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time when the run for this data quality result was completed.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The table associated with the data quality result, if any.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#evaluation_context ⇒ String
In the context of a job in Glue Studio, each node in the canvas is typically assigned some sort of name and data quality nodes will have names. In the case of multiple nodes, the ‘evaluationContext` can differentiate the nodes.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The job name associated with the data quality result, if any.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#job_run_id ⇒ String
The job run ID associated with the data quality result, if any.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#observations ⇒ Array<Types::DataQualityObservation>
A list of ‘DataQualityObservation` objects representing the observations generated after evaluating the rules and analyzers.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#profile_id ⇒ String
The Profile ID for the data quality result.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#result_id ⇒ String
A unique result ID for the data quality result.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#rule_results ⇒ Array<Types::DataQualityRuleResult>
A list of ‘DataQualityRuleResult` objects representing the results for each rule.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#ruleset_evaluation_run_id ⇒ String
The unique run ID associated with the ruleset evaluation.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#ruleset_name ⇒ String
The name of the ruleset associated with the data quality result.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#score ⇒ Float
An aggregate data quality score. Represents the ratio of rules that passed to the total number of rules.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when the run for this data quality result started.
12448 12449 12450 12451 12452 12453 12454 12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 |
# File 'lib/aws-sdk-glue/types.rb', line 12448 class GetDataQualityResultResponse < Struct.new( :result_id, :profile_id, :score, :data_source, :ruleset_name, :evaluation_context, :started_on, :completed_on, :job_name, :job_run_id, :ruleset_evaluation_run_id, :rule_results, :analyzer_results, :observations, :aggregated_metrics) SENSITIVE = [] include Aws::Structure end |