Class: Aws::Glue::Types::GetDataQualityResultResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The response for the data quality result.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregated_metricsTypes::DataQualityAggregatedMetrics

A summary of ‘DataQualityAggregatedMetrics` objects showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.



12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#analyzer_resultsArray<Types::DataQualityAnalyzerResult>

A list of ‘DataQualityAnalyzerResult` objects representing the results for each analyzer.



12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#completed_onTime

The date and time when the run for this data quality result was completed.

Returns:

  • (Time)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#data_sourceTypes::DataSource

The table associated with the data quality result, if any.

Returns:



12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_contextString

In the context of a job in Glue Studio, each node in the canvas is typically assigned some sort of name and data quality nodes will have names. In the case of multiple nodes, the ‘evaluationContext` can differentiate the nodes.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The job name associated with the data quality result, if any.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#job_run_idString

The job run ID associated with the data quality result, if any.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#observationsArray<Types::DataQualityObservation>

A list of ‘DataQualityObservation` objects representing the observations generated after evaluating the rules and analyzers.

Returns:



12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#profile_idString

The Profile ID for the data quality result.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#result_idString

A unique result ID for the data quality result.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#rule_resultsArray<Types::DataQualityRuleResult>

A list of ‘DataQualityRuleResult` objects representing the results for each rule.

Returns:



12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#ruleset_evaluation_run_idString

The unique run ID associated with the ruleset evaluation.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#ruleset_nameString

The name of the ruleset associated with the data quality result.

Returns:

  • (String)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#scoreFloat

An aggregate data quality score. Represents the ratio of rules that passed to the total number of rules.

Returns:

  • (Float)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#started_onTime

The date and time when the run for this data quality result started.

Returns:

  • (Time)


12067
12068
12069
12070
12071
12072
12073
12074
12075
12076
12077
12078
12079
12080
12081
12082
12083
12084
12085
# File 'lib/aws-sdk-glue/types.rb', line 12067

class GetDataQualityResultResponse < Struct.new(
  :result_id,
  :profile_id,
  :score,
  :data_source,
  :ruleset_name,
  :evaluation_context,
  :started_on,
  :completed_on,
  :job_name,
  :job_run_id,
  :ruleset_evaluation_run_id,
  :rule_results,
  :analyzer_results,
  :observations,
  :aggregated_metrics)
  SENSITIVE = []
  include Aws::Structure
end