Class: Aws::Glue::Types::GetDataQualityRuleRecommendationRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDataQualityRuleRecommendationRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_on ⇒ Time
The date and time when this run was completed.
-
#created_ruleset_name ⇒ String
The name of the ruleset that was created by the run.
-
#data_quality_security_configuration ⇒ String
The name of the security configuration created with the data quality encryption option.
-
#data_source ⇒ Types::DataSource
The data source (an Glue table) associated with this run.
-
#error_string ⇒ String
The error strings that are associated with the run.
-
#execution_time ⇒ Integer
The amount of time (in seconds) that the run consumed resources.
-
#last_modified_on ⇒ Time
A timestamp.
-
#number_of_workers ⇒ Integer
The number of ‘G.1X` workers to be used in the run.
-
#recommended_ruleset ⇒ String
When a start rule recommendation run completes, it creates a recommended ruleset (a set of rules).
-
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
-
#run_id ⇒ String
The unique run identifier associated with this run.
-
#started_on ⇒ Time
The date and time when this run started.
-
#status ⇒ String
The status for this run.
-
#timeout ⇒ Integer
The timeout for a run in minutes.
Instance Attribute Details
#completed_on ⇒ Time
The date and time when this run was completed.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#created_ruleset_name ⇒ String
The name of the ruleset that was created by the run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#data_quality_security_configuration ⇒ String
The name of the security configuration created with the data quality encryption option.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The data source (an Glue table) associated with this run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#error_string ⇒ String
The error strings that are associated with the run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_time ⇒ Integer
The amount of time (in seconds) that the run consumed resources.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
A timestamp. The last point in time when this data quality rule recommendation run was modified.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of ‘G.1X` workers to be used in the run. The default is 5.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#recommended_ruleset ⇒ String
When a start rule recommendation run completes, it creates a recommended ruleset (a set of rules). This member has those rules in Data Quality Definition Language (DQDL) format.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique run identifier associated with this run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when this run started.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for this run.
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters ‘TIMEOUT` status. The default is 2,880 minutes (48 hours).
11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 |
# File 'lib/aws-sdk-glue/types.rb', line 11913 class GetDataQualityRuleRecommendationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :recommended_ruleset, :created_ruleset_name, :data_quality_security_configuration) SENSITIVE = [] include Aws::Structure end |