Class: Aws::Glue::Types::GetDataQualityRulesetEvaluationRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDataQualityRulesetEvaluationRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_data_sources ⇒ Hash<String,Types::DataSource>
A map of reference strings to additional data sources you can specify for an evaluation run.
-
#additional_run_options ⇒ Types::DataQualityEvaluationRunAdditionalRunOptions
Additional run options you can specify for an evaluation run.
-
#completed_on ⇒ Time
The date and time when this run was completed.
-
#data_source ⇒ Types::DataSource
The data source (an Glue table) associated with this evaluation run.
-
#error_string ⇒ String
The error strings that are associated with the run.
-
#execution_time ⇒ Integer
The amount of time (in seconds) that the run consumed resources.
-
#last_modified_on ⇒ Time
A timestamp.
-
#number_of_workers ⇒ Integer
The number of ‘G.1X` workers to be used in the run.
-
#result_ids ⇒ Array<String>
A list of result IDs for the data quality results for the run.
-
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
-
#ruleset_names ⇒ Array<String>
A list of ruleset names for the run.
-
#run_id ⇒ String
The unique run identifier associated with this run.
-
#started_on ⇒ Time
The date and time when this run started.
-
#status ⇒ String
The status for this run.
-
#timeout ⇒ Integer
The timeout for a run in minutes.
Instance Attribute Details
#additional_data_sources ⇒ Hash<String,Types::DataSource>
A map of reference strings to additional data sources you can specify for an evaluation run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#additional_run_options ⇒ Types::DataQualityEvaluationRunAdditionalRunOptions
Additional run options you can specify for an evaluation run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time when this run was completed.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The data source (an Glue table) associated with this evaluation run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#error_string ⇒ String
The error strings that are associated with the run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#execution_time ⇒ Integer
The amount of time (in seconds) that the run consumed resources.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
A timestamp. The last point in time when this data quality rule recommendation run was modified.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of ‘G.1X` workers to be used in the run. The default is 5.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#result_ids ⇒ Array<String>
A list of result IDs for the data quality results for the run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#ruleset_names ⇒ Array<String>
A list of ruleset names for the run. Currently, this parameter takes only one Ruleset name.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The unique run identifier associated with this run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when this run started.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status for this run.
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters ‘TIMEOUT` status. The default is 2,880 minutes (48 hours).
13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 13174 13175 13176 13177 13178 13179 13180 13181 |
# File 'lib/aws-sdk-glue/types.rb', line 13163 class GetDataQualityRulesetEvaluationRunResponse < Struct.new( :run_id, :data_source, :role, :number_of_workers, :timeout, :additional_run_options, :status, :error_string, :started_on, :last_modified_on, :completed_on, :execution_time, :ruleset_names, :result_ids, :additional_data_sources) SENSITIVE = [] include Aws::Structure end |