Class: Aws::Glue::Types::GetDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides.
-
#name ⇒ String
The name of the database to retrieve.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the database resides. If none is provided, the Amazon Web Services account ID is used by default.
13261 13262 13263 13264 13265 13266 |
# File 'lib/aws-sdk-glue/types.rb', line 13261 class GetDatabaseRequest < Struct.new( :catalog_id, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database to retrieve. For Hive compatibility, this should be all lowercase.
13261 13262 13263 13264 13265 13266 |
# File 'lib/aws-sdk-glue/types.rb', line 13261 class GetDatabaseRequest < Struct.new( :catalog_id, :name) SENSITIVE = [] include Aws::Structure end |