Class: Aws::Glue::Types::GetIntegrationTablePropertiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

Returns:

  • (String)


12747
12748
12749
12750
12751
12752
# File 'lib/aws-sdk-glue/types.rb', line 12747

class GetIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table to be replicated.

Returns:

  • (String)


12747
12748
12749
12750
12751
12752
# File 'lib/aws-sdk-glue/types.rb', line 12747

class GetIntegrationTablePropertiesRequest < Struct.new(
  :resource_arn,
  :table_name)
  SENSITIVE = []
  include Aws::Structure
end