Class: Aws::Glue::Types::GetIntegrationTablePropertiesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetIntegrationTablePropertiesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties.
-
#source_table_config ⇒ Types::SourceTableConfig
A structure for the source table configuration.
-
#table_name ⇒ String
The name of the table to be replicated.
-
#target_table_config ⇒ Types::TargetTableConfig
A structure for the target table configuration.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
13111 13112 13113 13114 13115 13116 13117 13118 |
# File 'lib/aws-sdk-glue/types.rb', line 13111 class GetIntegrationTablePropertiesResponse < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#source_table_config ⇒ Types::SourceTableConfig
A structure for the source table configuration.
13111 13112 13113 13114 13115 13116 13117 13118 |
# File 'lib/aws-sdk-glue/types.rb', line 13111 class GetIntegrationTablePropertiesResponse < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table to be replicated.
13111 13112 13113 13114 13115 13116 13117 13118 |
# File 'lib/aws-sdk-glue/types.rb', line 13111 class GetIntegrationTablePropertiesResponse < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |
#target_table_config ⇒ Types::TargetTableConfig
A structure for the target table configuration.
13111 13112 13113 13114 13115 13116 13117 13118 |
# File 'lib/aws-sdk-glue/types.rb', line 13111 class GetIntegrationTablePropertiesResponse < Struct.new( :resource_arn, :table_name, :source_table_config, :target_table_config) SENSITIVE = [] include Aws::Structure end |