Class: Aws::Glue::Types::GetMLTransformRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetMLTransformRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetMLTransformRequest data as a hash:
{
transform_id: "HashString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
Instance Attribute Details
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
11538 11539 11540 11541 11542 |
# File 'lib/aws-sdk-glue/types.rb', line 11538 class GetMLTransformRequest < Struct.new( :transform_id) SENSITIVE = [] include Aws::Structure end |