Class: Aws::Glue::Types::GetMLTransformResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetMLTransformResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_on ⇒ Time
The date and time when the transform was created.
-
#description ⇒ String
A description of the transform.
-
#evaluation_metrics ⇒ Types::EvaluationMetrics
The latest evaluation metrics.
-
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with.
-
#input_record_tables ⇒ Array<Types::GlueTable>
A list of Glue table definitions used by the transform.
-
#label_count ⇒ Integer
The number of labels available for this transform.
-
#last_modified_on ⇒ Time
The date and time when the transform was last modified.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform.
-
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
-
#name ⇒ String
The unique name given to the transform when it was created.
-
#number_of_workers ⇒ Integer
The number of workers of a defined
workerTypethat are allocated when this task runs. -
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the algorithm used.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
-
#schema ⇒ Array<Types::SchemaColumn>
The
Map<Column, Type>object that represents the schema that this transform accepts. -
#status ⇒ String
The last known status of the transform (to indicate whether it can be used or not).
-
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes.
-
#transform_encryption ⇒ Types::TransformEncryption
The encryption-at-rest settings of the transform that apply to accessing user data.
-
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs.
Instance Attribute Details
#created_on ⇒ Time
The date and time when the transform was created.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the transform.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#evaluation_metrics ⇒ Types::EvaluationMetrics
The latest evaluation metrics.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see Glue Versions in the developer guide.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#input_record_tables ⇒ Array<Types::GlueTable>
A list of Glue table definitions used by the transform.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#label_count ⇒ Integer
The number of labels available for this transform.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
The date and time when the transform was last modified.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page.
When the WorkerType field is set to a value other than Standard,
the MaxCapacity field is set automatically and becomes read-only.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name given to the transform when it was created.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined workerType that are allocated
when this task runs.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the algorithm used.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ Array<Types::SchemaColumn>
The Map<Column, Type> object that represents the schema that this
transform accepts. Has an upper bound of 100 columns.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The last known status of the transform (to indicate whether it can be used or not). One of "NOT_READY", "READY", or "DELETING".
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes. This is
the maximum time that a task run for this transform can consume
resources before it is terminated and enters TIMEOUT status. The
default is 2,880 minutes (48 hours).
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#transform_encryption ⇒ Types::TransformEncryption
The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#transform_id ⇒ String
The unique identifier of the transform, generated at the time that the transform was created.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.
-
For the
Standardworker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker. -
For the
G.1Xworker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker. -
For the
G.2Xworker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.
15063 15064 15065 15066 15067 15068 15069 15070 15071 15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 |
# File 'lib/aws-sdk-glue/types.rb', line 15063 class GetMLTransformResponse < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |