Class: Aws::Glue::Types::GetMLTransformResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_onTime

The date and time when the transform was created.

Returns:

  • (Time)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the transform.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_metricsTypes::EvaluationMetrics

The latest evaluation metrics.



14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#input_record_tablesArray<Types::GlueTable>

A list of Glue table definitions used by the transform.

Returns:



14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#label_countInteger

The number of labels available for this transform.

Returns:

  • (Integer)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The date and time when the transform was last modified.

Returns:

  • (Time)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

When the ‘WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry a task for this transform after a task run fails.

Returns:

  • (Integer)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique name given to the transform when it was created.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined ‘workerType` that are allocated when this task runs.

Returns:

  • (Integer)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::TransformParameters

The configuration parameters that are specific to the algorithm used.



14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#schemaArray<Types::SchemaColumn>

The ‘Map<Column, Type>` object that represents the schema that this transform accepts. Has an upper bound of 100 columns.

Returns:



14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The last known status of the transform (to indicate whether it can be used or not). One of “NOT_READY”, “READY”, or “DELETING”.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The timeout for a task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters ‘TIMEOUT` status. The default is 2,880 minutes (48 hours).

Returns:

  • (Integer)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#transform_encryptionTypes::TransformEncryption

The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.



14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#transform_idString

The unique identifier of the transform, generated at the time that the transform was created.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.

  • For the ‘Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the ‘G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the ‘G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

Returns:

  • (String)


14122
14123
14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
14143
14144
# File 'lib/aws-sdk-glue/types.rb', line 14122

class GetMLTransformResponse < Struct.new(
  :transform_id,
  :name,
  :description,
  :status,
  :created_on,
  :last_modified_on,
  :input_record_tables,
  :parameters,
  :evaluation_metrics,
  :label_count,
  :schema,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries,
  :transform_encryption)
  SENSITIVE = []
  include Aws::Structure
end