Class: Aws::Glue::Types::GetPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition in question resides.
-
#database_name ⇒ String
The name of the catalog database where the partition resides.
-
#partition_values ⇒ Array<String>
The values that define the partition.
-
#table_name ⇒ String
The name of the partition’s table.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
14985 14986 14987 14988 14989 14990 14991 14992 14993 |
# File 'lib/aws-sdk-glue/types.rb', line 14985 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :audit_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the partition in question resides. If none is provided, the Amazon Web Services account ID is used by default.
14985 14986 14987 14988 14989 14990 14991 14992 14993 |
# File 'lib/aws-sdk-glue/types.rb', line 14985 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :audit_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partition resides.
14985 14986 14987 14988 14989 14990 14991 14992 14993 |
# File 'lib/aws-sdk-glue/types.rb', line 14985 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :audit_context) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
The values that define the partition.
14985 14986 14987 14988 14989 14990 14991 14992 14993 |
# File 'lib/aws-sdk-glue/types.rb', line 14985 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :audit_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partition’s table.
14985 14986 14987 14988 14989 14990 14991 14992 14993 |
# File 'lib/aws-sdk-glue/types.rb', line 14985 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :audit_context) SENSITIVE = [] include Aws::Structure end |