Class: Aws::Glue::Types::GetPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition in question resides.
-
#database_name ⇒ String
The name of the catalog database where the partition resides.
-
#partition_values ⇒ Array<String>
The values that define the partition.
-
#table_name ⇒ String
The name of the partition’s table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition in question resides. If none is provided, the Amazon Web Services account ID is used by default.
10541 10542 10543 10544 10545 10546 10547 10548 |
# File 'lib/aws-sdk-glue/types.rb', line 10541 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partition resides.
10541 10542 10543 10544 10545 10546 10547 10548 |
# File 'lib/aws-sdk-glue/types.rb', line 10541 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
The values that define the partition.
10541 10542 10543 10544 10545 10546 10547 10548 |
# File 'lib/aws-sdk-glue/types.rb', line 10541 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partition’s table.
10541 10542 10543 10544 10545 10546 10547 10548 |
# File 'lib/aws-sdk-glue/types.rb', line 10541 class GetPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values) SENSITIVE = [] include Aws::Structure end |