Class: Aws::Glue::Types::GetResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the Glue resource for which to retrieve the resource policy.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the Glue resource for which to retrieve the resource
policy. If not supplied, the Data Catalog resource policy is
returned. Use GetResourcePolicies to view all existing resource
policies. For more information see Specifying Glue Resource
ARNs.
15828 15829 15830 15831 15832 |
# File 'lib/aws-sdk-glue/types.rb', line 15828 class GetResourcePolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |