Class: Aws::Glue::Types::GetResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass GetResourcePolicyRequest data as a hash:

{
  resource_arn: "GlueResourceArn",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The ARN of the Glue resource for which to retrieve the resource policy. If not supplied, the Data Catalog resource policy is returned. Use `GetResourcePolicies` to view all existing resource policies. For more information see [Specifying Glue Resource ARNs].

[1]: docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

Returns:

  • (String)


9373
9374
9375
9376
9377
# File 'lib/aws-sdk-glue/types.rb', line 9373

class GetResourcePolicyRequest < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end