Class: Aws::Glue::Types::GetSchemaResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetSchemaResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatibility ⇒ String
The compatibility mode of the schema.
-
#created_time ⇒ String
The date and time the schema was created.
-
#data_format ⇒ String
The data format of the schema definition.
-
#description ⇒ String
A description of schema if specified when created.
-
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
-
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
-
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
-
#registry_name ⇒ String
The name of the registry.
-
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
-
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
-
#schema_name ⇒ String
The name of the schema.
-
#schema_status ⇒ String
The status of the schema.
-
#updated_time ⇒ String
The date and time the schema was updated.
Instance Attribute Details
#compatibility ⇒ String
The compatibility mode of the schema.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ String
The date and time the schema was created.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#data_format ⇒ String
The data format of the schema definition. Currently ‘AVRO`, `JSON` and `PROTOBUF` are supported.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of schema if specified when created
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#latest_schema_version ⇒ Integer
The latest version of the schema associated with the returned schema definition.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#next_schema_version ⇒ Integer
The next version of the schema associated with the returned schema definition.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#registry_arn ⇒ String
The Amazon Resource Name (ARN) of the registry.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#registry_name ⇒ String
The name of the registry.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#schema_arn ⇒ String
The Amazon Resource Name (ARN) of the schema.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#schema_checkpoint ⇒ Integer
The version number of the checkpoint (the last time the compatibility mode was changed).
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the schema.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#schema_status ⇒ String
The status of the schema.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |
#updated_time ⇒ String
The date and time the schema was updated.
11694 11695 11696 11697 11698 11699 11700 11701 11702 11703 11704 11705 11706 11707 11708 11709 11710 |
# File 'lib/aws-sdk-glue/types.rb', line 11694 class GetSchemaResponse < Struct.new( :registry_name, :registry_arn, :schema_name, :schema_arn, :description, :data_format, :compatibility, :schema_checkpoint, :latest_schema_version, :next_schema_version, :schema_status, :created_time, :updated_time) SENSITIVE = [] include Aws::Structure end |