Class: Aws::Glue::Types::GetSchemaVersionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetSchemaVersionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#schema_id ⇒ Types::SchemaId
This is a wrapper structure to contain schema identity fields.
-
#schema_version_id ⇒ String
The
SchemaVersionIdof the schema version. -
#schema_version_number ⇒ Types::SchemaVersionNumber
The version number of the schema.
Instance Attribute Details
#schema_id ⇒ Types::SchemaId
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
16038 16039 16040 16041 16042 16043 16044 |
# File 'lib/aws-sdk-glue/types.rb', line 16038 class GetSchemaVersionInput < Struct.new( :schema_id, :schema_version_id, :schema_version_number) SENSITIVE = [] include Aws::Structure end |
#schema_version_id ⇒ String
The SchemaVersionId of the schema version. This field is required
for fetching by schema ID. Either this or the SchemaId wrapper has
to be provided.
16038 16039 16040 16041 16042 16043 16044 |
# File 'lib/aws-sdk-glue/types.rb', line 16038 class GetSchemaVersionInput < Struct.new( :schema_id, :schema_version_id, :schema_version_number) SENSITIVE = [] include Aws::Structure end |
#schema_version_number ⇒ Types::SchemaVersionNumber
The version number of the schema.
16038 16039 16040 16041 16042 16043 16044 |
# File 'lib/aws-sdk-glue/types.rb', line 16038 class GetSchemaVersionInput < Struct.new( :schema_id, :schema_version_id, :schema_version_number) SENSITIVE = [] include Aws::Structure end |