Class: Aws::Glue::Types::GetTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributes_to_getArray<String>

Specifies the table fields returned by the ‘GetTable` call. This parameter doesn’t accept an empty list.

The following are the valid combinations of values:

  • ‘DEFAULT` - Returns the Hive-style table definition only.

  • ‘LATEST_ICEBERG_METADATA` - Returns only the latest Apache Iceberg table metadata.

  • ‘DEFAULT`, `LATEST_ICEBERG_METADATA` - Returns both the Hive-style table definition and the latest Apache Iceberg table metadata.

Returns:

  • (Array<String>)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#audit_contextTypes::AuditContext

A structure containing the Lake Formation [audit context].

[1]: docs.aws.amazon.com/glue/latest/webapi/API_AuditContext.html

Returns:



15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#catalog_idString

The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.

Returns:

  • (String)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#include_status_detailsBoolean

Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.

Returns:

  • (Boolean)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the table for which to retrieve the definition. For Hive compatibility, this name is entirely lowercase.

Returns:

  • (String)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#query_as_of_timeTime

The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with ‘TransactionId`.

Returns:

  • (Time)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end

#transaction_idString

The transaction ID at which to read the table contents.

Returns:

  • (String)


15255
15256
15257
15258
15259
15260
15261
15262
15263
15264
15265
15266
# File 'lib/aws-sdk-glue/types.rb', line 15255

class GetTableRequest < Struct.new(
  :catalog_id,
  :database_name,
  :name,
  :transaction_id,
  :query_as_of_time,
  :audit_context,
  :include_status_details,
  :attributes_to_get)
  SENSITIVE = []
  include Aws::Structure
end