Class: Aws::Glue::Types::GetTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the database in the catalog in which the table resides.
-
#include_status_details ⇒ Boolean
Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
-
#name ⇒ String
The name of the table for which to retrieve the definition.
-
#query_as_of_time ⇒ Time
The time as of when to read the table contents.
-
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |
#include_status_details ⇒ Boolean
Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the table for which to retrieve the definition. For Hive compatibility, this name is entirely lowercase.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |
#query_as_of_time ⇒ Time
The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with ‘TransactionId`.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 |
# File 'lib/aws-sdk-glue/types.rb', line 12095 class GetTableRequest < Struct.new( :catalog_id, :database_name, :name, :transaction_id, :query_as_of_time, :include_status_details) SENSITIVE = [] include Aws::Structure end |