Class: Aws::Glue::Types::GetTableVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTableVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog in which the table resides.
-
#table_name ⇒ String
The name of the table.
-
#version_id ⇒ String
The ID value of the table version to be retrieved.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
15965 15966 15967 15968 15969 15970 15971 15972 15973 |
# File 'lib/aws-sdk-glue/types.rb', line 15965 class GetTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id, :audit_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
15965 15966 15967 15968 15969 15970 15971 15972 15973 |
# File 'lib/aws-sdk-glue/types.rb', line 15965 class GetTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id, :audit_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
15965 15966 15967 15968 15969 15970 15971 15972 15973 |
# File 'lib/aws-sdk-glue/types.rb', line 15965 class GetTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id, :audit_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table. For Hive compatibility, this name is entirely lowercase.
15965 15966 15967 15968 15969 15970 15971 15972 15973 |
# File 'lib/aws-sdk-glue/types.rb', line 15965 class GetTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id, :audit_context) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID value of the table version to be retrieved. A ‘VersionID` is a string representation of an integer. Each version is incremented by 1.
15965 15966 15967 15968 15969 15970 15971 15972 15973 |
# File 'lib/aws-sdk-glue/types.rb', line 15965 class GetTableVersionRequest < Struct.new( :catalog_id, :database_name, :table_name, :version_id, :audit_context) SENSITIVE = [] include Aws::Structure end |