Class: Aws::Glue::Types::GetTableVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTableVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog in which the table resides.
-
#max_results ⇒ Integer
The maximum number of table versions to return in one response.
-
#next_token ⇒ String
A continuation token, if this is not the first call.
-
#table_name ⇒ String
The name of the table.
Instance Attribute Details
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation audit context.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of table versions to return in one response.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is not the first call.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table. For Hive compatibility, this name is entirely lowercase.
15358 15359 15360 15361 15362 15363 15364 15365 15366 15367 |
# File 'lib/aws-sdk-glue/types.rb', line 15358 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results, :audit_context) SENSITIVE = [] include Aws::Structure end |