Class: Aws::Glue::Types::GetTableVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTableVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass GetTableVersionsRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
next_token: "Token",
max_results: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog in which the table resides.
-
#max_results ⇒ Integer
The maximum number of table versions to return in one response.
-
#next_token ⇒ String
A continuation token, if this is not the first call.
-
#table_name ⇒ String
The name of the table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
13154 13155 13156 13157 13158 13159 13160 13161 13162 |
# File 'lib/aws-sdk-glue/types.rb', line 13154 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
13154 13155 13156 13157 13158 13159 13160 13161 13162 |
# File 'lib/aws-sdk-glue/types.rb', line 13154 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of table versions to return in one response.
13154 13155 13156 13157 13158 13159 13160 13161 13162 |
# File 'lib/aws-sdk-glue/types.rb', line 13154 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is not the first call.
13154 13155 13156 13157 13158 13159 13160 13161 13162 |
# File 'lib/aws-sdk-glue/types.rb', line 13154 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table. For Hive compatibility, this name is entirely lowercase.
13154 13155 13156 13157 13158 13159 13160 13161 13162 |
# File 'lib/aws-sdk-glue/types.rb', line 13154 class GetTableVersionsRequest < Struct.new( :catalog_id, :database_name, :table_name, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |