Class: Aws::Glue::Types::GetTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes_to_get ⇒ Array<String>
Specifies the table fields returned by the ‘GetTables` call.
-
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation [audit context].
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog whose tables to list.
-
#expression ⇒ String
A regular expression pattern.
-
#include_status_details ⇒ Boolean
Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
-
#max_results ⇒ Integer
The maximum number of tables to return in a single response.
-
#next_token ⇒ String
A continuation token, included if this is a continuation call.
-
#query_as_of_time ⇒ Time
The time as of when to read the table contents.
-
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
Instance Attribute Details
#attributes_to_get ⇒ Array<String>
Specifies the table fields returned by the ‘GetTables` call. This parameter doesn’t accept an empty list. The request must include `NAME`.
The following are the valid combinations of values:
-
‘NAME` - Names of all tables in the database.
-
‘NAME`, `TABLE_TYPE` - Names of all tables and the table types.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#audit_context ⇒ Types::AuditContext
A structure containing the Lake Formation [audit context].
[1]: docs.aws.amazon.com/glue/latest/webapi/API_AuditContext.html
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ String
A regular expression pattern. If present, only those tables whose names match the pattern are returned.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#include_status_details ⇒ Boolean
Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tables to return in a single response.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, included if this is a continuation call.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#query_as_of_time ⇒ Time
The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with ‘TransactionId`.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
16093 16094 16095 16096 16097 16098 16099 16100 16101 16102 16103 16104 16105 16106 |
# File 'lib/aws-sdk-glue/types.rb', line 16093 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time, :audit_context, :include_status_details, :attributes_to_get) SENSITIVE = [] include Aws::Structure end |