Class: Aws::Glue::Types::GetTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass GetTablesRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
expression: "FilterString",
next_token: "Token",
max_results: 1,
transaction_id: "TransactionIdString",
query_as_of_time: Time.now,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside.
-
#database_name ⇒ String
The database in the catalog whose tables to list.
-
#expression ⇒ String
A regular expression pattern.
-
#max_results ⇒ Integer
The maximum number of tables to return in a single response.
-
#next_token ⇒ String
A continuation token, included if this is a continuation call.
-
#query_as_of_time ⇒ Time
The time as of when to read the table contents.
-
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#expression ⇒ String
A regular expression pattern. If present, only those tables whose names match the pattern are returned.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of tables to return in a single response.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, included if this is a continuation call.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#query_as_of_time ⇒ Time
The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with `TransactionId`.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to read the table contents.
13123 13124 13125 13126 13127 13128 13129 13130 13131 13132 13133 |
# File 'lib/aws-sdk-glue/types.rb', line 13123 class GetTablesRequest < Struct.new( :catalog_id, :database_name, :expression, :next_token, :max_results, :transaction_id, :query_as_of_time) SENSITIVE = [] include Aws::Structure end |