Class: Aws::Glue::Types::GetTriggersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dependent_job_nameString

The name of the job to retrieve triggers for. The trigger that can start this job is returned, and if there is no such trigger, all triggers are returned.

Returns:

  • (String)


15466
15467
15468
15469
15470
15471
15472
# File 'lib/aws-sdk-glue/types.rb', line 15466

class GetTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum size of the response.

Returns:

  • (Integer)


15466
15467
15468
15469
15470
15471
15472
# File 'lib/aws-sdk-glue/types.rb', line 15466

class GetTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


15466
15467
15468
15469
15470
15471
15472
# File 'lib/aws-sdk-glue/types.rb', line 15466

class GetTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end