Class: Aws::Glue::Types::GetTriggersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTriggersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependent_job_name ⇒ String
The name of the job to retrieve triggers for.
-
#max_results ⇒ Integer
The maximum size of the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
Instance Attribute Details
#dependent_job_name ⇒ String
The name of the job to retrieve triggers for. The trigger that can start this job is returned, and if there is no such trigger, all triggers are returned.
11838 11839 11840 11841 11842 11843 11844 |
# File 'lib/aws-sdk-glue/types.rb', line 11838 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of the response.
11838 11839 11840 11841 11842 11843 11844 |
# File 'lib/aws-sdk-glue/types.rb', line 11838 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
11838 11839 11840 11841 11842 11843 11844 |
# File 'lib/aws-sdk-glue/types.rb', line 11838 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |