Class: Aws::Glue::Types::GetTriggersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetTriggersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GetTriggersRequest data as a hash:
{
next_token: "GenericString",
dependent_job_name: "NameString",
max_results: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependent_job_name ⇒ String
The name of the job to retrieve triggers for.
-
#max_results ⇒ Integer
The maximum size of the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
Instance Attribute Details
#dependent_job_name ⇒ String
The name of the job to retrieve triggers for. The trigger that can start this job is returned, and if there is no such trigger, all triggers are returned.
13331 13332 13333 13334 13335 13336 13337 |
# File 'lib/aws-sdk-glue/types.rb', line 13331 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of the response.
13331 13332 13333 13334 13335 13336 13337 |
# File 'lib/aws-sdk-glue/types.rb', line 13331 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
13331 13332 13333 13334 13335 13336 13337 |
# File 'lib/aws-sdk-glue/types.rb', line 13331 class GetTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results) SENSITIVE = [] include Aws::Structure end |