Class: Aws::Glue::Types::GetUserDefinedFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUserDefinedFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be retrieved is located.
-
#database_name ⇒ String
The name of the catalog database where the function is located.
-
#function_name ⇒ String
The name of the function.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be retrieved is located. If none is provided, the Amazon Web Services account ID is used by default.
12442 12443 12444 12445 12446 12447 12448 |
# File 'lib/aws-sdk-glue/types.rb', line 12442 class GetUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the function is located.
12442 12443 12444 12445 12446 12447 12448 |
# File 'lib/aws-sdk-glue/types.rb', line 12442 class GetUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
12442 12443 12444 12445 12446 12447 12448 |
# File 'lib/aws-sdk-glue/types.rb', line 12442 class GetUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name) SENSITIVE = [] include Aws::Structure end |