Class: Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located.
-
#database_name ⇒ String
The name of the catalog database where the functions are located.
-
#function_type ⇒ String
An optional function-type pattern string that filters the function definitions returned from Amazon Redshift Federated Permissions Catalog.
-
#max_results ⇒ Integer
The maximum number of functions to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located. If none is provided, the Amazon Web Services account ID is used by default.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the functions are located. If none is provided, functions from all the databases across the catalog will be returned.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#function_type ⇒ String
An optional function-type pattern string that filters the function definitions returned from Amazon Redshift Federated Permissions Catalog.
Specify a value of ‘REGULAR_FUNCTION` or `STORED_PROCEDURE`. The `STORED_PROCEDURE` function type is only compatible with Amazon Redshift Federated Permissions Catalog.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of functions to return in one response.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
16115 16116 16117 16118 16119 16120 16121 16122 16123 16124 |
# File 'lib/aws-sdk-glue/types.rb', line 16115 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :function_type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |