Class: Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located.
-
#database_name ⇒ String
The name of the catalog database where the functions are located.
-
#max_results ⇒ Integer
The maximum number of functions to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located. If none is provided, the Amazon Web Services account ID is used by default.
11458 11459 11460 11461 11462 11463 11464 11465 11466 |
# File 'lib/aws-sdk-glue/types.rb', line 11458 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the functions are located. If none is provided, functions from all the databases across the catalog will be returned.
11458 11459 11460 11461 11462 11463 11464 11465 11466 |
# File 'lib/aws-sdk-glue/types.rb', line 11458 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of functions to return in one response.
11458 11459 11460 11461 11462 11463 11464 11465 11466 |
# File 'lib/aws-sdk-glue/types.rb', line 11458 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
11458 11459 11460 11461 11462 11463 11464 11465 11466 |
# File 'lib/aws-sdk-glue/types.rb', line 11458 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
11458 11459 11460 11461 11462 11463 11464 11465 11466 |
# File 'lib/aws-sdk-glue/types.rb', line 11458 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |