Class: Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GetUserDefinedFunctionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass GetUserDefinedFunctionsRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString",
pattern: "NameString", # required
next_token: "Token",
max_results: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located.
-
#database_name ⇒ String
The name of the catalog database where the functions are located.
-
#max_results ⇒ Integer
The maximum number of functions to return in one response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the functions to be retrieved are located. If none is provided, the Amazon Web Services account ID is used by default.
13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-glue/types.rb', line 13721 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the functions are located. If none is provided, functions from all the databases across the catalog will be returned.
13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-glue/types.rb', line 13721 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of functions to return in one response.
13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-glue/types.rb', line 13721 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-glue/types.rb', line 13721 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
An optional function-name pattern string that filters the function definitions returned.
13721 13722 13723 13724 13725 13726 13727 13728 13729 |
# File 'lib/aws-sdk-glue/types.rb', line 13721 class GetUserDefinedFunctionsRequest < Struct.new( :catalog_id, :database_name, :pattern, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |