Class: Aws::Glue::Types::GetWorkflowRunsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_graphBoolean

Specifies whether to include the workflow graph in response or not.

Returns:

  • (Boolean)


11500
11501
11502
11503
11504
11505
11506
11507
# File 'lib/aws-sdk-glue/types.rb', line 11500

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of workflow runs to be included in the response.

Returns:

  • (Integer)


11500
11501
11502
11503
11504
11505
11506
11507
# File 'lib/aws-sdk-glue/types.rb', line 11500

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the workflow whose metadata of runs should be returned.

Returns:

  • (String)


11500
11501
11502
11503
11504
11505
11506
11507
# File 'lib/aws-sdk-glue/types.rb', line 11500

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The maximum size of the response.

Returns:

  • (String)


11500
11501
11502
11503
11504
11505
11506
11507
# File 'lib/aws-sdk-glue/types.rb', line 11500

class GetWorkflowRunsRequest < Struct.new(
  :name,
  :include_graph,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end