Class: Aws::Glue::Types::GlueStudioSchemaColumn
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GlueStudioSchemaColumn
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass GlueStudioSchemaColumn data as a hash:
{
name: "GlueStudioColumnNameString", # required
type: "ColumnTypeString",
}
Specifies a single column in a Glue schema definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the column in the Glue Studio schema.
-
#type ⇒ String
The hive type for this column in the Glue Studio schema.
Instance Attribute Details
#name ⇒ String
The name of the column in the Glue Studio schema.
13950 13951 13952 13953 13954 13955 |
# File 'lib/aws-sdk-glue/types.rb', line 13950 class GlueStudioSchemaColumn < Struct.new( :name, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The hive type for this column in the Glue Studio schema.
13950 13951 13952 13953 13954 13955 |
# File 'lib/aws-sdk-glue/types.rb', line 13950 class GlueStudioSchemaColumn < Struct.new( :name, :type) SENSITIVE = [] include Aws::Structure end |