Class: Aws::Glue::Types::GrokClassifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::GrokClassifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A classifier that uses grok patterns.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, and so on.
-
#creation_time ⇒ Time
The time that this classifier was registered.
-
#custom_patterns ⇒ String
Optional custom grok patterns defined by this classifier.
-
#grok_pattern ⇒ String
The grok pattern applied to a data store by this classifier.
-
#last_updated ⇒ Time
The time that this classifier was last updated.
-
#name ⇒ String
The name of the classifier.
-
#version ⇒ Integer
The version of this classifier.
Instance Attribute Details
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, and so on.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time that this classifier was registered.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#custom_patterns ⇒ String
Optional custom grok patterns defined by this classifier. For more information, see custom patterns in Writing Custom Classifiers.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#grok_pattern ⇒ String
The grok pattern applied to a data store by this classifier. For more information, see built-in patterns in Writing Custom Classifiers.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
The time that this classifier was last updated.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of this classifier.
17515 17516 17517 17518 17519 17520 17521 17522 17523 17524 17525 |
# File 'lib/aws-sdk-glue/types.rb', line 17515 class GrokClassifier < Struct.new( :name, :classification, :creation_time, :last_updated, :version, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |