Class: Aws::Glue::Types::HudiTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::HudiTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Apache Hudi data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to use to connect to the Hudi target.
-
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl.
-
#maximum_traversal_depth ⇒ Integer
The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Hudi metadata folder in your Amazon S3 path.
-
#paths ⇒ Array<String>
An array of Amazon S3 location strings for Hudi, each indicating the root folder with which the metadata files for a Hudi table resides.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to use to connect to the Hudi target. If your Hudi files are stored in buckets that require VPC authorization, you can set their connection properties here.
12503 12504 12505 12506 12507 12508 12509 12510 |
# File 'lib/aws-sdk-glue/types.rb', line 12503 class HudiTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl. For more information, see [Catalog Tables with a Crawler].
12503 12504 12505 12506 12507 12508 12509 12510 |
# File 'lib/aws-sdk-glue/types.rb', line 12503 class HudiTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#maximum_traversal_depth ⇒ Integer
The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Hudi metadata folder in your Amazon S3 path. Used to limit the crawler run time.
12503 12504 12505 12506 12507 12508 12509 12510 |
# File 'lib/aws-sdk-glue/types.rb', line 12503 class HudiTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<String>
An array of Amazon S3 location strings for Hudi, each indicating the root folder with which the metadata files for a Hudi table resides. The Hudi folder may be located in a child folder of the root folder.
The crawler will scan all folders underneath a path for a Hudi folder.
12503 12504 12505 12506 12507 12508 12509 12510 |
# File 'lib/aws-sdk-glue/types.rb', line 12503 class HudiTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |