Class: Aws::Glue::Types::IcebergOptimizationPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergOptimizationPropertiesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that contains the output properties of Iceberg table optimization configuration for your catalog resource in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compaction ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
-
#last_updated_time ⇒ Time
The timestamp when the Iceberg optimization properties were last updated.
-
#orphan_file_deletion ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
-
#retention ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
Instance Attribute Details
#compaction ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/aws-sdk-glue/types.rb', line 16840 class IcebergOptimizationPropertiesOutput < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp when the Iceberg optimization properties were last updated.
16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/aws-sdk-glue/types.rb', line 16840 class IcebergOptimizationPropertiesOutput < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/aws-sdk-glue/types.rb', line 16840 class IcebergOptimizationPropertiesOutput < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Hash<String,String>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/aws-sdk-glue/types.rb', line 16840 class IcebergOptimizationPropertiesOutput < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
16840 16841 16842 16843 16844 16845 16846 16847 16848 |
# File 'lib/aws-sdk-glue/types.rb', line 16840 class IcebergOptimizationPropertiesOutput < Struct.new( :role_arn, :compaction, :retention, :orphan_file_deletion, :last_updated_time) SENSITIVE = [] include Aws::Structure end |