Class: Aws::Glue::Types::IcebergPartitionField
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergPartitionField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Defines a single partition field within an Iceberg partition specification, including the source field, transformation function, partition name, and unique identifier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_id ⇒ Integer
The unique identifier assigned to this partition field within the Iceberg table’s partition specification.
-
#name ⇒ String
The name of the partition field as it will appear in the partitioned table structure.
-
#source_id ⇒ Integer
The identifier of the source field from the table schema that this partition field is based on.
-
#transform ⇒ String
The transformation function applied to the source field to create the partition, such as identity, bucket, truncate, year, month, day, or hour.
Instance Attribute Details
#field_id ⇒ Integer
The unique identifier assigned to this partition field within the Iceberg table’s partition specification.
16369 16370 16371 16372 16373 16374 16375 16376 |
# File 'lib/aws-sdk-glue/types.rb', line 16369 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the partition field as it will appear in the partitioned table structure.
16369 16370 16371 16372 16373 16374 16375 16376 |
# File 'lib/aws-sdk-glue/types.rb', line 16369 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ Integer
The identifier of the source field from the table schema that this partition field is based on.
16369 16370 16371 16372 16373 16374 16375 16376 |
# File 'lib/aws-sdk-glue/types.rb', line 16369 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |
#transform ⇒ String
The transformation function applied to the source field to create the partition, such as identity, bucket, truncate, year, month, day, or hour.
16369 16370 16371 16372 16373 16374 16375 16376 |
# File 'lib/aws-sdk-glue/types.rb', line 16369 class IcebergPartitionField < Struct.new( :source_id, :transform, :name, :field_id) SENSITIVE = [] include Aws::Structure end |