Class: Aws::Glue::Types::IcebergRetentionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The configuration for an Iceberg snapshot retention optimizer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clean_expired_filesBoolean

If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.

Returns:

  • (Boolean)


16035
16036
16037
16038
16039
16040
16041
# File 'lib/aws-sdk-glue/types.rb', line 16035

class IcebergRetentionConfiguration < Struct.new(
  :snapshot_retention_period_in_days,
  :number_of_snapshots_to_retain,
  :clean_expired_files)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_snapshots_to_retainInteger

The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.

Returns:

  • (Integer)


16035
16036
16037
16038
16039
16040
16041
# File 'lib/aws-sdk-glue/types.rb', line 16035

class IcebergRetentionConfiguration < Struct.new(
  :snapshot_retention_period_in_days,
  :number_of_snapshots_to_retain,
  :clean_expired_files)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_retention_period_in_daysInteger

The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.

Returns:

  • (Integer)


16035
16036
16037
16038
16039
16040
16041
# File 'lib/aws-sdk-glue/types.rb', line 16035

class IcebergRetentionConfiguration < Struct.new(
  :snapshot_retention_period_in_days,
  :number_of_snapshots_to_retain,
  :clean_expired_files)
  SENSITIVE = []
  include Aws::Structure
end