Class: Aws::Glue::Types::IcebergStructField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a single field within an Iceberg table schema, including its identifier, name, data type, nullability, and documentation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#docString

Optional documentation or description text that provides additional context about the purpose and usage of this field.

Returns:

  • (String)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#idInteger

The unique identifier assigned to this field within the Iceberg table schema, used for schema evolution and field tracking.

Returns:

  • (Integer)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#initial_defaultHash, ...

Default value used to populate the field’s value for all records that were written before the field was added to the schema. This enables backward compatibility when adding new fields to existing Iceberg tables.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the field as it appears in the table schema and query operations.

Returns:

  • (String)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#requiredBoolean

Indicates whether this field is required (non-nullable) or optional (nullable) in the table schema.

Returns:

  • (Boolean)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#typeHash, ...

The data type definition for this field, specifying the structure and format of the data it contains.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end

#write_defaultHash, ...

Default value used to populate the field’s value for any records written after the field was added to the schema, if the writer does not supply the field’s value. This can be changed through schema evolution.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


17080
17081
17082
17083
17084
17085
17086
17087
17088
17089
17090
# File 'lib/aws-sdk-glue/types.rb', line 17080

class IcebergStructField < Struct.new(
  :id,
  :name,
  :type,
  :required,
  :doc,
  :initial_default,
  :write_default)
  SENSITIVE = []
  include Aws::Structure
end