Class: Aws::Glue::Types::IcebergTableMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The Apache Iceberg table metadata, including format version, table identifier, schemas, partition specifications, sort orders, and table properties. This structure captures the current state of an Iceberg table's metadata as managed by the Glue Data Catalog.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_schema_idInteger

The identifier of the schema that is currently active for the Iceberg table. Matches an entry in Schemas.

Returns:

  • (Integer)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#default_sort_order_idInteger

The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.

Returns:

  • (Integer)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#default_spec_idInteger

The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.

Returns:

  • (Integer)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#format_versionString

The Apache Iceberg table format version, such as 1 or 2. Determines the set of features and on-disk layout supported by the table.

Returns:

  • (String)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#last_column_idInteger

The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.

Returns:

  • (Integer)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#last_partition_idInteger

The highest partition field identifier that has been assigned across the table's partition specifications.

Returns:

  • (Integer)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The base S3 location where the Iceberg table's data and metadata files are stored.

Returns:

  • (String)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#partition_specsArray<Types::IcebergPartitionSpec>

The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.

Returns:



18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,String>

A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.

Returns:

  • (Hash<String,String>)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#schemasArray<Types::IcebergSchema>

The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.

Returns:



18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#sort_ordersArray<Types::IcebergSortOrder>

The list of sort order specifications that have been associated with the Iceberg table over its history.

Returns:



18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end

#table_uuidString

The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.

Returns:

  • (String)


18515
18516
18517
18518
18519
18520
18521
18522
18523
18524
18525
18526
18527
18528
18529
18530
# File 'lib/aws-sdk-glue/types.rb', line 18515

class IcebergTableMetadata < Struct.new(
  :format_version,
  :table_uuid,
  :location,
  :properties,
  :schemas,
  :current_schema_id,
  :last_column_id,
  :partition_specs,
  :default_spec_id,
  :last_partition_id,
  :sort_orders,
  :default_sort_order_id)
  SENSITIVE = []
  include Aws::Structure
end