Class: Aws::Glue::Types::IcebergTableMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergTableMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The Apache Iceberg table metadata, including format version, table identifier, schemas, partition specifications, sort orders, and table properties. This structure captures the current state of an Iceberg table's metadata as managed by the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_schema_id ⇒ Integer
The identifier of the schema that is currently active for the Iceberg table.
-
#default_sort_order_id ⇒ Integer
The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.
-
#default_spec_id ⇒ Integer
The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.
-
#format_version ⇒ String
The Apache Iceberg table format version, such as
1or2. -
#last_column_id ⇒ Integer
The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.
-
#last_partition_id ⇒ Integer
The highest partition field identifier that has been assigned across the table's partition specifications.
-
#location ⇒ String
The base S3 location where the Iceberg table's data and metadata files are stored.
-
#partition_specs ⇒ Array<Types::IcebergPartitionSpec>
The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.
-
#properties ⇒ Hash<String,String>
A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.
-
#schemas ⇒ Array<Types::IcebergSchema>
The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.
-
#sort_orders ⇒ Array<Types::IcebergSortOrder>
The list of sort order specifications that have been associated with the Iceberg table over its history.
-
#table_uuid ⇒ String
The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.
Instance Attribute Details
#current_schema_id ⇒ Integer
The identifier of the schema that is currently active for the
Iceberg table. Matches an entry in Schemas.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#default_sort_order_id ⇒ Integer
The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#default_spec_id ⇒ Integer
The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#format_version ⇒ String
The Apache Iceberg table format version, such as 1 or 2.
Determines the set of features and on-disk layout supported by the
table.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#last_column_id ⇒ Integer
The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#last_partition_id ⇒ Integer
The highest partition field identifier that has been assigned across the table's partition specifications.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The base S3 location where the Iceberg table's data and metadata files are stored.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#partition_specs ⇒ Array<Types::IcebergPartitionSpec>
The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Hash<String,String>
A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#schemas ⇒ Array<Types::IcebergSchema>
The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#sort_orders ⇒ Array<Types::IcebergSortOrder>
The list of sort order specifications that have been associated with the Iceberg table over its history.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |
#table_uuid ⇒ String
The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.
18256 18257 18258 18259 18260 18261 18262 18263 18264 18265 18266 18267 18268 18269 18270 18271 |
# File 'lib/aws-sdk-glue/types.rb', line 18256 class IcebergTableMetadata < Struct.new( :format_version, :table_uuid, :location, :properties, :schemas, :current_schema_id, :last_column_id, :partition_specs, :default_spec_id, :last_partition_id, :sort_orders, :default_sort_order_id) SENSITIVE = [] include Aws::Structure end |