Class: Aws::Glue::Types::IcebergTableUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Defines a complete set of updates to be applied to an Iceberg table, including schema changes, partitioning modifications, sort order adjustments, location updates, and property changes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The type of update action to be performed on the Iceberg table. Defines the specific operation such as adding schema, setting current schema, adding partition spec, or managing encryption keys.

Returns:

  • (String)


16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_keyTypes::IcebergEncryptedKey

Encryption key information associated with an Iceberg table update operation. Used when adding or removing encryption keys from the table metadata during table evolution.



16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

Identifier of the encryption key involved in an Iceberg table update operation. References the specific key being added to or removed from the table’s encryption configuration.

Returns:

  • (String)


16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The updated S3 location where the Iceberg table data will be stored.

Returns:

  • (String)


16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#partition_specTypes::IcebergPartitionSpec

The updated partitioning specification that defines how the table data should be reorganized and partitioned.



16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesHash<String,String>

Updated key-value pairs of table properties and configuration settings for the Iceberg table.

Returns:

  • (Hash<String,String>)


16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#schemaTypes::IcebergSchema

The updated schema definition for the Iceberg table, specifying any changes to field structure, data types, or schema metadata.



16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderTypes::IcebergSortOrder

The updated sort order specification that defines how data should be ordered within partitions for optimal query performance.



16675
16676
16677
16678
16679
16680
16681
16682
16683
16684
16685
16686
# File 'lib/aws-sdk-glue/types.rb', line 16675

class IcebergTableUpdate < Struct.new(
  :schema,
  :partition_spec,
  :sort_order,
  :location,
  :properties,
  :action,
  :encryption_key,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end