Class: Aws::Glue::Types::IcebergTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies an Apache Iceberg data source where Iceberg tables are stored in Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_nameString

The name of the connection to use to connect to the Iceberg target.

Returns:

  • (String)


18067
18068
18069
18070
18071
18072
18073
18074
# File 'lib/aws-sdk-glue/types.rb', line 18067

class IcebergTarget < Struct.new(
  :paths,
  :connection_name,
  :exclusions,
  :maximum_traversal_depth)
  SENSITIVE = []
  include Aws::Structure
end

#exclusionsArray<String>

A list of glob patterns used to exclude from the crawl. For more information, see [Catalog Tables with a Crawler].

[1]: docs.aws.amazon.com/glue/latest/dg/add-crawler.html

Returns:

  • (Array<String>)


18067
18068
18069
18070
18071
18072
18073
18074
# File 'lib/aws-sdk-glue/types.rb', line 18067

class IcebergTarget < Struct.new(
  :paths,
  :connection_name,
  :exclusions,
  :maximum_traversal_depth)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_traversal_depthInteger

The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time.

Returns:

  • (Integer)


18067
18068
18069
18070
18071
18072
18073
18074
# File 'lib/aws-sdk-glue/types.rb', line 18067

class IcebergTarget < Struct.new(
  :paths,
  :connection_name,
  :exclusions,
  :maximum_traversal_depth)
  SENSITIVE = []
  include Aws::Structure
end

#pathsArray<String>

One or more Amazon S3 paths that contains Iceberg metadata folders as ‘s3://bucket/prefix`.

Returns:

  • (Array<String>)


18067
18068
18069
18070
18071
18072
18073
18074
# File 'lib/aws-sdk-glue/types.rb', line 18067

class IcebergTarget < Struct.new(
  :paths,
  :connection_name,
  :exclusions,
  :maximum_traversal_depth)
  SENSITIVE = []
  include Aws::Structure
end