Class: Aws::Glue::Types::IcebergTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IcebergTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Apache Iceberg data source where Iceberg tables are stored in Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of the connection to use to connect to the Iceberg target.
-
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl.
-
#maximum_traversal_depth ⇒ Integer
The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path.
-
#paths ⇒ Array<String>
One or more Amazon S3 paths that contains Iceberg metadata folders as ‘s3://bucket/prefix`.
Instance Attribute Details
#connection_name ⇒ String
The name of the connection to use to connect to the Iceberg target.
13136 13137 13138 13139 13140 13141 13142 13143 |
# File 'lib/aws-sdk-glue/types.rb', line 13136 class IcebergTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl. For more information, see [Catalog Tables with a Crawler].
13136 13137 13138 13139 13140 13141 13142 13143 |
# File 'lib/aws-sdk-glue/types.rb', line 13136 class IcebergTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#maximum_traversal_depth ⇒ Integer
The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time.
13136 13137 13138 13139 13140 13141 13142 13143 |
# File 'lib/aws-sdk-glue/types.rb', line 13136 class IcebergTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<String>
One or more Amazon S3 paths that contains Iceberg metadata folders as ‘s3://bucket/prefix`.
13136 13137 13138 13139 13140 13141 13142 13143 |
# File 'lib/aws-sdk-glue/types.rb', line 13136 class IcebergTarget < Struct.new( :paths, :connection_name, :exclusions, :maximum_traversal_depth) SENSITIVE = [] include Aws::Structure end |