Class: Aws::Glue::Types::IntegrationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Properties associated with the integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#refresh_intervalString

Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days). Currently supports creation of ‘RefreshInterval` only.

Returns:

  • (String)


15854
15855
15856
15857
15858
# File 'lib/aws-sdk-glue/types.rb', line 15854

class IntegrationConfig < Struct.new(
  :refresh_interval)
  SENSITIVE = []
  include Aws::Structure
end