Class: Aws::Glue::Types::IntegrationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IntegrationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Properties associated with the integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#refresh_interval ⇒ String
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur.
Instance Attribute Details
#refresh_interval ⇒ String
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days). Currently supports creation of ‘RefreshInterval` only.
15836 15837 15838 15839 15840 |
# File 'lib/aws-sdk-glue/types.rb', line 15836 class IntegrationConfig < Struct.new( :refresh_interval) SENSITIVE = [] include Aws::Structure end |