Class: Aws::Glue::Types::IntegrationPartition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IntegrationPartition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that describes how data is partitioned on the target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_name ⇒ String
The field name used to partition data on the target.
-
#function_spec ⇒ String
Specifies the function used to partition data on the target.
Instance Attribute Details
#field_name ⇒ String
The field name used to partition data on the target. Avoid using columns that have unique values for each row (for example, ‘LastModifiedTimestamp`, `SystemModTimeStamp`) as the partition column. These columns are not suitable for partitioning because they create a large number of small partitions, which can lead to performance issues.
15865 15866 15867 15868 15869 15870 |
# File 'lib/aws-sdk-glue/types.rb', line 15865 class IntegrationPartition < Struct.new( :field_name, :function_spec) SENSITIVE = [] include Aws::Structure end |
#function_spec ⇒ String
Specifies the function used to partition data on the target. The only accepted value for this parameter is ‘’identity’‘ (string). The `’identity’‘ function ensures that the data partitioning on the target follows the same scheme as the source. In other words, the partitioning structure of the source data is preserved in the target destination.
15865 15866 15867 15868 15869 15870 |
# File 'lib/aws-sdk-glue/types.rb', line 15865 class IntegrationPartition < Struct.new( :field_name, :function_spec) SENSITIVE = [] include Aws::Structure end |