Class: Aws::Glue::Types::ItemError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An error that occurred when retrieving an iterable form item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


18658
18659
18660
18661
18662
18663
18664
# File 'lib/aws-sdk-glue/types.rb', line 18658

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item that caused the error.

Returns:

  • (String)


18658
18659
18660
18661
18662
18663
18664
# File 'lib/aws-sdk-glue/types.rb', line 18658

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


18658
18659
18660
18661
18662
18663
18664
# File 'lib/aws-sdk-glue/types.rb', line 18658

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end