Class: Aws::Glue::Types::ItemError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

An error that occurred when retrieving an iterable form item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


18645
18646
18647
18648
18649
18650
18651
# File 'lib/aws-sdk-glue/types.rb', line 18645

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item that caused the error.

Returns:

  • (String)


18645
18646
18647
18648
18649
18650
18651
# File 'lib/aws-sdk-glue/types.rb', line 18645

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


18645
18646
18647
18648
18649
18650
18651
# File 'lib/aws-sdk-glue/types.rb', line 18645

class ItemError < Struct.new(
  :item_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end