Class: Aws::Glue::Types::ItemError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ItemError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An error that occurred when retrieving an iterable form item.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#item_identifier ⇒ String
The identifier of the item that caused the error.
-
#message ⇒ String
The error message.
Instance Attribute Details
#code ⇒ String
The error code.
18645 18646 18647 18648 18649 18650 18651 |
# File 'lib/aws-sdk-glue/types.rb', line 18645 class ItemError < Struct.new( :item_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |