Class: Aws::Glue::Types::IterableFormEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::IterableFormEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An iterable form available on an asset, identified by its form type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#form_type_id ⇒ String
The form type identifier of the iterable form (for example, ‘columns`), used to retrieve its items via `ListIterableForms` or `BatchGetIterableForms`.
Instance Attribute Details
#form_type_id ⇒ String
The form type identifier of the iterable form (for example, ‘columns`), used to retrieve its items via `ListIterableForms` or `BatchGetIterableForms`.
18663 18664 18665 18666 18667 |
# File 'lib/aws-sdk-glue/types.rb', line 18663 class IterableFormEntry < Struct.new( :form_type_id) SENSITIVE = [] include Aws::Structure end |