Class: Aws::Glue::Types::JDBCConnectorOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JDBCConnectorOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Additional connection options for the connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_type_mapping ⇒ Hash<String,String>
Custom data type mapping that builds a mapping from a JDBC data type to an Glue data type.
-
#filter_predicate ⇒ String
Extra condition clause to filter data from source.
-
#job_bookmark_keys ⇒ Array<String>
The name of the job bookmark keys on which to sort.
-
#job_bookmark_keys_sort_order ⇒ String
Specifies an ascending or descending sort order.
-
#lower_bound ⇒ Integer
The minimum value of ‘partitionColumn` that is used to decide partition stride.
-
#num_partitions ⇒ Integer
The number of partitions.
-
#partition_column ⇒ String
The name of an integer column that is used for partitioning.
-
#upper_bound ⇒ Integer
The maximum value of ‘partitionColumn` that is used to decide partition stride.
Instance Attribute Details
#data_type_mapping ⇒ Hash<String,String>
Custom data type mapping that builds a mapping from a JDBC data type to an Glue data type. For example, the option ‘“dataTypeMapping”:“FLOAT”:“STRING”` maps data fields of JDBC type `FLOAT` into the Java `String` type by calling the `ResultSet.getString()` method of the driver, and uses it to build the Glue record. The `ResultSet` object is implemented by each driver, so the behavior is specific to the driver you use. Refer to the documentation for your JDBC driver to understand how the driver performs the conversions.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#filter_predicate ⇒ String
Extra condition clause to filter data from source. For example:
‘BillingCity=’Mountain View’‘
When using a query instead of a table name, you should validate that the query works with the specified ‘filterPredicate`.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#job_bookmark_keys ⇒ Array<String>
The name of the job bookmark keys on which to sort.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#job_bookmark_keys_sort_order ⇒ String
Specifies an ascending or descending sort order.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#lower_bound ⇒ Integer
The minimum value of ‘partitionColumn` that is used to decide partition stride.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#num_partitions ⇒ Integer
The number of partitions. This value, along with ‘lowerBound` (inclusive) and `upperBound` (exclusive), form partition strides for generated `WHERE` clause expressions that are used to split the `partitionColumn`.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#partition_column ⇒ String
The name of an integer column that is used for partitioning. This option works only when it’s included with ‘lowerBound`, `upperBound`, and `numPartitions`. This option works the same way as in the Spark SQL JDBC reader.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |
#upper_bound ⇒ Integer
The maximum value of ‘partitionColumn` that is used to decide partition stride.
12156 12157 12158 12159 12160 12161 12162 12163 12164 12165 12166 12167 |
# File 'lib/aws-sdk-glue/types.rb', line 12156 class JDBCConnectorOptions < Struct.new( :filter_predicate, :partition_column, :lower_bound, :upper_bound, :num_partitions, :job_bookmark_keys, :job_bookmark_keys_sort_order, :data_type_mapping) SENSITIVE = [] include Aws::Structure end |