Class: Aws::Glue::Types::JDBCConnectorOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass JDBCConnectorOptions data as a hash:

{
  filter_predicate: "EnclosedInStringProperty",
  partition_column: "EnclosedInStringProperty",
  lower_bound: 1,
  upper_bound: 1,
  num_partitions: 1,
  job_bookmark_keys: ["EnclosedInStringProperty"],
  job_bookmark_keys_sort_order: "EnclosedInStringProperty",
  data_type_mapping: {
    "ARRAY" => "DATE", # accepts DATE, STRING, TIMESTAMP, INT, FLOAT, LONG, BIGDECIMAL, BYTE, SHORT, DOUBLE
  },
}

Additional connection options for the connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_type_mappingHash<String,String>

Custom data type mapping that builds a mapping from a JDBC data type to an Glue data type. For example, the option `“dataTypeMapping”:“FLOAT”:“STRING”` maps data fields of JDBC type `FLOAT` into the Java `String` type by calling the `ResultSet.getString()` method of the driver, and uses it to build the Glue record. The `ResultSet` object is implemented by each driver, so the behavior is specific to the driver you use. Refer to the documentation for your JDBC driver to understand how the driver performs the conversions.

Returns:

  • (Hash<String,String>)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#filter_predicateString

Extra condition clause to filter data from source. For example:

`BillingCity='Mountain View'`

When using a query instead of a table name, you should validate that the query works with the specified `filterPredicate`.

Returns:

  • (String)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#job_bookmark_keysArray<String>

The name of the job bookmark keys on which to sort.

Returns:

  • (Array<String>)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#job_bookmark_keys_sort_orderString

Specifies an ascending or descending sort order.

Returns:

  • (String)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#lower_boundInteger

The minimum value of `partitionColumn` that is used to decide partition stride.

Returns:

  • (Integer)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#num_partitionsInteger

The number of partitions. This value, along with `lowerBound` (inclusive) and `upperBound` (exclusive), form partition strides for generated `WHERE` clause expressions that are used to split the `partitionColumn`.

Returns:

  • (Integer)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#partition_columnString

The name of an integer column that is used for partitioning. This option works only when it's included with `lowerBound`, `upperBound`, and `numPartitions`. This option works the same way as in the Spark SQL JDBC reader.

Returns:

  • (String)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end

#upper_boundInteger

The maximum value of `partitionColumn` that is used to decide partition stride.

Returns:

  • (Integer)


14435
14436
14437
14438
14439
14440
14441
14442
14443
14444
14445
14446
# File 'lib/aws-sdk-glue/types.rb', line 14435

class JDBCConnectorOptions < Struct.new(
  :filter_predicate,
  :partition_column,
  :lower_bound,
  :upper_bound,
  :num_partitions,
  :job_bookmark_keys,
  :job_bookmark_keys_sort_order,
  :data_type_mapping)
  SENSITIVE = []
  include Aws::Structure
end