Class: Aws::Glue::Types::JDBCConnectorSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JDBCConnectorSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a connector to a JDBC data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Types::JDBCConnectorOptions
Additional connection options for the connector.
-
#connection_name ⇒ String
The name of the connection that is associated with the connector.
-
#connection_table ⇒ String
The name of the table in the data source.
-
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data store.
-
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
-
#name ⇒ String
The name of the data source.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom JDBC source.
-
#query ⇒ String
The table or SQL query to get the data from.
Instance Attribute Details
#additional_options ⇒ Types::JDBCConnectorOptions
Additional connection options for the connector.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection that is associated with the connector.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_table ⇒ String
The name of the table in the data source.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data store.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data source.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom JDBC source.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#query ⇒ String
The table or SQL query to get the data from. You can specify either
ConnectionTable or query, but not both.
19332 19333 19334 19335 19336 19337 19338 19339 19340 19341 19342 19343 |
# File 'lib/aws-sdk-glue/types.rb', line 19332 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |