Class: Aws::Glue::Types::JDBCConnectorSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JDBCConnectorSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass JDBCConnectorSource data as a hash:
{
name: "NodeName", # required
connection_name: "EnclosedInStringProperty", # required
connector_name: "EnclosedInStringProperty", # required
connection_type: "EnclosedInStringProperty", # required
additional_options: {
filter_predicate: "EnclosedInStringProperty",
partition_column: "EnclosedInStringProperty",
lower_bound: 1,
upper_bound: 1,
num_partitions: 1,
job_bookmark_keys: ["EnclosedInStringProperty"],
job_bookmark_keys_sort_order: "EnclosedInStringProperty",
data_type_mapping: {
"ARRAY" => "DATE", # accepts DATE, STRING, TIMESTAMP, INT, FLOAT, LONG, BIGDECIMAL, BYTE, SHORT, DOUBLE
},
},
connection_table: "EnclosedInStringPropertyWithQuote",
query: "SqlQuery",
output_schemas: [
{
columns: [
{
name: "GlueStudioColumnNameString", # required
type: "ColumnTypeString",
},
],
},
],
}
Specifies a connector to a JDBC data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Types::JDBCConnectorOptions
Additional connection options for the connector.
-
#connection_name ⇒ String
The name of the connection that is associated with the connector.
-
#connection_table ⇒ String
The name of the table in the data source.
-
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data store.
-
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
-
#name ⇒ String
The name of the data source.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom JDBC source.
-
#query ⇒ String
The table or SQL query to get the data from.
Instance Attribute Details
#additional_options ⇒ Types::JDBCConnectorOptions
Additional connection options for the connector.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection that is associated with the connector.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_table ⇒ String
The name of the table in the data source.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data store.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connector_name ⇒ String
The name of a connector that assists with accessing the data store in Glue Studio.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data source.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the custom JDBC source.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#query ⇒ String
The table or SQL query to get the data from. You can specify either `ConnectionTable` or `query`, but not both.
14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 |
# File 'lib/aws-sdk-glue/types.rb', line 14521 class JDBCConnectorSource < Struct.new( :name, :connection_name, :connector_name, :connection_type, :additional_options, :connection_table, :query, :output_schemas) SENSITIVE = [] include Aws::Structure end |