Class: Aws::Glue::Types::JDBCConnectorTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JDBCConnectorTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass JDBCConnectorTarget data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
connection_name: "EnclosedInStringProperty", # required
connection_table: "EnclosedInStringPropertyWithQuote", # required
connector_name: "EnclosedInStringProperty", # required
connection_type: "EnclosedInStringProperty", # required
additional_options: {
"EnclosedInStringProperty" => "EnclosedInStringProperty",
},
output_schemas: [
{
columns: [
{
name: "GlueStudioColumnNameString", # required
type: "ColumnTypeString",
},
],
},
],
}
Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Additional connection options for the connector.
-
#connection_name ⇒ String
The name of the connection that is associated with the connector.
-
#connection_table ⇒ String
The name of the table in the data target.
-
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data target.
-
#connector_name ⇒ String
The name of a connector that will be used.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the JDBC target.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Additional connection options for the connector.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
The name of the connection that is associated with the connector.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_table ⇒ String
The name of the table in the data target.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of connection, such as marketplace.jdbc or custom.jdbc, designating a connection to a JDBC data target.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#connector_name ⇒ String
The name of a connector that will be used.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the JDBC target.
14325 14326 14327 14328 14329 14330 14331 14332 14333 14334 14335 14336 |
# File 'lib/aws-sdk-glue/types.rb', line 14325 class JDBCConnectorTarget < Struct.new( :name, :inputs, :connection_name, :connection_table, :connector_name, :connection_type, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |