Class: Aws::Glue::Types::Job
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Job
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a job definition.
Constant Summary collapse
- SENSITIVE =
[:code_gen_configuration_nodes]
Instance Attribute Summary collapse
-
#allocated_capacity ⇒ Integer
This field is deprecated.
-
#code_gen_configuration_nodes ⇒ Hash<String,Types::CodeGenConfigurationNode>
The representation of a directed acyclic graph on which both the Glue Studio visual component and Glue Studio code generation is based.
-
#command ⇒ Types::JobCommand
The `JobCommand` that runs this job.
-
#connections ⇒ Types::ConnectionsList
The connections used for this job.
-
#created_on ⇒ Time
The time and date that this job definition was created.
-
#default_arguments ⇒ Hash<String,String>
The default arguments for this job, specified as name-value pairs.
-
#description ⇒ String
A description of the job.
-
#execution_property ⇒ Types::ExecutionProperty
An `ExecutionProperty` specifying the maximum number of concurrent runs allowed for this job.
-
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#last_modified_on ⇒ Time
The last point in time when this job definition was modified.
-
#log_uri ⇒ String
This field is reserved for future use.
-
#max_capacity ⇒ Float
For Glue version 1.0 or earlier jobs, using the standard worker type, the number of Glue data processing units (DPUs) that can be allocated when this job runs.
-
#max_retries ⇒ Integer
The maximum number of times to retry this job after a JobRun fails.
-
#name ⇒ String
The name you assign to this job definition.
-
#non_overridable_arguments ⇒ Hash<String,String>
Non-overridable arguments for this job, specified as name-value pairs.
-
#notification_property ⇒ Types::NotificationProperty
Specifies configuration properties of a job notification.
-
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when a job runs.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with this job.
-
#security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used with this job.
-
#timeout ⇒ Integer
The job timeout in minutes.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when a job runs.
Instance Attribute Details
#allocated_capacity ⇒ Integer
This field is deprecated. Use `MaxCapacity` instead.
The number of Glue data processing units (DPUs) allocated to runs of this job. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#code_gen_configuration_nodes ⇒ Hash<String,Types::CodeGenConfigurationNode>
The representation of a directed acyclic graph on which both the Glue Studio visual component and Glue Studio code generation is based.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#command ⇒ Types::JobCommand
The `JobCommand` that runs this job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#connections ⇒ Types::ConnectionsList
The connections used for this job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#created_on ⇒ Time
The time and date that this job definition was created.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#default_arguments ⇒ Hash<String,String>
The default arguments for this job, specified as name-value pairs.
You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.
For information about how to specify and consume your own Job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.
For information about the key-value pairs that Glue consumes to set up your job, see the [Special Parameters Used by Glue] topic in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#description ⇒ String
A description of the job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#execution_property ⇒ Types::ExecutionProperty
An `ExecutionProperty` specifying the maximum number of concurrent runs allowed for this job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for jobs of type Spark.
For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.
Jobs that are created without specifying a Glue version default to Glue 0.9.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#last_modified_on ⇒ Time
The last point in time when this job definition was modified.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#log_uri ⇒ String
This field is reserved for future use.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#max_capacity ⇒ Float
For Glue version 1.0 or earlier jobs, using the standard worker type, the number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
Do not set `Max Capacity` if using `WorkerType` and `NumberOfWorkers`.
The value that can be allocated for `MaxCapacity` depends on whether you are running a Python shell job, an Apache Spark ETL job, or an Apache Spark streaming ETL job:
-
When you specify a Python shell job (`JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.
-
When you specify an Apache Spark ETL job (`JobCommand.Name`=“glueetl”) or Apache Spark streaming ETL job (`JobCommand.Name`=“gluestreaming”), you can allocate from 2 to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.
For Glue version 2.0 jobs, you cannot instead specify a `Maximum capacity`. Instead, you should specify a `Worker type` and the `Number of workers`.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry this job after a JobRun fails.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#name ⇒ String
The name you assign to this job definition.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#non_overridable_arguments ⇒ Hash<String,String>
Non-overridable arguments for this job, specified as name-value pairs.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#notification_property ⇒ Types::NotificationProperty
Specifies configuration properties of a job notification.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when a job runs.
The maximum number of workers you can define are 299 for `G.1X`, and 149 for `G.2X`.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with this job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used with this job.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#timeout ⇒ Integer
The job timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. The default is 2,880 minutes (48 hours).
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.
-
For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.
-
For the `G.1X` worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.
-
For the `G.2X` worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.
14724 14725 14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 |
# File 'lib/aws-sdk-glue/types.rb', line 14724 class Job < Struct.new( :name, :description, :log_uri, :role, :created_on, :last_modified_on, :execution_property, :command, :default_arguments, :non_overridable_arguments, :connections, :max_retries, :allocated_capacity, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :notification_property, :glue_version, :code_gen_configuration_nodes) SENSITIVE = [:code_gen_configuration_nodes] include Aws::Structure end |