Class: Aws::Glue::Types::JobCommand
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JobCommand
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies code that runs when a job is run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the job command.
-
#python_version ⇒ String
The Python version being used to run a Python shell job.
-
#runtime ⇒ String
In Ray jobs, Runtime is used to specify the versions of Ray, Python and additional libraries available in your environment.
-
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
Instance Attribute Details
#name ⇒ String
The name of the job command. For an Apache Spark ETL job, this must be ‘glueetl`. For a Python shell job, it must be `pythonshell`. For an Apache Spark streaming ETL job, this must be `gluestreaming`. For a Ray job, this must be `glueray`.
13400 13401 13402 13403 13404 13405 13406 13407 |
# File 'lib/aws-sdk-glue/types.rb', line 13400 class JobCommand < Struct.new( :name, :script_location, :python_version, :runtime) SENSITIVE = [] include Aws::Structure end |
#python_version ⇒ String
The Python version being used to run a Python shell job. Allowed values are 2 or 3.
13400 13401 13402 13403 13404 13405 13406 13407 |
# File 'lib/aws-sdk-glue/types.rb', line 13400 class JobCommand < Struct.new( :name, :script_location, :python_version, :runtime) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
In Ray jobs, Runtime is used to specify the versions of Ray, Python and additional libraries available in your environment. This field is not used in other job types. For supported runtime environment values, see [Working with Ray jobs] in the Glue Developer Guide.
[1]: docs.aws.amazon.com/glue/latest/dg/author-job-ray-runtimes.html
13400 13401 13402 13403 13404 13405 13406 13407 |
# File 'lib/aws-sdk-glue/types.rb', line 13400 class JobCommand < Struct.new( :name, :script_location, :python_version, :runtime) SENSITIVE = [] include Aws::Structure end |
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
13400 13401 13402 13403 13404 13405 13406 13407 |
# File 'lib/aws-sdk-glue/types.rb', line 13400 class JobCommand < Struct.new( :name, :script_location, :python_version, :runtime) SENSITIVE = [] include Aws::Structure end |