Class: Aws::Glue::Types::JobCommand

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies code that runs when a job is run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the job command. For an Apache Spark ETL job, this must be ‘glueetl`. For a Python shell job, it must be `pythonshell`. For an Apache Spark streaming ETL job, this must be `gluestreaming`. For a Ray job, this must be `glueray`.

Returns:

  • (String)


12696
12697
12698
12699
12700
12701
12702
12703
# File 'lib/aws-sdk-glue/types.rb', line 12696

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#python_versionString

The Python version being used to run a Python shell job. Allowed values are 2 or 3.

Returns:

  • (String)


12696
12697
12698
12699
12700
12701
12702
12703
# File 'lib/aws-sdk-glue/types.rb', line 12696

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

In Ray jobs, Runtime is used to specify the versions of Ray, Python and additional libraries available in your environment. This field is not used in other job types. For supported runtime environment values, see [Working with Ray jobs] in the Glue Developer Guide.

[1]: docs.aws.amazon.com/glue/latest/dg/author-job-ray-runtimes.html

Returns:

  • (String)


12696
12697
12698
12699
12700
12701
12702
12703
# File 'lib/aws-sdk-glue/types.rb', line 12696

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#script_locationString

Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.

Returns:

  • (String)


12696
12697
12698
12699
12700
12701
12702
12703
# File 'lib/aws-sdk-glue/types.rb', line 12696

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end