Class: Aws::Glue::Types::JobCommand
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JobCommand
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies code that runs when a job is run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the job command.
-
#python_version ⇒ String
The Python version being used to run a Python shell job.
-
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
Instance Attribute Details
#name ⇒ String
The name of the job command. For an Apache Spark ETL job, this must be ‘glueetl`. For a Python shell job, it must be `pythonshell`. For an Apache Spark streaming ETL job, this must be `gluestreaming`.
12396 12397 12398 12399 12400 12401 12402 |
# File 'lib/aws-sdk-glue/types.rb', line 12396 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |
#python_version ⇒ String
The Python version being used to run a Python shell job. Allowed values are 2 or 3.
12396 12397 12398 12399 12400 12401 12402 |
# File 'lib/aws-sdk-glue/types.rb', line 12396 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
12396 12397 12398 12399 12400 12401 12402 |
# File 'lib/aws-sdk-glue/types.rb', line 12396 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |