Class: Aws::Glue::Types::JobCommand

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies code that runs when a job is run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the job command. For an Apache Spark ETL job, this must be ‘glueetl`. For a Python shell job, it must be `pythonshell`. For an Apache Spark streaming ETL job, this must be `gluestreaming`.

Returns:

  • (String)


12146
12147
12148
12149
12150
12151
12152
# File 'lib/aws-sdk-glue/types.rb', line 12146

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version)
  SENSITIVE = []
  include Aws::Structure
end

#python_versionString

The Python version being used to run a Python shell job. Allowed values are 2 or 3.

Returns:

  • (String)


12146
12147
12148
12149
12150
12151
12152
# File 'lib/aws-sdk-glue/types.rb', line 12146

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version)
  SENSITIVE = []
  include Aws::Structure
end

#script_locationString

Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.

Returns:

  • (String)


12146
12147
12148
12149
12150
12151
12152
# File 'lib/aws-sdk-glue/types.rb', line 12146

class JobCommand < Struct.new(
  :name,
  :script_location,
  :python_version)
  SENSITIVE = []
  include Aws::Structure
end