Class: Aws::Glue::Types::JobCommand
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JobCommand
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass JobCommand data as a hash:
{
name: "GenericString",
script_location: "ScriptLocationString",
python_version: "PythonVersionString",
}
Specifies code that runs when a job is run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the job command.
-
#python_version ⇒ String
The Python version being used to run a Python shell job.
-
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
Instance Attribute Details
#name ⇒ String
The name of the job command. For an Apache Spark ETL job, this must be `glueetl`. For a Python shell job, it must be `pythonshell`. For an Apache Spark streaming ETL job, this must be `gluestreaming`.
11385 11386 11387 11388 11389 11390 11391 |
# File 'lib/aws-sdk-glue/types.rb', line 11385 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |
#python_version ⇒ String
The Python version being used to run a Python shell job. Allowed values are 2 or 3.
11385 11386 11387 11388 11389 11390 11391 |
# File 'lib/aws-sdk-glue/types.rb', line 11385 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |
#script_location ⇒ String
Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that runs a job.
11385 11386 11387 11388 11389 11390 11391 |
# File 'lib/aws-sdk-glue/types.rb', line 11385 class JobCommand < Struct.new( :name, :script_location, :python_version) SENSITIVE = [] include Aws::Structure end |