Class: Aws::Glue::Types::JobRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::JobRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains information about a job run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_capacity ⇒ Integer
This field is deprecated.
-
#arguments ⇒ Hash<String,String>
The job arguments associated with this run.
-
#attempt ⇒ Integer
The number of the attempt to run this job.
-
#completed_on ⇒ Time
The date and time that this job run completed.
-
#dpu_seconds ⇒ Float
This field populates only for Auto Scaling job runs, and represents the total time each executor ran during the lifecycle of a job run in seconds, multiplied by a DPU factor (1 for `G.1X`, 2 for `G.2X`, or 0.25 for `G.025X` workers).
-
#error_message ⇒ String
An error message associated with this job run.
-
#execution_class ⇒ String
Indicates whether the job is run with a standard or flexible execution class.
-
#execution_time ⇒ Integer
The amount of time (in seconds) that the job run consumed resources.
-
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#id ⇒ String
The ID of this job run.
-
#job_name ⇒ String
The name of the job definition being used in this run.
-
#job_run_state ⇒ String
The current state of the job run.
-
#last_modified_on ⇒ Time
The last time that this job run was modified.
-
#log_group_name ⇒ String
The name of the log group for secure logging that can be server-side encrypted in Amazon CloudWatch using KMS.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when this job runs.
-
#notification_property ⇒ Types::NotificationProperty
Specifies configuration properties of a job run notification.
-
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when a job runs.
-
#predecessor_runs ⇒ Array<Types::Predecessor>
A list of predecessors to this job run.
-
#previous_run_id ⇒ String
The ID of the previous run of this job.
-
#security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used with this job run.
-
#started_on ⇒ Time
The date and time at which this job run was started.
-
#timeout ⇒ Integer
The `JobRun` timeout in minutes.
-
#trigger_name ⇒ String
The name of the trigger that started this job run.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when a job runs.
Instance Attribute Details
#allocated_capacity ⇒ Integer
This field is deprecated. Use `MaxCapacity` instead.
The number of Glue data processing units (DPUs) allocated to this JobRun. From 2 to 100 DPUs can be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#arguments ⇒ Hash<String,String>
The job arguments associated with this run. For this job run, they replace the default arguments set in the job definition itself.
You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.
For information about how to specify and consume your own job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.
For information about the key-value pairs that Glue consumes to set up your job, see the [Special Parameters Used by Glue] topic in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#attempt ⇒ Integer
The number of the attempt to run this job.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time that this job run completed.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#dpu_seconds ⇒ Float
This field populates only for Auto Scaling job runs, and represents the total time each executor ran during the lifecycle of a job run in seconds, multiplied by a DPU factor (1 for `G.1X`, 2 for `G.2X`, or 0.25 for `G.025X` workers). This value may be different than the `executionEngineRuntime` * `MaxCapacity` as in the case of Auto Scaling jobs, as the number of executors running at a given time may be less than the `MaxCapacity`. Therefore, it is possible that the value of `DPUSeconds` is less than `executionEngineRuntime` * `MaxCapacity`.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
An error message associated with this job run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#execution_class ⇒ String
Indicates whether the job is run with a standard or flexible execution class. The standard execution-class is ideal for time-sensitive workloads that require fast job startup and dedicated resources.
The flexible execution class is appropriate for time-insensitive jobs whose start and completion times may vary.
Only jobs with Glue version 3.0 and above and command type `glueetl` will be allowed to set `ExecutionClass` to `FLEX`. The flexible execution class is available for Spark jobs.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#execution_time ⇒ Integer
The amount of time (in seconds) that the job run consumed resources.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for jobs of type Spark.
For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.
Jobs that are created without specifying a Glue version default to Glue 0.9.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of this job run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name of the job definition being used in this run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#job_run_state ⇒ String
The current state of the job run. For more information about the statuses of jobs that have terminated abnormally, see [Glue Job Run Statuses].
[1]: docs.aws.amazon.com/glue/latest/dg/job-run-statuses.html
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
The last time that this job run was modified.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group for secure logging that can be server-side encrypted in Amazon CloudWatch using KMS. This name can be `/aws-glue/jobs/`, in which case the default encryption is `NONE`. If you add a role name and `SecurityConfiguration` name (in other words, `/aws-glue/jobs-yourRoleName-yourSecurityConfigurationName/`), then that security configuration is used to encrypt the log group.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
Do not set `Max Capacity` if using `WorkerType` and `NumberOfWorkers`.
The value that can be allocated for `MaxCapacity` depends on whether you are running a Python shell job or an Apache Spark ETL job:
-
When you specify a Python shell job (`JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.
-
When you specify an Apache Spark ETL job (`JobCommand.Name`=“glueetl”), you can allocate a minimum of 2 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#notification_property ⇒ Types::NotificationProperty
Specifies configuration properties of a job run notification.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when a job runs.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#predecessor_runs ⇒ Array<Types::Predecessor>
A list of predecessors to this job run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#previous_run_id ⇒ String
The ID of the previous run of this job. For example, the `JobRunId` specified in the `StartJobRun` action.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The name of the `SecurityConfiguration` structure to be used with this job run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time at which this job run was started.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The `JobRun` timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. This value overrides the timeout value set in the parent job.
Streaming jobs do not have a timeout. The default for non-streaming jobs is 2,880 minutes (48 hours).
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#trigger_name ⇒ String
The name of the trigger that started this job run.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, G.2X, or G.025X.
-
For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.
-
For the `G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.
-
For the `G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.
-
For the `G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.
11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 |
# File 'lib/aws-sdk-glue/types.rb', line 11897 class JobRun < Struct.new( :id, :attempt, :previous_run_id, :trigger_name, :job_name, :started_on, :last_modified_on, :completed_on, :job_run_state, :arguments, :error_message, :predecessor_runs, :allocated_capacity, :execution_time, :timeout, :max_capacity, :worker_type, :number_of_workers, :security_configuration, :log_group_name, :notification_property, :glue_version, :dpu_seconds, :execution_class) SENSITIVE = [] include Aws::Structure end |