Class: Aws::Glue::Types::JobRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Contains information about a job run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_capacityInteger

This field is deprecated. Use `MaxCapacity` instead.

The number of Glue data processing units (DPUs) allocated to this JobRun. From 2 to 100 DPUs can be allocated; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Integer)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#argumentsHash<String,String>

The job arguments associated with this run. For this job run, they replace the default arguments set in the job definition itself.

You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.

For information about how to specify and consume your own job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.

For information about the key-value pairs that Glue consumes to set up your job, see the [Special Parameters Used by Glue] topic in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html

Returns:

  • (Hash<String,String>)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#attemptInteger

The number of the attempt to run this job.

Returns:

  • (Integer)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#completed_onTime

The date and time that this job run completed.

Returns:

  • (Time)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

An error message associated with this job run.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#execution_timeInteger

The amount of time (in seconds) that the job run consumed resources.

Returns:

  • (Integer)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for jobs of type Spark.

For more information about the available Glue versions and corresponding Spark and Python versions, see [Glue version] in the developer guide.

Jobs that are created without specifying a Glue version default to Glue 0.9.

[1]: docs.aws.amazon.com/glue/latest/dg/add-job.html

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of this job run.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job definition being used in this run.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#job_run_stateString

The current state of the job run. For more information about the statuses of jobs that have terminated abnormally, see [Glue Job Run Statuses].

[1]: docs.aws.amazon.com/glue/latest/dg/job-run-statuses.html

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_onTime

The last time that this job run was modified.

Returns:

  • (Time)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group for secure logging that can be server-side encrypted in Amazon CloudWatch using KMS. This name can be `/aws-glue/jobs/`, in which case the default encryption is `NONE`. If you add a role name and `SecurityConfiguration` name (in other words, `/aws-glue/jobs-yourRoleName-yourSecurityConfigurationName/`), then that security configuration is used to encrypt the log group.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

Do not set `Max Capacity` if using `WorkerType` and `NumberOfWorkers`.

The value that can be allocated for `MaxCapacity` depends on whether you are running a Python shell job or an Apache Spark ETL job:

  • When you specify a Python shell job (`JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.

  • When you specify an Apache Spark ETL job (`JobCommand.Name`=“glueetl”), you can allocate from 2 to 100 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#notification_propertyTypes::NotificationProperty

Specifies configuration properties of a job run notification.



11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined `workerType` that are allocated when a job runs.

The maximum number of workers you can define are 299 for `G.1X`, and 149 for `G.2X`.

Returns:

  • (Integer)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#predecessor_runsArray<Types::Predecessor>

A list of predecessors to this job run.

Returns:



11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#previous_run_idString

The ID of the previous run of this job. For example, the `JobRunId` specified in the `StartJobRun` action.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the `SecurityConfiguration` structure to be used with this job run.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#started_onTime

The date and time at which this job run was started.

Returns:

  • (Time)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The `JobRun` timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. The default is 2,880 minutes (48 hours). This overrides the timeout value set in the parent job.

Returns:

  • (Integer)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_nameString

The name of the trigger that started this job run.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X.

  • For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the `G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the `G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

Returns:

  • (String)


11271
11272
11273
11274
11275
11276
11277
11278
11279
11280
11281
11282
11283
11284
11285
11286
11287
11288
11289
11290
11291
11292
11293
11294
11295
11296
# File 'lib/aws-sdk-glue/types.rb', line 11271

class JobRun < Struct.new(
  :id,
  :attempt,
  :previous_run_id,
  :trigger_name,
  :job_name,
  :started_on,
  :last_modified_on,
  :completed_on,
  :job_run_state,
  :arguments,
  :error_message,
  :predecessor_runs,
  :allocated_capacity,
  :execution_time,
  :timeout,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :security_configuration,
  :log_group_name,
  :notification_property,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end