Class: Aws::Glue::Types::Join
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Join
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass Join data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
join_type: "equijoin", # required, accepts equijoin, left, right, outer, leftsemi, leftanti
columns: [ # required
{
from: "EnclosedInStringProperty", # required
keys: [ # required
["EnclosedInStringProperty"],
],
},
],
}
Specifies a transform that joins two datasets into one dataset using a comparison phrase on the specified data property keys. You can use inner, outer, left, right, left semi, and left anti joins.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#columns ⇒ Array<Types::JoinColumn>
A list of the two columns to be joined.
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#join_type ⇒ String
Specifies the type of join to be performed on the datasets.
-
#name ⇒ String
The name of the transform node.
Instance Attribute Details
#columns ⇒ Array<Types::JoinColumn>
A list of the two columns to be joined.
16152 16153 16154 16155 16156 16157 16158 16159 |
# File 'lib/aws-sdk-glue/types.rb', line 16152 class Join < Struct.new( :name, :inputs, :join_type, :columns) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The data inputs identified by their node names.
16152 16153 16154 16155 16156 16157 16158 16159 |
# File 'lib/aws-sdk-glue/types.rb', line 16152 class Join < Struct.new( :name, :inputs, :join_type, :columns) SENSITIVE = [] include Aws::Structure end |