Class: Aws::Glue::Types::KafkaStreamingSourceOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Additional options for streaming.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_record_timestampString

When this option is set to ‘true’, the data output will contain an additional column named “_srctimestamp” that indicates the time when the corresponding record received by the topic. The default value is ‘false’. This option is supported in Glue version 4.0 or later.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#assignString

The specific ‘TopicPartitions` to consume. You must specify at least one of `“topicName”`, `“assign”` or `“subscribePattern”`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#bootstrap_serversString

A list of bootstrap server URLs, for example, as ‘b-1.vpc-test-2.o4q88o.c6.kafka.us-east-1.amazonaws.com:9094`. This option must be specified in the API call or defined in the table metadata in the Data Catalog.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#classificationString

An optional classification.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#connection_nameString

The name of the connection.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#delimiterString

Specifies the delimiter character.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#emit_consumer_lag_metricsString

When this option is set to ‘true’, for each batch, it will emit the metrics for the duration between the oldest record received by the topic and the time it arrives in Glue to CloudWatch. The metric’s name is “glue.driver.streaming.maxConsumerLagInMs”. The default value is ‘false’. This option is supported in Glue version 4.0 or later.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#ending_offsetsString

The end point when a batch query is ended. Possible values are either ‘“latest”` or a JSON string that specifies an ending offset for each `TopicPartition`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#include_headersBoolean

Whether to include the Kafka headers. When the option is set to “true”, the data output will contain an additional column named “glue_streaming_kafka_headers” with type ‘Array[Struct(key: String, value: String)]`. The default value is “false”. This option is available in Glue version 3.0 or later only.

Returns:

  • (Boolean)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#max_offsets_per_triggerInteger

The rate limit on the maximum number of offsets that are processed per trigger interval. The specified total number of offsets is proportionally split across ‘topicPartitions` of different volumes. The default value is null, which means that the consumer reads all offsets until the known latest offset.

Returns:

  • (Integer)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#min_partitionsInteger

The desired minimum number of partitions to read from Kafka. The default value is null, which means that the number of spark partitions is equal to the number of Kafka partitions.

Returns:

  • (Integer)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#num_retriesInteger

The number of times to retry before failing to fetch Kafka offsets. The default value is ‘3`.

Returns:

  • (Integer)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#poll_timeout_msInteger

The timeout in milliseconds to poll data from Kafka in Spark job executors. The default value is ‘512`.

Returns:

  • (Integer)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#retry_interval_msInteger

The time in milliseconds to wait before retrying to fetch Kafka offsets. The default value is ‘10`.

Returns:

  • (Integer)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#security_protocolString

The protocol used to communicate with brokers. The possible values are ‘“SSL”` or `“PLAINTEXT”`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#starting_offsetsString

The starting position in the Kafka topic to read data from. The possible values are ‘“earliest”` or `“latest”`. The default value is `“latest”`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#subscribe_patternString

A Java regex string that identifies the topic list to subscribe to. You must specify at least one of ‘“topicName”`, `“assign”` or `“subscribePattern”`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end

#topic_nameString

The topic name as specified in Apache Kafka. You must specify at least one of ‘“topicName”`, `“assign”` or `“subscribePattern”`.

Returns:

  • (String)


12826
12827
12828
12829
12830
12831
12832
12833
12834
12835
12836
12837
12838
12839
12840
12841
12842
12843
12844
12845
12846
12847
# File 'lib/aws-sdk-glue/types.rb', line 12826

class KafkaStreamingSourceOptions < Struct.new(
  :bootstrap_servers,
  :security_protocol,
  :connection_name,
  :topic_name,
  :assign,
  :subscribe_pattern,
  :classification,
  :delimiter,
  :starting_offsets,
  :ending_offsets,
  :poll_timeout_ms,
  :num_retries,
  :retry_interval_ms,
  :max_offsets_per_trigger,
  :min_partitions,
  :include_headers,
  :add_record_timestamp,
  :emit_consumer_lag_metrics)
  SENSITIVE = []
  include Aws::Structure
end