Class: Aws::Glue::Types::LakeFormationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass LakeFormationConfiguration data as a hash:

{
  use_lake_formation_credentials: false,
  account_id: "AccountId",
}

Specifies Lake Formation configuration settings for the crawler.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

Required for cross account crawls. For same account crawls as the target data, this can be left as null.

Returns:

  • (String)


16541
16542
16543
16544
16545
16546
# File 'lib/aws-sdk-glue/types.rb', line 16541

class LakeFormationConfiguration < Struct.new(
  :use_lake_formation_credentials,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end

#use_lake_formation_credentialsBoolean

Specifies whether to use Lake Formation credentials for the crawler instead of the IAM role credentials.

Returns:

  • (Boolean)


16541
16542
16543
16544
16545
16546
# File 'lib/aws-sdk-glue/types.rb', line 16541

class LakeFormationConfiguration < Struct.new(
  :use_lake_formation_credentials,
  :account_id)
  SENSITIVE = []
  include Aws::Structure
end