Class: Aws::Glue::Types::ListEntitiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListEntitiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The catalog ID of the catalog that contains the connection.
-
#connection_name ⇒ String
A name for the connection that has required credentials to query any connection type.
-
#data_store_api_version ⇒ String
The API version of the SaaS connector.
-
#next_token ⇒ String
A continuation token, included if this is a continuation call.
-
#parent_entity_name ⇒ String
Name of the parent entity for which you want to list the children.
Instance Attribute Details
#catalog_id ⇒ String
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
20188 20189 20190 20191 20192 20193 20194 20195 20196 |
# File 'lib/aws-sdk-glue/types.rb', line 20188 class ListEntitiesRequest < Struct.new( :connection_name, :catalog_id, :parent_entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
A name for the connection that has required credentials to query any connection type.
20188 20189 20190 20191 20192 20193 20194 20195 20196 |
# File 'lib/aws-sdk-glue/types.rb', line 20188 class ListEntitiesRequest < Struct.new( :connection_name, :catalog_id, :parent_entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#data_store_api_version ⇒ String
The API version of the SaaS connector.
20188 20189 20190 20191 20192 20193 20194 20195 20196 |
# File 'lib/aws-sdk-glue/types.rb', line 20188 class ListEntitiesRequest < Struct.new( :connection_name, :catalog_id, :parent_entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, included if this is a continuation call.
20188 20189 20190 20191 20192 20193 20194 20195 20196 |
# File 'lib/aws-sdk-glue/types.rb', line 20188 class ListEntitiesRequest < Struct.new( :connection_name, :catalog_id, :parent_entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |
#parent_entity_name ⇒ String
Name of the parent entity for which you want to list the children. This parameter takes a fully-qualified path of the entity in order to list the child entities.
20188 20189 20190 20191 20192 20193 20194 20195 20196 |
# File 'lib/aws-sdk-glue/types.rb', line 20188 class ListEntitiesRequest < Struct.new( :connection_name, :catalog_id, :parent_entity_name, :next_token, :data_store_api_version) SENSITIVE = [] include Aws::Structure end |