Class: Aws::Glue::Types::ListGlossaryTermsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListGlossaryTermsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glossary_identifier ⇒ String
The unique identifier of the glossary whose terms to list.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
Instance Attribute Details
#glossary_identifier ⇒ String
The unique identifier of the glossary whose terms to list.
22029 22030 22031 22032 22033 22034 22035 |
# File 'lib/aws-sdk-glue/types.rb', line 22029 class ListGlossaryTermsRequest < Struct.new( :glossary_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
22029 22030 22031 22032 22033 22034 22035 |
# File 'lib/aws-sdk-glue/types.rb', line 22029 class ListGlossaryTermsRequest < Struct.new( :glossary_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
22029 22030 22031 22032 22033 22034 22035 |
# File 'lib/aws-sdk-glue/types.rb', line 22029 class ListGlossaryTermsRequest < Struct.new( :glossary_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |