Class: Aws::Glue::Types::ListIntegrationTablePropertiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListIntegrationTablePropertiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::IntegrationTablePropertiesFilter>
A list of filters.
-
#marker ⇒ String
The pagination token for the next page of results.
-
#max_records ⇒ Integer
The maximum number of records to return in the response.
Instance Attribute Details
#filters ⇒ Array<Types::IntegrationTablePropertiesFilter>
A list of filters. Supported filter keys are SourceArn,
TargetArn, SourceTableName, and TargetTableName.
22111 22112 22113 22114 22115 22116 22117 |
# File 'lib/aws-sdk-glue/types.rb', line 22111 class ListIntegrationTablePropertiesRequest < Struct.new( :marker, :filters, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The pagination token for the next page of results. The initial value
is null.
22111 22112 22113 22114 22115 22116 22117 |
# File 'lib/aws-sdk-glue/types.rb', line 22111 class ListIntegrationTablePropertiesRequest < Struct.new( :marker, :filters, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to return in the response.
22111 22112 22113 22114 22115 22116 22117 |
# File 'lib/aws-sdk-glue/types.rb', line 22111 class ListIntegrationTablePropertiesRequest < Struct.new( :marker, :filters, :max_records) SENSITIVE = [] include Aws::Structure end |