Class: Aws::Glue::Types::ListTriggersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dependent_job_nameString

The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned.

Returns:

  • (String)


20698
20699
20700
20701
20702
20703
20704
20705
# File 'lib/aws-sdk-glue/types.rb', line 20698

class ListTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum size of a list to return.

Returns:

  • (Integer)


20698
20699
20700
20701
20702
20703
20704
20705
# File 'lib/aws-sdk-glue/types.rb', line 20698

class ListTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation request.

Returns:

  • (String)


20698
20699
20700
20701
20702
20703
20704
20705
# File 'lib/aws-sdk-glue/types.rb', line 20698

class ListTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Specifies to return only these tagged resources.

Returns:

  • (Hash<String,String>)


20698
20699
20700
20701
20702
20703
20704
20705
# File 'lib/aws-sdk-glue/types.rb', line 20698

class ListTriggersRequest < Struct.new(
  :next_token,
  :dependent_job_name,
  :max_results,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end