Class: Aws::Glue::Types::ListTriggersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ListTriggersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependent_job_name ⇒ String
The name of the job for which to retrieve triggers.
-
#max_results ⇒ Integer
The maximum size of a list to return.
-
#next_token ⇒ String
A continuation token, if this is a continuation request.
-
#tags ⇒ Hash<String,String>
Specifies to return only these tagged resources.
Instance Attribute Details
#dependent_job_name ⇒ String
The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned.
20698 20699 20700 20701 20702 20703 20704 20705 |
# File 'lib/aws-sdk-glue/types.rb', line 20698 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum size of a list to return.
20698 20699 20700 20701 20702 20703 20704 20705 |
# File 'lib/aws-sdk-glue/types.rb', line 20698 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation request.
20698 20699 20700 20701 20702 20703 20704 20705 |
# File 'lib/aws-sdk-glue/types.rb', line 20698 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Specifies to return only these tagged resources.
20698 20699 20700 20701 20702 20703 20704 20705 |
# File 'lib/aws-sdk-glue/types.rb', line 20698 class ListTriggersRequest < Struct.new( :next_token, :dependent_job_name, :max_results, :tags) SENSITIVE = [] include Aws::Structure end |