Class: Aws::Glue::Types::MLTransform
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::MLTransform
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure for a machine learning transform.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_on ⇒ Time
A timestamp.
-
#description ⇒ String
A user-defined, long-form description text for the machine learning transform.
-
#evaluation_metrics ⇒ Types::EvaluationMetrics
An ‘EvaluationMetrics` object.
-
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with.
-
#input_record_tables ⇒ Array<Types::GlueTable>
A list of Glue table definitions used by the transform.
-
#label_count ⇒ Integer
A count identifier for the labeling files generated by Glue for this transform.
-
#last_modified_on ⇒ Time
A timestamp.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform.
-
#max_retries ⇒ Integer
The maximum number of times to retry after an ‘MLTaskRun` of the machine learning transform fails.
-
#name ⇒ String
A user-defined name for the machine learning transform.
-
#number_of_workers ⇒ Integer
The number of workers of a defined ‘workerType` that are allocated when a task of the transform runs.
-
#parameters ⇒ Types::TransformParameters
A ‘TransformParameters` object.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
-
#schema ⇒ Array<Types::SchemaColumn>
A map of key-value pairs representing the columns and data types that this transform can run against.
-
#status ⇒ String
The current status of the machine learning transform.
-
#timeout ⇒ Integer
The timeout in minutes of the machine learning transform.
-
#transform_encryption ⇒ Types::TransformEncryption
The encryption-at-rest settings of the transform that apply to accessing user data.
-
#transform_id ⇒ String
The unique transform ID that is generated for the machine learning transform.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when a task of this transform runs.
Instance Attribute Details
#created_on ⇒ Time
A timestamp. The time and date that this machine learning transform was created.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A user-defined, long-form description text for the machine learning transform. Descriptions are not guaranteed to be unique and can be changed at any time.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#evaluation_metrics ⇒ Types::EvaluationMetrics
An ‘EvaluationMetrics` object. Evaluation metrics provide an estimate of the quality of your machine learning transform.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#input_record_tables ⇒ Array<Types::GlueTable>
A list of Glue table definitions used by the transform.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#label_count ⇒ Integer
A count identifier for the labeling files generated by Glue for this transform. As you create a better transform, you can iteratively download, label, and upload the labeling file.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
A timestamp. The last point in time when this machine learning transform was modified.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
‘MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.
-
If either ‘NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.
-
If ‘MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.
-
If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).
-
‘MaxCapacity` and `NumberOfWorkers` must both be at least 1.
When the ‘WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry after an ‘MLTaskRun` of the machine learning transform fails.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-defined name for the machine learning transform. Names are not guaranteed unique and can be changed at any time.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined ‘workerType` that are allocated when a task of the transform runs.
If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::TransformParameters
A ‘TransformParameters` object. You can use parameters to tune (customize) the behavior of the machine learning transform by specifying what data it learns from and your preference on various tradeoffs (such as precious vs. recall, or accuracy vs. cost).
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions. The required permissions include both Glue service role permissions to Glue resources, and Amazon S3 permissions required by the transform.
-
This role needs Glue service role permissions to allow access to resources in Glue. See [Attach a Policy to IAM Users That Access Glue].
-
This role needs permission to your Amazon Simple Storage Service (Amazon S3) sources, targets, temporary directory, scripts, and any libraries used by the task run for this transform.
[1]: docs.aws.amazon.com/glue/latest/dg/attach-policy-iam-user.html
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ Array<Types::SchemaColumn>
A map of key-value pairs representing the columns and data types that this transform can run against. Has an upper bound of 100 columns.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the machine learning transform.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout in minutes of the machine learning transform.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#transform_encryption ⇒ Types::TransformEncryption
The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#transform_id ⇒ String
The unique transform ID that is generated for the machine learning transform. The ID is guaranteed to be unique and does not change.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when a task of this transform runs. Accepts a value of Standard, G.1X, or G.2X.
-
For the ‘Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.
-
For the ‘G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.
-
For the ‘G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.
‘MaxCapacity` is a mutually exclusive option with `NumberOfWorkers` and `WorkerType`.
-
If either ‘NumberOfWorkers` or `WorkerType` is set, then `MaxCapacity` cannot be set.
-
If ‘MaxCapacity` is set then neither `NumberOfWorkers` or `WorkerType` can be set.
-
If ‘WorkerType` is set, then `NumberOfWorkers` is required (and vice versa).
-
‘MaxCapacity` and `NumberOfWorkers` must both be at least 1.
14638 14639 14640 14641 14642 14643 14644 14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 |
# File 'lib/aws-sdk-glue/types.rb', line 14638 class MLTransform < Struct.new( :transform_id, :name, :description, :status, :created_on, :last_modified_on, :input_record_tables, :parameters, :evaluation_metrics, :label_count, :schema, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries, :transform_encryption) SENSITIVE = [] include Aws::Structure end |