Class: Aws::Glue::Types::Mapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Mapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies the mapping of data property keys.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#children ⇒ Array<Types::Mapping>
Only applicable to nested data structures.
-
#dropped ⇒ Boolean
If true, then the column is removed.
-
#from_path ⇒ Array<String>
The table or column to be modified.
-
#from_type ⇒ String
The type of the data to be modified.
-
#to_key ⇒ String
After the apply mapping, what the name of the column should be.
-
#to_type ⇒ String
The data type that the data is to be modified to.
Instance Attribute Details
#children ⇒ Array<Types::Mapping>
Only applicable to nested data structures. If you want to change the parent structure, but also one of its children, you can fill out this data strucutre. It is also ‘Mapping`, but its `FromPath` will be the parent’s ‘FromPath` plus the `FromPath` from this structure.
For the children part, suppose you have the structure:
‘{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`
You can specify a ‘Mapping` that looks like:
‘{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |
#dropped ⇒ Boolean
If true, then the column is removed.
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |
#from_path ⇒ Array<String>
The table or column to be modified.
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |
#from_type ⇒ String
The type of the data to be modified.
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |
#to_key ⇒ String
After the apply mapping, what the name of the column should be. Can be the same as ‘FromPath`.
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |
#to_type ⇒ String
The data type that the data is to be modified to.
14902 14903 14904 14905 14906 14907 14908 14909 14910 14911 |
# File 'lib/aws-sdk-glue/types.rb', line 14902 class Mapping < Struct.new( :to_key, :from_path, :from_type, :to_type, :dropped, :children) SENSITIVE = [] include Aws::Structure end |