Class: Aws::Glue::Types::Mapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies the mapping of data property keys.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#childrenArray<Types::Mapping>

Only applicable to nested data structures. If you want to change the parent structure, but also one of its children, you can fill out this data strucutre. It is also ‘Mapping`, but its `FromPath` will be the parent’s ‘FromPath` plus the `FromPath` from this structure.

For the children part, suppose you have the structure:

‘{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`

You can specify a ‘Mapping` that looks like:

‘{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`

Returns:



14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#droppedBoolean

If true, then the column is removed.

Returns:

  • (Boolean)


14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#from_pathArray<String>

The table or column to be modified.

Returns:

  • (Array<String>)


14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#from_typeString

The type of the data to be modified.

Returns:

  • (String)


14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#to_keyString

After the apply mapping, what the name of the column should be. Can be the same as ‘FromPath`.

Returns:

  • (String)


14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#to_typeString

The data type that the data is to be modified to.

Returns:

  • (String)


14493
14494
14495
14496
14497
14498
14499
14500
14501
14502
# File 'lib/aws-sdk-glue/types.rb', line 14493

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end