Class: Aws::Glue::Types::Mapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass Mapping data as a hash:

{
  to_key: "EnclosedInStringProperty",
  from_path: ["EnclosedInStringProperty"],
  from_type: "EnclosedInStringProperty",
  to_type: "EnclosedInStringProperty",
  dropped: false,
  children: [
    {
      to_key: "EnclosedInStringProperty",
      from_path: ["EnclosedInStringProperty"],
      from_type: "EnclosedInStringProperty",
      to_type: "EnclosedInStringProperty",
      dropped: false,
      children: {
        # recursive Mappings
      },
    },
  ],
}

Specifies the mapping of data property keys.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#childrenArray<Types::Mapping>

Only applicable to nested data structures. If you want to change the parent structure, but also one of its children, you can fill out this data strucutre. It is also `Mapping`, but its `FromPath` will be the parent's `FromPath` plus the `FromPath` from this structure.

For the children part, suppose you have the structure:

`{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`

You can specify a `Mapping` that looks like:

`{ “FromPath”: “OuterStructure”, “ToKey”: “OuterStructure”, “ToType”: “Struct”, “Dropped”: false, “Chidlren”: [{ “FromPath”: “inner”, “ToKey”: “inner”, “ToType”: “Double”, “Dropped”: false, }] }`

Returns:



17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#droppedBoolean

If true, then the column is removed.

Returns:

  • (Boolean)


17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#from_pathArray<String>

The table or column to be modified.

Returns:

  • (Array<String>)


17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#from_typeString

The type of the data to be modified.

Returns:

  • (String)


17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#to_keyString

After the apply mapping, what the name of the column should be. Can be the same as `FromPath`.

Returns:

  • (String)


17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end

#to_typeString

The data type that the data is to be modified to.

Returns:

  • (String)


17908
17909
17910
17911
17912
17913
17914
17915
17916
17917
# File 'lib/aws-sdk-glue/types.rb', line 17908

class Mapping < Struct.new(
  :to_key,
  :from_path,
  :from_type,
  :to_type,
  :dropped,
  :children)
  SENSITIVE = []
  include Aws::Structure
end