Class: Aws::Glue::Types::Merge
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Merge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that merges a `DynamicFrame` with a staging `DynamicFrame` based on the specified primary keys to identify records. Duplicate records (records with the same primary keys) are not de-duplicated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
-
#source ⇒ String
The source `DynamicFrame` that will be merged with a staging `DynamicFrame`.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
13841 13842 13843 13844 13845 13846 13847 13848 |
# File 'lib/aws-sdk-glue/types.rb', line 13841 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
13841 13842 13843 13844 13845 13846 13847 13848 |
# File 'lib/aws-sdk-glue/types.rb', line 13841 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
13841 13842 13843 13844 13845 13846 13847 13848 |
# File 'lib/aws-sdk-glue/types.rb', line 13841 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |