Class: Aws::Glue::Types::Merge
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Merge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass Merge data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
source: "NodeId", # required
primary_keys: [ # required
["EnclosedInStringProperty"],
],
}
Specifies a transform that merges a `DynamicFrame` with a staging `DynamicFrame` based on the specified primary keys to identify records. Duplicate records (records with the same primary keys) are not de-duplicated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
-
#source ⇒ String
The source `DynamicFrame` that will be merged with a staging `DynamicFrame`.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
17772 17773 17774 17775 17776 17777 17778 17779 |
# File 'lib/aws-sdk-glue/types.rb', line 17772 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
17772 17773 17774 17775 17776 17777 17778 17779 |
# File 'lib/aws-sdk-glue/types.rb', line 17772 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |
#primary_keys ⇒ Array<Array<String>>
The list of primary key fields to match records from the source and staging dynamic frames.
17772 17773 17774 17775 17776 17777 17778 17779 |
# File 'lib/aws-sdk-glue/types.rb', line 17772 class Merge < Struct.new( :name, :inputs, :source, :primary_keys) SENSITIVE = [] include Aws::Structure end |