Class: Aws::Glue::Types::OffsetConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::OffsetConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Offset-based pagination configuration that defines how to handle pagination using numeric offsets and limits.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit_parameter ⇒ Types::ExtractedParameter
The parameter name used to specify the maximum number of results to return per page.
-
#offset_parameter ⇒ Types::ExtractedParameter
The parameter name used to specify the starting position or offset for retrieving results.
Instance Attribute Details
#limit_parameter ⇒ Types::ExtractedParameter
The parameter name used to specify the maximum number of results to return per page.
22000 22001 22002 22003 22004 22005 |
# File 'lib/aws-sdk-glue/types.rb', line 22000 class OffsetConfiguration < Struct.new( :offset_parameter, :limit_parameter) SENSITIVE = [] include Aws::Structure end |
#offset_parameter ⇒ Types::ExtractedParameter
The parameter name used to specify the starting position or offset for retrieving results.
22000 22001 22002 22003 22004 22005 |
# File 'lib/aws-sdk-glue/types.rb', line 22000 class OffsetConfiguration < Struct.new( :offset_parameter, :limit_parameter) SENSITIVE = [] include Aws::Structure end |