Class: Aws::Glue::Types::PIIDetection
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PIIDetection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that identifies, removes or masks PII data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detection_parameters ⇒ String
Additional parameters for configuring PII detection behavior and sensitivity settings.
-
#detection_sensitivity ⇒ String
The sensitivity level for PII detection.
-
#entity_types_to_detect ⇒ Array<String>
Indicates the types of entities the PIIDetection transform will identify as PII data.
-
#inputs ⇒ Array<String>
The node ID inputs to the transform.
-
#mask_value ⇒ String
Indicates the value that will replace the detected entity.
-
#match_pattern ⇒ String
A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.
-
#name ⇒ String
The name of the transform node.
-
#num_left_chars_to_exclude ⇒ Integer
The number of characters to exclude from redaction on the left side of detected PII content.
-
#num_right_chars_to_exclude ⇒ Integer
The number of characters to exclude from redaction on the right side of detected PII content.
-
#output_column_name ⇒ String
Indicates the output column name that will contain any entity type detected in that row.
-
#pii_type ⇒ String
Indicates the type of PIIDetection transform.
-
#redact_char ⇒ String
The character used to replace detected PII content when redaction is enabled.
-
#redact_text ⇒ String
Specifies whether to redact the detected PII text.
-
#sample_fraction ⇒ Float
Indicates the fraction of the data to sample when scanning for PII entities.
-
#threshold_fraction ⇒ Float
Indicates the fraction of the data that must be met in order for a column to be identified as PII data.
Instance Attribute Details
#detection_parameters ⇒ String
Additional parameters for configuring PII detection behavior and sensitivity settings.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#detection_sensitivity ⇒ String
The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#entity_types_to_detect ⇒ Array<String>
Indicates the types of entities the PIIDetection transform will identify as PII data.
PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The node ID inputs to the transform.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#mask_value ⇒ String
Indicates the value that will replace the detected entity.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#match_pattern ⇒ String
A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#num_left_chars_to_exclude ⇒ Integer
The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#num_right_chars_to_exclude ⇒ Integer
The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#output_column_name ⇒ String
Indicates the output column name that will contain any entity type detected in that row.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#pii_type ⇒ String
Indicates the type of PIIDetection transform.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#redact_char ⇒ String
The character used to replace detected PII content when redaction is enabled. The default redaction character is ‘*`.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#redact_text ⇒ String
Specifies whether to redact the detected PII text. When set to ‘true`, PII content is replaced with redaction characters.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#sample_fraction ⇒ Float
Indicates the fraction of the data to sample when scanning for PII entities.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |
#threshold_fraction ⇒ Float
Indicates the fraction of the data that must be met in order for a column to be identified as PII data.
22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 22272 22273 22274 22275 22276 22277 22278 22279 22280 |
# File 'lib/aws-sdk-glue/types.rb', line 22262 class PIIDetection < Struct.new( :name, :inputs, :pii_type, :entity_types_to_detect, :output_column_name, :sample_fraction, :threshold_fraction, :mask_value, :redact_text, :redact_char, :match_pattern, :num_left_chars_to_exclude, :num_right_chars_to_exclude, :detection_parameters, :detection_sensitivity) SENSITIVE = [] include Aws::Structure end |