Class: Aws::Glue::Types::PartitionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The structure used to create and update a partition.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_access_timeTime

The last time at which the partition was accessed.

Returns:

  • (Time)


22473
22474
22475
22476
22477
22478
22479
22480
22481
# File 'lib/aws-sdk-glue/types.rb', line 22473

class PartitionInput < Struct.new(
  :values,
  :last_access_time,
  :storage_descriptor,
  :parameters,
  :last_analyzed_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_analyzed_timeTime

The last time at which column statistics were computed for this partition.

Returns:

  • (Time)


22473
22474
22475
22476
22477
22478
22479
22480
22481
# File 'lib/aws-sdk-glue/types.rb', line 22473

class PartitionInput < Struct.new(
  :values,
  :last_access_time,
  :storage_descriptor,
  :parameters,
  :last_analyzed_time)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

These key-value pairs define partition parameters.

Returns:

  • (Hash<String,String>)


22473
22474
22475
22476
22477
22478
22479
22480
22481
# File 'lib/aws-sdk-glue/types.rb', line 22473

class PartitionInput < Struct.new(
  :values,
  :last_access_time,
  :storage_descriptor,
  :parameters,
  :last_analyzed_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_descriptorTypes::StorageDescriptor

Provides information about the physical location where the partition is stored.



22473
22474
22475
22476
22477
22478
22479
22480
22481
# File 'lib/aws-sdk-glue/types.rb', line 22473

class PartitionInput < Struct.new(
  :values,
  :last_access_time,
  :storage_descriptor,
  :parameters,
  :last_analyzed_time)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

The values of the partition. Although this parameter is not required by the SDK, you must specify this parameter for a valid input.

The values for the keys for the new partition must be passed as an array of String objects that must be ordered in the same order as the partition keys appearing in the Amazon S3 prefix. Otherwise Glue will add the values to the wrong keys.

Returns:

  • (Array<String>)


22473
22474
22475
22476
22477
22478
22479
22480
22481
# File 'lib/aws-sdk-glue/types.rb', line 22473

class PartitionInput < Struct.new(
  :values,
  :last_access_time,
  :storage_descriptor,
  :parameters,
  :last_analyzed_time)
  SENSITIVE = []
  include Aws::Structure
end