Class: Aws::Glue::Types::PartitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PartitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The structure used to create and update a partition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_access_time ⇒ Time
The last time at which the partition was accessed.
-
#last_analyzed_time ⇒ Time
The last time at which column statistics were computed for this partition.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define partition parameters.
-
#storage_descriptor ⇒ Types::StorageDescriptor
Provides information about the physical location where the partition is stored.
-
#values ⇒ Array<String>
The values of the partition.
Instance Attribute Details
#last_access_time ⇒ Time
The last time at which the partition was accessed.
15656 15657 15658 15659 15660 15661 15662 15663 15664 |
# File 'lib/aws-sdk-glue/types.rb', line 15656 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time at which column statistics were computed for this partition.
15656 15657 15658 15659 15660 15661 15662 15663 15664 |
# File 'lib/aws-sdk-glue/types.rb', line 15656 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define partition parameters.
15656 15657 15658 15659 15660 15661 15662 15663 15664 |
# File 'lib/aws-sdk-glue/types.rb', line 15656 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
Provides information about the physical location where the partition is stored.
15656 15657 15658 15659 15660 15661 15662 15663 15664 |
# File 'lib/aws-sdk-glue/types.rb', line 15656 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The values of the partition. Although this parameter is not required by the SDK, you must specify this parameter for a valid input.
The values for the keys for the new partition must be passed as an array of String objects that must be ordered in the same order as the partition keys appearing in the Amazon S3 prefix. Otherwise Glue will add the values to the wrong keys.
15656 15657 15658 15659 15660 15661 15662 15663 15664 |
# File 'lib/aws-sdk-glue/types.rb', line 15656 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |