Class: Aws::Glue::Types::PartitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PartitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass PartitionInput data as a hash:
{
values: ["ValueString"],
last_access_time: Time.now,
storage_descriptor: {
columns: [
{
name: "NameString", # required
type: "ColumnTypeString",
comment: "CommentString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
],
location: "LocationString",
additional_locations: ["LocationString"],
input_format: "FormatString",
output_format: "FormatString",
compressed: false,
number_of_buckets: 1,
serde_info: {
name: "NameString",
serialization_library: "NameString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
bucket_columns: ["NameString"],
sort_columns: [
{
column: "NameString", # required
sort_order: 1, # required
},
],
parameters: {
"KeyString" => "ParametersMapValue",
},
skewed_info: {
skewed_column_names: ["NameString"],
skewed_column_values: ["ColumnValuesString"],
skewed_column_value_location_maps: {
"ColumnValuesString" => "ColumnValuesString",
},
},
stored_as_sub_directories: false,
schema_reference: {
schema_id: {
schema_arn: "GlueResourceArn",
schema_name: "SchemaRegistryNameString",
registry_name: "SchemaRegistryNameString",
},
schema_version_id: "SchemaVersionIdString",
schema_version_number: 1,
},
},
parameters: {
"KeyString" => "ParametersMapValue",
},
last_analyzed_time: Time.now,
}
The structure used to create and update a partition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_access_time ⇒ Time
The last time at which the partition was accessed.
-
#last_analyzed_time ⇒ Time
The last time at which column statistics were computed for this partition.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define partition parameters.
-
#storage_descriptor ⇒ Types::StorageDescriptor
Provides information about the physical location where the partition is stored.
-
#values ⇒ Array<String>
The values of the partition.
Instance Attribute Details
#last_access_time ⇒ Time
The last time at which the partition was accessed.
18857 18858 18859 18860 18861 18862 18863 18864 18865 |
# File 'lib/aws-sdk-glue/types.rb', line 18857 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time at which column statistics were computed for this partition.
18857 18858 18859 18860 18861 18862 18863 18864 18865 |
# File 'lib/aws-sdk-glue/types.rb', line 18857 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define partition parameters.
18857 18858 18859 18860 18861 18862 18863 18864 18865 |
# File 'lib/aws-sdk-glue/types.rb', line 18857 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
Provides information about the physical location where the partition is stored.
18857 18858 18859 18860 18861 18862 18863 18864 18865 |
# File 'lib/aws-sdk-glue/types.rb', line 18857 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The values of the partition. Although this parameter is not required by the SDK, you must specify this parameter for a valid input.
The values for the keys for the new partition must be passed as an array of String objects that must be ordered in the same order as the partition keys appearing in the Amazon S3 prefix. Otherwise Glue will add the values to the wrong keys.
18857 18858 18859 18860 18861 18862 18863 18864 18865 |
# File 'lib/aws-sdk-glue/types.rb', line 18857 class PartitionInput < Struct.new( :values, :last_access_time, :storage_descriptor, :parameters, :last_analyzed_time) SENSITIVE = [] include Aws::Structure end |