Class: Aws::Glue::Types::Property
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Property
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
An object that defines a connection type for a compute environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<Types::AllowedValue>
A list of
AllowedValueobjects representing the values allowed for the property. -
#data_operation_scopes ⇒ Array<String>
Indicates which data operations are applicable to the property.
-
#default_value ⇒ String
The default value for the property.
-
#description ⇒ String
A description of the property.
-
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
-
#name ⇒ String
The name of the property.
-
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
-
#property_types ⇒ Array<String>
Describes the type of property.
-
#required ⇒ Boolean
Indicates whether the property is required.
Instance Attribute Details
#allowed_values ⇒ Array<Types::AllowedValue>
A list of AllowedValue objects representing the values allowed for
the property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#data_operation_scopes ⇒ Array<String>
Indicates which data operations are applicable to the property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ String
The default value for the property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#key_override ⇒ String
A key name to use when sending this property in API requests, if different from the display name.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#property_location ⇒ String
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#property_types ⇒ Array<String>
Describes the type of property.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |
#required ⇒ Boolean
Indicates whether the property is required.
24239 24240 24241 24242 24243 24244 24245 24246 24247 24248 24249 24250 24251 |
# File 'lib/aws-sdk-glue/types.rb', line 24239 class Property < Struct.new( :name, :description, :required, :default_value, :property_types, :allowed_values, :data_operation_scopes, :key_override, :property_location) SENSITIVE = [] include Aws::Structure end |