Class: Aws::Glue::Types::PropertyPredicate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PropertyPredicate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass PropertyPredicate data as a hash:
{
key: "ValueString",
value: "ValueString",
comparator: "EQUALS", # accepts EQUALS, GREATER_THAN, LESS_THAN, GREATER_THAN_EQUALS, LESS_THAN_EQUALS
}
Defines a property predicate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparator ⇒ String
The comparator used to compare this property to others.
-
#key ⇒ String
The key of the property.
-
#value ⇒ String
The value of the property.
Instance Attribute Details
#comparator ⇒ String
The comparator used to compare this property to others.
19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-glue/types.rb', line 19020 class PropertyPredicate < Struct.new( :key, :value, :comparator) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The key of the property.
19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-glue/types.rb', line 19020 class PropertyPredicate < Struct.new( :key, :value, :comparator) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the property.
19020 19021 19022 19023 19024 19025 19026 |
# File 'lib/aws-sdk-glue/types.rb', line 19020 class PropertyPredicate < Struct.new( :key, :value, :comparator) SENSITIVE = [] include Aws::Structure end |