Class: Aws::Glue::Types::PutAssetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutAssetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_type_id ⇒ String
The identifier of the asset type for the asset.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
The description of the asset.
-
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms to set on the asset, keyed by form name.
-
#identifier ⇒ String
The unique identifier of the asset.
-
#name ⇒ String
The name of the asset.
Instance Attribute Details
#asset_type_id ⇒ String
The identifier of the asset type for the asset.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the asset.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#forms ⇒ Hash<String,Types::AssetFormEntry>
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the asset.
23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-glue/types.rb', line 23976 class PutAssetRequest < Struct.new( :asset_type_id, :identifier, :name, :description, :forms, :client_token) SENSITIVE = [] include Aws::Structure end |