Class: Aws::Glue::Types::PutAssetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_type_idString

The identifier of the asset type for the asset.

Returns:

  • (String)


23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the asset.

Returns:

  • (String)


23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#formsHash<String,Types::AssetFormEntry>

The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.

Returns:



23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the asset. If an asset with this identifier already exists, it is updated.

Returns:

  • (String)


23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the asset.

Returns:

  • (String)


23963
23964
23965
23966
23967
23968
23969
23970
23971
23972
# File 'lib/aws-sdk-glue/types.rb', line 23963

class PutAssetRequest < Struct.new(
  :asset_type_id,
  :identifier,
  :name,
  :description,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end