Class: Aws::Glue::Types::PutAssetTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


24025
24026
24027
24028
24029
24030
24031
# File 'lib/aws-sdk-glue/types.rb', line 24025

class PutAssetTypeRequest < Struct.new(
  :name,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#formsHash<String,Types::AssetTypeFormReference>

The forms that make up the asset type, keyed by form name. Each entry references the form type that defines the form’s schema.

Returns:



24025
24026
24027
24028
24029
24030
24031
# File 'lib/aws-sdk-glue/types.rb', line 24025

class PutAssetTypeRequest < Struct.new(
  :name,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the asset type.

Returns:

  • (String)


24025
24026
24027
24028
24029
24030
24031
# File 'lib/aws-sdk-glue/types.rb', line 24025

class PutAssetTypeRequest < Struct.new(
  :name,
  :forms,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end