Class: Aws::Glue::Types::PutAttachmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::PutAttachmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_identifier ⇒ String
The unique identifier of the asset to attach the form to.
-
#attachment_name ⇒ String
The name of the attachment.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#content ⇒ String
The JSON content of the form, conforming to the schema of the specified form type.
-
#form_type_id ⇒ String
The identifier of the form type for this attachment.
-
#item_identifier ⇒ String
The identifier of the item within the iterable form.
-
#iterable_form_name ⇒ String
The name of the iterable form.
Instance Attribute Details
#asset_identifier ⇒ String
The unique identifier of the asset to attach the form to.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#attachment_name ⇒ String
The name of the attachment.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The JSON content of the form, conforming to the schema of the specified form type.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#form_type_id ⇒ String
The identifier of the form type for this attachment.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#item_identifier ⇒ String
The identifier of the item within the iterable form. Required when
iterableFormName is specified.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#iterable_form_name ⇒ String
The name of the iterable form. When specified along with
itemIdentifier, the attachment targets an item within the iterable
form rather than the asset itself.
24439 24440 24441 24442 24443 24444 24445 24446 24447 24448 24449 |
# File 'lib/aws-sdk-glue/types.rb', line 24439 class PutAttachmentRequest < Struct.new( :asset_identifier, :iterable_form_name, :item_identifier, :attachment_name, :content, :form_type_id, :client_token) SENSITIVE = [] include Aws::Structure end |