Class: Aws::Glue::Types::PutAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_identifierString

The unique identifier of the asset to attach the form to.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#attachment_nameString

The name of the attachment.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The JSON content of the form, conforming to the schema of the specified form type.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#form_type_idString

The identifier of the form type for this attachment.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#item_identifierString

The identifier of the item within the iterable form. Required when ‘iterableFormName` is specified.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#iterable_form_nameString

The name of the iterable form. When specified along with ‘itemIdentifier`, the attachment targets an item within the iterable form rather than the asset itself.

Returns:

  • (String)


24093
24094
24095
24096
24097
24098
24099
24100
24101
24102
24103
# File 'lib/aws-sdk-glue/types.rb', line 24093

class PutAttachmentRequest < Struct.new(
  :asset_identifier,
  :iterable_form_name,
  :item_identifier,
  :attachment_name,
  :content,
  :form_type_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end