Class: Aws::Glue::Types::PutResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_hybridString

If `'TRUE'`, indicates that you are using both methods to grant cross-account access to Data Catalog resources:

  • By directly updating the resource policy with `PutResourePolicy`

  • By using the **Grant permissions** command on the Amazon Web Services Management Console.

Must be set to `'TRUE'` if you have already used the Management Console to grant cross-account access, otherwise the call fails. Default is 'FALSE'.

Returns:

  • (String)


14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/aws-sdk-glue/types.rb', line 14677

class PutResourcePolicyRequest < Struct.new(
  :policy_in_json,
  :resource_arn,
  :policy_hash_condition,
  :policy_exists_condition,
  :enable_hybrid)
  SENSITIVE = []
  include Aws::Structure
end

#policy_exists_conditionString

A value of `MUST_EXIST` is used to update a policy. A value of `NOT_EXIST` is used to create a new policy. If a value of `NONE` or a null value is used, the call does not depend on the existence of a policy.

Returns:

  • (String)


14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/aws-sdk-glue/types.rb', line 14677

class PutResourcePolicyRequest < Struct.new(
  :policy_in_json,
  :resource_arn,
  :policy_hash_condition,
  :policy_exists_condition,
  :enable_hybrid)
  SENSITIVE = []
  include Aws::Structure
end

#policy_hash_conditionString

The hash value returned when the previous policy was set using `PutResourcePolicy`. Its purpose is to prevent concurrent modifications of a policy. Do not use this parameter if no previous policy has been set.

Returns:

  • (String)


14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/aws-sdk-glue/types.rb', line 14677

class PutResourcePolicyRequest < Struct.new(
  :policy_in_json,
  :resource_arn,
  :policy_hash_condition,
  :policy_exists_condition,
  :enable_hybrid)
  SENSITIVE = []
  include Aws::Structure
end

#policy_in_jsonString

Contains the policy document to set, in JSON format.

Returns:

  • (String)


14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/aws-sdk-glue/types.rb', line 14677

class PutResourcePolicyRequest < Struct.new(
  :policy_in_json,
  :resource_arn,
  :policy_hash_condition,
  :policy_exists_condition,
  :enable_hybrid)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

Do not use. For internal use only.

Returns:

  • (String)


14677
14678
14679
14680
14681
14682
14683
14684
14685
# File 'lib/aws-sdk-glue/types.rb', line 14677

class PutResourcePolicyRequest < Struct.new(
  :policy_in_json,
  :resource_arn,
  :policy_hash_condition,
  :policy_exists_condition,
  :enable_hybrid)
  SENSITIVE = []
  include Aws::Structure
end