Class: Aws::Glue::Types::QuerySchemaVersionMetadataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::QuerySchemaVersionMetadataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of results required per page.
-
#metadata_list ⇒ Array<Types::MetadataKeyValuePair>
Search key-value pairs for metadata, if they are not provided all the metadata information will be fetched.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#schema_id ⇒ Types::SchemaId
A wrapper structure that may contain the schema name and Amazon Resource Name (ARN).
-
#schema_version_id ⇒ String
The unique version ID of the schema version.
-
#schema_version_number ⇒ Types::SchemaVersionNumber
The version number of the schema.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#metadata_list ⇒ Array<Types::MetadataKeyValuePair>
Search key-value pairs for metadata, if they are not provided all the metadata information will be fetched.
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#schema_id ⇒ Types::SchemaId
A wrapper structure that may contain the schema name and Amazon Resource Name (ARN).
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#schema_version_id ⇒ String
The unique version ID of the schema version.
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#schema_version_number ⇒ Types::SchemaVersionNumber
The version number of the schema.
16790 16791 16792 16793 16794 16795 16796 16797 16798 16799 |
# File 'lib/aws-sdk-glue/types.rb', line 16790 class QuerySchemaVersionMetadataInput < Struct.new( :schema_id, :schema_version_number, :schema_version_id, :metadata_list, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |