Class: Aws::Glue::Types::QuerySchemaVersionMetadataInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.

Returns:

  • (Integer)


14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#metadata_listArray<Types::MetadataKeyValuePair>

Search key-value pairs for metadata, if they are not provided all the metadata information will be fetched.

Returns:



14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A continuation token, if this is a continuation call.

Returns:

  • (String)


14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#schema_idTypes::SchemaId

A wrapper structure that may contain the schema name and Amazon Resource Name (ARN).

Returns:



14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#schema_version_idString

The unique version ID of the schema version.

Returns:

  • (String)


14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#schema_version_numberTypes::SchemaVersionNumber

The version number of the schema.



14830
14831
14832
14833
14834
14835
14836
14837
14838
14839
# File 'lib/aws-sdk-glue/types.rb', line 14830

class QuerySchemaVersionMetadataInput < Struct.new(
  :schema_id,
  :schema_version_number,
  :schema_version_id,
  :metadata_list,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end