Class: Aws::Glue::Types::RecrawlPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RecrawlPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass RecrawlPolicy data as a hash:
{
recrawl_behavior: "CRAWL_EVERYTHING", # accepts CRAWL_EVERYTHING, CRAWL_NEW_FOLDERS_ONLY, CRAWL_EVENT_MODE
}
When crawling an Amazon S3 data source after the first crawl is complete, specifies whether to crawl the entire dataset again or to crawl only folders that were added since the last crawler run. For more information, see [Incremental Crawls in Glue] in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/incremental-crawls.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#recrawl_behavior ⇒ String
Specifies whether to crawl the entire dataset again or to crawl only folders that were added since the last crawler run.
Instance Attribute Details
#recrawl_behavior ⇒ String
Specifies whether to crawl the entire dataset again or to crawl only folders that were added since the last crawler run.
A value of `CRAWL_EVERYTHING` specifies crawling the entire dataset again.
A value of `CRAWL_NEW_FOLDERS_ONLY` specifies crawling only folders that were added since the last crawler run.
A value of `CRAWL_EVENT_MODE` specifies crawling only the changes identified by Amazon S3 events.
19410 19411 19412 19413 19414 |
# File 'lib/aws-sdk-glue/types.rb', line 19410 class RecrawlPolicy < Struct.new( :recrawl_behavior) SENSITIVE = [] include Aws::Structure end |