Class: Aws::Glue::Types::RedshiftTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass RedshiftTarget data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  database: "EnclosedInStringProperty", # required
  table: "EnclosedInStringProperty", # required
  redshift_tmp_dir: "EnclosedInStringProperty",
  tmp_dir_iam_role: "EnclosedInStringProperty",
  upsert_redshift_options: {
    table_location: "EnclosedInStringProperty",
    connection_name: "EnclosedInStringProperty",
    upsert_keys: ["EnclosedInStringProperty"],
  },
}

Specifies a target that uses Amazon Redshift.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#databaseString

The name of the database to write to.

Returns:

  • (String)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#redshift_tmp_dirString

The Amazon S3 path where temporary data can be staged when copying out of the database.

Returns:

  • (String)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#tableString

The name of the table in the database to write to.

Returns:

  • (String)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#tmp_dir_iam_roleString

The IAM role with permissions.

Returns:

  • (String)


19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end

#upsert_redshift_optionsTypes::UpsertRedshiftTargetOptions

The set of options to configure an upsert operation when writing to a Redshift target.



19495
19496
19497
19498
19499
19500
19501
19502
19503
19504
19505
# File 'lib/aws-sdk-glue/types.rb', line 19495

class RedshiftTarget < Struct.new(
  :name,
  :inputs,
  :database,
  :table,
  :redshift_tmp_dir,
  :tmp_dir_iam_role,
  :upsert_redshift_options)
  SENSITIVE = []
  include Aws::Structure
end