Class: Aws::Glue::Types::RenameField
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RenameField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass RenameField data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
source_path: ["EnclosedInStringProperty"], # required
target_path: ["EnclosedInStringProperty"], # required
}
Specifies a transform that renames a single data property key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#source_path ⇒ Array<String>
A JSON path to a variable in the data structure for the source data.
-
#target_path ⇒ Array<String>
A JSON path to a variable in the data structure for the target data.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
19733 19734 19735 19736 19737 19738 19739 19740 |
# File 'lib/aws-sdk-glue/types.rb', line 19733 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
19733 19734 19735 19736 19737 19738 19739 19740 |
# File 'lib/aws-sdk-glue/types.rb', line 19733 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#source_path ⇒ Array<String>
A JSON path to a variable in the data structure for the source data.
19733 19734 19735 19736 19737 19738 19739 19740 |
# File 'lib/aws-sdk-glue/types.rb', line 19733 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |
#target_path ⇒ Array<String>
A JSON path to a variable in the data structure for the target data.
19733 19734 19735 19736 19737 19738 19739 19740 |
# File 'lib/aws-sdk-glue/types.rb', line 19733 class RenameField < Struct.new( :name, :inputs, :source_path, :target_path) SENSITIVE = [] include Aws::Structure end |