Class: Aws::Glue::Types::RestConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RestConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Configuration that defines HTTP request and response handling, validation endpoints, and entity configurations for REST API interactions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_configurations ⇒ Hash<String,Types::EntityConfiguration>
A map of entity configurations that define how to interact with different data entities available through the REST API, including their schemas and access patterns.
-
#global_source_configuration ⇒ Types::SourceConfiguration
Global configuration settings that apply to all REST API requests for this connection type, including common request methods, paths, and parameters.
-
#validation_endpoint_configuration ⇒ Types::SourceConfiguration
Configuration for the endpoint used to validate connection credentials and test connectivity during connection creation.
Instance Attribute Details
#entity_configurations ⇒ Hash<String,Types::EntityConfiguration>
A map of entity configurations that define how to interact with different data entities available through the REST API, including their schemas and access patterns.
23754 23755 23756 23757 23758 23759 23760 |
# File 'lib/aws-sdk-glue/types.rb', line 23754 class RestConfiguration < Struct.new( :global_source_configuration, :validation_endpoint_configuration, :entity_configurations) SENSITIVE = [] include Aws::Structure end |
#global_source_configuration ⇒ Types::SourceConfiguration
Global configuration settings that apply to all REST API requests for this connection type, including common request methods, paths, and parameters.
23754 23755 23756 23757 23758 23759 23760 |
# File 'lib/aws-sdk-glue/types.rb', line 23754 class RestConfiguration < Struct.new( :global_source_configuration, :validation_endpoint_configuration, :entity_configurations) SENSITIVE = [] include Aws::Structure end |
#validation_endpoint_configuration ⇒ Types::SourceConfiguration
Configuration for the endpoint used to validate connection credentials and test connectivity during connection creation.
23754 23755 23756 23757 23758 23759 23760 |
# File 'lib/aws-sdk-glue/types.rb', line 23754 class RestConfiguration < Struct.new( :global_source_configuration, :validation_endpoint_configuration, :entity_configurations) SENSITIVE = [] include Aws::Structure end |