Class: Aws::Glue::Types::RowLevelResultsOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RowLevelResultsOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The configuration for writing row-level evaluation results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_table_config ⇒ Types::CatalogTableConfigOptions
The Glue Data Catalog table configuration for storing the results.
-
#max_rows_to_write ⇒ Integer
The maximum number of rows to write in the results.
-
#result_type ⇒ String
The result type to include in the row-level results output.
Instance Attribute Details
#catalog_table_config ⇒ Types::CatalogTableConfigOptions
The Glue Data Catalog table configuration for storing the results.
25628 25629 25630 25631 25632 25633 25634 |
# File 'lib/aws-sdk-glue/types.rb', line 25628 class RowLevelResultsOptions < Struct.new( :max_rows_to_write, :result_type, :catalog_table_config) SENSITIVE = [] include Aws::Structure end |
#max_rows_to_write ⇒ Integer
The maximum number of rows to write in the results.
25628 25629 25630 25631 25632 25633 25634 |
# File 'lib/aws-sdk-glue/types.rb', line 25628 class RowLevelResultsOptions < Struct.new( :max_rows_to_write, :result_type, :catalog_table_config) SENSITIVE = [] include Aws::Structure end |
#result_type ⇒ String
The result type to include in the row-level results output.
25628 25629 25630 25631 25632 25633 25634 |
# File 'lib/aws-sdk-glue/types.rb', line 25628 class RowLevelResultsOptions < Struct.new( :max_rows_to_write, :result_type, :catalog_table_config) SENSITIVE = [] include Aws::Structure end |