Class: Aws::Glue::Types::RunStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RunStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass RunStatementRequest data as a hash:
{
session_id: "NameString", # required
code: "OrchestrationStatementCodeString", # required
request_origin: "OrchestrationNameString",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The statement code to be run.
-
#request_origin ⇒ String
The origin of the request.
-
#session_id ⇒ String
The Session Id of the statement to be run.
Instance Attribute Details
#code ⇒ String
The statement code to be run.
20052 20053 20054 20055 20056 20057 20058 |
# File 'lib/aws-sdk-glue/types.rb', line 20052 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |
#request_origin ⇒ String
The origin of the request.
20052 20053 20054 20055 20056 20057 20058 |
# File 'lib/aws-sdk-glue/types.rb', line 20052 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The Session Id of the statement to be run.
20052 20053 20054 20055 20056 20057 20058 |
# File 'lib/aws-sdk-glue/types.rb', line 20052 class RunStatementRequest < Struct.new( :session_id, :code, :request_origin) SENSITIVE = [] include Aws::Structure end |