Class: Aws::Glue::Types::RunStatementResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::RunStatementResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ Integer
Returns the Id of the statement that was run.
Instance Attribute Details
#id ⇒ Integer
Returns the Id of the statement that was run.
22153 22154 22155 22156 22157 |
# File 'lib/aws-sdk-glue/types.rb', line 22153 class RunStatementResponse < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |