Class: Aws::Glue::Types::S3CatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3CatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3 using the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 catalog target.
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
-
#table ⇒ String
The name of the table in the database to write to.
Instance Attribute Details
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation
for the S3 catalog target. When set to true, data quality checks
are performed automatically during the write operation.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to write to.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table in the database to write to.
26366 26367 26368 26369 26370 26371 26372 26373 26374 26375 26376 |
# File 'lib/aws-sdk-glue/types.rb', line 26366 class S3CatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |