Class: Aws::Glue::Types::S3CsvSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass S3CsvSource data as a hash:

{
  name: "NodeName", # required
  paths: ["EnclosedInStringProperty"], # required
  compression_type: "gzip", # accepts gzip, bzip2
  exclusions: ["EnclosedInStringProperty"],
  group_size: "EnclosedInStringProperty",
  group_files: "EnclosedInStringProperty",
  recurse: false,
  max_band: 1,
  max_files_in_band: 1,
  additional_options: {
    bounded_size: 1,
    bounded_files: 1,
    enable_sample_path: false,
    sample_path: "EnclosedInStringProperty",
  },
  separator: "comma", # required, accepts comma, ctrla, pipe, semicolon, tab
  escaper: "EnclosedInStringPropertyWithQuote",
  quote_char: "quote", # required, accepts quote, quillemet, single_quote, disabled
  multiline: false,
  with_header: false,
  write_header: false,
  skip_first: false,
  optimize_performance: false,
  output_schemas: [
    {
      columns: [
        {
          name: "GlueStudioColumnNameString", # required
          type: "ColumnTypeString",
        },
      ],
    },
  ],
}

Specifies a command-separated value (CSV) data store stored in Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsTypes::S3DirectSourceAdditionalOptions

Specifies additional connection options.



20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#compression_typeString

Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are `“gzip”` and `“bzip”`).

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#escaperString

Specifies a character to use for escaping. This option is used only when reading CSV files. The default value is `none`. If enabled, the character which immediately follows is used as-is, except for a small set of well-known escapes (`n`, `r`, `t`, and `0`).

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#exclusionsArray<String>

A string containing a JSON list of Unix-style glob patterns to exclude. For example, “[\”**.pdf\“]” excludes all PDF files.

Returns:

  • (Array<String>)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#group_filesString

Grouping files is turned on by default when the input contains more than 50,000 files. To turn on grouping with fewer than 50,000 files, set this parameter to “inPartition”. To disable grouping when there are more than 50,000 files, set this parameter to `“none”`.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#group_sizeString

The target group size in bytes. The default is computed based on the input data size and the size of your cluster. When there are fewer than 50,000 input files, `“groupFiles”` must be set to `“inPartition”` for this to take effect.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#max_bandInteger

This option controls the duration in milliseconds after which the s3 listing is likely to be consistent. Files with modification timestamps falling within the last maxBand milliseconds are tracked specially when using JobBookmarks to account for Amazon S3 eventual consistency. Most users don't need to set this option. The default is 900000 milliseconds, or 15 minutes.

Returns:

  • (Integer)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#max_files_in_bandInteger

This option specifies the maximum number of files to save from the last maxBand seconds. If this number is exceeded, extra files are skipped and only processed in the next job run.

Returns:

  • (Integer)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#multilineBoolean

A Boolean value that specifies whether a single record can span multiple lines. This can occur when a field contains a quoted new-line character. You must set this option to True if any record spans multiple lines. The default value is `False`, which allows for more aggressive file-splitting during parsing.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data store.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#optimize_performanceBoolean

A Boolean value that specifies whether to use the advanced SIMD CSV reader along with Apache Arrow based columnar memory formats. Only available in Glue version 3.0.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the S3 CSV source.

Returns:



20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#pathsArray<String>

A list of the Amazon S3 paths to read from.

Returns:

  • (Array<String>)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#quote_charString

Specifies the character to use for quoting. The default is a double quote: `'“'`. Set this to `-1` to turn off quoting entirely.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#recurseBoolean

If set to true, recursively reads files in all subdirectories under the specified paths.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#separatorString

Specifies the delimiter character. The default is a comma: “,”, but any other character can be specified.

Returns:

  • (String)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#skip_firstBoolean

A Boolean value that specifies whether to skip the first data line. The default value is `False`.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#with_headerBoolean

A Boolean value that specifies whether to treat the first line as a header. The default value is `False`.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#write_headerBoolean

A Boolean value that specifies whether to write the header to output. The default value is `True`.

Returns:

  • (Boolean)


20477
20478
20479
20480
20481
20482
20483
20484
20485
20486
20487
20488
20489
20490
20491
20492
20493
20494
20495
20496
20497
20498
20499
# File 'lib/aws-sdk-glue/types.rb', line 20477

class S3CsvSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :separator,
  :escaper,
  :quote_char,
  :multiline,
  :with_header,
  :write_header,
  :skip_first,
  :optimize_performance,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end