Class: Aws::Glue::Types::S3DeltaCatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DeltaCatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a target that writes to a Delta Lake data source in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Delta catalog target.
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Delta catalog target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
-
#table ⇒ String
The name of the table in the database to write to.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation
for the S3 Delta catalog target. When set to true, data quality
checks are performed automatically during the write operation.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to write to.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Delta catalog target.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table in the database to write to.
26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 |
# File 'lib/aws-sdk-glue/types.rb', line 26558 class S3DeltaCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |