Class: Aws::Glue::Types::S3DeltaDirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DeltaDirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a target that writes to a Delta Lake data source in Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Delta direct target.
-
#compression ⇒ String
Specifies how the data is compressed.
-
#format ⇒ String
Specifies the data output format for the target.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#number_target_partitions ⇒ String
Specifies the number of target partitions for distributing Delta Lake dataset files across Amazon S3.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
The Amazon S3 path of your Delta Lake data source to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Delta direct target. When set to ‘true`, data quality checks are performed automatically during the write operation.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#compression ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are ‘“gzip”` and `“bzip”`).
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the data output format for the target.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#number_target_partitions ⇒ String
Specifies the number of target partitions for distributing Delta Lake dataset files across Amazon S3.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The Amazon S3 path of your Delta Lake data source to write to.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
24328 24329 24330 24331 24332 24333 24334 24335 24336 24337 24338 24339 24340 24341 |
# File 'lib/aws-sdk-glue/types.rb', line 24328 class S3DeltaDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |