Class: Aws::Glue::Types::S3DirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 direct target.
-
#compression ⇒ String
Specifies how the data is compressed.
-
#format ⇒ String
Specifies the data output format for the target.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#number_target_partitions ⇒ String
Specifies the number of target partitions when writing data directly to Amazon S3.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 direct target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation
for the S3 direct target. When set to true, data quality checks
are performed automatically during the write operation.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#compression ⇒ String
Specifies how the data is compressed. This is generally not
necessary if the data has a standard file extension. Possible values
are "gzip" and "bzip").
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the data output format for the target.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#number_target_partitions ⇒ String
Specifies the number of target partitions when writing data directly to Amazon S3.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 direct target.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
26657 26658 26659 26660 26661 26662 26663 26664 26665 26666 26667 26668 26669 26670 |
# File 'lib/aws-sdk-glue/types.rb', line 26657 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :format, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |