Class: Aws::Glue::Types::S3DirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression ⇒ String
Specifies how the data is compressed.
-
#format ⇒ String
Specifies the data output format for the target.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#compression ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are `“gzip”` and `“bzip”`).
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the data output format for the target.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
15638 15639 15640 15641 15642 15643 15644 15645 15646 15647 15648 |
# File 'lib/aws-sdk-glue/types.rb', line 15638 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |