Class: Aws::Glue::Types::S3DirectTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass S3DirectTarget data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  partition_keys: [
    ["EnclosedInStringProperty"],
  ],
  path: "EnclosedInStringProperty", # required
  compression: "EnclosedInStringProperty",
  format: "json", # required, accepts json, csv, avro, orc, parquet
  schema_change_policy: {
    enable_update_catalog: false,
    update_behavior: "UPDATE_IN_DATABASE", # accepts UPDATE_IN_DATABASE, LOG
    table: "EnclosedInStringProperty",
    database: "EnclosedInStringProperty",
  },
}

Specifies a data target that writes to Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compressionString

Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are `“gzip”` and `“bzip”`).

Returns:

  • (String)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

Specifies the data output format for the target.

Returns:

  • (String)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#inputsArray<String>

The nodes that are inputs to the data target.

Returns:

  • (Array<String>)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data target.

Returns:

  • (String)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Array<String>>

Specifies native partitioning using a sequence of keys.

Returns:

  • (Array<Array<String>>)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

A single Amazon S3 path to write to.

Returns:

  • (String)


20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::DirectSchemaChangePolicy

A policy that specifies update behavior for the crawler.



20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
# File 'lib/aws-sdk-glue/types.rb', line 20452

class S3DirectTarget < Struct.new(
  :name,
  :inputs,
  :partition_keys,
  :path,
  :compression,
  :format,
  :schema_change_policy)
  SENSITIVE = []
  include Aws::Structure
end