Class: Aws::Glue::Types::S3DirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3DirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass S3DirectTarget data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
partition_keys: [
["EnclosedInStringProperty"],
],
path: "EnclosedInStringProperty", # required
compression: "EnclosedInStringProperty",
format: "json", # required, accepts json, csv, avro, orc, parquet
schema_change_policy: {
enable_update_catalog: false,
update_behavior: "UPDATE_IN_DATABASE", # accepts UPDATE_IN_DATABASE, LOG
table: "EnclosedInStringProperty",
database: "EnclosedInStringProperty",
},
}
Specifies a data target that writes to Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression ⇒ String
Specifies how the data is compressed.
-
#format ⇒ String
Specifies the data output format for the target.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#compression ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are `“gzip”` and `“bzip”`).
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the data output format for the target.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
20368 20369 20370 20371 20372 20373 20374 20375 20376 20377 20378 |
# File 'lib/aws-sdk-glue/types.rb', line 20368 class S3DirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :format, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |