Class: Aws::Glue::Types::S3ExcelSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3ExcelSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an S3 Excel data source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Types::S3DirectSourceAdditionalOptions
Additional configuration options for S3 direct source processing.
-
#compression_type ⇒ String
The compression format used for the Excel files.
-
#exclusions ⇒ Array<String>
Patterns to exclude specific files or paths from processing.
-
#group_files ⇒ String
Specifies how files should be grouped for processing.
-
#group_size ⇒ String
Defines the size of file groups for batch processing.
-
#max_band ⇒ Integer
The maximum number of processing bands to use.
-
#max_files_in_band ⇒ Integer
The maximum number of files to process in each band.
-
#name ⇒ String
The name of the S3 Excel data source.
-
#number_rows ⇒ Integer
The number of rows to process from each Excel file.
-
#output_schemas ⇒ Array<Types::GlueSchema>
The AWS Glue schemas to apply to the processed data.
-
#paths ⇒ Array<String>
The S3 paths where the Excel files are located.
-
#recurse ⇒ Boolean
Indicates whether to recursively process subdirectories.
-
#skip_footer ⇒ Integer
The number of rows to skip at the end of each Excel file.
Instance Attribute Details
#additional_options ⇒ Types::S3DirectSourceAdditionalOptions
Additional configuration options for S3 direct source processing.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#compression_type ⇒ String
The compression format used for the Excel files.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
Patterns to exclude specific files or paths from processing.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#group_files ⇒ String
Specifies how files should be grouped for processing.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#group_size ⇒ String
Defines the size of file groups for batch processing.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#max_band ⇒ Integer
The maximum number of processing bands to use.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#max_files_in_band ⇒ Integer
The maximum number of files to process in each band.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the S3 Excel data source.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#number_rows ⇒ Integer
The number of rows to process from each Excel file.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
The AWS Glue schemas to apply to the processed data.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<String>
The S3 paths where the Excel files are located.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#recurse ⇒ Boolean
Indicates whether to recursively process subdirectories.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#skip_footer ⇒ Integer
The number of rows to skip at the end of each Excel file.
22328 22329 22330 22331 22332 22333 22334 22335 22336 22337 22338 22339 22340 22341 22342 22343 22344 |
# File 'lib/aws-sdk-glue/types.rb', line 22328 class S3ExcelSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :number_rows, :skip_footer, :output_schemas) SENSITIVE = [] include Aws::Structure end |