Class: Aws::Glue::Types::S3GlueParquetTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3GlueParquetTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target.
-
#compression ⇒ String
Specifies how the data is compressed.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#number_target_partitions ⇒ String
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation
for the S3 Glue Parquet target. When set to true, data quality
checks are performed automatically during the write operation.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#compression ⇒ String
Specifies how the data is compressed. This is generally not
necessary if the data has a standard file extension. Possible values
are "gzip" and "bzip").
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#number_target_partitions ⇒ String
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
26435 26436 26437 26438 26439 26440 26441 26442 26443 26444 26445 26446 |
# File 'lib/aws-sdk-glue/types.rb', line 26435 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :number_target_partitions, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |