Class: Aws::Glue::Types::S3GlueParquetTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3GlueParquetTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression ⇒ String
Specifies how the data is compressed.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#compression ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are ‘“gzip”` and `“bzip”`).
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
17229 17230 17231 17232 17233 17234 17235 17236 17237 17238 |
# File 'lib/aws-sdk-glue/types.rb', line 17229 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |