Class: Aws::Glue::Types::S3GlueParquetTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3GlueParquetTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compression ⇒ String
Specifies how the data is compressed.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#path ⇒ String
A single Amazon S3 path to write to.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
Instance Attribute Details
#compression ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are ‘“gzip”` and `“bzip”`).
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
A single Amazon S3 path to write to.
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
A policy that specifies update behavior for the crawler.
16907 16908 16909 16910 16911 16912 16913 16914 16915 16916 |
# File 'lib/aws-sdk-glue/types.rb', line 16907 class S3GlueParquetTarget < Struct.new( :name, :inputs, :partition_keys, :path, :compression, :schema_change_policy) SENSITIVE = [] include Aws::Structure end |