Class: Aws::Glue::Types::S3HudiCatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3HudiCatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a target that writes to a Hudi data source in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Hudi catalog target.
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
-
#name ⇒ String
The name of the data target.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Hudi catalog target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
-
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
-
#table ⇒ String
The name of the table in the database to write to.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the connector.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Hudi catalog target. When set to true, data quality checks are performed automatically during the write operation.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to write to.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The nodes that are inputs to the data target.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data target.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Hudi catalog target.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies native partitioning using a sequence of keys.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
A policy that specifies update behavior for the crawler.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table in the database to write to.
24644 24645 24646 24647 24648 24649 24650 24651 24652 24653 24654 24655 24656 |
# File 'lib/aws-sdk-glue/types.rb', line 24644 class S3HudiCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |