Class: Aws::Glue::Types::S3HyperDirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3HyperDirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a HyperDirect data target that writes to Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target.
-
#compression ⇒ String
The compression type to apply to the output data.
-
#format ⇒ String
Specifies the data output format for the HyperDirect target.
-
#inputs ⇒ Array<String>
Specifies the input source for the HyperDirect target.
-
#name ⇒ String
The unique identifier for the HyperDirect target node.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Hyper direct target.
-
#partition_keys ⇒ Array<Array<String>>
Defines the partitioning strategy for the output data.
-
#path ⇒ String
The S3 location where the output data will be written.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
Defines how schema changes are handled during write operations.
Instance Attribute Details
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#compression ⇒ String
The compression type to apply to the output data.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the data output format for the HyperDirect target.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
Specifies the input source for the HyperDirect target.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique identifier for the HyperDirect target node.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Hyper direct target.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Defines the partitioning strategy for the output data.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The S3 location where the output data will be written.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
Defines how schema changes are handled during write operations.
24819 24820 24821 24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 |
# File 'lib/aws-sdk-glue/types.rb', line 24819 class S3HyperDirectTarget < Struct.new( :name, :inputs, :format, :partition_keys, :path, :compression, :schema_change_policy, :auto_data_quality, :output_schemas) SENSITIVE = [] include Aws::Structure end |