Class: Aws::Glue::Types::S3IcebergCatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3IcebergCatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Apache Iceberg catalog target that writes data to Amazon S3 and registers the table in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the Iceberg catalog target.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Iceberg catalog target.
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The input connection for the Iceberg catalog target.
-
#name ⇒ String
The name of the Iceberg catalog target.
-
#partition_keys ⇒ Array<Array<String>>
A list of partition keys for the Iceberg table.
-
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
The policy for handling schema changes in the catalog target.
-
#table ⇒ String
The name of the table to write to in the catalog.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the Iceberg catalog target.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation
for the S3 Iceberg catalog target. When set to true, data quality
checks are performed automatically during the write operation.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to write to.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The input connection for the Iceberg catalog target.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Iceberg catalog target.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
A list of partition keys for the Iceberg table.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
The policy for handling schema changes in the catalog target.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table to write to in the catalog.
27073 27074 27075 27076 27077 27078 27079 27080 27081 27082 27083 27084 |
# File 'lib/aws-sdk-glue/types.rb', line 27073 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |