Class: Aws::Glue::Types::S3IcebergCatalogTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3IcebergCatalogTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Apache Iceberg catalog target that writes data to Amazon S3 and registers the table in the Glue Data Catalog.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the Iceberg catalog target.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Iceberg catalog target.
-
#database ⇒ String
The name of the database to write to.
-
#inputs ⇒ Array<String>
The input connection for the Iceberg catalog target.
-
#name ⇒ String
The name of the Iceberg catalog target.
-
#partition_keys ⇒ Array<Array<String>>
A list of partition keys for the Iceberg table.
-
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
The policy for handling schema changes in the catalog target.
-
#table ⇒ String
The name of the table to write to in the catalog.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Specifies additional connection options for the Iceberg catalog target.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies whether to automatically enable data quality evaluation for the S3 Iceberg catalog target. When set to true, data quality checks are performed automatically during the write operation.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database to write to.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The input connection for the Iceberg catalog target.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Iceberg catalog target.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
A list of partition keys for the Iceberg table.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::CatalogSchemaChangePolicy
The policy for handling schema changes in the catalog target.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
The name of the table to write to in the catalog.
24188 24189 24190 24191 24192 24193 24194 24195 24196 24197 24198 24199 |
# File 'lib/aws-sdk-glue/types.rb', line 24188 class S3IcebergCatalogTarget < Struct.new( :name, :inputs, :partition_keys, :table, :database, :additional_options, :schema_change_policy, :auto_data_quality) SENSITIVE = [] include Aws::Structure end |