Class: Aws::Glue::Types::S3IcebergDirectTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3IcebergDirectTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a target that writes to an Iceberg data source in Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Hash<String,String>
Provides additional configuration options for customizing the Iceberg table behavior.
-
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies configuration options for automatic data quality evaluation in Glue jobs.
-
#compression ⇒ String
Specifies the compression codec used for Iceberg table files in S3.
-
#format ⇒ String
Specifies the file format used for storing Iceberg table data (e.g., Parquet, ORC).
-
#inputs ⇒ Array<String>
Defines the single input source that provides data to this Iceberg target.
-
#name ⇒ String
Specifies the unique identifier for the Iceberg target node in your data pipeline.
-
#number_target_partitions ⇒ String
Sets the number of target partitions for distributing Iceberg table files across S3.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Iceberg direct target.
-
#partition_keys ⇒ Array<Array<String>>
Specifies the columns used to partition the Iceberg table data in S3.
-
#path ⇒ String
Defines the S3 location where the Iceberg table data will be stored.
-
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
Defines how schema changes are handled when writing data to the Iceberg table.
Instance Attribute Details
#additional_options ⇒ Hash<String,String>
Provides additional configuration options for customizing the Iceberg table behavior.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#auto_data_quality ⇒ Types::AutoDataQuality
Specifies configuration options for automatic data quality evaluation in Glue jobs. This structure enables automated data quality checks and monitoring during ETL operations, helping to ensure data integrity and reliability without manual intervention.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#compression ⇒ String
Specifies the compression codec used for Iceberg table files in S3.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
Specifies the file format used for storing Iceberg table data (e.g., Parquet, ORC).
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
Defines the single input source that provides data to this Iceberg target.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies the unique identifier for the Iceberg target node in your data pipeline.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#number_target_partitions ⇒ String
Sets the number of target partitions for distributing Iceberg table files across S3.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Iceberg direct target.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Array<String>>
Specifies the columns used to partition the Iceberg table data in S3.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
Defines the S3 location where the Iceberg table data will be stored.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#schema_change_policy ⇒ Types::DirectSchemaChangePolicy
Defines how schema changes are handled when writing data to the Iceberg table.
25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 |
# File 'lib/aws-sdk-glue/types.rb', line 25159 class S3IcebergDirectTarget < Struct.new( :name, :inputs, :partition_keys, :path, :format, :additional_options, :schema_change_policy, :auto_data_quality, :compression, :number_target_partitions, :output_schemas) SENSITIVE = [] include Aws::Structure end |