Class: Aws::Glue::Types::S3ParquetSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies an Apache Parquet data store stored in Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_optionsTypes::S3DirectSourceAdditionalOptions

Specifies additional connection options.



19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#compression_typeString

Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are ‘“gzip”` and `“bzip”`).

Returns:

  • (String)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#exclusionsArray<String>

A string containing a JSON list of Unix-style glob patterns to exclude. For example, “[\”**.pdf\“]” excludes all PDF files.

Returns:

  • (Array<String>)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#group_filesString

Grouping files is turned on by default when the input contains more than 50,000 files. To turn on grouping with fewer than 50,000 files, set this parameter to “inPartition”. To disable grouping when there are more than 50,000 files, set this parameter to ‘“none”`.

Returns:

  • (String)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#group_sizeString

The target group size in bytes. The default is computed based on the input data size and the size of your cluster. When there are fewer than 50,000 input files, ‘“groupFiles”` must be set to `“inPartition”` for this to take effect.

Returns:

  • (String)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#max_bandInteger

This option controls the duration in milliseconds after which the s3 listing is likely to be consistent. Files with modification timestamps falling within the last maxBand milliseconds are tracked specially when using JobBookmarks to account for Amazon S3 eventual consistency. Most users don’t need to set this option. The default is 900000 milliseconds, or 15 minutes.

Returns:

  • (Integer)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#max_files_in_bandInteger

This option specifies the maximum number of files to save from the last maxBand seconds. If this number is exceeded, extra files are skipped and only processed in the next job run.

Returns:

  • (Integer)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data store.

Returns:

  • (String)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#output_schemasArray<Types::GlueSchema>

Specifies the data schema for the S3 Parquet source.

Returns:



19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#pathsArray<String>

A list of the Amazon S3 paths to read from.

Returns:

  • (Array<String>)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end

#recurseBoolean

If set to true, recursively reads files in all subdirectories under the specified paths.

Returns:

  • (Boolean)


19894
19895
19896
19897
19898
19899
19900
19901
19902
19903
19904
19905
19906
19907
19908
# File 'lib/aws-sdk-glue/types.rb', line 19894

class S3ParquetSource < Struct.new(
  :name,
  :paths,
  :compression_type,
  :exclusions,
  :group_size,
  :group_files,
  :recurse,
  :max_band,
  :max_files_in_band,
  :additional_options,
  :output_schemas)
  SENSITIVE = []
  include Aws::Structure
end