Class: Aws::Glue::Types::S3ParquetSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3ParquetSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies an Apache Parquet data store stored in Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_options ⇒ Types::S3DirectSourceAdditionalOptions
Specifies additional connection options.
-
#compression_type ⇒ String
Specifies how the data is compressed.
-
#exclusions ⇒ Array<String>
A string containing a JSON list of Unix-style glob patterns to exclude.
-
#group_files ⇒ String
Grouping files is turned on by default when the input contains more than 50,000 files.
-
#group_size ⇒ String
The target group size in bytes.
-
#max_band ⇒ Integer
This option controls the duration in milliseconds after which the s3 listing is likely to be consistent.
-
#max_files_in_band ⇒ Integer
This option specifies the maximum number of files to save from the last maxBand seconds.
-
#name ⇒ String
The name of the data store.
-
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Parquet source.
-
#paths ⇒ Array<String>
A list of the Amazon S3 paths to read from.
-
#recurse ⇒ Boolean
If set to true, recursively reads files in all subdirectories under the specified paths.
Instance Attribute Details
#additional_options ⇒ Types::S3DirectSourceAdditionalOptions
Specifies additional connection options.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#compression_type ⇒ String
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are ‘“gzip”` and `“bzip”`).
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
A string containing a JSON list of Unix-style glob patterns to exclude. For example, “[\”**.pdf\“]” excludes all PDF files.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#group_files ⇒ String
Grouping files is turned on by default when the input contains more than 50,000 files. To turn on grouping with fewer than 50,000 files, set this parameter to “inPartition”. To disable grouping when there are more than 50,000 files, set this parameter to ‘“none”`.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#group_size ⇒ String
The target group size in bytes. The default is computed based on the input data size and the size of your cluster. When there are fewer than 50,000 input files, ‘“groupFiles”` must be set to `“inPartition”` for this to take effect.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#max_band ⇒ Integer
This option controls the duration in milliseconds after which the s3 listing is likely to be consistent. Files with modification timestamps falling within the last maxBand milliseconds are tracked specially when using JobBookmarks to account for Amazon S3 eventual consistency. Most users don’t need to set this option. The default is 900000 milliseconds, or 15 minutes.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#max_files_in_band ⇒ Integer
This option specifies the maximum number of files to save from the last maxBand seconds. If this number is exceeded, extra files are skipped and only processed in the next job run.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data store.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#output_schemas ⇒ Array<Types::GlueSchema>
Specifies the data schema for the S3 Parquet source.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<String>
A list of the Amazon S3 paths to read from.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |
#recurse ⇒ Boolean
If set to true, recursively reads files in all subdirectories under the specified paths.
18713 18714 18715 18716 18717 18718 18719 18720 18721 18722 18723 18724 18725 18726 18727 |
# File 'lib/aws-sdk-glue/types.rb', line 18713 class S3ParquetSource < Struct.new( :name, :paths, :compression_type, :exclusions, :group_size, :group_files, :recurse, :max_band, :max_files_in_band, :additional_options, :output_schemas) SENSITIVE = [] include Aws::Structure end |