Class: Aws::Glue::Types::S3Target
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::S3Target
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass S3Target data as a hash:
{
path: "Path",
exclusions: ["Path"],
connection_name: "ConnectionName",
sample_size: 1,
event_queue_arn: "EventQueueArn",
dlq_event_queue_arn: "EventQueueArn",
}
Specifies a data store in Amazon Simple Storage Service (Amazon S3).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
The name of a connection which allows a job or crawler to access data in Amazon S3 within an Amazon Virtual Private Cloud environment (Amazon VPC).
-
#dlq_event_queue_arn ⇒ String
A valid Amazon dead-letter SQS ARN.
-
#event_queue_arn ⇒ String
A valid Amazon SQS ARN.
-
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl.
-
#path ⇒ String
The path to the Amazon S3 target.
-
#sample_size ⇒ Integer
Sets the number of files in each leaf folder to be crawled when crawling sample files in a dataset.
Instance Attribute Details
#connection_name ⇒ String
The name of a connection which allows a job or crawler to access data in Amazon S3 within an Amazon Virtual Private Cloud environment (Amazon VPC).
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#dlq_event_queue_arn ⇒ String
A valid Amazon dead-letter SQS ARN. For example, `arn:aws:sqs:region:account:deadLetterQueue`.
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#event_queue_arn ⇒ String
A valid Amazon SQS ARN. For example, `arn:aws:sqs:region:account:sqs`.
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#exclusions ⇒ Array<String>
A list of glob patterns used to exclude from the crawl. For more information, see [Catalog Tables with a Crawler].
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The path to the Amazon S3 target.
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |
#sample_size ⇒ Integer
Sets the number of files in each leaf folder to be crawled when crawling sample files in a dataset. If not set, all the files are crawled. A valid value is an integer between 1 and 249.
21020 21021 21022 21023 21024 21025 21026 21027 21028 21029 |
# File 'lib/aws-sdk-glue/types.rb', line 21020 class S3Target < Struct.new( :path, :exclusions, :connection_name, :sample_size, :event_queue_arn, :dlq_event_queue_arn) SENSITIVE = [] include Aws::Structure end |