Class: Aws::Glue::Types::SchemaChangePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SchemaChangePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass SchemaChangePolicy data as a hash:
{
update_behavior: "LOG", # accepts LOG, UPDATE_IN_DATABASE
delete_behavior: "LOG", # accepts LOG, DELETE_FROM_DATABASE, DEPRECATE_IN_DATABASE
}
A policy that specifies update and deletion behaviors for the crawler.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_behavior ⇒ String
The deletion behavior when the crawler finds a deleted object.
-
#update_behavior ⇒ String
The update behavior when the crawler finds a changed schema.
Instance Attribute Details
#delete_behavior ⇒ String
The deletion behavior when the crawler finds a deleted object.
21118 21119 21120 21121 21122 21123 |
# File 'lib/aws-sdk-glue/types.rb', line 21118 class SchemaChangePolicy < Struct.new( :update_behavior, :delete_behavior) SENSITIVE = [] include Aws::Structure end |
#update_behavior ⇒ String
The update behavior when the crawler finds a changed schema.
21118 21119 21120 21121 21122 21123 |
# File 'lib/aws-sdk-glue/types.rb', line 21118 class SchemaChangePolicy < Struct.new( :update_behavior, :delete_behavior) SENSITIVE = [] include Aws::Structure end |