Class: Aws::Glue::Types::SearchAssetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SearchAssetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_clause ⇒ Types::SearchFilterClause
The filter clause to apply to the search.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#search_text ⇒ String
The text to search for.
-
#sort ⇒ Types::SearchSort
The sort criteria for the search results.
Instance Attribute Details
#filter_clause ⇒ Types::SearchFilterClause
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
26978 26979 26980 26981 26982 26983 26984 26985 26986 |
# File 'lib/aws-sdk-glue/types.rb', line 26978 class SearchAssetsInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
26978 26979 26980 26981 26982 26983 26984 26985 26986 |
# File 'lib/aws-sdk-glue/types.rb', line 26978 class SearchAssetsInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
26978 26979 26980 26981 26982 26983 26984 26985 26986 |
# File 'lib/aws-sdk-glue/types.rb', line 26978 class SearchAssetsInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#search_text ⇒ String
The text to search for. At least one of ‘searchText` or `filterClause` must be provided.
26978 26979 26980 26981 26982 26983 26984 26985 26986 |
# File 'lib/aws-sdk-glue/types.rb', line 26978 class SearchAssetsInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ Types::SearchSort
The sort criteria for the search results.
26978 26979 26980 26981 26982 26983 26984 26985 26986 |
# File 'lib/aws-sdk-glue/types.rb', line 26978 class SearchAssetsInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |