Class: Aws::Glue::Types::SearchInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SearchInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_clause ⇒ Types::SearchFilterClause
The filter clause to apply to the search.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
A continuation token, if this is a continuation call.
-
#search_text ⇒ String
The text to search for.
-
#sort ⇒ Types::SearchSort
The sort criteria for the search results.
Instance Attribute Details
#filter_clause ⇒ Types::SearchFilterClause
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
27060 27061 27062 27063 27064 27065 27066 27067 27068 |
# File 'lib/aws-sdk-glue/types.rb', line 27060 class SearchInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
27060 27061 27062 27063 27064 27065 27066 27067 27068 |
# File 'lib/aws-sdk-glue/types.rb', line 27060 class SearchInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A continuation token, if this is a continuation call.
27060 27061 27062 27063 27064 27065 27066 27067 27068 |
# File 'lib/aws-sdk-glue/types.rb', line 27060 class SearchInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#search_text ⇒ String
The text to search for. At least one of ‘searchText` or `filterClause` must be provided.
27060 27061 27062 27063 27064 27065 27066 27067 27068 |
# File 'lib/aws-sdk-glue/types.rb', line 27060 class SearchInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ Types::SearchSort
The sort criteria for the search results.
27060 27061 27062 27063 27064 27065 27066 27067 27068 |
# File 'lib/aws-sdk-glue/types.rb', line 27060 class SearchInput < Struct.new( :search_text, :max_results, :next_token, :sort, :filter_clause) SENSITIVE = [] include Aws::Structure end |