Class: Aws::Glue::Types::SelectFields

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass SelectFields data as a hash:

{
  name: "NodeName", # required
  inputs: ["NodeId"], # required
  paths: [ # required
    ["EnclosedInStringProperty"],
  ],
}

Specifies a transform that chooses the data property keys that you want to keep.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputsArray<String>

The data inputs identified by their node names.

Returns:

  • (Array<String>)


21413
21414
21415
21416
21417
21418
21419
# File 'lib/aws-sdk-glue/types.rb', line 21413

class SelectFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the transform node.

Returns:

  • (String)


21413
21414
21415
21416
21417
21418
21419
# File 'lib/aws-sdk-glue/types.rb', line 21413

class SelectFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end

#pathsArray<Array<String>>

A JSON path to a variable in the data structure.

Returns:

  • (Array<Array<String>>)


21413
21414
21415
21416
21417
21418
21419
# File 'lib/aws-sdk-glue/types.rb', line 21413

class SelectFields < Struct.new(
  :name,
  :inputs,
  :paths)
  SENSITIVE = []
  include Aws::Structure
end