Class: Aws::Glue::Types::SelectFields
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SelectFields
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass SelectFields data as a hash:
{
name: "NodeName", # required
inputs: ["NodeId"], # required
paths: [ # required
["EnclosedInStringProperty"],
],
}
Specifies a transform that chooses the data property keys that you want to keep.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The data inputs identified by their node names.
-
#name ⇒ String
The name of the transform node.
-
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
Instance Attribute Details
#inputs ⇒ Array<String>
The data inputs identified by their node names.
21413 21414 21415 21416 21417 21418 21419 |
# File 'lib/aws-sdk-glue/types.rb', line 21413 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
21413 21414 21415 21416 21417 21418 21419 |
# File 'lib/aws-sdk-glue/types.rb', line 21413 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |
#paths ⇒ Array<Array<String>>
A JSON path to a variable in the data structure.
21413 21414 21415 21416 21417 21418 21419 |
# File 'lib/aws-sdk-glue/types.rb', line 21413 class SelectFields < Struct.new( :name, :inputs, :paths) SENSITIVE = [] include Aws::Structure end |