Class: Aws::Glue::Types::Session

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The period in which a remote Spark runtime environment is running.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandTypes::SessionCommand

The command object.See SessionCommand.



25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#completed_onTime

The date and time that this session is completed.

Returns:

  • (Time)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#connectionsTypes::ConnectionsList

The number of connections used for the session.



25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#created_onTime

The time and date when the session was created.

Returns:

  • (Time)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#default_argumentsHash<String,String>

A map array of key-value pairs. Max is 75 pairs.

Returns:

  • (Hash<String,String>)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#dpu_secondsFloat

The DPUs consumed by the session (formula: ExecutionTime * MaxCapacity).

Returns:

  • (Float)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message displayed during the session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#execution_timeFloat

The total time the session ran for.

Returns:

  • (Float)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

The Glue version determines the versions of Apache Spark and Python that Glue supports. The GlueVersion must be greater than 2.0.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#idle_timeoutInteger

The number of minutes when idle before the session times out.

Returns:

  • (Integer)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.

Returns:

  • (Float)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined ‘WorkerType` to use for the session.

Returns:

  • (Integer)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#profile_nameString

The name of an Glue usage profile associated with the session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#progressFloat

The code execution progress of the session.

Returns:

  • (Float)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the SecurityConfiguration structure to be used with the session.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The session status.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a session runs. Accepts a value of ‘G.1X`, `G.2X`, `G.4X`, or `G.8X` for Spark sessions. Accepts the value `Z.2X` for Ray sessions.

Returns:

  • (String)


25109
25110
25111
25112
25113
25114
25115
25116
25117
25118
25119
25120
25121
25122
25123
25124
25125
25126
25127
25128
25129
25130
25131
25132
# File 'lib/aws-sdk-glue/types.rb', line 25109

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version,
  :number_of_workers,
  :worker_type,
  :completed_on,
  :execution_time,
  :dpu_seconds,
  :idle_timeout,
  :profile_name)
  SENSITIVE = []
  include Aws::Structure
end