Class: Aws::Glue::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The period in which a remote Spark runtime environment is running.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ Types::SessionCommand
The command object.See SessionCommand.
-
#completed_on ⇒ Time
The date and time that this session is completed.
-
#connections ⇒ Types::ConnectionsList
The number of connections used for the session.
-
#created_on ⇒ Time
The time and date when the session was created.
-
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs.
-
#description ⇒ String
The description of the session.
-
#dpu_seconds ⇒ Float
The DPUs consumed by the session (formula: ExecutionTime * MaxCapacity).
-
#error_message ⇒ String
The error message displayed during the session.
-
#execution_time ⇒ Float
The total time the session ran for.
-
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#id ⇒ String
The ID of the session.
-
#idle_timeout ⇒ Integer
The number of minutes when idle before the session times out.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs.
-
#number_of_workers ⇒ Integer
The number of workers of a defined ‘WorkerType` to use for the session.
-
#progress ⇒ Float
The code execution progress of the session.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.
-
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session.
-
#status ⇒ String
The session status.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when a session runs.
Instance Attribute Details
#command ⇒ Types::SessionCommand
The command object.See SessionCommand.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#completed_on ⇒ Time
The date and time that this session is completed.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#connections ⇒ Types::ConnectionsList
The number of connections used for the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#created_on ⇒ Time
The time and date when the session was created.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs. Max is 75 pairs.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#dpu_seconds ⇒ Float
The DPUs consumed by the session (formula: ExecutionTime * MaxCapacity).
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message displayed during the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#execution_time ⇒ Float
The total time the session ran for.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports. The GlueVersion must be greater than 2.0.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#idle_timeout ⇒ Integer
The number of minutes when idle before the session times out.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined ‘WorkerType` to use for the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ Float
The code execution progress of the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The session status.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when a session runs. Accepts a value of ‘G.1X`, `G.2X`, `G.4X`, or `G.8X` for Spark sessions. Accepts the value `Z.2X` for Ray sessions.
18284 18285 18286 18287 18288 18289 18290 18291 18292 18293 18294 18295 18296 18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 |
# File 'lib/aws-sdk-glue/types.rb', line 18284 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version, :number_of_workers, :worker_type, :completed_on, :execution_time, :dpu_seconds, :idle_timeout) SENSITIVE = [] include Aws::Structure end |