Class: Aws::Glue::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The period in which a remote Spark runtime environment is running.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command ⇒ Types::SessionCommand
The command object.See SessionCommand.
-
#connections ⇒ Types::ConnectionsList
The number of connections used for the session.
-
#created_on ⇒ Time
The time and date when the session was created.
-
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs.
-
#description ⇒ String
The description of the session.
-
#error_message ⇒ String
The error message displayed during the session.
-
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports.
-
#id ⇒ String
The ID of the session.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs.
-
#progress ⇒ Float
The code execution progress of the session.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.
-
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session.
-
#status ⇒ String
The session status.
Instance Attribute Details
#command ⇒ Types::SessionCommand
The command object.See SessionCommand.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#connections ⇒ Types::ConnectionsList
The number of connections used for the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#created_on ⇒ Time
The time and date when the session was created.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#default_arguments ⇒ Hash<String,String>
A map array of key-value pairs. Max is 75 pairs.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message displayed during the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
The Glue version determines the versions of Apache Spark and Python that Glue supports. The GlueVersion must be greater than 2.0.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#progress ⇒ Float
The code execution progress of the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The name of the SecurityConfiguration structure to be used with the session.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The session status.
17960 17961 17962 17963 17964 17965 17966 17967 17968 17969 17970 17971 17972 17973 17974 17975 17976 |
# File 'lib/aws-sdk-glue/types.rb', line 17960 class Session < Struct.new( :id, :created_on, :status, :error_message, :description, :role, :command, :default_arguments, :connections, :progress, :max_capacity, :security_configuration, :glue_version) SENSITIVE = [] include Aws::Structure end |