Class: Aws::Glue::Types::Session

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The period in which a remote Spark runtime environment is running.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#commandTypes::SessionCommand

The command object.See SessionCommand.



21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#connectionsTypes::ConnectionsList

The number of connections used for the session.



21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#created_onTime

The time and date when the session was created.

Returns:

  • (Time)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#default_argumentsHash<String,String>

A map array of key-value pairs. Max is 75 pairs.

Returns:

  • (Hash<String,String>)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the session.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message displayed during the session.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

The Glue version determines the versions of Apache Spark and Python that AWS Glue supports. The GlueVersion must be greater than 2.0.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the session.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of AWS Glue data processing units (DPUs) that can be allocated when the job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB memory.

Returns:

  • (Float)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#progressFloat

The code execution progress of the session.

Returns:

  • (Float)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role associated with the Session.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the SecurityConfiguration structure to be used with the session.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The session status.

Returns:

  • (String)


21306
21307
21308
21309
21310
21311
21312
21313
21314
21315
21316
21317
21318
21319
21320
21321
21322
# File 'lib/aws-sdk-glue/types.rb', line 21306

class Session < Struct.new(
  :id,
  :created_on,
  :status,
  :error_message,
  :description,
  :role,
  :command,
  :default_arguments,
  :connections,
  :progress,
  :max_capacity,
  :security_configuration,
  :glue_version)
  SENSITIVE = []
  include Aws::Structure
end