Class: Aws::Glue::Types::SessionEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SessionEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains the Spark Connect endpoint details for an interactive session, including the URL and authentication credentials.
Constant Summary collapse
- SENSITIVE =
[:auth_token]
Instance Attribute Summary collapse
-
#auth_token ⇒ String
The authentication token to include in requests to the Spark Connect endpoint.
-
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires.
-
#url ⇒ String
The Spark Connect endpoint URL for the session.
Instance Attribute Details
#auth_token ⇒ String
The authentication token to include in requests to the Spark Connect endpoint.
26093 26094 26095 26096 26097 26098 26099 |
# File 'lib/aws-sdk-glue/types.rb', line 26093 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires.
26093 26094 26095 26096 26097 26098 26099 |
# File 'lib/aws-sdk-glue/types.rb', line 26093 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |
#url ⇒ String
The Spark Connect endpoint URL for the session.
26093 26094 26095 26096 26097 26098 26099 |
# File 'lib/aws-sdk-glue/types.rb', line 26093 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |