Class: Aws::Glue::Types::SessionEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SessionEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains the Spark Connect endpoint details for an interactive session, including the URL and authentication credentials.
Constant Summary collapse
- SENSITIVE =
[:auth_token]
Instance Attribute Summary collapse
-
#auth_token ⇒ String
The authentication token to include in requests to the Spark Connect endpoint.
-
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires.
-
#url ⇒ String
The Spark Connect endpoint URL for the session.
Instance Attribute Details
#auth_token ⇒ String
The authentication token to include in requests to the Spark Connect endpoint.
25991 25992 25993 25994 25995 25996 25997 |
# File 'lib/aws-sdk-glue/types.rb', line 25991 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires.
25991 25992 25993 25994 25995 25996 25997 |
# File 'lib/aws-sdk-glue/types.rb', line 25991 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |
#url ⇒ String
The Spark Connect endpoint URL for the session.
25991 25992 25993 25994 25995 25996 25997 |
# File 'lib/aws-sdk-glue/types.rb', line 25991 class SessionEndpoint < Struct.new( :url, :auth_token, :auth_token_expiration_time) SENSITIVE = [:auth_token] include Aws::Structure end |