Class: Aws::Glue::Types::SnowflakeNodeData
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SnowflakeNodeData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies configuration for Snowflake nodes in Glue Studio.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Specifies what action to take when writing to a table with preexisting data.
-
#additional_options ⇒ Hash<String,String>
Specifies additional options passed to the Snowflake connector.
-
#auto_pushdown ⇒ Boolean
Specifies whether automatic query pushdown is enabled.
-
#connection ⇒ Types::Option
Specifies a Glue Data Catalog Connection to a Snowflake endpoint.
-
#database ⇒ String
Specifies a Snowflake database for your node to use.
-
#iam_role ⇒ Types::Option
Not currently used.
-
#merge_action ⇒ String
Specifies a merge action.
-
#merge_clause ⇒ String
A SQL statement that specifies a custom merge behavior.
-
#merge_when_matched ⇒ String
Specifies how to resolve records that match preexisting data when merging.
-
#merge_when_not_matched ⇒ String
Specifies how to process records that do not match preexisting data when merging.
-
#post_action ⇒ String
A SQL string run after the Snowflake connector performs its standard actions.
-
#pre_action ⇒ String
A SQL string run before the Snowflake connector performs its standard actions.
-
#sample_query ⇒ String
A SQL string used to retrieve data with the ‘query` sourcetype.
-
#schema ⇒ String
Specifies a Snowflake database schema for your node to use.
-
#selected_columns ⇒ Array<Types::Option>
Specifies the columns combined to identify a record when detecting matches for merges and upserts.
-
#source_type ⇒ String
Specifies how retrieved data is specified.
-
#staging_table ⇒ String
The name of a staging table used when performing ‘merge` or upsert `append` actions.
-
#table ⇒ String
Specifies a Snowflake table for your node to use.
-
#table_schema ⇒ Array<Types::Option>
Manually defines the target schema for the node.
-
#temp_dir ⇒ String
Not currently used.
-
#upsert ⇒ Boolean
Used when Action is ‘append`.
Instance Attribute Details
#action ⇒ String
Specifies what action to take when writing to a table with preexisting data. Valid values: ‘ append`, `merge`, `truncate`, `drop`.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#additional_options ⇒ Hash<String,String>
Specifies additional options passed to the Snowflake connector. If options are specified elsewhere in this node, this will take precedence.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#auto_pushdown ⇒ Boolean
Specifies whether automatic query pushdown is enabled. If pushdown is enabled, then when a query is run on Spark, if part of the query can be “pushed down” to the Snowflake server, it is pushed down. This improves performance of some queries.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#connection ⇒ Types::Option
Specifies a Glue Data Catalog Connection to a Snowflake endpoint.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
Specifies a Snowflake database for your node to use.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#iam_role ⇒ Types::Option
Not currently used.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#merge_action ⇒ String
Specifies a merge action. Valid values: ‘simple`, `custom`. If simple, merge behavior is defined by `MergeWhenMatched` and ` MergeWhenNotMatched`. If custom, defined by `MergeClause`.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#merge_clause ⇒ String
A SQL statement that specifies a custom merge behavior.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#merge_when_matched ⇒ String
Specifies how to resolve records that match preexisting data when merging. Valid values: ‘ update`, `delete`.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#merge_when_not_matched ⇒ String
Specifies how to process records that do not match preexisting data when merging. Valid values: ‘insert`, `none`.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#post_action ⇒ String
A SQL string run after the Snowflake connector performs its standard actions.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#pre_action ⇒ String
A SQL string run before the Snowflake connector performs its standard actions.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#sample_query ⇒ String
A SQL string used to retrieve data with the ‘query` sourcetype.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ String
Specifies a Snowflake database schema for your node to use.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#selected_columns ⇒ Array<Types::Option>
Specifies the columns combined to identify a record when detecting matches for merges and upserts. A list of structures with ‘value`, `label` and ` description` keys. Each structure describes a column.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
Specifies how retrieved data is specified. Valid values: ‘“table”`, ` “query”`.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#staging_table ⇒ String
The name of a staging table used when performing ‘merge` or upsert `append` actions. Data is written to this table, then moved to `table` by a generated postaction.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#table ⇒ String
Specifies a Snowflake table for your node to use.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#table_schema ⇒ Array<Types::Option>
Manually defines the target schema for the node. A list of structures with ‘value` , `label` and `description` keys. Each structure defines a column.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#temp_dir ⇒ String
Not currently used.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |
#upsert ⇒ Boolean
Used when Action is ‘append`. Specifies the resolution behavior when a row already exists. If true, preexisting rows will be updated. If false, those rows will be inserted.
19785 19786 19787 19788 19789 19790 19791 19792 19793 19794 19795 19796 19797 19798 19799 19800 19801 19802 19803 19804 19805 19806 19807 19808 19809 |
# File 'lib/aws-sdk-glue/types.rb', line 19785 class SnowflakeNodeData < Struct.new( :source_type, :connection, :schema, :table, :database, :temp_dir, :iam_role, :additional_options, :sample_query, :pre_action, :post_action, :action, :upsert, :merge_action, :merge_when_matched, :merge_when_not_matched, :merge_clause, :staging_table, :selected_columns, :auto_pushdown, :table_schema) SENSITIVE = [] include Aws::Structure end |