Class: Aws::Glue::Types::SourceControlDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass SourceControlDetails data as a hash:

{
  provider: "GITHUB", # accepts GITHUB, AWS_CODE_COMMIT
  repository: "Generic512CharString",
  owner: "Generic512CharString",
  branch: "Generic512CharString",
  folder: "Generic512CharString",
  last_commit_id: "Generic512CharString",
  auth_strategy: "PERSONAL_ACCESS_TOKEN", # accepts PERSONAL_ACCESS_TOKEN, AWS_SECRETS_MANAGER
  auth_token: "Generic512CharString",
}

The details for a source control configuration for a job, allowing synchronization of job artifacts to or from a remote repository.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_strategyString

The type of authentication, which can be an authentication token stored in Amazon Web Services Secrets Manager, or a personal access token.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#auth_tokenString

The value of an authorization token.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#branchString

An optional branch in the remote repository.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#folderString

An optional folder in the remote repository.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#last_commit_idString

The last commit ID for a commit in the remote repository.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the remote repository that contains the job artifacts.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#providerString

The provider for the remote repository.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end

#repositoryString

The name of the remote repository that contains the job artifacts.

Returns:

  • (String)


21679
21680
21681
21682
21683
21684
21685
21686
21687
21688
21689
21690
# File 'lib/aws-sdk-glue/types.rb', line 21679

class SourceControlDetails < Struct.new(
  :provider,
  :repository,
  :owner,
  :branch,
  :folder,
  :last_commit_id,
  :auth_strategy,
  :auth_token)
  SENSITIVE = []
  include Aws::Structure
end