Class: Aws::Glue::Types::SourceTableConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SourceTableConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Properties used by the source leg to process data from the source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fields ⇒ Array<String>
A list of fields used for column-level filtering.
-
#filter_predicate ⇒ String
A condition clause used for row-level filtering.
-
#primary_key ⇒ Array<String>
Provide the primary key set for this table.
-
#record_update_field ⇒ String
Incremental pull timestamp-based field.
Instance Attribute Details
#fields ⇒ Array<String>
A list of fields used for column-level filtering. Currently unsupported.
28629 28630 28631 28632 28633 28634 28635 28636 |
# File 'lib/aws-sdk-glue/types.rb', line 28629 class SourceTableConfig < Struct.new( :fields, :filter_predicate, :primary_key, :record_update_field) SENSITIVE = [] include Aws::Structure end |
#filter_predicate ⇒ String
A condition clause used for row-level filtering. Currently unsupported.
28629 28630 28631 28632 28633 28634 28635 28636 |
# File 'lib/aws-sdk-glue/types.rb', line 28629 class SourceTableConfig < Struct.new( :fields, :filter_predicate, :primary_key, :record_update_field) SENSITIVE = [] include Aws::Structure end |
#primary_key ⇒ Array<String>
Provide the primary key set for this table. Currently supported
specifically for SAP EntityOf entities upon request. Contact
Amazon Web Services Support to make this feature available.
28629 28630 28631 28632 28633 28634 28635 28636 |
# File 'lib/aws-sdk-glue/types.rb', line 28629 class SourceTableConfig < Struct.new( :fields, :filter_predicate, :primary_key, :record_update_field) SENSITIVE = [] include Aws::Structure end |
#record_update_field ⇒ String
Incremental pull timestamp-based field. Currently unsupported.
28629 28630 28631 28632 28633 28634 28635 28636 |
# File 'lib/aws-sdk-glue/types.rb', line 28629 class SourceTableConfig < Struct.new( :fields, :filter_predicate, :primary_key, :record_update_field) SENSITIVE = [] include Aws::Structure end |