Class: Aws::Glue::Types::SqlAlias

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass SqlAlias data as a hash:

{
  from: "NodeId", # required
  alias: "EnclosedInStringPropertyWithQuote", # required
}

Represents a single entry in the list of values for `SqlAliases`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

A temporary name given to a table, or a column in a table.

Returns:

  • (String)


22003
22004
22005
22006
22007
22008
# File 'lib/aws-sdk-glue/types.rb', line 22003

class SqlAlias < Struct.new(
  :from,
  :alias)
  SENSITIVE = []
  include Aws::Structure
end

#fromString

A table, or a column in a table.

Returns:

  • (String)


22003
22004
22005
22006
22007
22008
# File 'lib/aws-sdk-glue/types.rb', line 22003

class SqlAlias < Struct.new(
  :from,
  :alias)
  SENSITIVE = []
  include Aws::Structure
end