Class: Aws::Glue::Types::SqlAlias
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::SqlAlias
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass SqlAlias data as a hash:
{
from: "NodeId", # required
alias: "EnclosedInStringPropertyWithQuote", # required
}
Represents a single entry in the list of values for `SqlAliases`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
A temporary name given to a table, or a column in a table.
-
#from ⇒ String
A table, or a column in a table.