Class: Aws::Glue::Types::StartColumnStatisticsTaskRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartColumnStatisticsTaskRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table reside.
-
#column_name_list ⇒ Array<String>
A list of the column names to generate statistics.
-
#database_name ⇒ String
The name of the database where the table resides.
-
#role ⇒ String
The IAM role that the service assumes to generate statistics.
-
#sample_size ⇒ Float
The percentage of rows used to generate statistics.
-
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs for the column stats task run.
-
#table_name ⇒ String
The name of the table to generate statistics.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table reside. If none is supplied, the Amazon Web Services account ID is used by default.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#column_name_list ⇒ Array<String>
A list of the column names to generate statistics. If none is supplied, all column names for the table will be used by default.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database where the table resides.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The IAM role that the service assumes to generate statistics.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#sample_size ⇒ Float
The percentage of rows used to generate statistics. If none is supplied, the entire table will be used to generate stats.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
Name of the security configuration that is used to encrypt CloudWatch logs for the column stats task run.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table to generate statistics.
24561 24562 24563 24564 24565 24566 24567 24568 24569 24570 24571 |
# File 'lib/aws-sdk-glue/types.rb', line 24561 class StartColumnStatisticsTaskRunRequest < Struct.new( :database_name, :table_name, :column_name_list, :role, :sample_size, :catalog_id, :security_configuration) SENSITIVE = [] include Aws::Structure end |