Class: Aws::Glue::Types::StartDataQualityRuleRecommendationRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartDataQualityRuleRecommendationRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
The request of the Data Quality rule recommendation request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_run_options ⇒ Types::DataQualityRuleRecommendationRunAdditionalRunOptions
Additional run options you can specify for a recommendation run.
-
#client_token ⇒ String
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
-
#created_ruleset_name ⇒ String
A name for the ruleset.
-
#data_quality_security_configuration ⇒ String
The name of the security configuration created with the data quality encryption option.
-
#data_source ⇒ Types::DataSource
The data source (Glue table) associated with this run.
-
#number_of_workers ⇒ Integer
The number of
G.1Xworkers to be used in the run. -
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
-
#timeout ⇒ Integer
The timeout for a run in minutes.
Instance Attribute Details
#additional_run_options ⇒ Types::DataQualityRuleRecommendationRunAdditionalRunOptions
Additional run options you can specify for a recommendation run.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#created_ruleset_name ⇒ String
A name for the ruleset.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#data_quality_security_configuration ⇒ String
The name of the security configuration created with the data quality encryption option.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#data_source ⇒ Types::DataSource
The data source (Glue table) associated with this run.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of G.1X workers to be used in the run. The default is
5.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
An IAM role supplied to encrypt the results of the run.
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a run in minutes. This is the maximum time that a
run can consume resources before it is terminated and enters
TIMEOUT status. The default is 2,880 minutes (48 hours).
28730 28731 28732 28733 28734 28735 28736 28737 28738 28739 28740 28741 |
# File 'lib/aws-sdk-glue/types.rb', line 28730 class StartDataQualityRuleRecommendationRunRequest < Struct.new( :data_source, :role, :number_of_workers, :timeout, :created_ruleset_name, :data_quality_security_configuration, :client_token, :additional_run_options) SENSITIVE = [] include Aws::Structure end |