Class: Aws::Glue::Types::StartJobRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_capacityInteger

This field is deprecated. Use ‘MaxCapacity` instead.

The number of Glue data processing units (DPUs) to allocate to this JobRun. You can allocate a minimum of 2 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Integer)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#argumentsHash<String,String>

The job arguments specifically for this run. For this job run, they replace the default arguments set in the job definition itself.

You can specify arguments here that your own job-execution script consumes, as well as arguments that Glue itself consumes.

Job arguments may be logged. Do not pass plaintext secrets as arguments. Retrieve secrets from a Glue Connection, Secrets Manager or other secret management mechanism if you intend to keep them within the Job.

For information about how to specify and consume your own Job arguments, see the [Calling Glue APIs in Python] topic in the developer guide.

For information about the key-value pairs that Glue consumes to set up your job, see the [Special Parameters Used by Glue] topic in the developer guide.

[1]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-python-calling.html [2]: docs.aws.amazon.com/glue/latest/dg/aws-glue-programming-etl-glue-arguments.html

Returns:

  • (Hash<String,String>)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#execution_classString

Indicates whether the job is run with a standard or flexible execution class. The standard execution-class is ideal for time-sensitive workloads that require fast job startup and dedicated resources.

The flexible execution class is appropriate for time-insensitive jobs whose start and completion times may vary.

Only jobs with Glue version 3.0 and above and command type ‘glueetl` will be allowed to set `ExecutionClass` to `FLEX`. The flexible execution class is available for Spark jobs.

Returns:

  • (String)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the job definition to use.

Returns:

  • (String)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#job_run_idString

The ID of a previous ‘JobRun` to retry.

Returns:

  • (String)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].

Do not set ‘Max Capacity` if using `WorkerType` and `NumberOfWorkers`.

The value that can be allocated for ‘MaxCapacity` depends on whether you are running a Python shell job, or an Apache Spark ETL job:

  • When you specify a Python shell job (‘JobCommand.Name`=“pythonshell”), you can allocate either 0.0625 or 1 DPU. The default is 0.0625 DPU.

  • When you specify an Apache Spark ETL job (‘JobCommand.Name`=“glueetl”), you can allocate a minimum of 2 DPUs. The default is 10 DPUs. This job type cannot have a fractional DPU allocation.

[1]: aws.amazon.com/glue/pricing/

Returns:

  • (Float)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#notification_propertyTypes::NotificationProperty

Specifies configuration properties of a job run notification.



17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined ‘workerType` that are allocated when a job runs.

Returns:

  • (Integer)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#security_configurationString

The name of the ‘SecurityConfiguration` structure to be used with this job run.

Returns:

  • (String)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The ‘JobRun` timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters `TIMEOUT` status. This value overrides the timeout value set in the parent job.

Streaming jobs do not have a timeout. The default for non-streaming jobs is 2,880 minutes (48 hours).

Returns:

  • (Integer)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, G.2X, or G.025X.

  • For the ‘Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the ‘G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the ‘G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

  • For the ‘G.025X` worker type, each worker maps to 0.25 DPU (2 vCPU, 4 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for low volume streaming jobs. This worker type is only available for Glue version 3.0 streaming jobs.

Returns:

  • (String)


17985
17986
17987
17988
17989
17990
17991
17992
17993
17994
17995
17996
17997
17998
17999
# File 'lib/aws-sdk-glue/types.rb', line 17985

class StartJobRunRequest < Struct.new(
  :job_name,
  :job_run_id,
  :arguments,
  :allocated_capacity,
  :timeout,
  :max_capacity,
  :security_configuration,
  :notification_property,
  :worker_type,
  :number_of_workers,
  :execution_class)
  SENSITIVE = []
  include Aws::Structure
end