Class: Aws::Glue::Types::StartWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workflow to start.
-
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
Instance Attribute Details
#name ⇒ String
The name of the workflow to start.
18500 18501 18502 18503 18504 18505 |
# File 'lib/aws-sdk-glue/types.rb', line 18500 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
18500 18501 18502 18503 18504 18505 |
# File 'lib/aws-sdk-glue/types.rb', line 18500 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |