Class: Aws::Glue::Types::StartWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::StartWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass StartWorkflowRunRequest data as a hash:
{
name: "NameString", # required
run_properties: {
"IdString" => "GenericString",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the workflow to start.
-
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
Instance Attribute Details
#name ⇒ String
The name of the workflow to start.
15768 15769 15770 15771 15772 15773 |
# File 'lib/aws-sdk-glue/types.rb', line 15768 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |
#run_properties ⇒ Hash<String,String>
The workflow run properties for the new workflow run.
15768 15769 15770 15771 15772 15773 |
# File 'lib/aws-sdk-glue/types.rb', line 15768 class StartWorkflowRunRequest < Struct.new( :name, :run_properties) SENSITIVE = [] include Aws::Structure end |