Class: Aws::Glue::Types::Table
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Table
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Represents a collection of related data organized in columns and rows.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
-
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
-
#created_by ⇒ String
The person or entity who created the table.
-
#database_name ⇒ String
The name of the database where the table metadata resides.
-
#description ⇒ String
A description of the table.
-
#federated_table ⇒ Types::FederatedTable
A
FederatedTablestructure that references an entity outside the Glue Data Catalog. -
#iceberg_table_metadata ⇒ Types::IcebergTableMetadata
The latest Apache Iceberg table metadata for the table, including format version, schemas, partition specifications, and sort orders.
-
#is_materialized_view ⇒ Boolean
Indicates a table is a
MaterializedView. -
#is_multi_dialect_view ⇒ Boolean
Specifies whether the view supports the SQL dialects of one or more different query engines and can therefore be read by those engines.
-
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
-
#last_access_time ⇒ Time
The last time that the table was accessed.
-
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
-
#name ⇒ String
The table name.
-
#owner ⇒ String
The owner of the table.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
-
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned.
-
#retention ⇒ Integer
The retention time for this table.
-
#status ⇒ Types::TableStatus
Indicates the the state of an asynchronous change to a table.
-
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
-
#table_type ⇒ String
The type of this table.
-
#target_table ⇒ Types::TableIdentifier
A
TableIdentifierstructure that describes a target table for resource linking. -
#update_time ⇒ Time
The last time that the table was updated.
-
#version_id ⇒ String
The ID of the table version.
-
#view_definition ⇒ Types::ViewDefinition
A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.
-
#view_expanded_text ⇒ String
Included for Apache Hive compatibility.
-
#view_original_text ⇒ String
Included for Apache Hive compatibility.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The person or entity who created the table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#federated_table ⇒ Types::FederatedTable
A FederatedTable structure that references an entity outside the
Glue Data Catalog.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#iceberg_table_metadata ⇒ Types::IcebergTableMetadata
The latest Apache Iceberg table metadata for the table, including format version, schemas, partition specifications, and sort orders. This field is populated for Iceberg tables and reflects the current state of the table's Iceberg metadata.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#is_materialized_view ⇒ Boolean
Indicates a table is a MaterializedView.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#is_multi_dialect_view ⇒ Boolean
Specifies whether the view supports the SQL dialects of one or more different query engines and can therefore be read by those engines.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#last_access_time ⇒ Time
The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The table name. For Hive compatibility, this must be entirely lowercase.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.
When you create a table used by Amazon Athena, and you do not
specify any partitionKeys, you must at least set the value of
partitionKeys to an empty list. For example:
"PartitionKeys": []
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Integer
The retention time for this table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::TableStatus
Indicates the the state of an asynchronous change to a table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#table_type ⇒ String
The type of this table. Glue will create tables with the
EXTERNAL_TABLE type. Other services, such as Athena, may create
tables with additional table types.
Glue related table types:
EXTERNAL_TABLE
: Hive compatible attribute - indicates a non-Hive managed table.
GOVERNED
: Used by Lake Formation. The Glue Data Catalog understands
GOVERNED.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#target_table ⇒ Types::TableIdentifier
A TableIdentifier structure that describes a target table for
resource linking.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The last time that the table was updated.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of the table version.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#view_definition ⇒ Types::ViewDefinition
A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal course of Glue operations.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal
course of Glue operations. If the table is a VIRTUAL_VIEW, certain
Athena configuration encoded in base64.
30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 30048 30049 30050 30051 30052 30053 30054 30055 |
# File 'lib/aws-sdk-glue/types.rb', line 30026 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table, :view_definition, :is_multi_dialect_view, :is_materialized_view, :iceberg_table_metadata, :status) SENSITIVE = [] include Aws::Structure end |