Class: Aws::Glue::Types::Table
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Table
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Represents a collection of related data organized in columns and rows.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
-
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
-
#created_by ⇒ String
The person or entity who created the table.
-
#database_name ⇒ String
The name of the database where the table metadata resides.
-
#description ⇒ String
A description of the table.
-
#federated_table ⇒ Types::FederatedTable
A ‘FederatedTable` structure that references an entity outside the Glue Data Catalog.
-
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
-
#last_access_time ⇒ Time
The last time that the table was accessed.
-
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
-
#name ⇒ String
The table name.
-
#owner ⇒ String
The owner of the table.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
-
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned.
-
#retention ⇒ Integer
The retention time for this table.
-
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
-
#table_type ⇒ String
The type of this table.
-
#target_table ⇒ Types::TableIdentifier
A ‘TableIdentifier` structure that describes a target table for resource linking.
-
#update_time ⇒ Time
The last time that the table was updated.
-
#version_id ⇒ String
The ID of the table version.
-
#view_expanded_text ⇒ String
Included for Apache Hive compatibility.
-
#view_original_text ⇒ String
Included for Apache Hive compatibility.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The person or entity who created the table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#federated_table ⇒ Types::FederatedTable
A ‘FederatedTable` structure that references an entity outside the Glue Data Catalog.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#last_access_time ⇒ Time
The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The table name. For Hive compatibility, this must be entirely lowercase.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.
When you create a table used by Amazon Athena, and you do not specify any ‘partitionKeys`, you must at least set the value of `partitionKeys` to an empty list. For example:
‘“PartitionKeys”: []`
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Integer
The retention time for this table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#table_type ⇒ String
The type of this table. Glue will create tables with the ‘EXTERNAL_TABLE` type. Other services, such as Athena, may create tables with additional table types.
Glue related table types:
EXTERNAL_TABLE
: Hive compatible attribute - indicates a non-Hive managed table.
GOVERNED
: Used by Lake Formation. The Glue Data Catalog understands
`GOVERNED`.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#target_table ⇒ Types::TableIdentifier
A ‘TableIdentifier` structure that describes a target table for resource linking.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The last time that the table was updated.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of the table version.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal course of Glue operations.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a ‘VIRTUAL_VIEW`, certain Athena configuration encoded in base64.
20550 20551 20552 20553 20554 20555 20556 20557 20558 20559 20560 20561 20562 20563 20564 20565 20566 20567 20568 20569 20570 20571 20572 20573 20574 |
# File 'lib/aws-sdk-glue/types.rb', line 20550 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id, :federated_table) SENSITIVE = [] include Aws::Structure end |