Class: Aws::Glue::Types::Table

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Represents a collection of related data organized in columns and rows.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the table resides.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time when the table definition was created in the Data Catalog.

Returns:

  • (Time)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The person or entity who created the table.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the table.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#federated_tableTypes::FederatedTable

A ‘FederatedTable` structure that references an entity outside the Glue Data Catalog.



19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#is_registered_with_lake_formationBoolean

Indicates whether the table has been registered with Lake Formation.

Returns:

  • (Boolean)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#last_access_timeTime

The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.

Returns:

  • (Time)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#last_analyzed_timeTime

The last time that column statistics were computed for this table.

Returns:

  • (Time)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The table name. For Hive compatibility, this must be entirely lowercase.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the table.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

These key-value pairs define properties associated with the table.

Returns:

  • (Hash<String,String>)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Types::Column>

A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.

When you create a table used by Amazon Athena, and you do not specify any ‘partitionKeys`, you must at least set the value of `partitionKeys` to an empty list. For example:

‘“PartitionKeys”: []`

Returns:



19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#retentionInteger

The retention time for this table.

Returns:

  • (Integer)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#storage_descriptorTypes::StorageDescriptor

A storage descriptor containing information about the physical storage of this table.



19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#table_typeString

The type of this table. Glue will create tables with the ‘EXTERNAL_TABLE` type. Other services, such as Athena, may create tables with additional table types.

Glue related table types:

EXTERNAL_TABLE

: Hive compatible attribute - indicates a non-Hive managed table.

GOVERNED

: Used by Lake Formation. The Glue Data Catalog understands

`GOVERNED`.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#target_tableTypes::TableIdentifier

A ‘TableIdentifier` structure that describes a target table for resource linking.



19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The last time that the table was updated.

Returns:

  • (Time)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The ID of the table version.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#view_expanded_textString

Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end

#view_original_textString

Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a ‘VIRTUAL_VIEW`, certain Athena configuration encoded in base64.

Returns:

  • (String)


19292
19293
19294
19295
19296
19297
19298
19299
19300
19301
19302
19303
19304
19305
19306
19307
19308
19309
19310
19311
19312
19313
19314
19315
19316
# File 'lib/aws-sdk-glue/types.rb', line 19292

class Table < Struct.new(
  :name,
  :database_name,
  :description,
  :owner,
  :create_time,
  :update_time,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :created_by,
  :is_registered_with_lake_formation,
  :target_table,
  :catalog_id,
  :version_id,
  :federated_table)
  SENSITIVE = []
  include Aws::Structure
end