Class: Aws::Glue::Types::Table
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Table
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Represents a collection of related data organized in columns and rows.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
-
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
-
#created_by ⇒ String
The person or entity who created the table.
-
#database_name ⇒ String
The name of the database where the table metadata resides.
-
#description ⇒ String
A description of the table.
-
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
-
#last_access_time ⇒ Time
The last time that the table was accessed.
-
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
-
#name ⇒ String
The table name.
-
#owner ⇒ String
The owner of the table.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
-
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned.
-
#retention ⇒ Integer
The retention time for this table.
-
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
-
#table_type ⇒ String
The type of this table (`EXTERNAL_TABLE`, `VIRTUAL_VIEW`, etc.).
-
#target_table ⇒ Types::TableIdentifier
A `TableIdentifier` structure that describes a target table for resource linking.
-
#update_time ⇒ Time
The last time that the table was updated.
-
#version_id ⇒ String
The ID of the table version.
-
#view_expanded_text ⇒ String
If the table is a view, the expanded text of the view; otherwise `null`.
-
#view_original_text ⇒ String
If the table is a view, the original text of the view; otherwise `null`.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the table definition was created in the Data Catalog.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The person or entity who created the table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#is_registered_with_lake_formation ⇒ Boolean
Indicates whether the table has been registered with Lake Formation.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#last_access_time ⇒ Time
The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The table name. For Hive compatibility, this must be entirely lowercase.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.
When you create a table used by Amazon Athena, and you do not specify any `partitionKeys`, you must at least set the value of `partitionKeys` to an empty list. For example:
`“PartitionKeys”: []`
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Integer
The retention time for this table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#table_type ⇒ String
The type of this table (`EXTERNAL_TABLE`, `VIRTUAL_VIEW`, etc.).
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#target_table ⇒ Types::TableIdentifier
A `TableIdentifier` structure that describes a target table for resource linking.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The last time that the table was updated.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of the table version.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
If the table is a view, the expanded text of the view; otherwise `null`.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
If the table is a view, the original text of the view; otherwise `null`.
18073 18074 18075 18076 18077 18078 18079 18080 18081 18082 18083 18084 18085 18086 18087 18088 18089 18090 18091 18092 18093 18094 18095 18096 |
# File 'lib/aws-sdk-glue/types.rb', line 18073 class Table < Struct.new( :name, :database_name, :description, :owner, :create_time, :update_time, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :created_by, :is_registered_with_lake_formation, :target_table, :catalog_id, :version_id) SENSITIVE = [] include Aws::Structure end |