Class: Aws::Glue::Types::TableIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure that describes a target table for resource linking.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
-
#database_name ⇒ String
The name of the catalog database that contains the target table.
-
#name ⇒ String
The name of the target table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the table resides.
19149 19150 19151 19152 19153 19154 19155 |
# File 'lib/aws-sdk-glue/types.rb', line 19149 class TableIdentifier < Struct.new( :catalog_id, :database_name, :name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database that contains the target table.
19149 19150 19151 19152 19153 19154 19155 |
# File 'lib/aws-sdk-glue/types.rb', line 19149 class TableIdentifier < Struct.new( :catalog_id, :database_name, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the target table.
19149 19150 19151 19152 19153 19154 19155 |
# File 'lib/aws-sdk-glue/types.rb', line 19149 class TableIdentifier < Struct.new( :catalog_id, :database_name, :name) SENSITIVE = [] include Aws::Structure end |