Class: Aws::Glue::Types::TableIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass TableIdentifier data as a hash:

{
  catalog_id: "CatalogIdString",
  database_name: "NameString",
  name: "NameString",
}

A structure that describes a target table for resource linking.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the table resides.

Returns:

  • (String)


23176
23177
23178
23179
23180
23181
23182
# File 'lib/aws-sdk-glue/types.rb', line 23176

class TableIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database that contains the target table.

Returns:

  • (String)


23176
23177
23178
23179
23180
23181
23182
# File 'lib/aws-sdk-glue/types.rb', line 23176

class TableIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the target table.

Returns:

  • (String)


23176
23177
23178
23179
23180
23181
23182
# File 'lib/aws-sdk-glue/types.rb', line 23176

class TableIdentifier < Struct.new(
  :catalog_id,
  :database_name,
  :name)
  SENSITIVE = []
  include Aws::Structure
end