Class: Aws::Glue::Types::TableInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure used to define a table.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the table.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#last_access_timeTime

The last time that the table was accessed.

Returns:

  • (Time)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#last_analyzed_timeTime

The last time that column statistics were computed for this table.

Returns:

  • (Time)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The table name. For Hive compatibility, this is folded to lowercase when it is stored.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The table owner. Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

These key-value pairs define properties associated with the table.

Returns:

  • (Hash<String,String>)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#partition_keysArray<Types::Column>

A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.

When you create a table used by Amazon Athena, and you do not specify any ‘partitionKeys`, you must at least set the value of `partitionKeys` to an empty list. For example:

‘“PartitionKeys”: []`

Returns:



28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#retentionInteger

The retention time for this table.

Returns:

  • (Integer)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#storage_descriptorTypes::StorageDescriptor

A storage descriptor containing information about the physical storage of this table.



28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#table_typeString

The type of this table. Glue will create tables with the ‘EXTERNAL_TABLE` type. Other services, such as Athena, may create tables with additional table types.

Glue related table types:

EXTERNAL_TABLE

: Hive compatible attribute - indicates a non-Hive managed table.

GOVERNED

: Used by Lake Formation. The Glue Data Catalog understands

`GOVERNED`.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#target_tableTypes::TableIdentifier

A ‘TableIdentifier` structure that describes a target table for resource linking.



28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#view_definitionTypes::ViewDefinitionInput

A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.



28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#view_expanded_textString

Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end

#view_original_textString

Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a ‘VIRTUAL_VIEW`, certain Athena configuration encoded in base64.

Returns:

  • (String)


28092
28093
28094
28095
28096
28097
28098
28099
28100
28101
28102
28103
28104
28105
28106
28107
28108
28109
# File 'lib/aws-sdk-glue/types.rb', line 28092

class TableInput < Struct.new(
  :name,
  :description,
  :owner,
  :last_access_time,
  :last_analyzed_time,
  :retention,
  :storage_descriptor,
  :partition_keys,
  :view_original_text,
  :view_expanded_text,
  :table_type,
  :parameters,
  :target_table,
  :view_definition)
  SENSITIVE = []
  include Aws::Structure
end