Class: Aws::Glue::Types::TableInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure used to define a table.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the table.
-
#last_access_time ⇒ Time
The last time that the table was accessed.
-
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
-
#name ⇒ String
The table name.
-
#owner ⇒ String
The table owner.
-
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
-
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned.
-
#retention ⇒ Integer
The retention time for this table.
-
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
-
#table_type ⇒ String
The type of this table (‘EXTERNAL_TABLE`, `VIRTUAL_VIEW`, etc.).
-
#target_table ⇒ Types::TableIdentifier
A ‘TableIdentifier` structure that describes a target table for resource linking.
-
#view_expanded_text ⇒ String
If the table is a view, the expanded text of the view; otherwise ‘null`.
-
#view_original_text ⇒ String
If the table is a view, the original text of the view; otherwise ‘null`.
Instance Attribute Details
#description ⇒ String
A description of the table.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#last_access_time ⇒ Time
The last time that the table was accessed.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#last_analyzed_time ⇒ Time
The last time that column statistics were computed for this table.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The table name. For Hive compatibility, this is folded to lowercase when it is stored.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The table owner.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
These key-value pairs define properties associated with the table.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#partition_keys ⇒ Array<Types::Column>
A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.
When you create a table used by Amazon Athena, and you do not specify any ‘partitionKeys`, you must at least set the value of `partitionKeys` to an empty list. For example:
‘“PartitionKeys”: []`
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#retention ⇒ Integer
The retention time for this table.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#storage_descriptor ⇒ Types::StorageDescriptor
A storage descriptor containing information about the physical storage of this table.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#table_type ⇒ String
The type of this table (‘EXTERNAL_TABLE`, `VIRTUAL_VIEW`, etc.).
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#target_table ⇒ Types::TableIdentifier
A ‘TableIdentifier` structure that describes a target table for resource linking.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#view_expanded_text ⇒ String
If the table is a view, the expanded text of the view; otherwise ‘null`.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |
#view_original_text ⇒ String
If the table is a view, the original text of the view; otherwise ‘null`.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 |
# File 'lib/aws-sdk-glue/types.rb', line 18300 class TableInput < Struct.new( :name, :description, :owner, :last_access_time, :last_analyzed_time, :retention, :storage_descriptor, :partition_keys, :view_original_text, :view_expanded_text, :table_type, :parameters, :target_table) SENSITIVE = [] include Aws::Structure end |