Class: Aws::Glue::Types::TableOptimizerRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableOptimizerRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains details for a table optimizer run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
-
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
-
#error ⇒ String
An error that occured during the optimizer run.
-
#event_type ⇒ String
An event type representing the status of the table optimizer run.
-
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
-
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
-
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
-
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
Instance Attribute Details
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#error ⇒ String
An error that occured during the optimizer run.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
An event type representing the status of the table optimizer run.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
25817 25818 25819 25820 25821 25822 25823 25824 25825 25826 25827 25828 |
# File 'lib/aws-sdk-glue/types.rb', line 25817 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |