Class: Aws::Glue::Types::TableOptimizerRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TableOptimizerRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Contains details for a table optimizer run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
-
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
-
#error ⇒ String
An error that occured during the optimizer run.
-
#event_type ⇒ String
An event type representing the status of the table optimizer run.
-
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
-
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
-
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
-
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
Instance Attribute Details
#compaction_metrics ⇒ Types::CompactionMetrics
A ‘CompactionMetrics` object containing metrics for the optimizer run.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#end_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job ended.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#error ⇒ String
An error that occured during the optimizer run.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
An event type representing the status of the table optimizer run.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Types::RunMetrics
A ‘RunMetrics` object containing metrics for the optimizer run.
This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#orphan_file_deletion_metrics ⇒ Types::OrphanFileDeletionMetrics
An ‘OrphanFileDeletionMetrics` object containing metrics for the optimizer run.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#retention_metrics ⇒ Types::RetentionMetrics
A ‘RetentionMetrics` object containing metrics for the optimizer run.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |
#start_timestamp ⇒ Time
Represents the epoch timestamp at which the compaction job was started within Lake Formation.
22732 22733 22734 22735 22736 22737 22738 22739 22740 22741 22742 22743 |
# File 'lib/aws-sdk-glue/types.rb', line 22732 class TableOptimizerRun < Struct.new( :event_type, :start_timestamp, :end_timestamp, :metrics, :error, :compaction_metrics, :retention_metrics, :orphan_file_deletion_metrics) SENSITIVE = [] include Aws::Structure end |