Class: Aws::Glue::Types::TestConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TestConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The catalog ID where the connection resides.
-
#connection_name ⇒ String
Optional.
-
#test_connection_input ⇒ Types::TestConnectionInput
A structure that is used to specify testing a connection to a service.
Instance Attribute Details
#catalog_id ⇒ String
The catalog ID where the connection resides.
28769 28770 28771 28772 28773 28774 28775 |
# File 'lib/aws-sdk-glue/types.rb', line 28769 class TestConnectionRequest < Struct.new( :connection_name, :catalog_id, :test_connection_input) SENSITIVE = [] include Aws::Structure end |
#connection_name ⇒ String
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
28769 28770 28771 28772 28773 28774 28775 |
# File 'lib/aws-sdk-glue/types.rb', line 28769 class TestConnectionRequest < Struct.new( :connection_name, :catalog_id, :test_connection_input) SENSITIVE = [] include Aws::Structure end |
#test_connection_input ⇒ Types::TestConnectionInput
A structure that is used to specify testing a connection to a service.
28769 28770 28771 28772 28773 28774 28775 |
# File 'lib/aws-sdk-glue/types.rb', line 28769 class TestConnectionRequest < Struct.new( :connection_name, :catalog_id, :test_connection_input) SENSITIVE = [] include Aws::Structure end |