Class: Aws::Glue::Types::TestConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TestConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_name ⇒ String
Optional.
-
#test_connection_input ⇒ Types::TestConnectionInput
A structure that is used to specify testing a connection to a service.
Instance Attribute Details
#connection_name ⇒ String
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
23292 23293 23294 23295 23296 23297 |
# File 'lib/aws-sdk-glue/types.rb', line 23292 class TestConnectionRequest < Struct.new( :connection_name, :test_connection_input) SENSITIVE = [] include Aws::Structure end |
#test_connection_input ⇒ Types::TestConnectionInput
A structure that is used to specify testing a connection to a service.
23292 23293 23294 23295 23296 23297 |
# File 'lib/aws-sdk-glue/types.rb', line 23292 class TestConnectionRequest < Struct.new( :connection_name, :test_connection_input) SENSITIVE = [] include Aws::Structure end |