Class: Aws::Glue::Types::TransformConfigParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TransformConfigParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass TransformConfigParameter data as a hash:
{
name: "EnclosedInStringProperty", # required
type: "str", # required, accepts str, int, float, complex, bool, list, null
validation_rule: "EnclosedInStringProperty",
validation_message: "EnclosedInStringProperty",
value: ["EnclosedInStringProperty"],
list_type: "str", # accepts str, int, float, complex, bool, list, null
is_optional: false,
}
Specifies the parameters in the config file of the dynamic transform.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_optional ⇒ Boolean
Specifies whether the parameter is optional or not in the config file of the dynamic transform.
-
#list_type ⇒ String
Specifies the list type of the parameter in the config file of the dynamic transform.
-
#name ⇒ String
Specifies the name of the parameter in the config file of the dynamic transform.
-
#type ⇒ String
Specifies the parameter type in the config file of the dynamic transform.
-
#validation_message ⇒ String
Specifies the validation message in the config file of the dynamic transform.
-
#validation_rule ⇒ String
Specifies the validation rule in the config file of the dynamic transform.
-
#value ⇒ Array<String>
Specifies the value of the parameter in the config file of the dynamic transform.
Instance Attribute Details
#is_optional ⇒ Boolean
Specifies whether the parameter is optional or not in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#list_type ⇒ String
Specifies the list type of the parameter in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies the name of the parameter in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies the parameter type in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#validation_message ⇒ String
Specifies the validation message in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#validation_rule ⇒ String
Specifies the validation rule in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Array<String>
Specifies the value of the parameter in the config file of the dynamic transform.
23800 23801 23802 23803 23804 23805 23806 23807 23808 23809 23810 |
# File 'lib/aws-sdk-glue/types.rb', line 23800 class TransformConfigParameter < Struct.new( :name, :type, :validation_rule, :validation_message, :value, :list_type, :is_optional) SENSITIVE = [] include Aws::Structure end |