Class: Aws::Glue::Types::TransformEncryption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.

Additionally, imported labels and trained transforms can now be encrypted using a customer provided KMS key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ml_user_data_encryptionTypes::MLUserDataEncryption

An ‘MLUserDataEncryption` object containing the encryption mode and customer-provided KMS key ID.



19548
19549
19550
19551
19552
19553
# File 'lib/aws-sdk-glue/types.rb', line 19548

class TransformEncryption < Struct.new(
  :ml_user_data_encryption,
  :task_run_security_configuration_name)
  SENSITIVE = []
  include Aws::Structure
end

#task_run_security_configuration_nameString

The name of the security configuration.

Returns:

  • (String)


19548
19549
19550
19551
19552
19553
# File 'lib/aws-sdk-glue/types.rb', line 19548

class TransformEncryption < Struct.new(
  :ml_user_data_encryption,
  :task_run_security_configuration_name)
  SENSITIVE = []
  include Aws::Structure
end