Class: Aws::Glue::Types::TransformEncryption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TransformEncryption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass TransformEncryption data as a hash:
{
ml_user_data_encryption: {
ml_user_data_encryption_mode: "DISABLED", # required, accepts DISABLED, SSE-KMS
kms_key_id: "NameString",
},
task_run_security_configuration_name: "NameString",
}
The encryption-at-rest settings of the transform that apply to accessing user data. Machine learning transforms can access user data encrypted in Amazon S3 using KMS.
Additionally, imported labels and trained transforms can now be encrypted using a customer provided KMS key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ml_user_data_encryption ⇒ Types::MLUserDataEncryption
An `MLUserDataEncryption` object containing the encryption mode and customer-provided KMS key ID.
-
#task_run_security_configuration_name ⇒ String
The name of the security configuration.
Instance Attribute Details
#ml_user_data_encryption ⇒ Types::MLUserDataEncryption
An `MLUserDataEncryption` object containing the encryption mode and customer-provided KMS key ID.
23405 23406 23407 23408 23409 23410 |
# File 'lib/aws-sdk-glue/types.rb', line 23405 class TransformEncryption < Struct.new( :ml_user_data_encryption, :task_run_security_configuration_name) SENSITIVE = [] include Aws::Structure end |
#task_run_security_configuration_name ⇒ String
The name of the security configuration.
23405 23406 23407 23408 23409 23410 |
# File 'lib/aws-sdk-glue/types.rb', line 23405 class TransformEncryption < Struct.new( :ml_user_data_encryption, :task_run_security_configuration_name) SENSITIVE = [] include Aws::Structure end |