Class: Aws::Glue::Types::Trigger

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Information about a specific trigger.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::Action>

The actions initiated by this trigger.

Returns:



26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of this trigger.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#event_batching_conditionTypes::EventBatchingCondition

Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.



26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Reserved for future use.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the trigger.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#predicateTypes::Predicate

The predicate of this trigger, which defines when it will fire.

Returns:



26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.

[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the trigger.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of trigger that this is.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_nameString

The name of the workflow associated with the trigger.

Returns:

  • (String)


26711
26712
26713
26714
26715
26716
26717
26718
26719
26720
26721
26722
26723
26724
# File 'lib/aws-sdk-glue/types.rb', line 26711

class Trigger < Struct.new(
  :name,
  :workflow_name,
  :id,
  :type,
  :state,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end