Class: Aws::Glue::Types::Trigger
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Trigger
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Information about a specific trigger.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
-
#description ⇒ String
A description of this trigger.
-
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
-
#id ⇒ String
Reserved for future use.
-
#name ⇒ String
The name of the trigger.
-
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
-
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
-
#state ⇒ String
The current state of the trigger.
-
#type ⇒ String
The type of trigger that this is.
-
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of this trigger.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Reserved for future use.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the trigger.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the trigger.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of trigger that this is.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#workflow_name ⇒ String
The name of the workflow associated with the trigger.
23055 23056 23057 23058 23059 23060 23061 23062 23063 23064 23065 23066 23067 23068 |
# File 'lib/aws-sdk-glue/types.rb', line 23055 class Trigger < Struct.new( :name, :workflow_name, :id, :type, :state, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |