Class: Aws::Glue::Types::TriggerUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure used to provide information used to update a trigger. This object updates the previous trigger definition by overwriting it completely.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<Types::Action>

The actions initiated by this trigger.

Returns:



31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of this trigger.

Returns:

  • (String)


31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#event_batching_conditionTypes::EventBatchingCondition

Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.



31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Reserved for future use.

Returns:

  • (String)


31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#predicateTypes::Predicate

The predicate of this trigger, which defines when it will fire.

Returns:



31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

A cron expression used to specify the schedule (see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, you would specify: cron(15 12 * * ? *).

Returns:

  • (String)


31557
31558
31559
31560
31561
31562
31563
31564
31565
31566
# File 'lib/aws-sdk-glue/types.rb', line 31557

class TriggerUpdate < Struct.new(
  :name,
  :description,
  :schedule,
  :actions,
  :predicate,
  :event_batching_condition)
  SENSITIVE = []
  include Aws::Structure
end