Class: Aws::Glue::Types::TriggerUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TriggerUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure used to provide information used to update a trigger. This object updates the previous trigger definition by overwriting it completely.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
-
#description ⇒ String
A description of this trigger.
-
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
-
#name ⇒ String
Reserved for future use.
-
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
-
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of this trigger.
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Reserved for future use.
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html
27720 27721 27722 27723 27724 27725 27726 27727 27728 27729 |
# File 'lib/aws-sdk-glue/types.rb', line 27720 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |