Class: Aws::Glue::Types::TriggerUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::TriggerUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass TriggerUpdate data as a hash:
{
name: "NameString",
description: "DescriptionString",
schedule: "GenericString",
actions: [
{
job_name: "NameString",
arguments: {
"GenericString" => "GenericString",
},
timeout: 1,
security_configuration: "NameString",
notification_property: {
notify_delay_after: 1,
},
crawler_name: "NameString",
},
],
predicate: {
logical: "AND", # accepts AND, ANY
conditions: [
{
logical_operator: "EQUALS", # accepts EQUALS
job_name: "NameString",
state: "STARTING", # accepts STARTING, RUNNING, STOPPING, STOPPED, SUCCEEDED, FAILED, TIMEOUT
crawler_name: "NameString",
crawl_state: "RUNNING", # accepts RUNNING, CANCELLING, CANCELLED, SUCCEEDED, FAILED
},
],
},
event_batching_condition: {
batch_size: 1, # required
batch_window: 1,
},
}
A structure used to provide information used to update a trigger. This object updates the previous trigger definition by overwriting it completely.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
-
#description ⇒ String
A description of this trigger.
-
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
-
#name ⇒ String
Reserved for future use.
-
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
-
#schedule ⇒ String
A `cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
Instance Attribute Details
#actions ⇒ Array<Types::Action>
The actions initiated by this trigger.
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of this trigger.
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#event_batching_condition ⇒ Types::EventBatchingCondition
Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Reserved for future use.
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#predicate ⇒ Types::Predicate
The predicate of this trigger, which defines when it will fire.
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ String
A `cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.
[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html
16463 16464 16465 16466 16467 16468 16469 16470 16471 16472 |
# File 'lib/aws-sdk-glue/types.rb', line 16463 class TriggerUpdate < Struct.new( :name, :description, :schedule, :actions, :predicate, :event_batching_condition) SENSITIVE = [] include Aws::Structure end |