Class: Aws::Glue::Types::Union
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Union
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a transform that combines the rows from two or more datasets into a single result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inputs ⇒ Array<String>
The node ID inputs to the transform.
-
#name ⇒ String
The name of the transform node.
-
#union_type ⇒ String
Indicates the type of Union transform.
Instance Attribute Details
#inputs ⇒ Array<String>
The node ID inputs to the transform.
31505 31506 31507 31508 31509 31510 31511 |
# File 'lib/aws-sdk-glue/types.rb', line 31505 class Union < Struct.new( :name, :inputs, :union_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the transform node.
31505 31506 31507 31508 31509 31510 31511 |
# File 'lib/aws-sdk-glue/types.rb', line 31505 class Union < Struct.new( :name, :inputs, :union_type) SENSITIVE = [] include Aws::Structure end |
#union_type ⇒ String
Indicates the type of Union transform.
Specify ALL to join all rows from data sources to the resulting
DynamicFrame. The resulting union does not remove duplicate rows.
Specify DISTINCT to remove duplicate rows in the resulting
DynamicFrame.
31505 31506 31507 31508 31509 31510 31511 |
# File 'lib/aws-sdk-glue/types.rb', line 31505 class Union < Struct.new( :name, :inputs, :union_type) SENSITIVE = [] include Aws::Structure end |