Class: Aws::Glue::Types::UpdateColumnStatisticsForPartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateColumnStatisticsForPartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_statistics_list ⇒ Array<Types::ColumnStatistics>
A list of the column statistics.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-glue/types.rb', line 29329 class UpdateColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#column_statistics_list ⇒ Array<Types::ColumnStatistics>
A list of the column statistics.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-glue/types.rb', line 29329 class UpdateColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-glue/types.rb', line 29329 class UpdateColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#partition_values ⇒ Array<String>
A list of partition values identifying the partition.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-glue/types.rb', line 29329 class UpdateColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
29329 29330 29331 29332 29333 29334 29335 29336 29337 |
# File 'lib/aws-sdk-glue/types.rb', line 29329 class UpdateColumnStatisticsForPartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_values, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |