Class: Aws::Glue::Types::UpdateColumnStatisticsForTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateColumnStatisticsForTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside.
-
#column_statistics_list ⇒ Array<Types::ColumnStatistics>
A list of the column statistics.
-
#database_name ⇒ String
The name of the catalog database where the partitions reside.
-
#table_name ⇒ String
The name of the partitions’ table.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
29511 29512 29513 29514 29515 29516 29517 29518 |
# File 'lib/aws-sdk-glue/types.rb', line 29511 class UpdateColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#column_statistics_list ⇒ Array<Types::ColumnStatistics>
A list of the column statistics.
29511 29512 29513 29514 29515 29516 29517 29518 |
# File 'lib/aws-sdk-glue/types.rb', line 29511 class UpdateColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the partitions reside.
29511 29512 29513 29514 29515 29516 29517 29518 |
# File 'lib/aws-sdk-glue/types.rb', line 29511 class UpdateColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the partitions’ table.
29511 29512 29513 29514 29515 29516 29517 29518 |
# File 'lib/aws-sdk-glue/types.rb', line 29511 class UpdateColumnStatisticsForTableRequest < Struct.new( :catalog_id, :database_name, :table_name, :column_statistics_list) SENSITIVE = [] include Aws::Structure end |