Class: Aws::Glue::Types::UpdateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass UpdateConnectionRequest data as a hash:
{
catalog_id: "CatalogIdString",
name: "NameString", # required
connection_input: { # required
name: "NameString", # required
description: "DescriptionString",
connection_type: "JDBC", # required, accepts JDBC, SFTP, MONGODB, KAFKA, NETWORK, MARKETPLACE, CUSTOM
match_criteria: ["NameString"],
connection_properties: { # required
"HOST" => "ValueString",
},
physical_connection_requirements: {
subnet_id: "NameString",
security_group_id_list: ["NameString"],
availability_zone: "NameString",
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides.
-
#connection_input ⇒ Types::ConnectionInput
A `ConnectionInput` object that redefines the connection in question.
-
#name ⇒ String
The name of the connection definition to update.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.
17813 17814 17815 17816 17817 17818 17819 |
# File 'lib/aws-sdk-glue/types.rb', line 17813 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |
#connection_input ⇒ Types::ConnectionInput
A `ConnectionInput` object that redefines the connection in question.
17813 17814 17815 17816 17817 17818 17819 |
# File 'lib/aws-sdk-glue/types.rb', line 17813 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connection definition to update.
17813 17814 17815 17816 17817 17818 17819 |
# File 'lib/aws-sdk-glue/types.rb', line 17813 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |