Class: Aws::Glue::Types::UpdateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides.
-
#connection_input ⇒ Types::ConnectionInput
A
ConnectionInputobject that redefines the connection in question. -
#name ⇒ String
The name of the connection definition to update.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the connection resides. If none is provided, the Amazon Web Services account ID is used by default.
29441 29442 29443 29444 29445 29446 29447 |
# File 'lib/aws-sdk-glue/types.rb', line 29441 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |
#connection_input ⇒ Types::ConnectionInput
A ConnectionInput object that redefines the connection in question.
29441 29442 29443 29444 29445 29446 29447 |
# File 'lib/aws-sdk-glue/types.rb', line 29441 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the connection definition to update.
29441 29442 29443 29444 29445 29446 29447 |
# File 'lib/aws-sdk-glue/types.rb', line 29441 class UpdateConnectionRequest < Struct.new( :catalog_id, :name, :connection_input) SENSITIVE = [] include Aws::Structure end |