Class: Aws::Glue::Types::UpdateCrawlerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classifiersArray<String>

A list of custom classifiers that the user has registered. By default, all built-in classifiers are included in a crawl, but these custom classifiers always override the default classifiers for a given classification.

Returns:

  • (Array<String>)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationString

Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler’s behavior. For more information, see [Setting crawler configuration options].

[1]: docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#crawler_security_configurationString

The name of the ‘SecurityConfiguration` structure to be used by this crawler.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The Glue database where results are stored, such as: ‘arn:aws:daylight:us-east-1::database/sometable/*`.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the new crawler.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lake_formation_configurationTypes::LakeFormationConfiguration

Specifies Lake Formation configuration settings for the crawler.



20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_configurationTypes::LineageConfiguration

Specifies data lineage configuration settings for the crawler.



20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the new crawler.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#recrawl_policyTypes::RecrawlPolicy

A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run.



20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The IAM role or Amazon Resource Name (ARN) of an IAM role that is used by the new crawler to access customer resources.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

A ‘cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.

[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::SchemaChangePolicy

The policy for the crawler’s update and deletion behavior.



20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#table_prefixString

The table prefix used for catalog tables that are created.

Returns:

  • (String)


20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#targetsTypes::CrawlerTargets

A list of targets to crawl.



20139
20140
20141
20142
20143
20144
20145
20146
20147
20148
20149
20150
20151
20152
20153
20154
20155
20156
# File 'lib/aws-sdk-glue/types.rb', line 20139

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end