Class: Aws::Glue::Types::UpdateCrawlerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Note:

When making an API call, you may pass UpdateCrawlerRequest data as a hash:

{
  name: "NameString", # required
  role: "Role",
  database_name: "DatabaseName",
  description: "DescriptionStringRemovable",
  targets: {
    s3_targets: [
      {
        path: "Path",
        exclusions: ["Path"],
        connection_name: "ConnectionName",
        sample_size: 1,
        event_queue_arn: "EventQueueArn",
        dlq_event_queue_arn: "EventQueueArn",
      },
    ],
    jdbc_targets: [
      {
        connection_name: "ConnectionName",
        path: "Path",
        exclusions: ["Path"],
      },
    ],
    mongo_db_targets: [
      {
        connection_name: "ConnectionName",
        path: "Path",
        scan_all: false,
      },
    ],
    dynamo_db_targets: [
      {
        path: "Path",
        scan_all: false,
        scan_rate: 1.0,
      },
    ],
    catalog_targets: [
      {
        database_name: "NameString", # required
        tables: ["NameString"], # required
        connection_name: "ConnectionName",
      },
    ],
    delta_targets: [
      {
        delta_tables: ["Path"],
        connection_name: "ConnectionName",
        write_manifest: false,
      },
    ],
  },
  schedule: "CronExpression",
  classifiers: ["NameString"],
  table_prefix: "TablePrefix",
  schema_change_policy: {
    update_behavior: "LOG", # accepts LOG, UPDATE_IN_DATABASE
    delete_behavior: "LOG", # accepts LOG, DELETE_FROM_DATABASE, DEPRECATE_IN_DATABASE
  },
  recrawl_policy: {
    recrawl_behavior: "CRAWL_EVERYTHING", # accepts CRAWL_EVERYTHING, CRAWL_NEW_FOLDERS_ONLY, CRAWL_EVENT_MODE
  },
  lineage_configuration: {
    crawler_lineage_settings: "ENABLE", # accepts ENABLE, DISABLE
  },
  lake_formation_configuration: {
    use_lake_formation_credentials: false,
    account_id: "AccountId",
  },
  configuration: "CrawlerConfiguration",
  crawler_security_configuration: "CrawlerSecurityConfiguration",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classifiersArray<String>

A list of custom classifiers that the user has registered. By default, all built-in classifiers are included in a crawl, but these custom classifiers always override the default classifiers for a given classification.

Returns:

  • (Array<String>)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationString

Crawler configuration information. This versioned JSON string allows users to specify aspects of a crawler's behavior. For more information, see [Configuring a Crawler].

[1]: docs.aws.amazon.com/glue/latest/dg/crawler-configuration.html

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#crawler_security_configurationString

The name of the `SecurityConfiguration` structure to be used by this crawler.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The Glue database where results are stored, such as: `arn:aws:daylight:us-east-1::database/sometable/*`.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the new crawler.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lake_formation_configurationTypes::LakeFormationConfiguration

Specifies Lake Formation configuration settings for the crawler.



24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_configurationTypes::LineageConfiguration

Specifies data lineage configuration settings for the crawler.



24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the new crawler.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#recrawl_policyTypes::RecrawlPolicy

A policy that specifies whether to crawl the entire dataset again, or to crawl only folders that were added since the last crawler run.



24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The IAM role or Amazon Resource Name (ARN) of an IAM role that is used by the new crawler to access customer resources.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

A `cron` expression used to specify the schedule (see [Time-Based Schedules for Jobs and Crawlers]. For example, to run something every day at 12:15 UTC, you would specify: `cron(15 12 * * ? *)`.

[1]: docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#schema_change_policyTypes::SchemaChangePolicy

The policy for the crawler's update and deletion behavior.



24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#table_prefixString

The table prefix used for catalog tables that are created.

Returns:

  • (String)


24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#targetsTypes::CrawlerTargets

A list of targets to crawl.



24251
24252
24253
24254
24255
24256
24257
24258
24259
24260
24261
24262
24263
24264
24265
24266
24267
24268
# File 'lib/aws-sdk-glue/types.rb', line 24251

class UpdateCrawlerRequest < Struct.new(
  :name,
  :role,
  :database_name,
  :description,
  :targets,
  :schedule,
  :classifiers,
  :table_prefix,
  :schema_change_policy,
  :recrawl_policy,
  :lineage_configuration,
  :lake_formation_configuration,
  :configuration,
  :crawler_security_configuration)
  SENSITIVE = []
  include Aws::Structure
end