Class: Aws::Glue::Types::UpdateCsvClassifierRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a custom CSV classifier to be updated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_single_columnBoolean

Enables the processing of files that contain only one column.

Returns:

  • (Boolean)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#contains_headerString

Indicates whether the CSV file contains a header.

Returns:

  • (String)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#custom_datatype_configuredBoolean

Specifies the configuration of custom datatypes.

Returns:

  • (Boolean)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#custom_datatypesArray<String>

Specifies a list of supported custom datatypes.

Returns:

  • (Array<String>)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#delimiterString

A custom symbol to denote what separates each column entry in the row.

Returns:

  • (String)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#disable_value_trimmingBoolean

Specifies not to trim values before identifying the type of column values. The default value is true.

Returns:

  • (Boolean)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#headerArray<String>

A list of strings representing column names.

Returns:

  • (Array<String>)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the classifier.

Returns:

  • (String)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#quote_symbolString

A custom symbol to denote what combines content into a single column value. It must be different from the column delimiter.

Returns:

  • (String)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end

#serdeString

Sets the SerDe for processing CSV in the classifier, which will be applied in the Data Catalog. Valid values are OpenCSVSerDe, LazySimpleSerDe, and None. You can specify the None value when you want the crawler to do the detection.

Returns:

  • (String)


32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
# File 'lib/aws-sdk-glue/types.rb', line 32207

class UpdateCsvClassifierRequest < Struct.new(
  :name,
  :delimiter,
  :quote_symbol,
  :contains_header,
  :header,
  :disable_value_trimming,
  :allow_single_column,
  :custom_datatype_configured,
  :custom_datatypes,
  :serde)
  SENSITIVE = []
  include Aws::Structure
end