Class: Aws::Glue::Types::UpdateCsvClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateCsvClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a custom CSV classifier to be updated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
-
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
-
#custom_datatype_configured ⇒ Boolean
Specifies the configuration of custom datatypes.
-
#custom_datatypes ⇒ Array<String>
Specifies a list of supported custom datatypes.
-
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
-
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values.
-
#header ⇒ Array<String>
A list of strings representing column names.
-
#name ⇒ String
The name of the classifier.
-
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value.
-
#serde ⇒ String
Sets the SerDe for processing CSV in the classifier, which will be applied in the Data Catalog.
Instance Attribute Details
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#custom_datatype_configured ⇒ Boolean
Specifies the configuration of custom datatypes.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#custom_datatypes ⇒ Array<String>
Specifies a list of supported custom datatypes.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values. The default value is true.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Array<String>
A list of strings representing column names.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value. It must be different from the column delimiter.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |
#serde ⇒ String
Sets the SerDe for processing CSV in the classifier, which will be applied in the Data Catalog. Valid values are ‘OpenCSVSerDe`, `LazySimpleSerDe`, and `None`. You can specify the `None` value when you want the crawler to do the detection.
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/aws-sdk-glue/types.rb', line 23489 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes, :serde) SENSITIVE = [] include Aws::Structure end |