Class: Aws::Glue::Types::UpdateCsvClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateCsvClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a custom CSV classifier to be updated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
-
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
-
#custom_datatype_configured ⇒ Boolean
Specifies the configuration of custom datatypes.
-
#custom_datatypes ⇒ Array<String>
Specifies a list of supported custom datatypes.
-
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
-
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values.
-
#header ⇒ Array<String>
A list of strings representing column names.
-
#name ⇒ String
The name of the classifier.
-
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value.
Instance Attribute Details
#allow_single_column ⇒ Boolean
Enables the processing of files that contain only one column.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#contains_header ⇒ String
Indicates whether the CSV file contains a header.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatype_configured ⇒ Boolean
Specifies the configuration of custom datatypes.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#custom_datatypes ⇒ Array<String>
Specifies a list of supported custom datatypes.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#delimiter ⇒ String
A custom symbol to denote what separates each column entry in the row.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#disable_value_trimming ⇒ Boolean
Specifies not to trim values before identifying the type of column values. The default value is true.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Array<String>
A list of strings representing column names.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the classifier.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |
#quote_symbol ⇒ String
A custom symbol to denote what combines content into a single column value. It must be different from the column delimiter.
18970 18971 18972 18973 18974 18975 18976 18977 18978 18979 18980 18981 18982 |
# File 'lib/aws-sdk-glue/types.rb', line 18970 class UpdateCsvClassifierRequest < Struct.new( :name, :delimiter, :quote_symbol, :contains_header, :header, :disable_value_trimming, :allow_single_column, :custom_datatype_configured, :custom_datatypes) SENSITIVE = [] include Aws::Structure end |