Class: Aws::Glue::Types::UpdateDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the metadata database resides.
-
#database_input ⇒ Types::DatabaseInput
A ‘DatabaseInput` object specifying the new definition of the metadata database in the catalog.
-
#name ⇒ String
The name of the database to update in the catalog.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the metadata database resides. If none is provided, the Amazon Web Services account ID is used by default.
20451 20452 20453 20454 20455 20456 20457 |
# File 'lib/aws-sdk-glue/types.rb', line 20451 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |
#database_input ⇒ Types::DatabaseInput
A ‘DatabaseInput` object specifying the new definition of the metadata database in the catalog.
20451 20452 20453 20454 20455 20456 20457 |
# File 'lib/aws-sdk-glue/types.rb', line 20451 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database to update in the catalog. For Hive compatibility, this is folded to lowercase.
20451 20452 20453 20454 20455 20456 20457 |
# File 'lib/aws-sdk-glue/types.rb', line 20451 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |