Class: Aws::Glue::Types::UpdateDatabaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateDatabaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass UpdateDatabaseRequest data as a hash:
{
catalog_id: "CatalogIdString",
name: "NameString", # required
database_input: { # required
name: "NameString", # required
description: "DescriptionString",
location_uri: "URI",
parameters: {
"KeyString" => "ParametersMapValue",
},
create_table_default_permissions: [
{
principal: {
data_lake_principal_identifier: "DataLakePrincipalString",
},
permissions: ["ALL"], # accepts ALL, SELECT, ALTER, DROP, DELETE, INSERT, CREATE_DATABASE, CREATE_TABLE, DATA_LOCATION_ACCESS
},
],
target_database: {
catalog_id: "CatalogIdString",
database_name: "NameString",
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the metadata database resides.
-
#database_input ⇒ Types::DatabaseInput
A `DatabaseInput` object specifying the new definition of the metadata database in the catalog.
-
#name ⇒ String
The name of the database to update in the catalog.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the metadata database resides. If none is provided, the Amazon Web Services account ID is used by default.
24466 24467 24468 24469 24470 24471 24472 |
# File 'lib/aws-sdk-glue/types.rb', line 24466 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |
#database_input ⇒ Types::DatabaseInput
A `DatabaseInput` object specifying the new definition of the metadata database in the catalog.
24466 24467 24468 24469 24470 24471 24472 |
# File 'lib/aws-sdk-glue/types.rb', line 24466 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the database to update in the catalog. For Hive compatibility, this is folded to lowercase.
24466 24467 24468 24469 24470 24471 24472 |
# File 'lib/aws-sdk-glue/types.rb', line 24466 class UpdateDatabaseRequest < Struct.new( :catalog_id, :name, :database_input) SENSITIVE = [] include Aws::Structure end |