Class: Aws::Glue::Types::UpdateDatabaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog in which the metadata database resides. If none is provided, the Amazon Web Services account ID is used by default.



28707
28708
28709
28710
28711
28712
28713
# File 'lib/aws-sdk-glue/types.rb', line 28707

class UpdateDatabaseRequest < Struct.new(
  :catalog_id,
  :name,
  :database_input)
  SENSITIVE = []
  include Aws::Structure
end

#database_inputTypes::DatabaseInput

A ‘DatabaseInput` object specifying the new definition of the metadata database in the catalog.



28707
28708
28709
28710
28711
28712
28713
# File 'lib/aws-sdk-glue/types.rb', line 28707

class UpdateDatabaseRequest < Struct.new(
  :catalog_id,
  :name,
  :database_input)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the database to update in the catalog. For Hive compatibility, this is folded to lowercase.



28707
28708
28709
28710
28711
28712
28713
# File 'lib/aws-sdk-glue/types.rb', line 28707

class UpdateDatabaseRequest < Struct.new(
  :catalog_id,
  :name,
  :database_input)
  SENSITIVE = []
  include Aws::Structure
end