Class: Aws::Glue::Types::UpdateGlossaryTermRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateGlossaryTermRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#identifier ⇒ String
The unique identifier of the glossary term to update.
-
#long_description ⇒ String
The updated long description of the glossary term.
-
#name ⇒ String
The updated name of the glossary term.
-
#short_description ⇒ String
The updated short description of the glossary term.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
31693 31694 31695 31696 31697 31698 31699 31700 31701 |
# File 'lib/aws-sdk-glue/types.rb', line 31693 class UpdateGlossaryTermRequest < Struct.new( :identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the glossary term to update.
31693 31694 31695 31696 31697 31698 31699 31700 31701 |
# File 'lib/aws-sdk-glue/types.rb', line 31693 class UpdateGlossaryTermRequest < Struct.new( :identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#long_description ⇒ String
The updated long description of the glossary term.
31693 31694 31695 31696 31697 31698 31699 31700 31701 |
# File 'lib/aws-sdk-glue/types.rb', line 31693 class UpdateGlossaryTermRequest < Struct.new( :identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the glossary term.
31693 31694 31695 31696 31697 31698 31699 31700 31701 |
# File 'lib/aws-sdk-glue/types.rb', line 31693 class UpdateGlossaryTermRequest < Struct.new( :identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |
#short_description ⇒ String
The updated short description of the glossary term.
31693 31694 31695 31696 31697 31698 31699 31700 31701 |
# File 'lib/aws-sdk-glue/types.rb', line 31693 class UpdateGlossaryTermRequest < Struct.new( :identifier, :name, :short_description, :long_description, :client_token) SENSITIVE = [] include Aws::Structure end |