Class: Aws::Glue::Types::UpdateGlossaryTermRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


31622
31623
31624
31625
31626
31627
31628
31629
31630
# File 'lib/aws-sdk-glue/types.rb', line 31622

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the glossary term to update.

Returns:

  • (String)


31622
31623
31624
31625
31626
31627
31628
31629
31630
# File 'lib/aws-sdk-glue/types.rb', line 31622

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#long_descriptionString

The updated long description of the glossary term.

Returns:

  • (String)


31622
31623
31624
31625
31626
31627
31628
31629
31630
# File 'lib/aws-sdk-glue/types.rb', line 31622

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated name of the glossary term.

Returns:

  • (String)


31622
31623
31624
31625
31626
31627
31628
31629
31630
# File 'lib/aws-sdk-glue/types.rb', line 31622

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#short_descriptionString

The updated short description of the glossary term.

Returns:

  • (String)


31622
31623
31624
31625
31626
31627
31628
31629
31630
# File 'lib/aws-sdk-glue/types.rb', line 31622

class UpdateGlossaryTermRequest < Struct.new(
  :identifier,
  :name,
  :short_description,
  :long_description,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end