Class: Aws::Glue::Types::UpdateGrokClassifierRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateGrokClassifierRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Specifies a grok classifier to update when passed to ‘UpdateClassifier`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, Amazon CloudWatch Logs, and so on.
-
#custom_patterns ⇒ String
Optional custom grok patterns used by this classifier.
-
#grok_pattern ⇒ String
The grok pattern used by this classifier.
-
#name ⇒ String
The name of the ‘GrokClassifier`.
Instance Attribute Details
#classification ⇒ String
An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, Amazon CloudWatch Logs, and so on.
21080 21081 21082 21083 21084 21085 21086 21087 |
# File 'lib/aws-sdk-glue/types.rb', line 21080 class UpdateGrokClassifierRequest < Struct.new( :name, :classification, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#custom_patterns ⇒ String
Optional custom grok patterns used by this classifier.
21080 21081 21082 21083 21084 21085 21086 21087 |
# File 'lib/aws-sdk-glue/types.rb', line 21080 class UpdateGrokClassifierRequest < Struct.new( :name, :classification, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#grok_pattern ⇒ String
The grok pattern used by this classifier.
21080 21081 21082 21083 21084 21085 21086 21087 |
# File 'lib/aws-sdk-glue/types.rb', line 21080 class UpdateGrokClassifierRequest < Struct.new( :name, :classification, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the ‘GrokClassifier`.
21080 21081 21082 21083 21084 21085 21086 21087 |
# File 'lib/aws-sdk-glue/types.rb', line 21080 class UpdateGrokClassifierRequest < Struct.new( :name, :classification, :grok_pattern, :custom_patterns) SENSITIVE = [] include Aws::Structure end |