Class: Aws::Glue::Types::UpdateGrokClassifierRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Specifies a grok classifier to update when passed to ‘UpdateClassifier`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#classificationString

An identifier of the data format that the classifier matches, such as Twitter, JSON, Omniture logs, Amazon CloudWatch Logs, and so on.



28833
28834
28835
28836
28837
28838
28839
28840
# File 'lib/aws-sdk-glue/types.rb', line 28833

class UpdateGrokClassifierRequest < Struct.new(
  :name,
  :classification,
  :grok_pattern,
  :custom_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#custom_patternsString

Optional custom grok patterns used by this classifier.



28833
28834
28835
28836
28837
28838
28839
28840
# File 'lib/aws-sdk-glue/types.rb', line 28833

class UpdateGrokClassifierRequest < Struct.new(
  :name,
  :classification,
  :grok_pattern,
  :custom_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#grok_patternString

The grok pattern used by this classifier.



28833
28834
28835
28836
28837
28838
28839
28840
# File 'lib/aws-sdk-glue/types.rb', line 28833

class UpdateGrokClassifierRequest < Struct.new(
  :name,
  :classification,
  :grok_pattern,
  :custom_patterns)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the ‘GrokClassifier`.



28833
28834
28835
28836
28837
28838
28839
28840
# File 'lib/aws-sdk-glue/types.rb', line 28833

class UpdateGrokClassifierRequest < Struct.new(
  :name,
  :classification,
  :grok_pattern,
  :custom_patterns)
  SENSITIVE = []
  include Aws::Structure
end