Class: Aws::Glue::Types::UpdateMLTransformRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the transform. The default is an empty string.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#glue_versionString

This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see Glue Versions in the developer guide.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityFloat

The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the Glue pricing page.

When the WorkerType field is set to a value other than Standard, the MaxCapacity field is set automatically and becomes read-only.

Returns:

  • (Float)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#max_retriesInteger

The maximum number of times to retry a task for this transform after a task run fails.

Returns:

  • (Integer)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique name that you gave the transform when you created it.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_workersInteger

The number of workers of a defined workerType that are allocated when this task runs.

Returns:

  • (Integer)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#parametersTypes::TransformParameters

The configuration parameters that are specific to the transform type (algorithm) used. Conditionally dependent on the transform type.



32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The timeout for a task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).

Returns:

  • (Integer)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#transform_idString

A unique identifier that was generated when the transform was created.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end

#worker_typeString

The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.

  • For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.

  • For the G.1X worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.

  • For the G.2X worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.

Returns:

  • (String)


32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
# File 'lib/aws-sdk-glue/types.rb', line 32868

class UpdateMLTransformRequest < Struct.new(
  :transform_id,
  :name,
  :description,
  :parameters,
  :role,
  :glue_version,
  :max_capacity,
  :worker_type,
  :number_of_workers,
  :timeout,
  :max_retries)
  SENSITIVE = []
  include Aws::Structure
end