Class: Aws::Glue::Types::UpdateMLTransformRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateMLTransformRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass UpdateMLTransformRequest data as a hash:
{
transform_id: "HashString", # required
name: "NameString",
description: "DescriptionString",
parameters: {
transform_type: "FIND_MATCHES", # required, accepts FIND_MATCHES
find_matches_parameters: {
primary_key_column_name: "ColumnNameString",
precision_recall_tradeoff: 1.0,
accuracy_cost_tradeoff: 1.0,
enforce_provided_labels: false,
},
},
role: "RoleString",
glue_version: "GlueVersionString",
max_capacity: 1.0,
worker_type: "Standard", # accepts Standard, G.1X, G.2X
number_of_workers: 1,
timeout: 1,
max_retries: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the transform.
-
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with.
-
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform.
-
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
-
#name ⇒ String
The unique name that you gave the transform when you created it.
-
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when this task runs.
-
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the transform type (algorithm) used.
-
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
-
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes.
-
#transform_id ⇒ String
A unique identifier that was generated when the transform was created.
-
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs.
Instance Attribute Details
#description ⇒ String
A description of the transform. The default is an empty string.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
This value determines which version of Glue this machine learning transform is compatible with. Glue 1.0 is recommended for most customers. If the value is not set, the Glue compatibility defaults to Glue 0.9. For more information, see [Glue Versions] in the developer guide.
[1]: docs.aws.amazon.com/glue/latest/dg/release-notes.html#release-notes-versions
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Float
The number of Glue data processing units (DPUs) that are allocated to task runs for this transform. You can allocate from 2 to 100 DPUs; the default is 10. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory. For more information, see the [Glue pricing page].
When the `WorkerType` field is set to a value other than `Standard`, the `MaxCapacity` field is set automatically and becomes read-only.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#max_retries ⇒ Integer
The maximum number of times to retry a task for this transform after a task run fails.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique name that you gave the transform when you created it.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers of a defined `workerType` that are allocated when this task runs.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::TransformParameters
The configuration parameters that are specific to the transform type (algorithm) used. Conditionally dependent on the transform type.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role with the required permissions.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The timeout for a task run for this transform in minutes. This is the maximum time that a task run for this transform can consume resources before it is terminated and enters `TIMEOUT` status. The default is 2,880 minutes (48 hours).
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#transform_id ⇒ String
A unique identifier that was generated when the transform was created.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The type of predefined worker that is allocated when this task runs. Accepts a value of Standard, G.1X, or G.2X.
-
For the `Standard` worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.
-
For the `G.1X` worker type, each worker provides 4 vCPU, 16 GB of memory and a 64GB disk, and 1 executor per worker.
-
For the `G.2X` worker type, each worker provides 8 vCPU, 32 GB of memory and a 128GB disk, and 1 executor per worker.
17564 17565 17566 17567 17568 17569 17570 17571 17572 17573 17574 17575 17576 17577 17578 |
# File 'lib/aws-sdk-glue/types.rb', line 17564 class UpdateMLTransformRequest < Struct.new( :transform_id, :name, :description, :parameters, :role, :glue_version, :max_capacity, :worker_type, :number_of_workers, :timeout, :max_retries) SENSITIVE = [] include Aws::Structure end |