Class: Aws::Glue::Types::UpdatePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdatePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be updated resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partition_input ⇒ Types::PartitionInput
The new partition object to update the partition to.
-
#partition_value_list ⇒ Array<String>
List of partition key values that define the partition to update.
-
#table_name ⇒ String
The name of the table in which the partition to be updated is located.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be updated resides. If none is provided, the Amazon Web Services account ID is used by default.
28824 28825 28826 28827 28828 28829 28830 28831 28832 |
# File 'lib/aws-sdk-glue/types.rb', line 28824 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
28824 28825 28826 28827 28828 28829 28830 28831 28832 |
# File 'lib/aws-sdk-glue/types.rb', line 28824 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#partition_input ⇒ Types::PartitionInput
The new partition object to update the partition to.
The ‘Values` property can’t be changed. If you want to change the partition key values for a partition, delete and recreate the partition.
28824 28825 28826 28827 28828 28829 28830 28831 28832 |
# File 'lib/aws-sdk-glue/types.rb', line 28824 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#partition_value_list ⇒ Array<String>
List of partition key values that define the partition to update.
28824 28825 28826 28827 28828 28829 28830 28831 28832 |
# File 'lib/aws-sdk-glue/types.rb', line 28824 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table in which the partition to be updated is located.
28824 28825 28826 28827 28828 28829 28830 28831 28832 |
# File 'lib/aws-sdk-glue/types.rb', line 28824 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |