Class: Aws::Glue::Types::UpdatePartitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdatePartitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass UpdatePartitionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_name: "NameString", # required
partition_value_list: ["ValueString"], # required
partition_input: { # required
values: ["ValueString"],
last_access_time: Time.now,
storage_descriptor: {
columns: [
{
name: "NameString", # required
type: "ColumnTypeString",
comment: "CommentString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
],
location: "LocationString",
additional_locations: ["LocationString"],
input_format: "FormatString",
output_format: "FormatString",
compressed: false,
number_of_buckets: 1,
serde_info: {
name: "NameString",
serialization_library: "NameString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
bucket_columns: ["NameString"],
sort_columns: [
{
column: "NameString", # required
sort_order: 1, # required
},
],
parameters: {
"KeyString" => "ParametersMapValue",
},
skewed_info: {
skewed_column_names: ["NameString"],
skewed_column_values: ["ColumnValuesString"],
skewed_column_value_location_maps: {
"ColumnValuesString" => "ColumnValuesString",
},
},
stored_as_sub_directories: false,
schema_reference: {
schema_id: {
schema_arn: "GlueResourceArn",
schema_name: "SchemaRegistryNameString",
registry_name: "SchemaRegistryNameString",
},
schema_version_id: "SchemaVersionIdString",
schema_version_number: 1,
},
},
parameters: {
"KeyString" => "ParametersMapValue",
},
last_analyzed_time: Time.now,
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be updated resides.
-
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
-
#partition_input ⇒ Types::PartitionInput
The new partition object to update the partition to.
-
#partition_value_list ⇒ Array<String>
List of partition key values that define the partition to update.
-
#table_name ⇒ String
The name of the table in which the partition to be updated is located.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the partition to be updated resides. If none is provided, the Amazon Web Services account ID is used by default.
18617 18618 18619 18620 18621 18622 18623 18624 18625 |
# File 'lib/aws-sdk-glue/types.rb', line 18617 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table in question resides.
18617 18618 18619 18620 18621 18622 18623 18624 18625 |
# File 'lib/aws-sdk-glue/types.rb', line 18617 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#partition_input ⇒ Types::PartitionInput
The new partition object to update the partition to.
The `Values` property can't be changed. If you want to change the partition key values for a partition, delete and recreate the partition.
18617 18618 18619 18620 18621 18622 18623 18624 18625 |
# File 'lib/aws-sdk-glue/types.rb', line 18617 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#partition_value_list ⇒ Array<String>
List of partition key values that define the partition to update.
18617 18618 18619 18620 18621 18622 18623 18624 18625 |
# File 'lib/aws-sdk-glue/types.rb', line 18617 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table in which the partition to be updated is located.
18617 18618 18619 18620 18621 18622 18623 18624 18625 |
# File 'lib/aws-sdk-glue/types.rb', line 18617 class UpdatePartitionRequest < Struct.new( :catalog_id, :database_name, :table_name, :partition_value_list, :partition_input) SENSITIVE = [] include Aws::Structure end |