Class: Aws::Glue::Types::UpdatePartitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog where the partition to be updated resides. If none is provided, the Amazon Web Services account ID is used by default.



29521
29522
29523
29524
29525
29526
29527
29528
29529
# File 'lib/aws-sdk-glue/types.rb', line 29521

class UpdatePartitionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :partition_value_list,
  :partition_input)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database in which the table in question resides.



29521
29522
29523
29524
29525
29526
29527
29528
29529
# File 'lib/aws-sdk-glue/types.rb', line 29521

class UpdatePartitionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :partition_value_list,
  :partition_input)
  SENSITIVE = []
  include Aws::Structure
end

#partition_inputTypes::PartitionInput

The new partition object to update the partition to.

The ‘Values` property can’t be changed. If you want to change the partition key values for a partition, delete and recreate the partition.



29521
29522
29523
29524
29525
29526
29527
29528
29529
# File 'lib/aws-sdk-glue/types.rb', line 29521

class UpdatePartitionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :partition_value_list,
  :partition_input)
  SENSITIVE = []
  include Aws::Structure
end

#partition_value_listArray<String>

List of partition key values that define the partition to update.



29521
29522
29523
29524
29525
29526
29527
29528
29529
# File 'lib/aws-sdk-glue/types.rb', line 29521

class UpdatePartitionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :partition_value_list,
  :partition_input)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the table in which the partition to be updated is located.



29521
29522
29523
29524
29525
29526
29527
29528
29529
# File 'lib/aws-sdk-glue/types.rb', line 29521

class UpdatePartitionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :table_name,
  :partition_value_list,
  :partition_input)
  SENSITIVE = []
  include Aws::Structure
end