Method: Aws::Glue::Types::UpdateSourceControlFromJobRequest#auth_strategy
- Defined in:
- lib/aws-sdk-glue/types.rb
#auth_strategy ⇒ String
The type of authentication, which can be an authentication token stored in Amazon Web Services Secrets Manager, or a personal access token.
30377 30378 30379 30380 30381 30382 30383 30384 30385 30386 30387 30388 30389 |
# File 'lib/aws-sdk-glue/types.rb', line 30377 class UpdateSourceControlFromJobRequest < Struct.new( :job_name, :provider, :repository_name, :repository_owner, :branch_name, :folder, :commit_id, :auth_strategy, :auth_token) SENSITIVE = [] include Aws::Structure end |