Class: Aws::Glue::Types::UpdateTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the catalog database in which the table resides.
-
#force ⇒ Boolean
A flag that can be set to true to ignore matching storage descriptor and subobject matching requirements.
-
#name ⇒ String
The unique identifier for the table within the specified database that will be created in the Glue Data Catalog.
-
#skip_archive ⇒ Boolean
By default, ‘UpdateTable` always creates an archived version of the table before updating it.
-
#table_input ⇒ Types::TableInput
An updated ‘TableInput` object to define the metadata table in the catalog.
-
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
-
#update_open_table_format_input ⇒ Types::UpdateOpenTableFormatInput
Input parameters for updating open table format tables in GlueData Catalog, serving as a wrapper for format-specific update operations such as Apache Iceberg.
-
#version_id ⇒ String
The version ID at which to update the table contents.
-
#view_update_action ⇒ String
The operation to be performed when updating the view.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
A flag that can be set to true to ignore matching storage descriptor and subobject matching requirements.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique identifier for the table within the specified database that will be created in the Glue Data Catalog.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#skip_archive ⇒ Boolean
By default, ‘UpdateTable` always creates an archived version of the table before updating it. However, if `skipArchive` is set to true, `UpdateTable` does not create the archived version.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#table_input ⇒ Types::TableInput
An updated ‘TableInput` object to define the metadata table in the catalog.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#update_open_table_format_input ⇒ Types::UpdateOpenTableFormatInput
Input parameters for updating open table format tables in GlueData Catalog, serving as a wrapper for format-specific update operations such as Apache Iceberg.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID at which to update the table contents.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |
#view_update_action ⇒ String
The operation to be performed when updating the view.
30532 30533 30534 30535 30536 30537 30538 30539 30540 30541 30542 30543 30544 30545 |
# File 'lib/aws-sdk-glue/types.rb', line 30532 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :name, :table_input, :skip_archive, :transaction_id, :version_id, :view_update_action, :force, :update_open_table_format_input) SENSITIVE = [] include Aws::Structure end |