Class: Aws::Glue::Types::UpdateTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the catalog database in which the table resides.
-
#skip_archive ⇒ Boolean
By default, ‘UpdateTable` always creates an archived version of the table before updating it.
-
#table_input ⇒ Types::TableInput
An updated ‘TableInput` object to define the metadata table in the catalog.
-
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
-
#version_id ⇒ String
The version ID at which to update the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#skip_archive ⇒ Boolean
By default, ‘UpdateTable` always creates an archived version of the table before updating it. However, if `skipArchive` is set to true, `UpdateTable` does not create the archived version.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#table_input ⇒ Types::TableInput
An updated ‘TableInput` object to define the metadata table in the catalog.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID at which to update the table contents.
20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 |
# File 'lib/aws-sdk-glue/types.rb', line 20813 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id, :version_id) SENSITIVE = [] include Aws::Structure end |