Class: Aws::Glue::Types::UpdateTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
When making an API call, you may pass UpdateTableRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
table_input: { # required
name: "NameString", # required
description: "DescriptionString",
owner: "NameString",
last_access_time: Time.now,
last_analyzed_time: Time.now,
retention: 1,
storage_descriptor: {
columns: [
{
name: "NameString", # required
type: "ColumnTypeString",
comment: "CommentString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
],
location: "LocationString",
additional_locations: ["LocationString"],
input_format: "FormatString",
output_format: "FormatString",
compressed: false,
number_of_buckets: 1,
serde_info: {
name: "NameString",
serialization_library: "NameString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
bucket_columns: ["NameString"],
sort_columns: [
{
column: "NameString", # required
sort_order: 1, # required
},
],
parameters: {
"KeyString" => "ParametersMapValue",
},
skewed_info: {
skewed_column_names: ["NameString"],
skewed_column_values: ["ColumnValuesString"],
skewed_column_value_location_maps: {
"ColumnValuesString" => "ColumnValuesString",
},
},
stored_as_sub_directories: false,
schema_reference: {
schema_id: {
schema_arn: "GlueResourceArn",
schema_name: "SchemaRegistryNameString",
registry_name: "SchemaRegistryNameString",
},
schema_version_id: "SchemaVersionIdString",
schema_version_number: 1,
},
},
partition_keys: [
{
name: "NameString", # required
type: "ColumnTypeString",
comment: "CommentString",
parameters: {
"KeyString" => "ParametersMapValue",
},
},
],
view_original_text: "ViewTextString",
view_expanded_text: "ViewTextString",
table_type: "TableTypeString",
parameters: {
"KeyString" => "ParametersMapValue",
},
target_table: {
catalog_id: "CatalogIdString",
database_name: "NameString",
name: "NameString",
},
},
skip_archive: false,
transaction_id: "TransactionIdString",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides.
-
#database_name ⇒ String
The name of the catalog database in which the table resides.
-
#skip_archive ⇒ Boolean
By default, `UpdateTable` always creates an archived version of the table before updating it.
-
#table_input ⇒ Types::TableInput
An updated `TableInput` object to define the metadata table in the catalog.
-
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default.
17941 17942 17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/aws-sdk-glue/types.rb', line 17941 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
17941 17942 17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/aws-sdk-glue/types.rb', line 17941 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#skip_archive ⇒ Boolean
By default, `UpdateTable` always creates an archived version of the table before updating it. However, if `skipArchive` is set to true, `UpdateTable` does not create the archived version.
17941 17942 17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/aws-sdk-glue/types.rb', line 17941 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#table_input ⇒ Types::TableInput
An updated `TableInput` object to define the metadata table in the catalog.
17941 17942 17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/aws-sdk-glue/types.rb', line 17941 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The transaction ID at which to update the table contents.
17941 17942 17943 17944 17945 17946 17947 17948 17949 |
# File 'lib/aws-sdk-glue/types.rb', line 17941 class UpdateTableRequest < Struct.new( :catalog_id, :database_name, :table_input, :skip_archive, :transaction_id) SENSITIVE = [] include Aws::Structure end |