Class: Aws::Glue::Types::UpdateUserDefinedFunctionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_idString

The ID of the Data Catalog where the function to be updated is located. If none is provided, the Amazon Web Services account ID is used by default.

Returns:

  • (String)


32494
32495
32496
32497
32498
32499
32500
32501
# File 'lib/aws-sdk-glue/types.rb', line 32494

class UpdateUserDefinedFunctionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :function_name,
  :function_input)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the catalog database where the function to be updated is located.

Returns:

  • (String)


32494
32495
32496
32497
32498
32499
32500
32501
# File 'lib/aws-sdk-glue/types.rb', line 32494

class UpdateUserDefinedFunctionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :function_name,
  :function_input)
  SENSITIVE = []
  include Aws::Structure
end

#function_inputTypes::UserDefinedFunctionInput

A ‘FunctionInput` object that redefines the function in the Data Catalog.



32494
32495
32496
32497
32498
32499
32500
32501
# File 'lib/aws-sdk-glue/types.rb', line 32494

class UpdateUserDefinedFunctionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :function_name,
  :function_input)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the function.

Returns:

  • (String)


32494
32495
32496
32497
32498
32499
32500
32501
# File 'lib/aws-sdk-glue/types.rb', line 32494

class UpdateUserDefinedFunctionRequest < Struct.new(
  :catalog_id,
  :database_name,
  :function_name,
  :function_input)
  SENSITIVE = []
  include Aws::Structure
end