Class: Aws::Glue::Types::UpdateUserDefinedFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateUserDefinedFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be updated is located.
-
#database_name ⇒ String
The name of the catalog database where the function to be updated is located.
-
#function_input ⇒ Types::UserDefinedFunctionInput
A ‘FunctionInput` object that redefines the function in the Data Catalog.
-
#function_name ⇒ String
The name of the function.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be updated is located. If none is provided, the Amazon Web Services account ID is used by default.
30651 30652 30653 30654 30655 30656 30657 30658 |
# File 'lib/aws-sdk-glue/types.rb', line 30651 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the function to be updated is located.
30651 30652 30653 30654 30655 30656 30657 30658 |
# File 'lib/aws-sdk-glue/types.rb', line 30651 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#function_input ⇒ Types::UserDefinedFunctionInput
A ‘FunctionInput` object that redefines the function in the Data Catalog.
30651 30652 30653 30654 30655 30656 30657 30658 |
# File 'lib/aws-sdk-glue/types.rb', line 30651 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
30651 30652 30653 30654 30655 30656 30657 30658 |
# File 'lib/aws-sdk-glue/types.rb', line 30651 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |