Class: Aws::Glue::Types::UpdateUserDefinedFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateUserDefinedFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Note:
When making an API call, you may pass UpdateUserDefinedFunctionRequest data as a hash:
{
catalog_id: "CatalogIdString",
database_name: "NameString", # required
function_name: "NameString", # required
function_input: { # required
function_name: "NameString",
class_name: "NameString",
owner_name: "NameString",
owner_type: "USER", # accepts USER, ROLE, GROUP
resource_uris: [
{
resource_type: "JAR", # accepts JAR, FILE, ARCHIVE
uri: "URI",
},
],
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be updated is located.
-
#database_name ⇒ String
The name of the catalog database where the function to be updated is located.
-
#function_input ⇒ Types::UserDefinedFunctionInput
A `FunctionInput` object that redefines the function in the Data Catalog.
-
#function_name ⇒ String
The name of the function.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog where the function to be updated is located. If none is provided, the Amazon Web Services account ID is used by default.
26151 26152 26153 26154 26155 26156 26157 26158 |
# File 'lib/aws-sdk-glue/types.rb', line 26151 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database where the function to be updated is located.
26151 26152 26153 26154 26155 26156 26157 26158 |
# File 'lib/aws-sdk-glue/types.rb', line 26151 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#function_input ⇒ Types::UserDefinedFunctionInput
A `FunctionInput` object that redefines the function in the Data Catalog.
26151 26152 26153 26154 26155 26156 26157 26158 |
# File 'lib/aws-sdk-glue/types.rb', line 26151 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
26151 26152 26153 26154 26155 26156 26157 26158 |
# File 'lib/aws-sdk-glue/types.rb', line 26151 class UpdateUserDefinedFunctionRequest < Struct.new( :catalog_id, :database_name, :function_name, :function_input) SENSITIVE = [] include Aws::Structure end |