Class: Aws::Glue::Types::UpdateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_run_propertiesHash<String,String>

A collection of properties to be used as part of each execution of the workflow.

Returns:

  • (Hash<String,String>)


22880
22881
22882
22883
22884
22885
22886
22887
# File 'lib/aws-sdk-glue/types.rb', line 22880

class UpdateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workflow.

Returns:

  • (String)


22880
22881
22882
22883
22884
22885
22886
22887
# File 'lib/aws-sdk-glue/types.rb', line 22880

class UpdateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#max_concurrent_runsInteger

You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.

Returns:

  • (Integer)


22880
22881
22882
22883
22884
22885
22886
22887
# File 'lib/aws-sdk-glue/types.rb', line 22880

class UpdateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the workflow to be updated.

Returns:

  • (String)


22880
22881
22882
22883
22884
22885
22886
22887
# File 'lib/aws-sdk-glue/types.rb', line 22880

class UpdateWorkflowRequest < Struct.new(
  :name,
  :description,
  :default_run_properties,
  :max_concurrent_runs)
  SENSITIVE = []
  include Aws::Structure
end