Class: Aws::Glue::Types::UpdateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UpdateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow.
-
#description ⇒ String
The description of the workflow.
-
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs.
-
#name ⇒ String
Name of the workflow to be updated.
Instance Attribute Details
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow.
21789 21790 21791 21792 21793 21794 21795 21796 |
# File 'lib/aws-sdk-glue/types.rb', line 21789 class UpdateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the workflow.
21789 21790 21791 21792 21793 21794 21795 21796 |
# File 'lib/aws-sdk-glue/types.rb', line 21789 class UpdateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.
21789 21790 21791 21792 21793 21794 21795 21796 |
# File 'lib/aws-sdk-glue/types.rb', line 21789 class UpdateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the workflow to be updated.
21789 21790 21791 21792 21793 21794 21795 21796 |
# File 'lib/aws-sdk-glue/types.rb', line 21789 class UpdateWorkflowRequest < Struct.new( :name, :description, :default_run_properties, :max_concurrent_runs) SENSITIVE = [] include Aws::Structure end |