Class: Aws::Glue::Types::UserDefinedFunction
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::UserDefinedFunction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
Represents the equivalent of a Hive user-defined function (‘UDF`) definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The ID of the Data Catalog in which the function resides.
-
#class_name ⇒ String
The Java class that contains the function code.
-
#create_time ⇒ Time
The time at which the function was created.
-
#database_name ⇒ String
The name of the catalog database that contains the function.
-
#function_name ⇒ String
The name of the function.
-
#owner_name ⇒ String
The owner of the function.
-
#owner_type ⇒ String
The owner type.
-
#resource_uris ⇒ Array<Types::ResourceUri>
The resource URIs for the function.
Instance Attribute Details
#catalog_id ⇒ String
The ID of the Data Catalog in which the function resides.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#class_name ⇒ String
The Java class that contains the function code.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the function was created.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of the catalog database that contains the function.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#owner_name ⇒ String
The owner of the function.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#owner_type ⇒ String
The owner type.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |
#resource_uris ⇒ Array<Types::ResourceUri>
The resource URIs for the function.
20748 20749 20750 20751 20752 20753 20754 20755 20756 20757 20758 20759 |
# File 'lib/aws-sdk-glue/types.rb', line 20748 class UserDefinedFunction < Struct.new( :function_name, :database_name, :class_name, :owner_name, :owner_type, :create_time, :resource_uris, :catalog_id) SENSITIVE = [] include Aws::Structure end |