Class: Aws::Glue::Types::ViewDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ViewDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure containing details for representations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definer ⇒ String
The definer of a view in SQL.
-
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning.
-
#last_refresh_type ⇒ String
Sets the method used for the most recent refresh.
-
#refresh_seconds ⇒ Integer
Auto refresh interval in seconds for the materialized view.
-
#representations ⇒ Array<Types::ViewRepresentation>
A list of representations.
-
#sub_object_version_ids ⇒ Array<Integer>
List of the Apache Iceberg table versions referenced by the materialized view.
-
#sub_objects ⇒ Array<String>
A list of table Amazon Resource Names (ARNs).
-
#view_version_id ⇒ Integer
The ID value that identifies this view's version.
-
#view_version_token ⇒ String
The version ID of the Apache Iceberg table.
Instance Attribute Details
#definer ⇒ String
The definer of a view in SQL.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#last_refresh_type ⇒ String
Sets the method used for the most recent refresh.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#refresh_seconds ⇒ Integer
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#representations ⇒ Array<Types::ViewRepresentation>
A list of representations.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#sub_object_version_ids ⇒ Array<Integer>
List of the Apache Iceberg table versions referenced by the materialized view.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#sub_objects ⇒ Array<String>
A list of table Amazon Resource Names (ARNs).
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#view_version_id ⇒ Integer
The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |
#view_version_token ⇒ String
The version ID of the Apache Iceberg table.
33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 |
# File 'lib/aws-sdk-glue/types.rb', line 33246 class ViewDefinition < Struct.new( :is_protected, :definer, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids, :representations) SENSITIVE = [] include Aws::Structure end |