Class: Aws::Glue::Types::ViewDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure containing details for representations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definerString

The definer of a view in SQL.

Returns:

  • (String)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#is_protectedBoolean

You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine’s documentation to understand the guarantees provided, if any.

Returns:

  • (Boolean)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#last_refresh_typeString

Sets the method used for the most recent refresh.

Returns:

  • (String)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#refresh_secondsInteger

Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.

Returns:

  • (Integer)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#representationsArray<Types::ViewRepresentation>

A list of representations.

Returns:



31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#sub_object_version_idsArray<Integer>

List of the Apache Iceberg table versions referenced by the materialized view.

Returns:

  • (Array<Integer>)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#sub_objectsArray<String>

A list of table Amazon Resource Names (ARNs).

Returns:

  • (Array<String>)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#view_version_idInteger

The ID value that identifies this view’s version. For materialized views, the version ID is the Apache Iceberg table’s snapshot ID.

Returns:

  • (Integer)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#view_version_tokenString

The version ID of the Apache Iceberg table.

Returns:

  • (String)


31091
31092
31093
31094
31095
31096
31097
31098
31099
31100
31101
31102
31103
# File 'lib/aws-sdk-glue/types.rb', line 31091

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :view_version_id,
  :view_version_token,
  :refresh_seconds,
  :last_refresh_type,
  :sub_objects,
  :sub_object_version_ids,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end