Class: Aws::Glue::Types::ViewDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A structure containing details for representations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#definerString

The definer of a view in SQL.

Returns:

  • (String)


24991
24992
24993
24994
24995
24996
24997
24998
# File 'lib/aws-sdk-glue/types.rb', line 24991

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :sub_objects,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#is_protectedBoolean

You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine’s documentation to understand the guarantees provided, if any.

Returns:

  • (Boolean)


24991
24992
24993
24994
24995
24996
24997
24998
# File 'lib/aws-sdk-glue/types.rb', line 24991

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :sub_objects,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#representationsArray<Types::ViewRepresentation>

A list of representations.

Returns:



24991
24992
24993
24994
24995
24996
24997
24998
# File 'lib/aws-sdk-glue/types.rb', line 24991

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :sub_objects,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end

#sub_objectsArray<String>

A list of table Amazon Resource Names (ARNs).

Returns:

  • (Array<String>)


24991
24992
24993
24994
24995
24996
24997
24998
# File 'lib/aws-sdk-glue/types.rb', line 24991

class ViewDefinition < Struct.new(
  :is_protected,
  :definer,
  :sub_objects,
  :representations)
  SENSITIVE = []
  include Aws::Structure
end