Class: Aws::Glue::Types::ViewDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ViewDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure containing details for representations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definer ⇒ String
The definer of a view in SQL.
-
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning.
-
#representations ⇒ Array<Types::ViewRepresentation>
A list of representations.
-
#sub_objects ⇒ Array<String>
A list of table Amazon Resource Names (ARNs).
Instance Attribute Details
#definer ⇒ String
The definer of a view in SQL.
23185 23186 23187 23188 23189 23190 23191 23192 |
# File 'lib/aws-sdk-glue/types.rb', line 23185 class ViewDefinition < Struct.new( :is_protected, :definer, :sub_objects, :representations) SENSITIVE = [] include Aws::Structure end |
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine’s documentation to understand the guarantees provided, if any.
23185 23186 23187 23188 23189 23190 23191 23192 |
# File 'lib/aws-sdk-glue/types.rb', line 23185 class ViewDefinition < Struct.new( :is_protected, :definer, :sub_objects, :representations) SENSITIVE = [] include Aws::Structure end |
#representations ⇒ Array<Types::ViewRepresentation>
A list of representations.
23185 23186 23187 23188 23189 23190 23191 23192 |
# File 'lib/aws-sdk-glue/types.rb', line 23185 class ViewDefinition < Struct.new( :is_protected, :definer, :sub_objects, :representations) SENSITIVE = [] include Aws::Structure end |
#sub_objects ⇒ Array<String>
A list of table Amazon Resource Names (ARNs).
23185 23186 23187 23188 23189 23190 23191 23192 |
# File 'lib/aws-sdk-glue/types.rb', line 23185 class ViewDefinition < Struct.new( :is_protected, :definer, :sub_objects, :representations) SENSITIVE = [] include Aws::Structure end |