Class: Aws::Glue::Types::ViewDefinitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ViewDefinitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure containing details for creating or updating an Glue view.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definer ⇒ String
The definer of a view in SQL.
-
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning.
-
#last_refresh_type ⇒ String
The type of the materialized view’s last refresh.
-
#refresh_seconds ⇒ Integer
Auto refresh interval in seconds for the materialized view.
-
#representations ⇒ Array<Types::ViewRepresentationInput>
A list of structures that contains the dialect of the view, and the query that defines the view.
-
#sub_object_version_ids ⇒ Array<Integer>
List of the Apache Iceberg table versions referenced by the materialized view.
-
#sub_objects ⇒ Array<String>
A list of base table ARNs that make up the view.
-
#view_version_id ⇒ Integer
The ID value that identifies this view’s version.
-
#view_version_token ⇒ String
The version ID of the Apache Iceberg table.
Instance Attribute Details
#definer ⇒ String
The definer of a view in SQL.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine’s documentation to understand the guarantees provided, if any.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#last_refresh_type ⇒ String
The type of the materialized view’s last refresh. Valid values: ‘Full`, `Incremental`.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#refresh_seconds ⇒ Integer
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#representations ⇒ Array<Types::ViewRepresentationInput>
A list of structures that contains the dialect of the view, and the query that defines the view.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#sub_object_version_ids ⇒ Array<Integer>
List of the Apache Iceberg table versions referenced by the materialized view.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#sub_objects ⇒ Array<String>
A list of base table ARNs that make up the view.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#view_version_id ⇒ Integer
The ID value that identifies this view’s version. For materialized views, the version ID is the Apache Iceberg table’s snapshot ID.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |
#view_version_token ⇒ String
The version ID of the Apache Iceberg table.
31028 31029 31030 31031 31032 31033 31034 31035 31036 31037 31038 31039 31040 |
# File 'lib/aws-sdk-glue/types.rb', line 31028 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :view_version_id, :view_version_token, :refresh_seconds, :last_refresh_type, :sub_objects, :sub_object_version_ids) SENSITIVE = [] include Aws::Structure end |