Class: Aws::Glue::Types::ViewDefinitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::ViewDefinitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A structure containing details for creating or updating an Glue view.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#definer ⇒ String
The definer of a view in SQL.
-
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning.
-
#representations ⇒ Array<Types::ViewRepresentationInput>
A list of structures that contains the dialect of the view, and the query that defines the view.
-
#sub_objects ⇒ Array<String>
A list of base table ARNs that make up the view.
Instance Attribute Details
#definer ⇒ String
The definer of a view in SQL.
28871 28872 28873 28874 28875 28876 28877 28878 |
# File 'lib/aws-sdk-glue/types.rb', line 28871 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :sub_objects) SENSITIVE = [] include Aws::Structure end |
#is_protected ⇒ Boolean
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine’s documentation to understand the guarantees provided, if any.
28871 28872 28873 28874 28875 28876 28877 28878 |
# File 'lib/aws-sdk-glue/types.rb', line 28871 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :sub_objects) SENSITIVE = [] include Aws::Structure end |
#representations ⇒ Array<Types::ViewRepresentationInput>
A list of structures that contains the dialect of the view, and the query that defines the view.
28871 28872 28873 28874 28875 28876 28877 28878 |
# File 'lib/aws-sdk-glue/types.rb', line 28871 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :sub_objects) SENSITIVE = [] include Aws::Structure end |
#sub_objects ⇒ Array<String>
A list of base table ARNs that make up the view.
28871 28872 28873 28874 28875 28876 28877 28878 |
# File 'lib/aws-sdk-glue/types.rb', line 28871 class ViewDefinitionInput < Struct.new( :is_protected, :definer, :representations, :sub_objects) SENSITIVE = [] include Aws::Structure end |