Class: Aws::Glue::Types::Workflow
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::Workflow
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A workflow is a collection of multiple dependent Glue jobs and crawlers that are run to complete a complex ETL task. A workflow manages the execution and monitoring of all its jobs and crawlers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blueprint_details ⇒ Types::BlueprintDetails
This structure indicates the details of the blueprint that this particular workflow is created from.
-
#created_on ⇒ Time
The date and time when the workflow was created.
-
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow.
-
#description ⇒ String
A description of the workflow.
-
#graph ⇒ Types::WorkflowGraph
The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.
-
#last_modified_on ⇒ Time
The date and time when the workflow was last modified.
-
#last_run ⇒ Types::WorkflowRun
The information about the last execution of the workflow.
-
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs.
-
#name ⇒ String
The name of the workflow.
Instance Attribute Details
#blueprint_details ⇒ Types::BlueprintDetails
This structure indicates the details of the blueprint that this particular workflow is created from.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#created_on ⇒ Time
The date and time when the workflow was created.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#default_run_properties ⇒ Hash<String,String>
A collection of properties to be used as part of each execution of the workflow. The run properties are made available to each job in the workflow. A job can modify the properties for the next jobs in the flow.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the workflow.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#graph ⇒ Types::WorkflowGraph
The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#last_modified_on ⇒ Time
The date and time when the workflow was last modified.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#last_run ⇒ Types::WorkflowRun
The information about the last execution of the workflow.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#max_concurrent_runs ⇒ Integer
You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow.
29067 29068 29069 29070 29071 29072 29073 29074 29075 29076 29077 29078 29079 |
# File 'lib/aws-sdk-glue/types.rb', line 29067 class Workflow < Struct.new( :name, :description, :default_run_properties, :created_on, :last_modified_on, :last_run, :graph, :max_concurrent_runs, :blueprint_details) SENSITIVE = [] include Aws::Structure end |