Class: Aws::Glue::Types::WorkflowRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::Glue::Types::WorkflowRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-glue/types.rb
Overview
A workflow run is an execution of a workflow providing all the runtime information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_on ⇒ Time
The date and time when the workflow run completed.
-
#error_message ⇒ String
This error message describes any error that may have occurred in starting the workflow run.
-
#graph ⇒ Types::WorkflowGraph
The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.
-
#name ⇒ String
Name of the workflow that was run.
-
#previous_run_id ⇒ String
The ID of the previous workflow run.
-
#started_on ⇒ Time
The date and time when the workflow run was started.
-
#starting_event_batch_condition ⇒ Types::StartingEventBatchCondition
The batch condition that started the workflow run.
-
#statistics ⇒ Types::WorkflowRunStatistics
The statistics of the run.
-
#status ⇒ String
The status of the workflow run.
-
#workflow_run_id ⇒ String
The ID of this workflow run.
-
#workflow_run_properties ⇒ Hash<String,String>
The workflow run properties which were set during the run.
Instance Attribute Details
#completed_on ⇒ Time
The date and time when the workflow run completed.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
This error message describes any error that may have occurred in starting the workflow run. Currently the only error message is “Concurrent runs exceeded for workflow: ‘foo`.”
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#graph ⇒ Types::WorkflowGraph
The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the workflow that was run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#previous_run_id ⇒ String
The ID of the previous workflow run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#started_on ⇒ Time
The date and time when the workflow run was started.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#starting_event_batch_condition ⇒ Types::StartingEventBatchCondition
The batch condition that started the workflow run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#statistics ⇒ Types::WorkflowRunStatistics
The statistics of the run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the workflow run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#workflow_run_id ⇒ String
The ID of this workflow run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |
#workflow_run_properties ⇒ Hash<String,String>
The workflow run properties which were set during the run.
31284 31285 31286 31287 31288 31289 31290 31291 31292 31293 31294 31295 31296 31297 31298 |
# File 'lib/aws-sdk-glue/types.rb', line 31284 class WorkflowRun < Struct.new( :name, :workflow_run_id, :previous_run_id, :workflow_run_properties, :started_on, :completed_on, :status, :error_message, :statistics, :graph, :starting_event_batch_condition) SENSITIVE = [] include Aws::Structure end |