Class: Aws::Glue::Types::WorkflowRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-glue/types.rb

Overview

A workflow run is an execution of a workflow providing all the runtime information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_onTime

The date and time when the workflow run completed.

Returns:

  • (Time)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

This error message describes any error that may have occurred in starting the workflow run. Currently the only error message is “Concurrent runs exceeded for workflow: `foo`.”

Returns:

  • (String)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#graphTypes::WorkflowGraph

The graph representing all the Glue components that belong to the workflow as nodes and directed connections between them as edges.



19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the workflow that was run.

Returns:

  • (String)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#previous_run_idString

The ID of the previous workflow run.

Returns:

  • (String)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#started_onTime

The date and time when the workflow run was started.

Returns:

  • (Time)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#starting_event_batch_conditionTypes::StartingEventBatchCondition

The batch condition that started the workflow run.



19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#statisticsTypes::WorkflowRunStatistics

The statistics of the run.



19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the workflow run.

Returns:

  • (String)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_idString

The ID of this workflow run.

Returns:

  • (String)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_propertiesHash<String,String>

The workflow run properties which were set during the run.

Returns:

  • (Hash<String,String>)


19170
19171
19172
19173
19174
19175
19176
19177
19178
19179
19180
19181
19182
19183
19184
# File 'lib/aws-sdk-glue/types.rb', line 19170

class WorkflowRun < Struct.new(
  :name,
  :workflow_run_id,
  :previous_run_id,
  :workflow_run_properties,
  :started_on,
  :completed_on,
  :status,
  :error_message,
  :statistics,
  :graph,
  :starting_event_batch_condition)
  SENSITIVE = []
  include Aws::Structure
end